// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type AsyncInvokeStatus string

// Enum values for AsyncInvokeStatus
const (
	AsyncInvokeStatusInProgress AsyncInvokeStatus = "InProgress"
	AsyncInvokeStatusCompleted  AsyncInvokeStatus = "Completed"
	AsyncInvokeStatusFailed     AsyncInvokeStatus = "Failed"
)

// Values returns all known values for AsyncInvokeStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AsyncInvokeStatus) Values() []AsyncInvokeStatus {
	return []AsyncInvokeStatus{
		"InProgress",
		"Completed",
		"Failed",
	}
}

type AudioFormat string

// Enum values for AudioFormat
const (
	AudioFormatMp3  AudioFormat = "mp3"
	AudioFormatOpus AudioFormat = "opus"
	AudioFormatWav  AudioFormat = "wav"
	AudioFormatAac  AudioFormat = "aac"
	AudioFormatFlac AudioFormat = "flac"
	AudioFormatMp4  AudioFormat = "mp4"
	AudioFormatOgg  AudioFormat = "ogg"
	AudioFormatMkv  AudioFormat = "mkv"
	AudioFormatMka  AudioFormat = "mka"
	AudioFormatXAac AudioFormat = "x-aac"
	AudioFormatM4a  AudioFormat = "m4a"
	AudioFormatMpeg AudioFormat = "mpeg"
	AudioFormatMpga AudioFormat = "mpga"
	AudioFormatPcm  AudioFormat = "pcm"
	AudioFormatWebm AudioFormat = "webm"
)

// Values returns all known values for AudioFormat. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AudioFormat) Values() []AudioFormat {
	return []AudioFormat{
		"mp3",
		"opus",
		"wav",
		"aac",
		"flac",
		"mp4",
		"ogg",
		"mkv",
		"mka",
		"x-aac",
		"m4a",
		"mpeg",
		"mpga",
		"pcm",
		"webm",
	}
}

type CachePointType string

// Enum values for CachePointType
const (
	CachePointTypeDefault CachePointType = "default"
)

// Values returns all known values for CachePointType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CachePointType) Values() []CachePointType {
	return []CachePointType{
		"default",
	}
}

type CacheTTL string

// Enum values for CacheTTL
const (
	CacheTTLFiveMinutes CacheTTL = "5m"
	CacheTTLOneHour     CacheTTL = "1h"
)

// Values returns all known values for CacheTTL. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CacheTTL) Values() []CacheTTL {
	return []CacheTTL{
		"5m",
		"1h",
	}
}

type ConversationRole string

// Enum values for ConversationRole
const (
	ConversationRoleUser      ConversationRole = "user"
	ConversationRoleAssistant ConversationRole = "assistant"
	ConversationRoleSystem    ConversationRole = "system"
)

// Values returns all known values for ConversationRole. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ConversationRole) Values() []ConversationRole {
	return []ConversationRole{
		"user",
		"assistant",
		"system",
	}
}

type DocumentFormat string

// Enum values for DocumentFormat
const (
	DocumentFormatPdf  DocumentFormat = "pdf"
	DocumentFormatCsv  DocumentFormat = "csv"
	DocumentFormatDoc  DocumentFormat = "doc"
	DocumentFormatDocx DocumentFormat = "docx"
	DocumentFormatXls  DocumentFormat = "xls"
	DocumentFormatXlsx DocumentFormat = "xlsx"
	DocumentFormatHtml DocumentFormat = "html"
	DocumentFormatTxt  DocumentFormat = "txt"
	DocumentFormatMd   DocumentFormat = "md"
)

// Values returns all known values for DocumentFormat. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DocumentFormat) Values() []DocumentFormat {
	return []DocumentFormat{
		"pdf",
		"csv",
		"doc",
		"docx",
		"xls",
		"xlsx",
		"html",
		"txt",
		"md",
	}
}

type GuardrailAction string

// Enum values for GuardrailAction
const (
	GuardrailActionNone                GuardrailAction = "NONE"
	GuardrailActionGuardrailIntervened GuardrailAction = "GUARDRAIL_INTERVENED"
)

// Values returns all known values for GuardrailAction. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailAction) Values() []GuardrailAction {
	return []GuardrailAction{
		"NONE",
		"GUARDRAIL_INTERVENED",
	}
}

type GuardrailAutomatedReasoningLogicWarningType string

// Enum values for GuardrailAutomatedReasoningLogicWarningType
const (
	GuardrailAutomatedReasoningLogicWarningTypeAlwaysFalse GuardrailAutomatedReasoningLogicWarningType = "ALWAYS_FALSE"
	GuardrailAutomatedReasoningLogicWarningTypeAlwaysTrue  GuardrailAutomatedReasoningLogicWarningType = "ALWAYS_TRUE"
)

// Values returns all known values for
// GuardrailAutomatedReasoningLogicWarningType. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailAutomatedReasoningLogicWarningType) Values() []GuardrailAutomatedReasoningLogicWarningType {
	return []GuardrailAutomatedReasoningLogicWarningType{
		"ALWAYS_FALSE",
		"ALWAYS_TRUE",
	}
}

type GuardrailChecksContentFilterCategory string

// Enum values for GuardrailChecksContentFilterCategory
const (
	GuardrailChecksContentFilterCategoryViolence   GuardrailChecksContentFilterCategory = "VIOLENCE"
	GuardrailChecksContentFilterCategoryHate       GuardrailChecksContentFilterCategory = "HATE"
	GuardrailChecksContentFilterCategorySexual     GuardrailChecksContentFilterCategory = "SEXUAL"
	GuardrailChecksContentFilterCategoryMisconduct GuardrailChecksContentFilterCategory = "MISCONDUCT"
	GuardrailChecksContentFilterCategoryInsults    GuardrailChecksContentFilterCategory = "INSULTS"
)

// Values returns all known values for GuardrailChecksContentFilterCategory. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailChecksContentFilterCategory) Values() []GuardrailChecksContentFilterCategory {
	return []GuardrailChecksContentFilterCategory{
		"VIOLENCE",
		"HATE",
		"SEXUAL",
		"MISCONDUCT",
		"INSULTS",
	}
}

type GuardrailChecksPromptAttackCategory string

// Enum values for GuardrailChecksPromptAttackCategory
const (
	GuardrailChecksPromptAttackCategoryJailbreak       GuardrailChecksPromptAttackCategory = "JAILBREAK"
	GuardrailChecksPromptAttackCategoryPromptInjection GuardrailChecksPromptAttackCategory = "PROMPT_INJECTION"
	GuardrailChecksPromptAttackCategoryPromptLeakage   GuardrailChecksPromptAttackCategory = "PROMPT_LEAKAGE"
)

// Values returns all known values for GuardrailChecksPromptAttackCategory. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailChecksPromptAttackCategory) Values() []GuardrailChecksPromptAttackCategory {
	return []GuardrailChecksPromptAttackCategory{
		"JAILBREAK",
		"PROMPT_INJECTION",
		"PROMPT_LEAKAGE",
	}
}

type GuardrailChecksRole string

// Enum values for GuardrailChecksRole
const (
	GuardrailChecksRoleUser      GuardrailChecksRole = "user"
	GuardrailChecksRoleAssistant GuardrailChecksRole = "assistant"
	GuardrailChecksRoleSystem    GuardrailChecksRole = "system"
)

// Values returns all known values for GuardrailChecksRole. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailChecksRole) Values() []GuardrailChecksRole {
	return []GuardrailChecksRole{
		"user",
		"assistant",
		"system",
	}
}

type GuardrailChecksSensitiveInformationEntityType string

// Enum values for GuardrailChecksSensitiveInformationEntityType
const (
	GuardrailChecksSensitiveInformationEntityTypeAddress                             GuardrailChecksSensitiveInformationEntityType = "ADDRESS"
	GuardrailChecksSensitiveInformationEntityTypeAge                                 GuardrailChecksSensitiveInformationEntityType = "AGE"
	GuardrailChecksSensitiveInformationEntityTypeAwsAccessKey                        GuardrailChecksSensitiveInformationEntityType = "AWS_ACCESS_KEY"
	GuardrailChecksSensitiveInformationEntityTypeAwsSecretKey                        GuardrailChecksSensitiveInformationEntityType = "AWS_SECRET_KEY"
	GuardrailChecksSensitiveInformationEntityTypeCaHealthNumber                      GuardrailChecksSensitiveInformationEntityType = "CA_HEALTH_NUMBER"
	GuardrailChecksSensitiveInformationEntityTypeCaSocialInsuranceNumber             GuardrailChecksSensitiveInformationEntityType = "CA_SOCIAL_INSURANCE_NUMBER"
	GuardrailChecksSensitiveInformationEntityTypeCreditDebitCardCvv                  GuardrailChecksSensitiveInformationEntityType = "CREDIT_DEBIT_CARD_CVV"
	GuardrailChecksSensitiveInformationEntityTypeCreditDebitCardExpiry               GuardrailChecksSensitiveInformationEntityType = "CREDIT_DEBIT_CARD_EXPIRY"
	GuardrailChecksSensitiveInformationEntityTypeCreditDebitCardNumber               GuardrailChecksSensitiveInformationEntityType = "CREDIT_DEBIT_CARD_NUMBER"
	GuardrailChecksSensitiveInformationEntityTypeDriverId                            GuardrailChecksSensitiveInformationEntityType = "DRIVER_ID"
	GuardrailChecksSensitiveInformationEntityTypeEmail                               GuardrailChecksSensitiveInformationEntityType = "EMAIL"
	GuardrailChecksSensitiveInformationEntityTypeInternationalBankAccountNumber      GuardrailChecksSensitiveInformationEntityType = "INTERNATIONAL_BANK_ACCOUNT_NUMBER"
	GuardrailChecksSensitiveInformationEntityTypeIpAddress                           GuardrailChecksSensitiveInformationEntityType = "IP_ADDRESS"
	GuardrailChecksSensitiveInformationEntityTypeLicensePlate                        GuardrailChecksSensitiveInformationEntityType = "LICENSE_PLATE"
	GuardrailChecksSensitiveInformationEntityTypeMacAddress                          GuardrailChecksSensitiveInformationEntityType = "MAC_ADDRESS"
	GuardrailChecksSensitiveInformationEntityTypeName                                GuardrailChecksSensitiveInformationEntityType = "NAME"
	GuardrailChecksSensitiveInformationEntityTypePassword                            GuardrailChecksSensitiveInformationEntityType = "PASSWORD"
	GuardrailChecksSensitiveInformationEntityTypePhone                               GuardrailChecksSensitiveInformationEntityType = "PHONE"
	GuardrailChecksSensitiveInformationEntityTypePin                                 GuardrailChecksSensitiveInformationEntityType = "PIN"
	GuardrailChecksSensitiveInformationEntityTypeSwiftCode                           GuardrailChecksSensitiveInformationEntityType = "SWIFT_CODE"
	GuardrailChecksSensitiveInformationEntityTypeUkNationalHealthServiceNumber       GuardrailChecksSensitiveInformationEntityType = "UK_NATIONAL_HEALTH_SERVICE_NUMBER"
	GuardrailChecksSensitiveInformationEntityTypeUkNationalInsuranceNumber           GuardrailChecksSensitiveInformationEntityType = "UK_NATIONAL_INSURANCE_NUMBER"
	GuardrailChecksSensitiveInformationEntityTypeUkUniqueTaxpayerReferenceNumber     GuardrailChecksSensitiveInformationEntityType = "UK_UNIQUE_TAXPAYER_REFERENCE_NUMBER"
	GuardrailChecksSensitiveInformationEntityTypeUrl                                 GuardrailChecksSensitiveInformationEntityType = "URL"
	GuardrailChecksSensitiveInformationEntityTypeUsername                            GuardrailChecksSensitiveInformationEntityType = "USERNAME"
	GuardrailChecksSensitiveInformationEntityTypeUsBankAccountNumber                 GuardrailChecksSensitiveInformationEntityType = "US_BANK_ACCOUNT_NUMBER"
	GuardrailChecksSensitiveInformationEntityTypeUsBankRoutingNumber                 GuardrailChecksSensitiveInformationEntityType = "US_BANK_ROUTING_NUMBER"
	GuardrailChecksSensitiveInformationEntityTypeUsIndividualTaxIdentificationNumber GuardrailChecksSensitiveInformationEntityType = "US_INDIVIDUAL_TAX_IDENTIFICATION_NUMBER"
	GuardrailChecksSensitiveInformationEntityTypeUsPassportNumber                    GuardrailChecksSensitiveInformationEntityType = "US_PASSPORT_NUMBER"
	GuardrailChecksSensitiveInformationEntityTypeUsSocialSecurityNumber              GuardrailChecksSensitiveInformationEntityType = "US_SOCIAL_SECURITY_NUMBER"
	GuardrailChecksSensitiveInformationEntityTypeVehicleIdentificationNumber         GuardrailChecksSensitiveInformationEntityType = "VEHICLE_IDENTIFICATION_NUMBER"
)

// Values returns all known values for
// GuardrailChecksSensitiveInformationEntityType. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailChecksSensitiveInformationEntityType) Values() []GuardrailChecksSensitiveInformationEntityType {
	return []GuardrailChecksSensitiveInformationEntityType{
		"ADDRESS",
		"AGE",
		"AWS_ACCESS_KEY",
		"AWS_SECRET_KEY",
		"CA_HEALTH_NUMBER",
		"CA_SOCIAL_INSURANCE_NUMBER",
		"CREDIT_DEBIT_CARD_CVV",
		"CREDIT_DEBIT_CARD_EXPIRY",
		"CREDIT_DEBIT_CARD_NUMBER",
		"DRIVER_ID",
		"EMAIL",
		"INTERNATIONAL_BANK_ACCOUNT_NUMBER",
		"IP_ADDRESS",
		"LICENSE_PLATE",
		"MAC_ADDRESS",
		"NAME",
		"PASSWORD",
		"PHONE",
		"PIN",
		"SWIFT_CODE",
		"UK_NATIONAL_HEALTH_SERVICE_NUMBER",
		"UK_NATIONAL_INSURANCE_NUMBER",
		"UK_UNIQUE_TAXPAYER_REFERENCE_NUMBER",
		"URL",
		"USERNAME",
		"US_BANK_ACCOUNT_NUMBER",
		"US_BANK_ROUTING_NUMBER",
		"US_INDIVIDUAL_TAX_IDENTIFICATION_NUMBER",
		"US_PASSPORT_NUMBER",
		"US_SOCIAL_SECURITY_NUMBER",
		"VEHICLE_IDENTIFICATION_NUMBER",
	}
}

type GuardrailContentFilterConfidence string

// Enum values for GuardrailContentFilterConfidence
const (
	GuardrailContentFilterConfidenceNone   GuardrailContentFilterConfidence = "NONE"
	GuardrailContentFilterConfidenceLow    GuardrailContentFilterConfidence = "LOW"
	GuardrailContentFilterConfidenceMedium GuardrailContentFilterConfidence = "MEDIUM"
	GuardrailContentFilterConfidenceHigh   GuardrailContentFilterConfidence = "HIGH"
)

// Values returns all known values for GuardrailContentFilterConfidence. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailContentFilterConfidence) Values() []GuardrailContentFilterConfidence {
	return []GuardrailContentFilterConfidence{
		"NONE",
		"LOW",
		"MEDIUM",
		"HIGH",
	}
}

type GuardrailContentFilterStrength string

// Enum values for GuardrailContentFilterStrength
const (
	GuardrailContentFilterStrengthNone   GuardrailContentFilterStrength = "NONE"
	GuardrailContentFilterStrengthLow    GuardrailContentFilterStrength = "LOW"
	GuardrailContentFilterStrengthMedium GuardrailContentFilterStrength = "MEDIUM"
	GuardrailContentFilterStrengthHigh   GuardrailContentFilterStrength = "HIGH"
)

// Values returns all known values for GuardrailContentFilterStrength. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailContentFilterStrength) Values() []GuardrailContentFilterStrength {
	return []GuardrailContentFilterStrength{
		"NONE",
		"LOW",
		"MEDIUM",
		"HIGH",
	}
}

type GuardrailContentFilterType string

// Enum values for GuardrailContentFilterType
const (
	GuardrailContentFilterTypeInsults      GuardrailContentFilterType = "INSULTS"
	GuardrailContentFilterTypeHate         GuardrailContentFilterType = "HATE"
	GuardrailContentFilterTypeSexual       GuardrailContentFilterType = "SEXUAL"
	GuardrailContentFilterTypeViolence     GuardrailContentFilterType = "VIOLENCE"
	GuardrailContentFilterTypeMisconduct   GuardrailContentFilterType = "MISCONDUCT"
	GuardrailContentFilterTypePromptAttack GuardrailContentFilterType = "PROMPT_ATTACK"
)

// Values returns all known values for GuardrailContentFilterType. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailContentFilterType) Values() []GuardrailContentFilterType {
	return []GuardrailContentFilterType{
		"INSULTS",
		"HATE",
		"SEXUAL",
		"VIOLENCE",
		"MISCONDUCT",
		"PROMPT_ATTACK",
	}
}

type GuardrailContentPolicyAction string

// Enum values for GuardrailContentPolicyAction
const (
	GuardrailContentPolicyActionBlocked GuardrailContentPolicyAction = "BLOCKED"
	GuardrailContentPolicyActionNone    GuardrailContentPolicyAction = "NONE"
)

// Values returns all known values for GuardrailContentPolicyAction. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailContentPolicyAction) Values() []GuardrailContentPolicyAction {
	return []GuardrailContentPolicyAction{
		"BLOCKED",
		"NONE",
	}
}

type GuardrailContentQualifier string

// Enum values for GuardrailContentQualifier
const (
	GuardrailContentQualifierGroundingSource GuardrailContentQualifier = "grounding_source"
	GuardrailContentQualifierQuery           GuardrailContentQualifier = "query"
	GuardrailContentQualifierGuardContent    GuardrailContentQualifier = "guard_content"
)

// Values returns all known values for GuardrailContentQualifier. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailContentQualifier) Values() []GuardrailContentQualifier {
	return []GuardrailContentQualifier{
		"grounding_source",
		"query",
		"guard_content",
	}
}

type GuardrailContentSource string

// Enum values for GuardrailContentSource
const (
	GuardrailContentSourceInput  GuardrailContentSource = "INPUT"
	GuardrailContentSourceOutput GuardrailContentSource = "OUTPUT"
)

// Values returns all known values for GuardrailContentSource. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailContentSource) Values() []GuardrailContentSource {
	return []GuardrailContentSource{
		"INPUT",
		"OUTPUT",
	}
}

type GuardrailContextualGroundingFilterType string

// Enum values for GuardrailContextualGroundingFilterType
const (
	GuardrailContextualGroundingFilterTypeGrounding GuardrailContextualGroundingFilterType = "GROUNDING"
	GuardrailContextualGroundingFilterTypeRelevance GuardrailContextualGroundingFilterType = "RELEVANCE"
)

// Values returns all known values for GuardrailContextualGroundingFilterType.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailContextualGroundingFilterType) Values() []GuardrailContextualGroundingFilterType {
	return []GuardrailContextualGroundingFilterType{
		"GROUNDING",
		"RELEVANCE",
	}
}

type GuardrailContextualGroundingPolicyAction string

// Enum values for GuardrailContextualGroundingPolicyAction
const (
	GuardrailContextualGroundingPolicyActionBlocked GuardrailContextualGroundingPolicyAction = "BLOCKED"
	GuardrailContextualGroundingPolicyActionNone    GuardrailContextualGroundingPolicyAction = "NONE"
)

// Values returns all known values for GuardrailContextualGroundingPolicyAction.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailContextualGroundingPolicyAction) Values() []GuardrailContextualGroundingPolicyAction {
	return []GuardrailContextualGroundingPolicyAction{
		"BLOCKED",
		"NONE",
	}
}

type GuardrailConverseContentQualifier string

// Enum values for GuardrailConverseContentQualifier
const (
	GuardrailConverseContentQualifierGroundingSource GuardrailConverseContentQualifier = "grounding_source"
	GuardrailConverseContentQualifierQuery           GuardrailConverseContentQualifier = "query"
	GuardrailConverseContentQualifierGuardContent    GuardrailConverseContentQualifier = "guard_content"
)

// Values returns all known values for GuardrailConverseContentQualifier. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailConverseContentQualifier) Values() []GuardrailConverseContentQualifier {
	return []GuardrailConverseContentQualifier{
		"grounding_source",
		"query",
		"guard_content",
	}
}

type GuardrailConverseImageFormat string

// Enum values for GuardrailConverseImageFormat
const (
	GuardrailConverseImageFormatPng  GuardrailConverseImageFormat = "png"
	GuardrailConverseImageFormatJpeg GuardrailConverseImageFormat = "jpeg"
)

// Values returns all known values for GuardrailConverseImageFormat. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailConverseImageFormat) Values() []GuardrailConverseImageFormat {
	return []GuardrailConverseImageFormat{
		"png",
		"jpeg",
	}
}

type GuardrailImageFormat string

// Enum values for GuardrailImageFormat
const (
	GuardrailImageFormatPng  GuardrailImageFormat = "png"
	GuardrailImageFormatJpeg GuardrailImageFormat = "jpeg"
)

// Values returns all known values for GuardrailImageFormat. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailImageFormat) Values() []GuardrailImageFormat {
	return []GuardrailImageFormat{
		"png",
		"jpeg",
	}
}

type GuardrailManagedWordType string

// Enum values for GuardrailManagedWordType
const (
	GuardrailManagedWordTypeProfanity GuardrailManagedWordType = "PROFANITY"
)

// Values returns all known values for GuardrailManagedWordType. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailManagedWordType) Values() []GuardrailManagedWordType {
	return []GuardrailManagedWordType{
		"PROFANITY",
	}
}

type GuardrailOrigin string

// Enum values for GuardrailOrigin
const (
	GuardrailOriginRequest              GuardrailOrigin = "REQUEST"
	GuardrailOriginAccountEnforced      GuardrailOrigin = "ACCOUNT_ENFORCED"
	GuardrailOriginOrganizationEnforced GuardrailOrigin = "ORGANIZATION_ENFORCED"
)

// Values returns all known values for GuardrailOrigin. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailOrigin) Values() []GuardrailOrigin {
	return []GuardrailOrigin{
		"REQUEST",
		"ACCOUNT_ENFORCED",
		"ORGANIZATION_ENFORCED",
	}
}

type GuardrailOutputScope string

// Enum values for GuardrailOutputScope
const (
	GuardrailOutputScopeInterventions GuardrailOutputScope = "INTERVENTIONS"
	GuardrailOutputScopeFull          GuardrailOutputScope = "FULL"
)

// Values returns all known values for GuardrailOutputScope. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailOutputScope) Values() []GuardrailOutputScope {
	return []GuardrailOutputScope{
		"INTERVENTIONS",
		"FULL",
	}
}

type GuardrailOwnership string

// Enum values for GuardrailOwnership
const (
	GuardrailOwnershipSelf         GuardrailOwnership = "SELF"
	GuardrailOwnershipCrossAccount GuardrailOwnership = "CROSS_ACCOUNT"
)

// Values returns all known values for GuardrailOwnership. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailOwnership) Values() []GuardrailOwnership {
	return []GuardrailOwnership{
		"SELF",
		"CROSS_ACCOUNT",
	}
}

type GuardrailPiiEntityType string

// Enum values for GuardrailPiiEntityType
const (
	GuardrailPiiEntityTypeAddress                             GuardrailPiiEntityType = "ADDRESS"
	GuardrailPiiEntityTypeAge                                 GuardrailPiiEntityType = "AGE"
	GuardrailPiiEntityTypeAwsAccessKey                        GuardrailPiiEntityType = "AWS_ACCESS_KEY"
	GuardrailPiiEntityTypeAwsSecretKey                        GuardrailPiiEntityType = "AWS_SECRET_KEY"
	GuardrailPiiEntityTypeCaHealthNumber                      GuardrailPiiEntityType = "CA_HEALTH_NUMBER"
	GuardrailPiiEntityTypeCaSocialInsuranceNumber             GuardrailPiiEntityType = "CA_SOCIAL_INSURANCE_NUMBER"
	GuardrailPiiEntityTypeCreditDebitCardCvv                  GuardrailPiiEntityType = "CREDIT_DEBIT_CARD_CVV"
	GuardrailPiiEntityTypeCreditDebitCardExpiry               GuardrailPiiEntityType = "CREDIT_DEBIT_CARD_EXPIRY"
	GuardrailPiiEntityTypeCreditDebitCardNumber               GuardrailPiiEntityType = "CREDIT_DEBIT_CARD_NUMBER"
	GuardrailPiiEntityTypeDriverId                            GuardrailPiiEntityType = "DRIVER_ID"
	GuardrailPiiEntityTypeEmail                               GuardrailPiiEntityType = "EMAIL"
	GuardrailPiiEntityTypeInternationalBankAccountNumber      GuardrailPiiEntityType = "INTERNATIONAL_BANK_ACCOUNT_NUMBER"
	GuardrailPiiEntityTypeIpAddress                           GuardrailPiiEntityType = "IP_ADDRESS"
	GuardrailPiiEntityTypeLicensePlate                        GuardrailPiiEntityType = "LICENSE_PLATE"
	GuardrailPiiEntityTypeMacAddress                          GuardrailPiiEntityType = "MAC_ADDRESS"
	GuardrailPiiEntityTypeName                                GuardrailPiiEntityType = "NAME"
	GuardrailPiiEntityTypePassword                            GuardrailPiiEntityType = "PASSWORD"
	GuardrailPiiEntityTypePhone                               GuardrailPiiEntityType = "PHONE"
	GuardrailPiiEntityTypePin                                 GuardrailPiiEntityType = "PIN"
	GuardrailPiiEntityTypeSwiftCode                           GuardrailPiiEntityType = "SWIFT_CODE"
	GuardrailPiiEntityTypeUkNationalHealthServiceNumber       GuardrailPiiEntityType = "UK_NATIONAL_HEALTH_SERVICE_NUMBER"
	GuardrailPiiEntityTypeUkNationalInsuranceNumber           GuardrailPiiEntityType = "UK_NATIONAL_INSURANCE_NUMBER"
	GuardrailPiiEntityTypeUkUniqueTaxpayerReferenceNumber     GuardrailPiiEntityType = "UK_UNIQUE_TAXPAYER_REFERENCE_NUMBER"
	GuardrailPiiEntityTypeUrl                                 GuardrailPiiEntityType = "URL"
	GuardrailPiiEntityTypeUsername                            GuardrailPiiEntityType = "USERNAME"
	GuardrailPiiEntityTypeUsBankAccountNumber                 GuardrailPiiEntityType = "US_BANK_ACCOUNT_NUMBER"
	GuardrailPiiEntityTypeUsBankRoutingNumber                 GuardrailPiiEntityType = "US_BANK_ROUTING_NUMBER"
	GuardrailPiiEntityTypeUsIndividualTaxIdentificationNumber GuardrailPiiEntityType = "US_INDIVIDUAL_TAX_IDENTIFICATION_NUMBER"
	GuardrailPiiEntityTypeUsPassportNumber                    GuardrailPiiEntityType = "US_PASSPORT_NUMBER"
	GuardrailPiiEntityTypeUsSocialSecurityNumber              GuardrailPiiEntityType = "US_SOCIAL_SECURITY_NUMBER"
	GuardrailPiiEntityTypeVehicleIdentificationNumber         GuardrailPiiEntityType = "VEHICLE_IDENTIFICATION_NUMBER"
)

// Values returns all known values for GuardrailPiiEntityType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailPiiEntityType) Values() []GuardrailPiiEntityType {
	return []GuardrailPiiEntityType{
		"ADDRESS",
		"AGE",
		"AWS_ACCESS_KEY",
		"AWS_SECRET_KEY",
		"CA_HEALTH_NUMBER",
		"CA_SOCIAL_INSURANCE_NUMBER",
		"CREDIT_DEBIT_CARD_CVV",
		"CREDIT_DEBIT_CARD_EXPIRY",
		"CREDIT_DEBIT_CARD_NUMBER",
		"DRIVER_ID",
		"EMAIL",
		"INTERNATIONAL_BANK_ACCOUNT_NUMBER",
		"IP_ADDRESS",
		"LICENSE_PLATE",
		"MAC_ADDRESS",
		"NAME",
		"PASSWORD",
		"PHONE",
		"PIN",
		"SWIFT_CODE",
		"UK_NATIONAL_HEALTH_SERVICE_NUMBER",
		"UK_NATIONAL_INSURANCE_NUMBER",
		"UK_UNIQUE_TAXPAYER_REFERENCE_NUMBER",
		"URL",
		"USERNAME",
		"US_BANK_ACCOUNT_NUMBER",
		"US_BANK_ROUTING_NUMBER",
		"US_INDIVIDUAL_TAX_IDENTIFICATION_NUMBER",
		"US_PASSPORT_NUMBER",
		"US_SOCIAL_SECURITY_NUMBER",
		"VEHICLE_IDENTIFICATION_NUMBER",
	}
}

type GuardrailSensitiveInformationPolicyAction string

// Enum values for GuardrailSensitiveInformationPolicyAction
const (
	GuardrailSensitiveInformationPolicyActionAnonymized GuardrailSensitiveInformationPolicyAction = "ANONYMIZED"
	GuardrailSensitiveInformationPolicyActionBlocked    GuardrailSensitiveInformationPolicyAction = "BLOCKED"
	GuardrailSensitiveInformationPolicyActionNone       GuardrailSensitiveInformationPolicyAction = "NONE"
)

// Values returns all known values for GuardrailSensitiveInformationPolicyAction.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailSensitiveInformationPolicyAction) Values() []GuardrailSensitiveInformationPolicyAction {
	return []GuardrailSensitiveInformationPolicyAction{
		"ANONYMIZED",
		"BLOCKED",
		"NONE",
	}
}

type GuardrailStreamProcessingMode string

// Enum values for GuardrailStreamProcessingMode
const (
	GuardrailStreamProcessingModeSync  GuardrailStreamProcessingMode = "sync"
	GuardrailStreamProcessingModeAsync GuardrailStreamProcessingMode = "async"
)

// Values returns all known values for GuardrailStreamProcessingMode. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailStreamProcessingMode) Values() []GuardrailStreamProcessingMode {
	return []GuardrailStreamProcessingMode{
		"sync",
		"async",
	}
}

type GuardrailTopicPolicyAction string

// Enum values for GuardrailTopicPolicyAction
const (
	GuardrailTopicPolicyActionBlocked GuardrailTopicPolicyAction = "BLOCKED"
	GuardrailTopicPolicyActionNone    GuardrailTopicPolicyAction = "NONE"
)

// Values returns all known values for GuardrailTopicPolicyAction. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailTopicPolicyAction) Values() []GuardrailTopicPolicyAction {
	return []GuardrailTopicPolicyAction{
		"BLOCKED",
		"NONE",
	}
}

type GuardrailTopicType string

// Enum values for GuardrailTopicType
const (
	GuardrailTopicTypeDeny GuardrailTopicType = "DENY"
)

// Values returns all known values for GuardrailTopicType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailTopicType) Values() []GuardrailTopicType {
	return []GuardrailTopicType{
		"DENY",
	}
}

type GuardrailTrace string

// Enum values for GuardrailTrace
const (
	GuardrailTraceEnabled     GuardrailTrace = "enabled"
	GuardrailTraceDisabled    GuardrailTrace = "disabled"
	GuardrailTraceEnabledFull GuardrailTrace = "enabled_full"
)

// Values returns all known values for GuardrailTrace. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailTrace) Values() []GuardrailTrace {
	return []GuardrailTrace{
		"enabled",
		"disabled",
		"enabled_full",
	}
}

type GuardrailWordPolicyAction string

// Enum values for GuardrailWordPolicyAction
const (
	GuardrailWordPolicyActionBlocked GuardrailWordPolicyAction = "BLOCKED"
	GuardrailWordPolicyActionNone    GuardrailWordPolicyAction = "NONE"
)

// Values returns all known values for GuardrailWordPolicyAction. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailWordPolicyAction) Values() []GuardrailWordPolicyAction {
	return []GuardrailWordPolicyAction{
		"BLOCKED",
		"NONE",
	}
}

type ImageFormat string

// Enum values for ImageFormat
const (
	ImageFormatPng  ImageFormat = "png"
	ImageFormatJpeg ImageFormat = "jpeg"
	ImageFormatGif  ImageFormat = "gif"
	ImageFormatWebp ImageFormat = "webp"
)

// Values returns all known values for ImageFormat. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ImageFormat) Values() []ImageFormat {
	return []ImageFormat{
		"png",
		"jpeg",
		"gif",
		"webp",
	}
}

type OutputFormatType string

// Enum values for OutputFormatType
const (
	OutputFormatTypeJsonSchema OutputFormatType = "json_schema"
)

// Values returns all known values for OutputFormatType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (OutputFormatType) Values() []OutputFormatType {
	return []OutputFormatType{
		"json_schema",
	}
}

type PerformanceConfigLatency string

// Enum values for PerformanceConfigLatency
const (
	PerformanceConfigLatencyStandard  PerformanceConfigLatency = "standard"
	PerformanceConfigLatencyOptimized PerformanceConfigLatency = "optimized"
)

// Values returns all known values for PerformanceConfigLatency. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PerformanceConfigLatency) Values() []PerformanceConfigLatency {
	return []PerformanceConfigLatency{
		"standard",
		"optimized",
	}
}

type ServiceTierType string

// Enum values for ServiceTierType
const (
	ServiceTierTypePriority ServiceTierType = "priority"
	ServiceTierTypeDefault  ServiceTierType = "default"
	ServiceTierTypeFlex     ServiceTierType = "flex"
	ServiceTierTypeReserved ServiceTierType = "reserved"
)

// Values returns all known values for ServiceTierType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ServiceTierType) Values() []ServiceTierType {
	return []ServiceTierType{
		"priority",
		"default",
		"flex",
		"reserved",
	}
}

type SortAsyncInvocationBy string

// Enum values for SortAsyncInvocationBy
const (
	SortAsyncInvocationBySubmissionTime SortAsyncInvocationBy = "SubmissionTime"
)

// Values returns all known values for SortAsyncInvocationBy. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SortAsyncInvocationBy) Values() []SortAsyncInvocationBy {
	return []SortAsyncInvocationBy{
		"SubmissionTime",
	}
}

type SortOrder string

// Enum values for SortOrder
const (
	SortOrderAscending  SortOrder = "Ascending"
	SortOrderDescending SortOrder = "Descending"
)

// Values returns all known values for SortOrder. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SortOrder) Values() []SortOrder {
	return []SortOrder{
		"Ascending",
		"Descending",
	}
}

type StopReason string

// Enum values for StopReason
const (
	StopReasonEndTurn                    StopReason = "end_turn"
	StopReasonToolUse                    StopReason = "tool_use"
	StopReasonMaxTokens                  StopReason = "max_tokens"
	StopReasonStopSequence               StopReason = "stop_sequence"
	StopReasonGuardrailIntervened        StopReason = "guardrail_intervened"
	StopReasonContentFiltered            StopReason = "content_filtered"
	StopReasonMalformedModelOutput       StopReason = "malformed_model_output"
	StopReasonMalformedToolUse           StopReason = "malformed_tool_use"
	StopReasonModelContextWindowExceeded StopReason = "model_context_window_exceeded"
)

// Values returns all known values for StopReason. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (StopReason) Values() []StopReason {
	return []StopReason{
		"end_turn",
		"tool_use",
		"max_tokens",
		"stop_sequence",
		"guardrail_intervened",
		"content_filtered",
		"malformed_model_output",
		"malformed_tool_use",
		"model_context_window_exceeded",
	}
}

type ToolResultStatus string

// Enum values for ToolResultStatus
const (
	ToolResultStatusSuccess ToolResultStatus = "success"
	ToolResultStatusError   ToolResultStatus = "error"
)

// Values returns all known values for ToolResultStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ToolResultStatus) Values() []ToolResultStatus {
	return []ToolResultStatus{
		"success",
		"error",
	}
}

type ToolUseType string

// Enum values for ToolUseType
const (
	ToolUseTypeServerToolUse ToolUseType = "server_tool_use"
)

// Values returns all known values for ToolUseType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ToolUseType) Values() []ToolUseType {
	return []ToolUseType{
		"server_tool_use",
	}
}

type Trace string

// Enum values for Trace
const (
	TraceEnabled     Trace = "ENABLED"
	TraceDisabled    Trace = "DISABLED"
	TraceEnabledFull Trace = "ENABLED_FULL"
)

// Values returns all known values for Trace. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (Trace) Values() []Trace {
	return []Trace{
		"ENABLED",
		"DISABLED",
		"ENABLED_FULL",
	}
}

type VideoFormat string

// Enum values for VideoFormat
const (
	VideoFormatMkv     VideoFormat = "mkv"
	VideoFormatMov     VideoFormat = "mov"
	VideoFormatMp4     VideoFormat = "mp4"
	VideoFormatWebm    VideoFormat = "webm"
	VideoFormatFlv     VideoFormat = "flv"
	VideoFormatMpeg    VideoFormat = "mpeg"
	VideoFormatMpg     VideoFormat = "mpg"
	VideoFormatWmv     VideoFormat = "wmv"
	VideoFormatThreeGp VideoFormat = "three_gp"
)

// Values returns all known values for VideoFormat. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (VideoFormat) Values() []VideoFormat {
	return []VideoFormat{
		"mkv",
		"mov",
		"mp4",
		"webm",
		"flv",
		"mpeg",
		"mpg",
		"wmv",
		"three_gp",
	}
}
