// Code generated by smithy-go-codegen DO NOT EDIT.

package cleanroomsml

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/cleanroomsml/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Provides the information necessary to start a trained model export job.
func (c *Client) StartTrainedModelExportJob(ctx context.Context, params *StartTrainedModelExportJobInput, optFns ...func(*Options)) (*StartTrainedModelExportJobOutput, error) {
	if params == nil {
		params = &StartTrainedModelExportJobInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "StartTrainedModelExportJob", params, optFns, c.addOperationStartTrainedModelExportJobMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*StartTrainedModelExportJobOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type StartTrainedModelExportJobInput struct {

	// The membership ID of the member that is receiving the exported trained model
	// artifacts.
	//
	// This member is required.
	MembershipIdentifier *string

	// The name of the trained model export job.
	//
	// This member is required.
	Name *string

	// The output configuration information for the trained model export job.
	//
	// This member is required.
	OutputConfiguration *types.TrainedModelExportOutputConfiguration

	// The Amazon Resource Name (ARN) of the trained model that you want to export.
	//
	// This member is required.
	TrainedModelArn *string

	// The description of the trained model export job.
	Description *string

	// The version identifier of the trained model to export. This specifies which
	// version of the trained model should be exported to the specified destination.
	TrainedModelVersionIdentifier *string

	noSmithyDocumentSerde
}

type StartTrainedModelExportJobOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationStartTrainedModelExportJobMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpStartTrainedModelExportJob{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpStartTrainedModelExportJob{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpStartTrainedModelExportJobValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "StartTrainedModelExportJob"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
