// Code generated by smithy-go-codegen DO NOT EDIT.

// Package comprehend provides the API client, operations, and parameter types for
// Amazon Comprehend.
//
// Amazon Comprehend is an Amazon Web Services service for gaining insight into
// the content of documents. Use these actions to determine the topics contained in
// your documents, the topics they discuss, the predominant sentiment expressed in
// them, the predominant language used, and more.
package comprehend
