// Code generated by smithy-go-codegen DO NOT EDIT.

package cognitoidentity

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Generates (or retrieves) IdentityID. Supplying multiple logins will create an
// implicit linked account.
//
// This is a public API. You do not need any credentials to call this API.
func (c *Client) GetId(ctx context.Context, params *GetIdInput, optFns ...func(*Options)) (*GetIdOutput, error) {
	if params == nil {
		params = &GetIdInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetId", params, optFns, c.addOperationGetIdMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetIdOutput)
	out.ResultMetadata = metadata
	return out, nil
}

// Input to the GetId action.
type GetIdInput struct {

	// An identity pool ID in the format REGION:GUID.
	//
	// This member is required.
	IdentityPoolId *string

	// A standard Amazon Web Services account ID (9+ digits).
	AccountId *string

	// A set of optional name-value pairs that map provider names to provider tokens.
	// The available provider names for Logins are as follows:
	//
	//   - Facebook: graph.facebook.com
	//
	//   - Amazon Cognito user pool: cognito-idp..amazonaws.com/ , for example,
	//   cognito-idp.us-east-1.amazonaws.com/us-east-1_123456789 .
	//
	//   - Google: accounts.google.com
	//
	//   - Amazon: www.amazon.com
	//
	//   - Twitter: api.twitter.com
	//
	//   - Digits: www.digits.com
	Logins map[string]string

	noSmithyDocumentSerde
}

// Returned in response to a GetId request.
type GetIdOutput struct {

	// A unique identifier in the format REGION:GUID.
	IdentityId *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetIdMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpGetId{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpGetId{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetIdValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetId"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
