// Code generated by smithy-go-codegen DO NOT EDIT.

package connect

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/connect/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

// Provides information about the child hours of operations for the specified
// parent hours of operation.
//
// For more information about child hours of operations, see [Link overrides from different hours of operation] in the Administrator
// Guide.
//
// [Link overrides from different hours of operation]: https://docs.aws.amazon.com/connect/latest/adminguide/hours-of-operation-overrides.html
func (c *Client) ListChildHoursOfOperations(ctx context.Context, params *ListChildHoursOfOperationsInput, optFns ...func(*Options)) (*ListChildHoursOfOperationsOutput, error) {
	if params == nil {
		params = &ListChildHoursOfOperationsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "ListChildHoursOfOperations", params, optFns, c.addOperationListChildHoursOfOperationsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*ListChildHoursOfOperationsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type ListChildHoursOfOperationsInput struct {

	// The identifier of the parent hours of operation.
	//
	// This member is required.
	HoursOfOperationId *string

	// The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource
	// Name (ARN) of the instance.
	//
	// [find the instance ID]: https://docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
	//
	// This member is required.
	InstanceId *string

	// The maximum number of results to return per page. The default MaxResult size is
	// 100.
	MaxResults *int32

	// The token for the next set of results. Use the value returned in the previous
	// response in the next request to retrieve the next set of results.
	NextToken *string

	noSmithyDocumentSerde
}

type ListChildHoursOfOperationsOutput struct {

	// Information about the hours of operation.
	ChildHoursOfOperationsSummaryList []types.HoursOfOperationsIdentifier

	// The Amazon Web Services Region where this resource was last modified.
	LastModifiedRegion *string

	// The timestamp when this resource was last modified.
	LastModifiedTime *time.Time

	// If there are additional results, this is the token for the next set of results.
	NextToken *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationListChildHoursOfOperationsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpListChildHoursOfOperations{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpListChildHoursOfOperations{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpListChildHoursOfOperationsValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "ListChildHoursOfOperations"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

// ListChildHoursOfOperationsPaginatorOptions is the paginator options for
// ListChildHoursOfOperations
type ListChildHoursOfOperationsPaginatorOptions struct {
	// The maximum number of results to return per page. The default MaxResult size is
	// 100.
	Limit int32

	// Set to true if pagination should stop if the service returns a pagination token
	// that matches the most recent token provided to the service.
	StopOnDuplicateToken bool
}

// ListChildHoursOfOperationsPaginator is a paginator for
// ListChildHoursOfOperations
type ListChildHoursOfOperationsPaginator struct {
	options   ListChildHoursOfOperationsPaginatorOptions
	client    ListChildHoursOfOperationsAPIClient
	params    *ListChildHoursOfOperationsInput
	nextToken *string
	firstPage bool
}

// NewListChildHoursOfOperationsPaginator returns a new
// ListChildHoursOfOperationsPaginator
func NewListChildHoursOfOperationsPaginator(client ListChildHoursOfOperationsAPIClient, params *ListChildHoursOfOperationsInput, optFns ...func(*ListChildHoursOfOperationsPaginatorOptions)) *ListChildHoursOfOperationsPaginator {
	if params == nil {
		params = &ListChildHoursOfOperationsInput{}
	}

	options := ListChildHoursOfOperationsPaginatorOptions{}
	if params.MaxResults != nil {
		options.Limit = *params.MaxResults
	}

	for _, fn := range optFns {
		fn(&options)
	}

	return &ListChildHoursOfOperationsPaginator{
		options:   options,
		client:    client,
		params:    params,
		firstPage: true,
		nextToken: params.NextToken,
	}
}

// HasMorePages returns a boolean indicating whether more pages are available
func (p *ListChildHoursOfOperationsPaginator) HasMorePages() bool {
	return p.firstPage || (p.nextToken != nil && len(*p.nextToken) != 0)
}

// NextPage retrieves the next ListChildHoursOfOperations page.
func (p *ListChildHoursOfOperationsPaginator) NextPage(ctx context.Context, optFns ...func(*Options)) (*ListChildHoursOfOperationsOutput, error) {
	if !p.HasMorePages() {
		return nil, fmt.Errorf("no more pages available")
	}

	params := *p.params
	params.NextToken = p.nextToken

	var limit *int32
	if p.options.Limit > 0 {
		limit = &p.options.Limit
	}
	params.MaxResults = limit

	optFns = append([]func(*Options){
		addIsPaginatorUserAgent,
	}, optFns...)
	result, err := p.client.ListChildHoursOfOperations(ctx, &params, optFns...)
	if err != nil {
		return nil, err
	}
	p.firstPage = false

	prevToken := p.nextToken
	p.nextToken = result.NextToken

	if p.options.StopOnDuplicateToken &&
		prevToken != nil &&
		p.nextToken != nil &&
		*prevToken == *p.nextToken {
		p.nextToken = nil
	}

	return result, nil
}

// ListChildHoursOfOperationsAPIClient is a client that implements the
// ListChildHoursOfOperations operation.
type ListChildHoursOfOperationsAPIClient interface {
	ListChildHoursOfOperations(context.Context, *ListChildHoursOfOperationsInput, ...func(*Options)) (*ListChildHoursOfOperationsOutput, error)
}

var _ ListChildHoursOfOperationsAPIClient = (*Client)(nil)
