// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type ABTestExecutionStatus string

// Enum values for ABTestExecutionStatus
const (
	ABTestExecutionStatusPaused     ABTestExecutionStatus = "PAUSED"
	ABTestExecutionStatusRunning    ABTestExecutionStatus = "RUNNING"
	ABTestExecutionStatusStopped    ABTestExecutionStatus = "STOPPED"
	ABTestExecutionStatusNotStarted ABTestExecutionStatus = "NOT_STARTED"
)

// Values returns all known values for ABTestExecutionStatus. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ABTestExecutionStatus) Values() []ABTestExecutionStatus {
	return []ABTestExecutionStatus{
		"PAUSED",
		"RUNNING",
		"STOPPED",
		"NOT_STARTED",
	}
}

type ABTestStatus string

// Enum values for ABTestStatus
const (
	ABTestStatusCreating     ABTestStatus = "CREATING"
	ABTestStatusActive       ABTestStatus = "ACTIVE"
	ABTestStatusCreateFailed ABTestStatus = "CREATE_FAILED"
	ABTestStatusUpdating     ABTestStatus = "UPDATING"
	ABTestStatusUpdateFailed ABTestStatus = "UPDATE_FAILED"
	ABTestStatusDeleting     ABTestStatus = "DELETING"
	ABTestStatusDeleteFailed ABTestStatus = "DELETE_FAILED"
	ABTestStatusFailed       ABTestStatus = "FAILED"
)

// Values returns all known values for ABTestStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ABTestStatus) Values() []ABTestStatus {
	return []ABTestStatus{
		"CREATING",
		"ACTIVE",
		"CREATE_FAILED",
		"UPDATING",
		"UPDATE_FAILED",
		"DELETING",
		"DELETE_FAILED",
		"FAILED",
	}
}

type AutomationStreamStatus string

// Enum values for AutomationStreamStatus
const (
	AutomationStreamStatusEnabled  AutomationStreamStatus = "ENABLED"
	AutomationStreamStatusDisabled AutomationStreamStatus = "DISABLED"
)

// Values returns all known values for AutomationStreamStatus. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutomationStreamStatus) Values() []AutomationStreamStatus {
	return []AutomationStreamStatus{
		"ENABLED",
		"DISABLED",
	}
}

type BatchEvaluationStatus string

// Enum values for BatchEvaluationStatus
const (
	BatchEvaluationStatusPending             BatchEvaluationStatus = "PENDING"
	BatchEvaluationStatusInProgress          BatchEvaluationStatus = "IN_PROGRESS"
	BatchEvaluationStatusCompleted           BatchEvaluationStatus = "COMPLETED"
	BatchEvaluationStatusCompletedWithErrors BatchEvaluationStatus = "COMPLETED_WITH_ERRORS"
	BatchEvaluationStatusFailed              BatchEvaluationStatus = "FAILED"
	BatchEvaluationStatusStopping            BatchEvaluationStatus = "STOPPING"
	BatchEvaluationStatusStopped             BatchEvaluationStatus = "STOPPED"
	BatchEvaluationStatusDeleting            BatchEvaluationStatus = "DELETING"
)

// Values returns all known values for BatchEvaluationStatus. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BatchEvaluationStatus) Values() []BatchEvaluationStatus {
	return []BatchEvaluationStatus{
		"PENDING",
		"IN_PROGRESS",
		"COMPLETED",
		"COMPLETED_WITH_ERRORS",
		"FAILED",
		"STOPPING",
		"STOPPED",
		"DELETING",
	}
}

type BlockchainChainId string

// Enum values for BlockchainChainId
const (
	// Base Mainnet (EVM L2)
	BlockchainChainIdBase BlockchainChainId = "BASE"
	// Base Sepolia testnet (EVM L2)
	BlockchainChainIdBaseSepolia BlockchainChainId = "BASE_SEPOLIA"
	// Ethereum Mainnet (EVM L1)
	BlockchainChainIdEthereum BlockchainChainId = "ETHEREUM"
	// Solana Mainnet
	BlockchainChainIdSolana BlockchainChainId = "SOLANA"
	// Solana Devnet testnet
	BlockchainChainIdSolanaDevnet BlockchainChainId = "SOLANA_DEVNET"
)

// Values returns all known values for BlockchainChainId. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BlockchainChainId) Values() []BlockchainChainId {
	return []BlockchainChainId{
		"BASE",
		"BASE_SEPOLIA",
		"ETHEREUM",
		"SOLANA",
		"SOLANA_DEVNET",
	}
}

type BrowserActionStatus string

// Enum values for BrowserActionStatus
const (
	BrowserActionStatusSuccess BrowserActionStatus = "SUCCESS"
	BrowserActionStatusFailed  BrowserActionStatus = "FAILED"
)

// Values returns all known values for BrowserActionStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BrowserActionStatus) Values() []BrowserActionStatus {
	return []BrowserActionStatus{
		"SUCCESS",
		"FAILED",
	}
}

type BrowserEnterprisePolicyType string

// Enum values for BrowserEnterprisePolicyType
const (
	BrowserEnterprisePolicyTypeManaged     BrowserEnterprisePolicyType = "MANAGED"
	BrowserEnterprisePolicyTypeRecommended BrowserEnterprisePolicyType = "RECOMMENDED"
)

// Values returns all known values for BrowserEnterprisePolicyType. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BrowserEnterprisePolicyType) Values() []BrowserEnterprisePolicyType {
	return []BrowserEnterprisePolicyType{
		"MANAGED",
		"RECOMMENDED",
	}
}

type BrowserSessionStatus string

// Enum values for BrowserSessionStatus
const (
	BrowserSessionStatusReady      BrowserSessionStatus = "READY"
	BrowserSessionStatusTerminated BrowserSessionStatus = "TERMINATED"
)

// Values returns all known values for BrowserSessionStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BrowserSessionStatus) Values() []BrowserSessionStatus {
	return []BrowserSessionStatus{
		"READY",
		"TERMINATED",
	}
}

type CloudWatchLogsFilterOperator string

// Enum values for CloudWatchLogsFilterOperator
const (
	CloudWatchLogsFilterOperatorEquals             CloudWatchLogsFilterOperator = "Equals"
	CloudWatchLogsFilterOperatorNotEquals          CloudWatchLogsFilterOperator = "NotEquals"
	CloudWatchLogsFilterOperatorGreaterThan        CloudWatchLogsFilterOperator = "GreaterThan"
	CloudWatchLogsFilterOperatorLessThan           CloudWatchLogsFilterOperator = "LessThan"
	CloudWatchLogsFilterOperatorGreaterThanOrEqual CloudWatchLogsFilterOperator = "GreaterThanOrEqual"
	CloudWatchLogsFilterOperatorLessThanOrEqual    CloudWatchLogsFilterOperator = "LessThanOrEqual"
	CloudWatchLogsFilterOperatorContains           CloudWatchLogsFilterOperator = "Contains"
	CloudWatchLogsFilterOperatorNotContains        CloudWatchLogsFilterOperator = "NotContains"
)

// Values returns all known values for CloudWatchLogsFilterOperator. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CloudWatchLogsFilterOperator) Values() []CloudWatchLogsFilterOperator {
	return []CloudWatchLogsFilterOperator{
		"Equals",
		"NotEquals",
		"GreaterThan",
		"LessThan",
		"GreaterThanOrEqual",
		"LessThanOrEqual",
		"Contains",
		"NotContains",
	}
}

type CodeInterpreterSessionStatus string

// Enum values for CodeInterpreterSessionStatus
const (
	CodeInterpreterSessionStatusReady      CodeInterpreterSessionStatus = "READY"
	CodeInterpreterSessionStatusTerminated CodeInterpreterSessionStatus = "TERMINATED"
)

// Values returns all known values for CodeInterpreterSessionStatus. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CodeInterpreterSessionStatus) Values() []CodeInterpreterSessionStatus {
	return []CodeInterpreterSessionStatus{
		"READY",
		"TERMINATED",
	}
}

type CommandExecutionStatus string

// Enum values for CommandExecutionStatus
const (
	CommandExecutionStatusCompleted CommandExecutionStatus = "COMPLETED"
	CommandExecutionStatusTimedOut  CommandExecutionStatus = "TIMED_OUT"
)

// Values returns all known values for CommandExecutionStatus. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CommandExecutionStatus) Values() []CommandExecutionStatus {
	return []CommandExecutionStatus{
		"COMPLETED",
		"TIMED_OUT",
	}
}

type ContentBlockType string

// Enum values for ContentBlockType
const (
	ContentBlockTypeText             ContentBlockType = "text"
	ContentBlockTypeImage            ContentBlockType = "image"
	ContentBlockTypeEmbeddedResource ContentBlockType = "resource"
	ContentBlockTypeResourceLink     ContentBlockType = "resource_link"
)

// Values returns all known values for ContentBlockType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ContentBlockType) Values() []ContentBlockType {
	return []ContentBlockType{
		"text",
		"image",
		"resource",
		"resource_link",
	}
}

type CryptoWalletNetwork string

// Enum values for CryptoWalletNetwork
const (
	CryptoWalletNetworkEthereum CryptoWalletNetwork = "ETHEREUM"
	CryptoWalletNetworkSolana   CryptoWalletNetwork = "SOLANA"
)

// Values returns all known values for CryptoWalletNetwork. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CryptoWalletNetwork) Values() []CryptoWalletNetwork {
	return []CryptoWalletNetwork{
		"ETHEREUM",
		"SOLANA",
	}
}

type Currency string

// Enum values for Currency
const (
	CurrencyUsd Currency = "USD"
)

// Values returns all known values for Currency. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (Currency) Values() []Currency {
	return []Currency{
		"USD",
	}
}

type DescriptorType string

// Enum values for DescriptorType
const (
	DescriptorTypeMcp         DescriptorType = "MCP"
	DescriptorTypeA2a         DescriptorType = "A2A"
	DescriptorTypeCustom      DescriptorType = "CUSTOM"
	DescriptorTypeAgentSkills DescriptorType = "AGENT_SKILLS"
)

// Values returns all known values for DescriptorType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DescriptorType) Values() []DescriptorType {
	return []DescriptorType{
		"MCP",
		"A2A",
		"CUSTOM",
		"AGENT_SKILLS",
	}
}

type EventFilterCondition string

// Enum values for EventFilterCondition
const (
	EventFilterConditionHasEvents EventFilterCondition = "HAS_EVENTS"
)

// Values returns all known values for EventFilterCondition. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EventFilterCondition) Values() []EventFilterCondition {
	return []EventFilterCondition{
		"HAS_EVENTS",
	}
}

type ExtractionJobStatus string

// Enum values for ExtractionJobStatus
const (
	ExtractionJobStatusFailed ExtractionJobStatus = "FAILED"
)

// Values returns all known values for ExtractionJobStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExtractionJobStatus) Values() []ExtractionJobStatus {
	return []ExtractionJobStatus{
		"FAILED",
	}
}

type ExtractionMode string

// Enum values for ExtractionMode
const (
	ExtractionModeSkip ExtractionMode = "SKIP"
)

// Values returns all known values for ExtractionMode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExtractionMode) Values() []ExtractionMode {
	return []ExtractionMode{
		"SKIP",
	}
}

type HarnessBedrockApiFormat string

// Enum values for HarnessBedrockApiFormat
const (
	// Use the Bedrock Converse Stream API format.
	HarnessBedrockApiFormatConverseStream HarnessBedrockApiFormat = "converse_stream"
	// Use the Responses API format.
	HarnessBedrockApiFormatResponses HarnessBedrockApiFormat = "responses"
	// Use the Chat Completions API format.
	HarnessBedrockApiFormatChatCompletions HarnessBedrockApiFormat = "chat_completions"
)

// Values returns all known values for HarnessBedrockApiFormat. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (HarnessBedrockApiFormat) Values() []HarnessBedrockApiFormat {
	return []HarnessBedrockApiFormat{
		"converse_stream",
		"responses",
		"chat_completions",
	}
}

type HarnessConversationRole string

// Enum values for HarnessConversationRole
const (
	HarnessConversationRoleUser      HarnessConversationRole = "user"
	HarnessConversationRoleAssistant HarnessConversationRole = "assistant"
)

// Values returns all known values for HarnessConversationRole. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (HarnessConversationRole) Values() []HarnessConversationRole {
	return []HarnessConversationRole{
		"user",
		"assistant",
	}
}

type HarnessOpenAiApiFormat string

// Enum values for HarnessOpenAiApiFormat
const (
	// Use the Chat Completions API format.
	HarnessOpenAiApiFormatChatCompletions HarnessOpenAiApiFormat = "chat_completions"
	// Use the Responses API format.
	HarnessOpenAiApiFormatResponses HarnessOpenAiApiFormat = "responses"
)

// Values returns all known values for HarnessOpenAiApiFormat. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (HarnessOpenAiApiFormat) Values() []HarnessOpenAiApiFormat {
	return []HarnessOpenAiApiFormat{
		"chat_completions",
		"responses",
	}
}

type HarnessStopReason string

// Enum values for HarnessStopReason
const (
	HarnessStopReasonEndTurn                    HarnessStopReason = "end_turn"
	HarnessStopReasonToolUse                    HarnessStopReason = "tool_use"
	HarnessStopReasonToolResult                 HarnessStopReason = "tool_result"
	HarnessStopReasonMaxTokens                  HarnessStopReason = "max_tokens"
	HarnessStopReasonStopSequence               HarnessStopReason = "stop_sequence"
	HarnessStopReasonContentFiltered            HarnessStopReason = "content_filtered"
	HarnessStopReasonMalformedModelOutput       HarnessStopReason = "malformed_model_output"
	HarnessStopReasonMalformedToolUse           HarnessStopReason = "malformed_tool_use"
	HarnessStopReasonInterrupted                HarnessStopReason = "interrupted"
	HarnessStopReasonPartialTurn                HarnessStopReason = "partial_turn"
	HarnessStopReasonModelContextWindowExceeded HarnessStopReason = "model_context_window_exceeded"
	HarnessStopReasonMaxIterationsExceeded      HarnessStopReason = "max_iterations_exceeded"
	HarnessStopReasonMaxOutputTokensExceeded    HarnessStopReason = "max_output_tokens_exceeded"
	HarnessStopReasonTimeoutExceeded            HarnessStopReason = "timeout_exceeded"
)

// Values returns all known values for HarnessStopReason. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (HarnessStopReason) Values() []HarnessStopReason {
	return []HarnessStopReason{
		"end_turn",
		"tool_use",
		"tool_result",
		"max_tokens",
		"stop_sequence",
		"content_filtered",
		"malformed_model_output",
		"malformed_tool_use",
		"interrupted",
		"partial_turn",
		"model_context_window_exceeded",
		"max_iterations_exceeded",
		"max_output_tokens_exceeded",
		"timeout_exceeded",
	}
}

type HarnessToolType string

// Enum values for HarnessToolType
const (
	HarnessToolTypeRemoteMcp                HarnessToolType = "remote_mcp"
	HarnessToolTypeAgentcoreBrowser         HarnessToolType = "agentcore_browser"
	HarnessToolTypeAgentcoreGateway         HarnessToolType = "agentcore_gateway"
	HarnessToolTypeInlineFunction           HarnessToolType = "inline_function"
	HarnessToolTypeAgentcoreCodeInterpreter HarnessToolType = "agentcore_code_interpreter"
)

// Values returns all known values for HarnessToolType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (HarnessToolType) Values() []HarnessToolType {
	return []HarnessToolType{
		"remote_mcp",
		"agentcore_browser",
		"agentcore_gateway",
		"inline_function",
		"agentcore_code_interpreter",
	}
}

type HarnessToolUseStatus string

// Enum values for HarnessToolUseStatus
const (
	HarnessToolUseStatusSuccess HarnessToolUseStatus = "success"
	HarnessToolUseStatusError   HarnessToolUseStatus = "error"
)

// Values returns all known values for HarnessToolUseStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (HarnessToolUseStatus) Values() []HarnessToolUseStatus {
	return []HarnessToolUseStatus{
		"success",
		"error",
	}
}

type HarnessToolUseType string

// Enum values for HarnessToolUseType
const (
	HarnessToolUseTypeToolUse       HarnessToolUseType = "tool_use"
	HarnessToolUseTypeServerToolUse HarnessToolUseType = "server_tool_use"
	HarnessToolUseTypeMcpToolUse    HarnessToolUseType = "mcp_tool_use"
)

// Values returns all known values for HarnessToolUseType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (HarnessToolUseType) Values() []HarnessToolUseType {
	return []HarnessToolUseType{
		"tool_use",
		"server_tool_use",
		"mcp_tool_use",
	}
}

type InsightsFailureCategory string

// Enum values for InsightsFailureCategory
const (
	InsightsFailureCategoryExecutionErrorAuthentication             InsightsFailureCategory = "execution-error-category-authentication"
	InsightsFailureCategoryExecutionErrorResourceNotFound           InsightsFailureCategory = "execution-error-category-resource-not-found"
	InsightsFailureCategoryExecutionErrorServiceErrors              InsightsFailureCategory = "execution-error-category-service-errors"
	InsightsFailureCategoryExecutionErrorRateLimiting               InsightsFailureCategory = "execution-error-category-rate-limiting"
	InsightsFailureCategoryExecutionErrorFormatting                 InsightsFailureCategory = "execution-error-category-formatting"
	InsightsFailureCategoryExecutionErrorTimeout                    InsightsFailureCategory = "execution-error-category-timeout"
	InsightsFailureCategoryExecutionErrorResourceExhaustion         InsightsFailureCategory = "execution-error-category-resource-exhaustion"
	InsightsFailureCategoryExecutionErrorEnvironment                InsightsFailureCategory = "execution-error-category-environment"
	InsightsFailureCategoryExecutionErrorToolSchema                 InsightsFailureCategory = "execution-error-category-tool-schema"
	InsightsFailureCategoryTaskInstructionNonCompliance             InsightsFailureCategory = "task-instruction-category-non-compliance"
	InsightsFailureCategoryTaskInstructionProblemId                 InsightsFailureCategory = "task-instruction-category-problem-id"
	InsightsFailureCategoryIncorrectActionsToolSelection            InsightsFailureCategory = "incorrect-actions-category-tool-selection"
	InsightsFailureCategoryIncorrectActionsPoorInformationRetrieval InsightsFailureCategory = "incorrect-actions-category-poor-information-retrieval"
	InsightsFailureCategoryIncorrectActionsClarification            InsightsFailureCategory = "incorrect-actions-category-clarification"
	InsightsFailureCategoryIncorrectActionsInappropriateInfoRequest InsightsFailureCategory = "incorrect-actions-category-inappropriate-info-request"
	InsightsFailureCategoryContextHandlingFailures                  InsightsFailureCategory = "context-handling-error-category-context-handling-failures"
	InsightsFailureCategoryHallucinationCapabilities                InsightsFailureCategory = "hallucination-category-hall-capabilities"
	InsightsFailureCategoryHallucinationMisunderstand               InsightsFailureCategory = "hallucination-category-hall-misunderstand"
	InsightsFailureCategoryHallucinationUsage                       InsightsFailureCategory = "hallucination-category-hall-usage"
	InsightsFailureCategoryHallucinationHistory                     InsightsFailureCategory = "hallucination-category-hall-history"
	InsightsFailureCategoryHallucinationParams                      InsightsFailureCategory = "hallucination-category-hall-params"
	InsightsFailureCategoryHallucinationFabricateToolOutputs        InsightsFailureCategory = "hallucination-category-fabricate-tool-outputs"
	InsightsFailureCategoryRepetitiveBehaviorTool                   InsightsFailureCategory = "repetitive-behavior-category-repetition-tool"
	InsightsFailureCategoryRepetitiveBehaviorInfo                   InsightsFailureCategory = "repetitive-behavior-category-repetition-info"
	InsightsFailureCategoryRepetitiveBehaviorStep                   InsightsFailureCategory = "repetitive-behavior-category-step-repetition"
	InsightsFailureCategoryOrchestrationReasoningMismatch           InsightsFailureCategory = "orchestration-related-errors-category-reasoning-mismatch"
	InsightsFailureCategoryOrchestrationGoalDeviation               InsightsFailureCategory = "orchestration-related-errors-category-goal-deviation"
	InsightsFailureCategoryOrchestrationPrematureTermination        InsightsFailureCategory = "orchestration-related-errors-category-premature-termination"
	InsightsFailureCategoryOrchestrationUnawareTermination          InsightsFailureCategory = "orchestration-related-errors-category-unaware-termination"
	InsightsFailureCategoryLlmOutputNonsensical                     InsightsFailureCategory = "llm-output-category-nonsensical"
	InsightsFailureCategoryConfigurationMismatchToolDefinition      InsightsFailureCategory = "configuration-mismatch-category-tool-definition"
	InsightsFailureCategoryCodingEdgeCaseOversights                 InsightsFailureCategory = "coding-use-case-specific-failure-types-category-edge-case-oversights"
	InsightsFailureCategoryCodingDependencyIssues                   InsightsFailureCategory = "coding-use-case-specific-failure-types-category-dependency-issues"
	InsightsFailureCategoryOther                                    InsightsFailureCategory = "other"
)

// Values returns all known values for InsightsFailureCategory. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InsightsFailureCategory) Values() []InsightsFailureCategory {
	return []InsightsFailureCategory{
		"execution-error-category-authentication",
		"execution-error-category-resource-not-found",
		"execution-error-category-service-errors",
		"execution-error-category-rate-limiting",
		"execution-error-category-formatting",
		"execution-error-category-timeout",
		"execution-error-category-resource-exhaustion",
		"execution-error-category-environment",
		"execution-error-category-tool-schema",
		"task-instruction-category-non-compliance",
		"task-instruction-category-problem-id",
		"incorrect-actions-category-tool-selection",
		"incorrect-actions-category-poor-information-retrieval",
		"incorrect-actions-category-clarification",
		"incorrect-actions-category-inappropriate-info-request",
		"context-handling-error-category-context-handling-failures",
		"hallucination-category-hall-capabilities",
		"hallucination-category-hall-misunderstand",
		"hallucination-category-hall-usage",
		"hallucination-category-hall-history",
		"hallucination-category-hall-params",
		"hallucination-category-fabricate-tool-outputs",
		"repetitive-behavior-category-repetition-tool",
		"repetitive-behavior-category-repetition-info",
		"repetitive-behavior-category-step-repetition",
		"orchestration-related-errors-category-reasoning-mismatch",
		"orchestration-related-errors-category-goal-deviation",
		"orchestration-related-errors-category-premature-termination",
		"orchestration-related-errors-category-unaware-termination",
		"llm-output-category-nonsensical",
		"configuration-mismatch-category-tool-definition",
		"coding-use-case-specific-failure-types-category-edge-case-oversights",
		"coding-use-case-specific-failure-types-category-dependency-issues",
		"other",
	}
}

type InstrumentBalanceToken string

// Enum values for InstrumentBalanceToken
const (
	InstrumentBalanceTokenUsdc InstrumentBalanceToken = "USDC"
)

// Values returns all known values for InstrumentBalanceToken. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InstrumentBalanceToken) Values() []InstrumentBalanceToken {
	return []InstrumentBalanceToken{
		"USDC",
	}
}

type LanguageRuntime string

// Enum values for LanguageRuntime
const (
	LanguageRuntimeNodejs LanguageRuntime = "nodejs"
	LanguageRuntimeDeno   LanguageRuntime = "deno"
	LanguageRuntimePython LanguageRuntime = "python"
)

// Values returns all known values for LanguageRuntime. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LanguageRuntime) Values() []LanguageRuntime {
	return []LanguageRuntime{
		"nodejs",
		"deno",
		"python",
	}
}

type MemoryRecordOperatorType string

// Enum values for MemoryRecordOperatorType
const (
	MemoryRecordOperatorTypeEqualsTo            MemoryRecordOperatorType = "EQUALS_TO"
	MemoryRecordOperatorTypeExists              MemoryRecordOperatorType = "EXISTS"
	MemoryRecordOperatorTypeNotExists           MemoryRecordOperatorType = "NOT_EXISTS"
	MemoryRecordOperatorTypeBefore              MemoryRecordOperatorType = "BEFORE"
	MemoryRecordOperatorTypeAfter               MemoryRecordOperatorType = "AFTER"
	MemoryRecordOperatorTypeContains            MemoryRecordOperatorType = "CONTAINS"
	MemoryRecordOperatorTypeGreaterThan         MemoryRecordOperatorType = "GREATER_THAN"
	MemoryRecordOperatorTypeGreaterThanOrEquals MemoryRecordOperatorType = "GREATER_THAN_OR_EQUALS"
	MemoryRecordOperatorTypeLessThan            MemoryRecordOperatorType = "LESS_THAN"
	MemoryRecordOperatorTypeLessThanOrEquals    MemoryRecordOperatorType = "LESS_THAN_OR_EQUALS"
)

// Values returns all known values for MemoryRecordOperatorType. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MemoryRecordOperatorType) Values() []MemoryRecordOperatorType {
	return []MemoryRecordOperatorType{
		"EQUALS_TO",
		"EXISTS",
		"NOT_EXISTS",
		"BEFORE",
		"AFTER",
		"CONTAINS",
		"GREATER_THAN",
		"GREATER_THAN_OR_EQUALS",
		"LESS_THAN",
		"LESS_THAN_OR_EQUALS",
	}
}

type MemoryRecordStatus string

// Enum values for MemoryRecordStatus
const (
	MemoryRecordStatusSucceeded MemoryRecordStatus = "SUCCEEDED"
	MemoryRecordStatusFailed    MemoryRecordStatus = "FAILED"
)

// Values returns all known values for MemoryRecordStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MemoryRecordStatus) Values() []MemoryRecordStatus {
	return []MemoryRecordStatus{
		"SUCCEEDED",
		"FAILED",
	}
}

type MouseButton string

// Enum values for MouseButton
const (
	MouseButtonLeft   MouseButton = "LEFT"
	MouseButtonRight  MouseButton = "RIGHT"
	MouseButtonMiddle MouseButton = "MIDDLE"
)

// Values returns all known values for MouseButton. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MouseButton) Values() []MouseButton {
	return []MouseButton{
		"LEFT",
		"RIGHT",
		"MIDDLE",
	}
}

type Oauth2FlowType string

// Enum values for Oauth2FlowType
const (
	Oauth2FlowTypeUserFederation          Oauth2FlowType = "USER_FEDERATION"
	Oauth2FlowTypeM2m                     Oauth2FlowType = "M2M"
	Oauth2FlowTypeOnBehalfOfTokenExchange Oauth2FlowType = "ON_BEHALF_OF_TOKEN_EXCHANGE"
)

// Values returns all known values for Oauth2FlowType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (Oauth2FlowType) Values() []Oauth2FlowType {
	return []Oauth2FlowType{
		"USER_FEDERATION",
		"M2M",
		"ON_BEHALF_OF_TOKEN_EXCHANGE",
	}
}

type OAuthGrantType string

// Enum values for OAuthGrantType
const (
	OAuthGrantTypeClientCredentials OAuthGrantType = "CLIENT_CREDENTIALS"
	OAuthGrantTypeAuthorizationCode OAuthGrantType = "AUTHORIZATION_CODE"
	OAuthGrantTypeTokenExchange     OAuthGrantType = "TOKEN_EXCHANGE"
)

// Values returns all known values for OAuthGrantType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (OAuthGrantType) Values() []OAuthGrantType {
	return []OAuthGrantType{
		"CLIENT_CREDENTIALS",
		"AUTHORIZATION_CODE",
		"TOKEN_EXCHANGE",
	}
}

type OperatorType string

// Enum values for OperatorType
const (
	OperatorTypeEqualsTo  OperatorType = "EQUALS_TO"
	OperatorTypeExists    OperatorType = "EXISTS"
	OperatorTypeNotExists OperatorType = "NOT_EXISTS"
)

// Values returns all known values for OperatorType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (OperatorType) Values() []OperatorType {
	return []OperatorType{
		"EQUALS_TO",
		"EXISTS",
		"NOT_EXISTS",
	}
}

type PaymentHttpMethodType string

// Enum values for PaymentHttpMethodType
const (
	PaymentHttpMethodTypeGet    PaymentHttpMethodType = "GET"
	PaymentHttpMethodTypePost   PaymentHttpMethodType = "POST"
	PaymentHttpMethodTypePut    PaymentHttpMethodType = "PUT"
	PaymentHttpMethodTypeDelete PaymentHttpMethodType = "DELETE"
	PaymentHttpMethodTypePatch  PaymentHttpMethodType = "PATCH"
)

// Values returns all known values for PaymentHttpMethodType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PaymentHttpMethodType) Values() []PaymentHttpMethodType {
	return []PaymentHttpMethodType{
		"GET",
		"POST",
		"PUT",
		"DELETE",
		"PATCH",
	}
}

type PaymentInstrumentStatus string

// Enum values for PaymentInstrumentStatus
const (
	PaymentInstrumentStatusInitiated PaymentInstrumentStatus = "INITIATED"
	PaymentInstrumentStatusActive    PaymentInstrumentStatus = "ACTIVE"
	PaymentInstrumentStatusFailed    PaymentInstrumentStatus = "FAILED"
	PaymentInstrumentStatusDeleted   PaymentInstrumentStatus = "DELETED"
)

// Values returns all known values for PaymentInstrumentStatus. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PaymentInstrumentStatus) Values() []PaymentInstrumentStatus {
	return []PaymentInstrumentStatus{
		"INITIATED",
		"ACTIVE",
		"FAILED",
		"DELETED",
	}
}

type PaymentInstrumentType string

// Enum values for PaymentInstrumentType
const (
	PaymentInstrumentTypeEmbeddedCryptoWallet PaymentInstrumentType = "EMBEDDED_CRYPTO_WALLET"
)

// Values returns all known values for PaymentInstrumentType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PaymentInstrumentType) Values() []PaymentInstrumentType {
	return []PaymentInstrumentType{
		"EMBEDDED_CRYPTO_WALLET",
	}
}

type PaymentSessionStatus string

// Enum values for PaymentSessionStatus
const (
	PaymentSessionStatusActive  PaymentSessionStatus = "ACTIVE"
	PaymentSessionStatusExpired PaymentSessionStatus = "EXPIRED"
	PaymentSessionStatusDeleted PaymentSessionStatus = "DELETED"
)

// Values returns all known values for PaymentSessionStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PaymentSessionStatus) Values() []PaymentSessionStatus {
	return []PaymentSessionStatus{
		"ACTIVE",
		"EXPIRED",
		"DELETED",
	}
}

type PaymentStatus string

// Enum values for PaymentStatus
const (
	PaymentStatusProofGenerated PaymentStatus = "PROOF_GENERATED"
)

// Values returns all known values for PaymentStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PaymentStatus) Values() []PaymentStatus {
	return []PaymentStatus{
		"PROOF_GENERATED",
	}
}

type PaymentType string

// Enum values for PaymentType
const (
	PaymentTypeCryptoX402 PaymentType = "CRYPTO_X402"
)

// Values returns all known values for PaymentType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PaymentType) Values() []PaymentType {
	return []PaymentType{
		"CRYPTO_X402",
	}
}

type ProgrammingLanguage string

// Enum values for ProgrammingLanguage
const (
	ProgrammingLanguagePython     ProgrammingLanguage = "python"
	ProgrammingLanguageJavascript ProgrammingLanguage = "javascript"
	ProgrammingLanguageTypescript ProgrammingLanguage = "typescript"
)

// Values returns all known values for ProgrammingLanguage. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ProgrammingLanguage) Values() []ProgrammingLanguage {
	return []ProgrammingLanguage{
		"python",
		"javascript",
		"typescript",
	}
}

type RecommendationStatus string

// Enum values for RecommendationStatus
const (
	RecommendationStatusPending    RecommendationStatus = "PENDING"
	RecommendationStatusInProgress RecommendationStatus = "IN_PROGRESS"
	RecommendationStatusCompleted  RecommendationStatus = "COMPLETED"
	RecommendationStatusFailed     RecommendationStatus = "FAILED"
	RecommendationStatusDeleting   RecommendationStatus = "DELETING"
)

// Values returns all known values for RecommendationStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RecommendationStatus) Values() []RecommendationStatus {
	return []RecommendationStatus{
		"PENDING",
		"IN_PROGRESS",
		"COMPLETED",
		"FAILED",
		"DELETING",
	}
}

type RecommendationType string

// Enum values for RecommendationType
const (
	RecommendationTypeSystemPromptRecommendation    RecommendationType = "SYSTEM_PROMPT_RECOMMENDATION"
	RecommendationTypeToolDescriptionRecommendation RecommendationType = "TOOL_DESCRIPTION_RECOMMENDATION"
)

// Values returns all known values for RecommendationType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RecommendationType) Values() []RecommendationType {
	return []RecommendationType{
		"SYSTEM_PROMPT_RECOMMENDATION",
		"TOOL_DESCRIPTION_RECOMMENDATION",
	}
}

type RegistryRecordStatus string

// Enum values for RegistryRecordStatus
const (
	RegistryRecordStatusDraft           RegistryRecordStatus = "DRAFT"
	RegistryRecordStatusPendingApproval RegistryRecordStatus = "PENDING_APPROVAL"
	RegistryRecordStatusApproved        RegistryRecordStatus = "APPROVED"
	RegistryRecordStatusRejected        RegistryRecordStatus = "REJECTED"
	RegistryRecordStatusDeprecated      RegistryRecordStatus = "DEPRECATED"
)

// Values returns all known values for RegistryRecordStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RegistryRecordStatus) Values() []RegistryRecordStatus {
	return []RegistryRecordStatus{
		"DRAFT",
		"PENDING_APPROVAL",
		"APPROVED",
		"REJECTED",
		"DEPRECATED",
	}
}

type ResourceContentType string

// Enum values for ResourceContentType
const (
	ResourceContentTypeText ResourceContentType = "text"
	ResourceContentTypeBlob ResourceContentType = "blob"
)

// Values returns all known values for ResourceContentType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ResourceContentType) Values() []ResourceContentType {
	return []ResourceContentType{
		"text",
		"blob",
	}
}

type Role string

// Enum values for Role
const (
	RoleAssistant Role = "ASSISTANT"
	RoleUser      Role = "USER"
	RoleTool      Role = "TOOL"
	RoleOther     Role = "OTHER"
)

// Values returns all known values for Role. Note that this can be expanded in the
// future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (Role) Values() []Role {
	return []Role{
		"ASSISTANT",
		"USER",
		"TOOL",
		"OTHER",
	}
}

type ScreenshotFormat string

// Enum values for ScreenshotFormat
const (
	ScreenshotFormatPng ScreenshotFormat = "PNG"
)

// Values returns all known values for ScreenshotFormat. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ScreenshotFormat) Values() []ScreenshotFormat {
	return []ScreenshotFormat{
		"PNG",
	}
}

type SessionStatus string

// Enum values for SessionStatus
const (
	SessionStatusInProgress SessionStatus = "IN_PROGRESS"
	SessionStatusFailed     SessionStatus = "FAILED"
)

// Values returns all known values for SessionStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SessionStatus) Values() []SessionStatus {
	return []SessionStatus{
		"IN_PROGRESS",
		"FAILED",
	}
}

type TaskStatus string

// Enum values for TaskStatus
const (
	TaskStatusSubmitted TaskStatus = "submitted"
	TaskStatusWorking   TaskStatus = "working"
	TaskStatusCompleted TaskStatus = "completed"
	TaskStatusCanceled  TaskStatus = "canceled"
	TaskStatusFailed    TaskStatus = "failed"
)

// Values returns all known values for TaskStatus. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TaskStatus) Values() []TaskStatus {
	return []TaskStatus{
		"submitted",
		"working",
		"completed",
		"canceled",
		"failed",
	}
}

type ToolName string

// Enum values for ToolName
const (
	ToolNameExecuteCode           ToolName = "executeCode"
	ToolNameExecuteCommand        ToolName = "executeCommand"
	ToolNameReadFiles             ToolName = "readFiles"
	ToolNameListFiles             ToolName = "listFiles"
	ToolNameRemoveFiles           ToolName = "removeFiles"
	ToolNameWriteFiles            ToolName = "writeFiles"
	ToolNameStartCommandExecution ToolName = "startCommandExecution"
	ToolNameGetTask               ToolName = "getTask"
	ToolNameStopTask              ToolName = "stopTask"
)

// Values returns all known values for ToolName. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ToolName) Values() []ToolName {
	return []ToolName{
		"executeCode",
		"executeCommand",
		"readFiles",
		"listFiles",
		"removeFiles",
		"writeFiles",
		"startCommandExecution",
		"getTask",
		"stopTask",
	}
}

type ValidationExceptionReason string

// Enum values for ValidationExceptionReason
const (
	ValidationExceptionReasonCannotParse                          ValidationExceptionReason = "CannotParse"
	ValidationExceptionReasonFieldValidationFailed                ValidationExceptionReason = "FieldValidationFailed"
	ValidationExceptionReasonIdempotentParameterMismatchException ValidationExceptionReason = "IdempotentParameterMismatchException"
	ValidationExceptionReasonRootEventInOtherSession              ValidationExceptionReason = "EventInOtherSession"
	ValidationExceptionReasonResourceConflict                     ValidationExceptionReason = "ResourceConflict"
)

// Values returns all known values for ValidationExceptionReason. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ValidationExceptionReason) Values() []ValidationExceptionReason {
	return []ValidationExceptionReason{
		"CannotParse",
		"FieldValidationFailed",
		"IdempotentParameterMismatchException",
		"EventInOtherSession",
		"ResourceConflict",
	}
}
