// Code generated by smithy-go-codegen DO NOT EDIT.

// Package chimesdkmeetings provides the API client, operations, and parameter
// types for Amazon Chime SDK Meetings.
//
// The Amazon Chime SDK meetings APIs in this section allow software developers to
// create Amazon Chime SDK meetings, set the Amazon Web Services Regions for
// meetings, create and manage users, and send and receive meeting notifications.
// For more information about the meeting APIs, see [Amazon Chime SDK meetings].
//
// [Amazon Chime SDK meetings]: https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_Operations_Amazon_Chime_SDK_Meetings.html
package chimesdkmeetings
