// Code generated by smithy-go-codegen DO NOT EDIT.

package budgets

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/budgets/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Deletes a budget action.
func (c *Client) DeleteBudgetAction(ctx context.Context, params *DeleteBudgetActionInput, optFns ...func(*Options)) (*DeleteBudgetActionOutput, error) {
	if params == nil {
		params = &DeleteBudgetActionInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeleteBudgetAction", params, optFns, c.addOperationDeleteBudgetActionMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeleteBudgetActionOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DeleteBudgetActionInput struct {

	// The account ID of the user. It's a 12-digit number.
	//
	// This member is required.
	AccountId *string

	//  A system-generated universally unique identifier (UUID) for the action.
	//
	// This member is required.
	ActionId *string

	//  A string that represents the budget name. The ":" and "\" characters, and the
	// "/action/" substring, aren't allowed.
	//
	// Budget names are validated for content. Names that contain phone numbers, URLs,
	// or email addresses combined with certain terms may be rejected.
	//
	// This member is required.
	BudgetName *string

	noSmithyDocumentSerde
}

type DeleteBudgetActionOutput struct {

	// The account ID of the user. It's a 12-digit number.
	//
	// This member is required.
	AccountId *string

	// A budget action resource.
	//
	// This member is required.
	Action *types.Action

	//  A string that represents the budget name. The ":" and "\" characters, and the
	// "/action/" substring, aren't allowed.
	//
	// Budget names are validated for content. Names that contain phone numbers, URLs,
	// or email addresses combined with certain terms may be rejected.
	//
	// This member is required.
	BudgetName *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeleteBudgetActionMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpDeleteBudgetAction{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpDeleteBudgetAction{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDeleteBudgetActionValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeleteBudgetAction"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
