// Code generated by smithy-go-codegen DO NOT EDIT.

package cleanroomsml

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Submits a request to cancel the trained model job.
func (c *Client) CancelTrainedModel(ctx context.Context, params *CancelTrainedModelInput, optFns ...func(*Options)) (*CancelTrainedModelOutput, error) {
	if params == nil {
		params = &CancelTrainedModelInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "CancelTrainedModel", params, optFns, c.addOperationCancelTrainedModelMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*CancelTrainedModelOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type CancelTrainedModelInput struct {

	// The membership ID of the trained model job that you want to cancel.
	//
	// This member is required.
	MembershipIdentifier *string

	// The Amazon Resource Name (ARN) of the trained model job that you want to cancel.
	//
	// This member is required.
	TrainedModelArn *string

	// The version identifier of the trained model to cancel. This parameter allows
	// you to specify which version of the trained model you want to cancel when
	// multiple versions exist.
	//
	// If versionIdentifier is not specified, the base model will be cancelled.
	VersionIdentifier *string

	noSmithyDocumentSerde
}

type CancelTrainedModelOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationCancelTrainedModelMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpCancelTrainedModel{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpCancelTrainedModel{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpCancelTrainedModelValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "CancelTrainedModel"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
