// Code generated by smithy-go-codegen DO NOT EDIT.

package billing

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

//	Removes the association between one or more source billing views and an
//
// existing billing view. This allows modifying the composition of aggregate
// billing views.
func (c *Client) DisassociateSourceViews(ctx context.Context, params *DisassociateSourceViewsInput, optFns ...func(*Options)) (*DisassociateSourceViewsOutput, error) {
	if params == nil {
		params = &DisassociateSourceViewsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DisassociateSourceViews", params, optFns, c.addOperationDisassociateSourceViewsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DisassociateSourceViewsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DisassociateSourceViewsInput struct {

	//  The Amazon Resource Name (ARN) of the billing view to disassociate source
	// views from.
	//
	// This member is required.
	Arn *string

	//  A list of ARNs of the source billing views to disassociate.
	//
	// This member is required.
	SourceViews []string

	noSmithyDocumentSerde
}

type DisassociateSourceViewsOutput struct {

	//  The ARN of the billing view that the source views were disassociated from.
	//
	// This member is required.
	Arn *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDisassociateSourceViewsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson10_serializeOpDisassociateSourceViews{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson10_deserializeOpDisassociateSourceViews{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDisassociateSourceViewsValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DisassociateSourceViews"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
