// Code generated by smithy-go-codegen DO NOT EDIT.

package restxml

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/internal/protocoltest/restxml/schemas"
	"github.com/aws/aws-sdk-go-v2/internal/protocoltest/restxml/types"
	smithy "github.com/aws/smithy-go"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Flattened maps
func (c *Client) FlattenedXmlMap(ctx context.Context, params *FlattenedXmlMapInput, optFns ...func(*Options)) (*FlattenedXmlMapOutput, error) {
	if params == nil {
		params = &FlattenedXmlMapInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "FlattenedXmlMap", params, optFns, c.addOperationFlattenedXmlMapMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*FlattenedXmlMapOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type FlattenedXmlMapInput struct {
	MyMap map[string]types.FooEnum

	noSmithyDocumentSerde
}

func (v *FlattenedXmlMapInput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.FlattenedXmlMapRequest)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *FlattenedXmlMapInput) SerializeMembers(s smithy.ShapeSerializer) {
	serializeFooEnumMap(s, schemas.FlattenedXmlMapRequest_myMap, v.MyMap)
}

type FlattenedXmlMapOutput struct {
	MyMap map[string]types.FooEnum

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (v *FlattenedXmlMapOutput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.FlattenedXmlMapResponse)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *FlattenedXmlMapOutput) SerializeMembers(s smithy.ShapeSerializer) {
	serializeFooEnumMap(s, schemas.FlattenedXmlMapResponse_myMap, v.MyMap)
}
func (v *FlattenedXmlMapOutput) Deserialize(d smithy.ShapeDeserializer) error {
	return smithy.ReadStruct(d, schemas.FlattenedXmlMapResponse, func(s *smithy.Schema) error {
		switch s {
		case schemas.FlattenedXmlMapResponse_myMap:
			return deserializeFooEnumMap(d, schemas.FlattenedXmlMapResponse_myMap, &v.MyMap)
		}
		return nil
	})
}
func (c *Client) addOperationFlattenedXmlMapMiddlewares(stack *middleware.Stack, options Options) (err error) {
	if err := stack.Serialize.Add(&serializeRequestMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.FlattenedXmlMap, schemas.FlattenedXmlMapRequest, schemas.FlattenedXmlMapResponse)}, middleware.After); err != nil {
		return err
	}
	if err := stack.Deserialize.Add(&deserializeResponseMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.FlattenedXmlMap, schemas.FlattenedXmlMapRequest, schemas.FlattenedXmlMapResponse), output: &FlattenedXmlMapOutput{}}, middleware.After); err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "FlattenedXmlMap"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
