// Code generated by smithy-go-codegen DO NOT EDIT.

// Package cloudtrail provides the API client, operations, and parameter types for
// AWS CloudTrail.
//
// # CloudTrail
//
// This is the CloudTrail API Reference. It provides descriptions of actions, data
// types, common parameters, and common errors for CloudTrail.
//
// CloudTrail is a web service that records Amazon Web Services API calls for your
// Amazon Web Services account and delivers log files to an Amazon S3 bucket. The
// recorded information includes the identity of the user, the start time of the
// Amazon Web Services API call, the source IP address, the request parameters, and
// the response elements returned by the service.
//
// As an alternative to the API, you can use one of the Amazon Web Services SDKs,
// which consist of libraries and sample code for various programming languages and
// platforms (Java, Ruby, .NET, iOS, Android, etc.). The SDKs provide programmatic
// access to CloudTrail. For example, the SDKs handle cryptographically signing
// requests, managing errors, and retrying requests automatically. For more
// information about the Amazon Web Services SDKs, including how to download and
// install them, see [Tools to Build on Amazon Web Services].
//
// See the [CloudTrail User Guide] for information about the data that is included with each Amazon Web
// Services API call listed in the log files.
//
// [CloudTrail User Guide]: https://docs.aws.amazon.com/awscloudtrail/latest/userguide/cloudtrail-user-guide.html
// [Tools to Build on Amazon Web Services]: http://aws.amazon.com/tools/
package cloudtrail
