// Code generated by smithy-go-codegen DO NOT EDIT.

package query

import (
	"bytes"
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyrand "github.com/aws/smithy-go/rand"
	smithytesting "github.com/aws/smithy-go/testing"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"io"
	"net/http"
	"testing"
)

func TestClient_XmlEmptyBlobs_Deserialize(t *testing.T) {
	cases := map[string]struct {
		StatusCode    int
		Header        http.Header
		BodyMediaType string
		Body          []byte
		ExpectResult  *XmlEmptyBlobsOutput
	}{
		// Empty blobs are deserialized as empty string
		"QueryXmlEmptyBlobs": {
			StatusCode: 200,
			Header: http.Header{
				"Content-Type": []string{"text/xml"},
			},
			BodyMediaType: "application/xml",
			Body: []byte(`<XmlEmptyBlobsResponse xmlns="https://example.com/">
			    <XmlEmptyBlobsResult>
			        <data></data>
			    </XmlEmptyBlobsResult>
			</XmlEmptyBlobsResponse>
			`),
			ExpectResult: &XmlEmptyBlobsOutput{
				Data: []byte(""),
			},
		},
		// Empty self closed blobs are deserialized as empty string
		"QueryXmlEmptySelfClosedBlobs": {
			StatusCode: 200,
			Header: http.Header{
				"Content-Type": []string{"text/xml"},
			},
			BodyMediaType: "application/xml",
			Body: []byte(`<XmlEmptyBlobsResponse xmlns="https://example.com/">
			    <XmlEmptyBlobsResult>
			        <data/>
			    </XmlEmptyBlobsResult>
			</XmlEmptyBlobsResponse>
			`),
			ExpectResult: &XmlEmptyBlobsOutput{
				Data: []byte(""),
			},
		},
	}
	for name, c := range cases {
		t.Run(name, func(t *testing.T) {
			serverURL := "http://localhost:8888/"
			client := New(Options{
				HTTPClient: smithyhttp.ClientDoFunc(func(r *http.Request) (*http.Response, error) {
					headers := http.Header{}
					for k, vs := range c.Header {
						for _, v := range vs {
							headers.Add(k, v)
						}
					}
					if len(c.BodyMediaType) != 0 && len(headers.Values("Content-Type")) == 0 {
						headers.Set("Content-Type", c.BodyMediaType)
					}
					response := &http.Response{
						StatusCode: c.StatusCode,
						Header:     headers,
						Request:    r,
					}
					if len(c.Body) != 0 {
						response.ContentLength = int64(len(c.Body))
						response.Body = io.NopCloser(bytes.NewReader(c.Body))
					} else {

						response.Body = http.NoBody
					}
					return response, nil
				}),
				APIOptions: []func(*middleware.Stack) error{
					func(s *middleware.Stack) error {
						s.Finalize.Clear()
						s.Initialize.Remove(`OperationInputValidation`)
						return nil
					},
				},
				EndpointResolverV2:       &protocolTestEndpointResolver{serverURL},
				IdempotencyTokenProvider: smithyrand.NewUUIDIdempotencyToken(&smithytesting.ByteLoop{}),
			})
			var params XmlEmptyBlobsInput
			result, err := client.XmlEmptyBlobs(context.Background(), &params)
			if err != nil {
				t.Fatalf("expect nil err, got %v", err)
			}
			if result == nil {
				t.Fatalf("expect not nil result")
			}
			if err := smithytesting.CompareValues(c.ExpectResult, result); err != nil {
				t.Errorf("expect c.ExpectResult value match:\n%v", err)
			}
		})
	}
}

func BenchmarkClient_XmlEmptyBlobs_Deserialize(b *testing.B) {
	cases := map[string]struct {
		StatusCode    int
		Header        http.Header
		BodyMediaType string
		Body          []byte
		ExpectResult  *XmlEmptyBlobsOutput
	}{
		"QueryXmlEmptyBlobs": {
			StatusCode: 200,
			Header: http.Header{
				"Content-Type": []string{"text/xml"},
			},
			BodyMediaType: "application/xml",
			Body: []byte(`<XmlEmptyBlobsResponse xmlns="https://example.com/">
			    <XmlEmptyBlobsResult>
			        <data></data>
			    </XmlEmptyBlobsResult>
			</XmlEmptyBlobsResponse>
			`),
			ExpectResult: &XmlEmptyBlobsOutput{
				Data: []byte(""),
			},
		},
		"QueryXmlEmptySelfClosedBlobs": {
			StatusCode: 200,
			Header: http.Header{
				"Content-Type": []string{"text/xml"},
			},
			BodyMediaType: "application/xml",
			Body: []byte(`<XmlEmptyBlobsResponse xmlns="https://example.com/">
			    <XmlEmptyBlobsResult>
			        <data/>
			    </XmlEmptyBlobsResult>
			</XmlEmptyBlobsResponse>
			`),
			ExpectResult: &XmlEmptyBlobsOutput{
				Data: []byte(""),
			},
		},
	}
	for name, c := range cases {
		b.Run(name, func(b *testing.B) {
			var params XmlEmptyBlobsInput
			serverURL := "http://localhost:8888/"
			client := New(Options{
				HTTPClient: smithyhttp.ClientDoFunc(func(r *http.Request) (*http.Response, error) {
					headers := http.Header{}
					for k, vs := range c.Header {
						for _, v := range vs {
							headers.Add(k, v)
						}
					}
					if len(c.BodyMediaType) != 0 && len(headers.Values("Content-Type")) == 0 {
						headers.Set("Content-Type", c.BodyMediaType)
					}
					response := &http.Response{
						StatusCode: c.StatusCode,
						Header:     headers,
						Request:    r,
					}
					if len(c.Body) != 0 {
						response.ContentLength = int64(len(c.Body))
						response.Body = io.NopCloser(bytes.NewReader(c.Body))
					} else {

						response.Body = http.NoBody
					}
					return response, nil
				}),
				APIOptions: []func(*middleware.Stack) error{
					func(s *middleware.Stack) error {
						s.Finalize.Clear()
						s.Initialize.Remove(`OperationInputValidation`)
						return nil
					},
				},
				EndpointResolverV2:       &protocolTestEndpointResolver{serverURL},
				IdempotencyTokenProvider: smithyrand.NewUUIDIdempotencyToken(&smithytesting.ByteLoop{}),
			})
			for i := 0; i < b.N; i++ {
				client.XmlEmptyBlobs(context.Background(), &params)
			}
		})
	}
}
