// Code generated by smithy-go-codegen DO NOT EDIT.

// Package appflow provides the API client, operations, and parameter types for
// Amazon Appflow.
//
// Welcome to the Amazon AppFlow API reference. This guide is for developers who
// need detailed information about the Amazon AppFlow API operations, data types,
// and errors.
//
// Amazon AppFlow is a fully managed integration service that enables you to
// securely transfer data between software as a service (SaaS) applications like
// Salesforce, Marketo, Slack, and ServiceNow, and Amazon Web Services like Amazon
// S3 and Amazon Redshift.
//
// Use the following links to get started on the Amazon AppFlow API:
//
// [Actions]
//   - : An alphabetical list of all Amazon AppFlow API operations.
//
// [Data types]
//   - : An alphabetical list of all Amazon AppFlow data types.
//
// [Common parameters]
//   - : Parameters that all Query operations can use.
//
// [Common errors]
//   - : Client and server errors that all operations can return.
//
// If you're new to Amazon AppFlow, we recommend that you review the [Amazon AppFlow User Guide].
//
// Amazon AppFlow API users can use vendor-specific mechanisms for OAuth, and
// include applicable OAuth attributes (such as auth-code and redirecturi ) with
// the connector-specific ConnectorProfileProperties when creating a new connector
// profile using Amazon AppFlow API operations. For example, Salesforce users can
// refer to the [Authorize Apps with OAuth]documentation.
//
// [Common errors]: https://docs.aws.amazon.com/appflow/1.0/APIReference/CommonErrors.html
// [Actions]: https://docs.aws.amazon.com/appflow/1.0/APIReference/API_Operations.html
// [Authorize Apps with OAuth]: https://help.salesforce.com/articleView?id=remoteaccess_authenticate.htm
// [Data types]: https://docs.aws.amazon.com/appflow/1.0/APIReference/API_Types.html
// [Common parameters]: https://docs.aws.amazon.com/appflow/1.0/APIReference/CommonParameters.html
// [Amazon AppFlow User Guide]: https://docs.aws.amazon.com/appflow/latest/userguide/what-is-appflow.html
package appflow
