// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type CapabilityDirection string

// Enum values for CapabilityDirection
const (
	CapabilityDirectionInbound  CapabilityDirection = "INBOUND"
	CapabilityDirectionOutbound CapabilityDirection = "OUTBOUND"
)

// Values returns all known values for CapabilityDirection. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CapabilityDirection) Values() []CapabilityDirection {
	return []CapabilityDirection{
		"INBOUND",
		"OUTBOUND",
	}
}

type CapabilityType string

// Enum values for CapabilityType
const (
	CapabilityTypeEdi CapabilityType = "edi"
)

// Values returns all known values for CapabilityType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CapabilityType) Values() []CapabilityType {
	return []CapabilityType{
		"edi",
	}
}

type ConversionSourceFormat string

// Enum values for ConversionSourceFormat
const (
	ConversionSourceFormatJson ConversionSourceFormat = "JSON"
	ConversionSourceFormatXml  ConversionSourceFormat = "XML"
)

// Values returns all known values for ConversionSourceFormat. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ConversionSourceFormat) Values() []ConversionSourceFormat {
	return []ConversionSourceFormat{
		"JSON",
		"XML",
	}
}

type ConversionTargetFormat string

// Enum values for ConversionTargetFormat
const (
	ConversionTargetFormatX12 ConversionTargetFormat = "X12"
)

// Values returns all known values for ConversionTargetFormat. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ConversionTargetFormat) Values() []ConversionTargetFormat {
	return []ConversionTargetFormat{
		"X12",
	}
}

type ElementRequirement string

// Enum values for ElementRequirement
const (
	ElementRequirementOptional  ElementRequirement = "OPTIONAL"
	ElementRequirementMandatory ElementRequirement = "MANDATORY"
)

// Values returns all known values for ElementRequirement. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ElementRequirement) Values() []ElementRequirement {
	return []ElementRequirement{
		"OPTIONAL",
		"MANDATORY",
	}
}

type FileFormat string

// Enum values for FileFormat
const (
	FileFormatXml     FileFormat = "XML"
	FileFormatJson    FileFormat = "JSON"
	FileFormatNotUsed FileFormat = "NOT_USED"
)

// Values returns all known values for FileFormat. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (FileFormat) Values() []FileFormat {
	return []FileFormat{
		"XML",
		"JSON",
		"NOT_USED",
	}
}

type FromFormat string

// Enum values for FromFormat
const (
	FromFormatX12 FromFormat = "X12"
)

// Values returns all known values for FromFormat. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (FromFormat) Values() []FromFormat {
	return []FromFormat{
		"X12",
	}
}

type LineTerminator string

// Enum values for LineTerminator
const (
	LineTerminatorCrlf LineTerminator = "CRLF"
	LineTerminatorLf   LineTerminator = "LF"
	LineTerminatorCr   LineTerminator = "CR"
)

// Values returns all known values for LineTerminator. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LineTerminator) Values() []LineTerminator {
	return []LineTerminator{
		"CRLF",
		"LF",
		"CR",
	}
}

type Logging string

// Enum values for Logging
const (
	LoggingEnabled  Logging = "ENABLED"
	LoggingDisabled Logging = "DISABLED"
)

// Values returns all known values for Logging. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (Logging) Values() []Logging {
	return []Logging{
		"ENABLED",
		"DISABLED",
	}
}

type MappingTemplateLanguage string

// Enum values for MappingTemplateLanguage
const (
	MappingTemplateLanguageXslt    MappingTemplateLanguage = "XSLT"
	MappingTemplateLanguageJsonata MappingTemplateLanguage = "JSONATA"
)

// Values returns all known values for MappingTemplateLanguage. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MappingTemplateLanguage) Values() []MappingTemplateLanguage {
	return []MappingTemplateLanguage{
		"XSLT",
		"JSONATA",
	}
}

type MappingType string

// Enum values for MappingType
const (
	MappingTypeJsonata MappingType = "JSONATA"
	MappingTypeXslt    MappingType = "XSLT"
)

// Values returns all known values for MappingType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MappingType) Values() []MappingType {
	return []MappingType{
		"JSONATA",
		"XSLT",
	}
}

type ToFormat string

// Enum values for ToFormat
const (
	ToFormatX12 ToFormat = "X12"
)

// Values returns all known values for ToFormat. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ToFormat) Values() []ToFormat {
	return []ToFormat{
		"X12",
	}
}

type TransformerJobStatus string

// Enum values for TransformerJobStatus
const (
	TransformerJobStatusRunning   TransformerJobStatus = "running"
	TransformerJobStatusSucceeded TransformerJobStatus = "succeeded"
	TransformerJobStatusFailed    TransformerJobStatus = "failed"
)

// Values returns all known values for TransformerJobStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TransformerJobStatus) Values() []TransformerJobStatus {
	return []TransformerJobStatus{
		"running",
		"succeeded",
		"failed",
	}
}

type TransformerStatus string

// Enum values for TransformerStatus
const (
	TransformerStatusActive   TransformerStatus = "active"
	TransformerStatusInactive TransformerStatus = "inactive"
)

// Values returns all known values for TransformerStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TransformerStatus) Values() []TransformerStatus {
	return []TransformerStatus{
		"active",
		"inactive",
	}
}

type WrapFormat string

// Enum values for WrapFormat
const (
	WrapFormatSegment    WrapFormat = "SEGMENT"
	WrapFormatOneLine    WrapFormat = "ONE_LINE"
	WrapFormatLineLength WrapFormat = "LINE_LENGTH"
)

// Values returns all known values for WrapFormat. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (WrapFormat) Values() []WrapFormat {
	return []WrapFormat{
		"SEGMENT",
		"ONE_LINE",
		"LINE_LENGTH",
	}
}

type X12FunctionalAcknowledgment string

// Enum values for X12FunctionalAcknowledgment
const (
	X12FunctionalAcknowledgmentDoNotGenerate                             X12FunctionalAcknowledgment = "DO_NOT_GENERATE"
	X12FunctionalAcknowledgmentGenerateAllSegments                       X12FunctionalAcknowledgment = "GENERATE_ALL_SEGMENTS"
	X12FunctionalAcknowledgmentGenerateWithoutTransactionSetResponseLoop X12FunctionalAcknowledgment = "GENERATE_WITHOUT_TRANSACTION_SET_RESPONSE_LOOP"
)

// Values returns all known values for X12FunctionalAcknowledgment. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (X12FunctionalAcknowledgment) Values() []X12FunctionalAcknowledgment {
	return []X12FunctionalAcknowledgment{
		"DO_NOT_GENERATE",
		"GENERATE_ALL_SEGMENTS",
		"GENERATE_WITHOUT_TRANSACTION_SET_RESPONSE_LOOP",
	}
}

type X12GS05TimeFormat string

// Enum values for X12GS05TimeFormat
const (
	X12GS05TimeFormatHhmm     X12GS05TimeFormat = "HHMM"
	X12GS05TimeFormatHhmmss   X12GS05TimeFormat = "HHMMSS"
	X12GS05TimeFormatHhmmssdd X12GS05TimeFormat = "HHMMSSDD"
)

// Values returns all known values for X12GS05TimeFormat. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (X12GS05TimeFormat) Values() []X12GS05TimeFormat {
	return []X12GS05TimeFormat{
		"HHMM",
		"HHMMSS",
		"HHMMSSDD",
	}
}

type X12SplitBy string

// Enum values for X12SplitBy
const (
	X12SplitByNone        X12SplitBy = "NONE"
	X12SplitByTransaction X12SplitBy = "TRANSACTION"
)

// Values returns all known values for X12SplitBy. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (X12SplitBy) Values() []X12SplitBy {
	return []X12SplitBy{
		"NONE",
		"TRANSACTION",
	}
}

type X12TechnicalAcknowledgment string

// Enum values for X12TechnicalAcknowledgment
const (
	X12TechnicalAcknowledgmentDoNotGenerate       X12TechnicalAcknowledgment = "DO_NOT_GENERATE"
	X12TechnicalAcknowledgmentGenerateAllSegments X12TechnicalAcknowledgment = "GENERATE_ALL_SEGMENTS"
)

// Values returns all known values for X12TechnicalAcknowledgment. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (X12TechnicalAcknowledgment) Values() []X12TechnicalAcknowledgment {
	return []X12TechnicalAcknowledgment{
		"DO_NOT_GENERATE",
		"GENERATE_ALL_SEGMENTS",
	}
}

type X12TransactionSet string

// Enum values for X12TransactionSet
const (
	X12TransactionSetX12100     X12TransactionSet = "X12_100"
	X12TransactionSetX12101     X12TransactionSet = "X12_101"
	X12TransactionSetX12102     X12TransactionSet = "X12_102"
	X12TransactionSetX12103     X12TransactionSet = "X12_103"
	X12TransactionSetX12104     X12TransactionSet = "X12_104"
	X12TransactionSetX12105     X12TransactionSet = "X12_105"
	X12TransactionSetX12106     X12TransactionSet = "X12_106"
	X12TransactionSetX12107     X12TransactionSet = "X12_107"
	X12TransactionSetX12108     X12TransactionSet = "X12_108"
	X12TransactionSetX12109     X12TransactionSet = "X12_109"
	X12TransactionSetX12110     X12TransactionSet = "X12_110"
	X12TransactionSetX12111     X12TransactionSet = "X12_111"
	X12TransactionSetX12112     X12TransactionSet = "X12_112"
	X12TransactionSetX12113     X12TransactionSet = "X12_113"
	X12TransactionSetX12120     X12TransactionSet = "X12_120"
	X12TransactionSetX12121     X12TransactionSet = "X12_121"
	X12TransactionSetX12124     X12TransactionSet = "X12_124"
	X12TransactionSetX12125     X12TransactionSet = "X12_125"
	X12TransactionSetX12126     X12TransactionSet = "X12_126"
	X12TransactionSetX12127     X12TransactionSet = "X12_127"
	X12TransactionSetX12128     X12TransactionSet = "X12_128"
	X12TransactionSetX12129     X12TransactionSet = "X12_129"
	X12TransactionSetX12130     X12TransactionSet = "X12_130"
	X12TransactionSetX12131     X12TransactionSet = "X12_131"
	X12TransactionSetX12132     X12TransactionSet = "X12_132"
	X12TransactionSetX12133     X12TransactionSet = "X12_133"
	X12TransactionSetX12135     X12TransactionSet = "X12_135"
	X12TransactionSetX12138     X12TransactionSet = "X12_138"
	X12TransactionSetX12139     X12TransactionSet = "X12_139"
	X12TransactionSetX12140     X12TransactionSet = "X12_140"
	X12TransactionSetX12141     X12TransactionSet = "X12_141"
	X12TransactionSetX12142     X12TransactionSet = "X12_142"
	X12TransactionSetX12143     X12TransactionSet = "X12_143"
	X12TransactionSetX12144     X12TransactionSet = "X12_144"
	X12TransactionSetX12146     X12TransactionSet = "X12_146"
	X12TransactionSetX12147     X12TransactionSet = "X12_147"
	X12TransactionSetX12148     X12TransactionSet = "X12_148"
	X12TransactionSetX12149     X12TransactionSet = "X12_149"
	X12TransactionSetX12150     X12TransactionSet = "X12_150"
	X12TransactionSetX12151     X12TransactionSet = "X12_151"
	X12TransactionSetX12152     X12TransactionSet = "X12_152"
	X12TransactionSetX12153     X12TransactionSet = "X12_153"
	X12TransactionSetX12154     X12TransactionSet = "X12_154"
	X12TransactionSetX12155     X12TransactionSet = "X12_155"
	X12TransactionSetX12157     X12TransactionSet = "X12_157"
	X12TransactionSetX12158     X12TransactionSet = "X12_158"
	X12TransactionSetX12159     X12TransactionSet = "X12_159"
	X12TransactionSetX12160     X12TransactionSet = "X12_160"
	X12TransactionSetX12161     X12TransactionSet = "X12_161"
	X12TransactionSetX12163     X12TransactionSet = "X12_163"
	X12TransactionSetX12170     X12TransactionSet = "X12_170"
	X12TransactionSetX12175     X12TransactionSet = "X12_175"
	X12TransactionSetX12176     X12TransactionSet = "X12_176"
	X12TransactionSetX12179     X12TransactionSet = "X12_179"
	X12TransactionSetX12180     X12TransactionSet = "X12_180"
	X12TransactionSetX12185     X12TransactionSet = "X12_185"
	X12TransactionSetX12186     X12TransactionSet = "X12_186"
	X12TransactionSetX12187     X12TransactionSet = "X12_187"
	X12TransactionSetX12188     X12TransactionSet = "X12_188"
	X12TransactionSetX12189     X12TransactionSet = "X12_189"
	X12TransactionSetX12190     X12TransactionSet = "X12_190"
	X12TransactionSetX12191     X12TransactionSet = "X12_191"
	X12TransactionSetX12194     X12TransactionSet = "X12_194"
	X12TransactionSetX12195     X12TransactionSet = "X12_195"
	X12TransactionSetX12196     X12TransactionSet = "X12_196"
	X12TransactionSetX12197     X12TransactionSet = "X12_197"
	X12TransactionSetX12198     X12TransactionSet = "X12_198"
	X12TransactionSetX12199     X12TransactionSet = "X12_199"
	X12TransactionSetX12200     X12TransactionSet = "X12_200"
	X12TransactionSetX12201     X12TransactionSet = "X12_201"
	X12TransactionSetX12202     X12TransactionSet = "X12_202"
	X12TransactionSetX12203     X12TransactionSet = "X12_203"
	X12TransactionSetX12204     X12TransactionSet = "X12_204"
	X12TransactionSetX12205     X12TransactionSet = "X12_205"
	X12TransactionSetX12206     X12TransactionSet = "X12_206"
	X12TransactionSetX12210     X12TransactionSet = "X12_210"
	X12TransactionSetX12211     X12TransactionSet = "X12_211"
	X12TransactionSetX12212     X12TransactionSet = "X12_212"
	X12TransactionSetX12213     X12TransactionSet = "X12_213"
	X12TransactionSetX12214     X12TransactionSet = "X12_214"
	X12TransactionSetX12215     X12TransactionSet = "X12_215"
	X12TransactionSetX12216     X12TransactionSet = "X12_216"
	X12TransactionSetX12217     X12TransactionSet = "X12_217"
	X12TransactionSetX12218     X12TransactionSet = "X12_218"
	X12TransactionSetX12219     X12TransactionSet = "X12_219"
	X12TransactionSetX12220     X12TransactionSet = "X12_220"
	X12TransactionSetX12222     X12TransactionSet = "X12_222"
	X12TransactionSetX12223     X12TransactionSet = "X12_223"
	X12TransactionSetX12224     X12TransactionSet = "X12_224"
	X12TransactionSetX12225     X12TransactionSet = "X12_225"
	X12TransactionSetX12227     X12TransactionSet = "X12_227"
	X12TransactionSetX12228     X12TransactionSet = "X12_228"
	X12TransactionSetX12240     X12TransactionSet = "X12_240"
	X12TransactionSetX12242     X12TransactionSet = "X12_242"
	X12TransactionSetX12244     X12TransactionSet = "X12_244"
	X12TransactionSetX12245     X12TransactionSet = "X12_245"
	X12TransactionSetX12248     X12TransactionSet = "X12_248"
	X12TransactionSetX12249     X12TransactionSet = "X12_249"
	X12TransactionSetX12250     X12TransactionSet = "X12_250"
	X12TransactionSetX12251     X12TransactionSet = "X12_251"
	X12TransactionSetX12252     X12TransactionSet = "X12_252"
	X12TransactionSetX12255     X12TransactionSet = "X12_255"
	X12TransactionSetX12256     X12TransactionSet = "X12_256"
	X12TransactionSetX12259     X12TransactionSet = "X12_259"
	X12TransactionSetX12260     X12TransactionSet = "X12_260"
	X12TransactionSetX12261     X12TransactionSet = "X12_261"
	X12TransactionSetX12262     X12TransactionSet = "X12_262"
	X12TransactionSetX12263     X12TransactionSet = "X12_263"
	X12TransactionSetX12264     X12TransactionSet = "X12_264"
	X12TransactionSetX12265     X12TransactionSet = "X12_265"
	X12TransactionSetX12266     X12TransactionSet = "X12_266"
	X12TransactionSetX12267     X12TransactionSet = "X12_267"
	X12TransactionSetX12268     X12TransactionSet = "X12_268"
	X12TransactionSetX12269     X12TransactionSet = "X12_269"
	X12TransactionSetX12270     X12TransactionSet = "X12_270"
	X12TransactionSetX12271     X12TransactionSet = "X12_271"
	X12TransactionSetX12272     X12TransactionSet = "X12_272"
	X12TransactionSetX12273     X12TransactionSet = "X12_273"
	X12TransactionSetX12274     X12TransactionSet = "X12_274"
	X12TransactionSetX12275     X12TransactionSet = "X12_275"
	X12TransactionSetX12276     X12TransactionSet = "X12_276"
	X12TransactionSetX12277     X12TransactionSet = "X12_277"
	X12TransactionSetX12278     X12TransactionSet = "X12_278"
	X12TransactionSetX12280     X12TransactionSet = "X12_280"
	X12TransactionSetX12283     X12TransactionSet = "X12_283"
	X12TransactionSetX12284     X12TransactionSet = "X12_284"
	X12TransactionSetX12285     X12TransactionSet = "X12_285"
	X12TransactionSetX12286     X12TransactionSet = "X12_286"
	X12TransactionSetX12288     X12TransactionSet = "X12_288"
	X12TransactionSetX12290     X12TransactionSet = "X12_290"
	X12TransactionSetX12300     X12TransactionSet = "X12_300"
	X12TransactionSetX12301     X12TransactionSet = "X12_301"
	X12TransactionSetX12303     X12TransactionSet = "X12_303"
	X12TransactionSetX12304     X12TransactionSet = "X12_304"
	X12TransactionSetX12309     X12TransactionSet = "X12_309"
	X12TransactionSetX12310     X12TransactionSet = "X12_310"
	X12TransactionSetX12311     X12TransactionSet = "X12_311"
	X12TransactionSetX12312     X12TransactionSet = "X12_312"
	X12TransactionSetX12313     X12TransactionSet = "X12_313"
	X12TransactionSetX12315     X12TransactionSet = "X12_315"
	X12TransactionSetX12317     X12TransactionSet = "X12_317"
	X12TransactionSetX12319     X12TransactionSet = "X12_319"
	X12TransactionSetX12322     X12TransactionSet = "X12_322"
	X12TransactionSetX12323     X12TransactionSet = "X12_323"
	X12TransactionSetX12324     X12TransactionSet = "X12_324"
	X12TransactionSetX12325     X12TransactionSet = "X12_325"
	X12TransactionSetX12326     X12TransactionSet = "X12_326"
	X12TransactionSetX12350     X12TransactionSet = "X12_350"
	X12TransactionSetX12352     X12TransactionSet = "X12_352"
	X12TransactionSetX12353     X12TransactionSet = "X12_353"
	X12TransactionSetX12354     X12TransactionSet = "X12_354"
	X12TransactionSetX12355     X12TransactionSet = "X12_355"
	X12TransactionSetX12356     X12TransactionSet = "X12_356"
	X12TransactionSetX12357     X12TransactionSet = "X12_357"
	X12TransactionSetX12358     X12TransactionSet = "X12_358"
	X12TransactionSetX12361     X12TransactionSet = "X12_361"
	X12TransactionSetX12362     X12TransactionSet = "X12_362"
	X12TransactionSetX12404     X12TransactionSet = "X12_404"
	X12TransactionSetX12410     X12TransactionSet = "X12_410"
	X12TransactionSetX12412     X12TransactionSet = "X12_412"
	X12TransactionSetX12414     X12TransactionSet = "X12_414"
	X12TransactionSetX12417     X12TransactionSet = "X12_417"
	X12TransactionSetX12418     X12TransactionSet = "X12_418"
	X12TransactionSetX12419     X12TransactionSet = "X12_419"
	X12TransactionSetX12420     X12TransactionSet = "X12_420"
	X12TransactionSetX12421     X12TransactionSet = "X12_421"
	X12TransactionSetX12422     X12TransactionSet = "X12_422"
	X12TransactionSetX12423     X12TransactionSet = "X12_423"
	X12TransactionSetX12424     X12TransactionSet = "X12_424"
	X12TransactionSetX12425     X12TransactionSet = "X12_425"
	X12TransactionSetX12426     X12TransactionSet = "X12_426"
	X12TransactionSetX12429     X12TransactionSet = "X12_429"
	X12TransactionSetX12431     X12TransactionSet = "X12_431"
	X12TransactionSetX12432     X12TransactionSet = "X12_432"
	X12TransactionSetX12433     X12TransactionSet = "X12_433"
	X12TransactionSetX12434     X12TransactionSet = "X12_434"
	X12TransactionSetX12435     X12TransactionSet = "X12_435"
	X12TransactionSetX12436     X12TransactionSet = "X12_436"
	X12TransactionSetX12437     X12TransactionSet = "X12_437"
	X12TransactionSetX12440     X12TransactionSet = "X12_440"
	X12TransactionSetX12451     X12TransactionSet = "X12_451"
	X12TransactionSetX12452     X12TransactionSet = "X12_452"
	X12TransactionSetX12453     X12TransactionSet = "X12_453"
	X12TransactionSetX12455     X12TransactionSet = "X12_455"
	X12TransactionSetX12456     X12TransactionSet = "X12_456"
	X12TransactionSetX12460     X12TransactionSet = "X12_460"
	X12TransactionSetX12463     X12TransactionSet = "X12_463"
	X12TransactionSetX12466     X12TransactionSet = "X12_466"
	X12TransactionSetX12468     X12TransactionSet = "X12_468"
	X12TransactionSetX12470     X12TransactionSet = "X12_470"
	X12TransactionSetX12475     X12TransactionSet = "X12_475"
	X12TransactionSetX12485     X12TransactionSet = "X12_485"
	X12TransactionSetX12486     X12TransactionSet = "X12_486"
	X12TransactionSetX12490     X12TransactionSet = "X12_490"
	X12TransactionSetX12492     X12TransactionSet = "X12_492"
	X12TransactionSetX12494     X12TransactionSet = "X12_494"
	X12TransactionSetX12500     X12TransactionSet = "X12_500"
	X12TransactionSetX12501     X12TransactionSet = "X12_501"
	X12TransactionSetX12503     X12TransactionSet = "X12_503"
	X12TransactionSetX12504     X12TransactionSet = "X12_504"
	X12TransactionSetX12511     X12TransactionSet = "X12_511"
	X12TransactionSetX12517     X12TransactionSet = "X12_517"
	X12TransactionSetX12521     X12TransactionSet = "X12_521"
	X12TransactionSetX12527     X12TransactionSet = "X12_527"
	X12TransactionSetX12536     X12TransactionSet = "X12_536"
	X12TransactionSetX12540     X12TransactionSet = "X12_540"
	X12TransactionSetX12561     X12TransactionSet = "X12_561"
	X12TransactionSetX12567     X12TransactionSet = "X12_567"
	X12TransactionSetX12568     X12TransactionSet = "X12_568"
	X12TransactionSetX12601     X12TransactionSet = "X12_601"
	X12TransactionSetX12602     X12TransactionSet = "X12_602"
	X12TransactionSetX12620     X12TransactionSet = "X12_620"
	X12TransactionSetX12625     X12TransactionSet = "X12_625"
	X12TransactionSetX12650     X12TransactionSet = "X12_650"
	X12TransactionSetX12715     X12TransactionSet = "X12_715"
	X12TransactionSetX12753     X12TransactionSet = "X12_753"
	X12TransactionSetX12754     X12TransactionSet = "X12_754"
	X12TransactionSetX12805     X12TransactionSet = "X12_805"
	X12TransactionSetX12806     X12TransactionSet = "X12_806"
	X12TransactionSetX12810     X12TransactionSet = "X12_810"
	X12TransactionSetX12811     X12TransactionSet = "X12_811"
	X12TransactionSetX12812     X12TransactionSet = "X12_812"
	X12TransactionSetX12813     X12TransactionSet = "X12_813"
	X12TransactionSetX12814     X12TransactionSet = "X12_814"
	X12TransactionSetX12815     X12TransactionSet = "X12_815"
	X12TransactionSetX12816     X12TransactionSet = "X12_816"
	X12TransactionSetX12818     X12TransactionSet = "X12_818"
	X12TransactionSetX12819     X12TransactionSet = "X12_819"
	X12TransactionSetX12820     X12TransactionSet = "X12_820"
	X12TransactionSetX12821     X12TransactionSet = "X12_821"
	X12TransactionSetX12822     X12TransactionSet = "X12_822"
	X12TransactionSetX12823     X12TransactionSet = "X12_823"
	X12TransactionSetX12824     X12TransactionSet = "X12_824"
	X12TransactionSetX12826     X12TransactionSet = "X12_826"
	X12TransactionSetX12827     X12TransactionSet = "X12_827"
	X12TransactionSetX12828     X12TransactionSet = "X12_828"
	X12TransactionSetX12829     X12TransactionSet = "X12_829"
	X12TransactionSetX12830     X12TransactionSet = "X12_830"
	X12TransactionSetX12831     X12TransactionSet = "X12_831"
	X12TransactionSetX12832     X12TransactionSet = "X12_832"
	X12TransactionSetX12833     X12TransactionSet = "X12_833"
	X12TransactionSetX12834     X12TransactionSet = "X12_834"
	X12TransactionSetX12835     X12TransactionSet = "X12_835"
	X12TransactionSetX12836     X12TransactionSet = "X12_836"
	X12TransactionSetX12837     X12TransactionSet = "X12_837"
	X12TransactionSetX12838     X12TransactionSet = "X12_838"
	X12TransactionSetX12839     X12TransactionSet = "X12_839"
	X12TransactionSetX12840     X12TransactionSet = "X12_840"
	X12TransactionSetX12841     X12TransactionSet = "X12_841"
	X12TransactionSetX12842     X12TransactionSet = "X12_842"
	X12TransactionSetX12843     X12TransactionSet = "X12_843"
	X12TransactionSetX12844     X12TransactionSet = "X12_844"
	X12TransactionSetX12845     X12TransactionSet = "X12_845"
	X12TransactionSetX12846     X12TransactionSet = "X12_846"
	X12TransactionSetX12847     X12TransactionSet = "X12_847"
	X12TransactionSetX12848     X12TransactionSet = "X12_848"
	X12TransactionSetX12849     X12TransactionSet = "X12_849"
	X12TransactionSetX12850     X12TransactionSet = "X12_850"
	X12TransactionSetX12851     X12TransactionSet = "X12_851"
	X12TransactionSetX12852     X12TransactionSet = "X12_852"
	X12TransactionSetX12853     X12TransactionSet = "X12_853"
	X12TransactionSetX12854     X12TransactionSet = "X12_854"
	X12TransactionSetX12855     X12TransactionSet = "X12_855"
	X12TransactionSetX12856     X12TransactionSet = "X12_856"
	X12TransactionSetX12857     X12TransactionSet = "X12_857"
	X12TransactionSetX12858     X12TransactionSet = "X12_858"
	X12TransactionSetX12859     X12TransactionSet = "X12_859"
	X12TransactionSetX12860     X12TransactionSet = "X12_860"
	X12TransactionSetX12861     X12TransactionSet = "X12_861"
	X12TransactionSetX12862     X12TransactionSet = "X12_862"
	X12TransactionSetX12863     X12TransactionSet = "X12_863"
	X12TransactionSetX12864     X12TransactionSet = "X12_864"
	X12TransactionSetX12865     X12TransactionSet = "X12_865"
	X12TransactionSetX12866     X12TransactionSet = "X12_866"
	X12TransactionSetX12867     X12TransactionSet = "X12_867"
	X12TransactionSetX12868     X12TransactionSet = "X12_868"
	X12TransactionSetX12869     X12TransactionSet = "X12_869"
	X12TransactionSetX12870     X12TransactionSet = "X12_870"
	X12TransactionSetX12871     X12TransactionSet = "X12_871"
	X12TransactionSetX12872     X12TransactionSet = "X12_872"
	X12TransactionSetX12873     X12TransactionSet = "X12_873"
	X12TransactionSetX12874     X12TransactionSet = "X12_874"
	X12TransactionSetX12875     X12TransactionSet = "X12_875"
	X12TransactionSetX12876     X12TransactionSet = "X12_876"
	X12TransactionSetX12877     X12TransactionSet = "X12_877"
	X12TransactionSetX12878     X12TransactionSet = "X12_878"
	X12TransactionSetX12879     X12TransactionSet = "X12_879"
	X12TransactionSetX12880     X12TransactionSet = "X12_880"
	X12TransactionSetX12881     X12TransactionSet = "X12_881"
	X12TransactionSetX12882     X12TransactionSet = "X12_882"
	X12TransactionSetX12883     X12TransactionSet = "X12_883"
	X12TransactionSetX12884     X12TransactionSet = "X12_884"
	X12TransactionSetX12885     X12TransactionSet = "X12_885"
	X12TransactionSetX12886     X12TransactionSet = "X12_886"
	X12TransactionSetX12887     X12TransactionSet = "X12_887"
	X12TransactionSetX12888     X12TransactionSet = "X12_888"
	X12TransactionSetX12889     X12TransactionSet = "X12_889"
	X12TransactionSetX12891     X12TransactionSet = "X12_891"
	X12TransactionSetX12893     X12TransactionSet = "X12_893"
	X12TransactionSetX12894     X12TransactionSet = "X12_894"
	X12TransactionSetX12895     X12TransactionSet = "X12_895"
	X12TransactionSetX12896     X12TransactionSet = "X12_896"
	X12TransactionSetX12920     X12TransactionSet = "X12_920"
	X12TransactionSetX12924     X12TransactionSet = "X12_924"
	X12TransactionSetX12925     X12TransactionSet = "X12_925"
	X12TransactionSetX12926     X12TransactionSet = "X12_926"
	X12TransactionSetX12928     X12TransactionSet = "X12_928"
	X12TransactionSetX12940     X12TransactionSet = "X12_940"
	X12TransactionSetX12943     X12TransactionSet = "X12_943"
	X12TransactionSetX12944     X12TransactionSet = "X12_944"
	X12TransactionSetX12945     X12TransactionSet = "X12_945"
	X12TransactionSetX12947     X12TransactionSet = "X12_947"
	X12TransactionSetX12980     X12TransactionSet = "X12_980"
	X12TransactionSetX12990     X12TransactionSet = "X12_990"
	X12TransactionSetX12993     X12TransactionSet = "X12_993"
	X12TransactionSetX12996     X12TransactionSet = "X12_996"
	X12TransactionSetX12997     X12TransactionSet = "X12_997"
	X12TransactionSetX12998     X12TransactionSet = "X12_998"
	X12TransactionSetX12999     X12TransactionSet = "X12_999"
	X12TransactionSetX12270X279 X12TransactionSet = "X12_270_X279"
	X12TransactionSetX12271X279 X12TransactionSet = "X12_271_X279"
	X12TransactionSetX12275X210 X12TransactionSet = "X12_275_X210"
	X12TransactionSetX12275X211 X12TransactionSet = "X12_275_X211"
	X12TransactionSetX12276X212 X12TransactionSet = "X12_276_X212"
	X12TransactionSetX12277X212 X12TransactionSet = "X12_277_X212"
	X12TransactionSetX12277X214 X12TransactionSet = "X12_277_X214"
	X12TransactionSetX12277X364 X12TransactionSet = "X12_277_X364"
	X12TransactionSetX12278X217 X12TransactionSet = "X12_278_X217"
	X12TransactionSetX12820X218 X12TransactionSet = "X12_820_X218"
	X12TransactionSetX12820X306 X12TransactionSet = "X12_820_X306"
	X12TransactionSetX12824X186 X12TransactionSet = "X12_824_X186"
	X12TransactionSetX12834X220 X12TransactionSet = "X12_834_X220"
	X12TransactionSetX12834X307 X12TransactionSet = "X12_834_X307"
	X12TransactionSetX12834X318 X12TransactionSet = "X12_834_X318"
	X12TransactionSetX12835X221 X12TransactionSet = "X12_835_X221"
	X12TransactionSetX12837X222 X12TransactionSet = "X12_837_X222"
	X12TransactionSetX12837X223 X12TransactionSet = "X12_837_X223"
	X12TransactionSetX12837X224 X12TransactionSet = "X12_837_X224"
	X12TransactionSetX12837X291 X12TransactionSet = "X12_837_X291"
	X12TransactionSetX12837X292 X12TransactionSet = "X12_837_X292"
	X12TransactionSetX12837X298 X12TransactionSet = "X12_837_X298"
	X12TransactionSetX12999X231 X12TransactionSet = "X12_999_X231"
)

// Values returns all known values for X12TransactionSet. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (X12TransactionSet) Values() []X12TransactionSet {
	return []X12TransactionSet{
		"X12_100",
		"X12_101",
		"X12_102",
		"X12_103",
		"X12_104",
		"X12_105",
		"X12_106",
		"X12_107",
		"X12_108",
		"X12_109",
		"X12_110",
		"X12_111",
		"X12_112",
		"X12_113",
		"X12_120",
		"X12_121",
		"X12_124",
		"X12_125",
		"X12_126",
		"X12_127",
		"X12_128",
		"X12_129",
		"X12_130",
		"X12_131",
		"X12_132",
		"X12_133",
		"X12_135",
		"X12_138",
		"X12_139",
		"X12_140",
		"X12_141",
		"X12_142",
		"X12_143",
		"X12_144",
		"X12_146",
		"X12_147",
		"X12_148",
		"X12_149",
		"X12_150",
		"X12_151",
		"X12_152",
		"X12_153",
		"X12_154",
		"X12_155",
		"X12_157",
		"X12_158",
		"X12_159",
		"X12_160",
		"X12_161",
		"X12_163",
		"X12_170",
		"X12_175",
		"X12_176",
		"X12_179",
		"X12_180",
		"X12_185",
		"X12_186",
		"X12_187",
		"X12_188",
		"X12_189",
		"X12_190",
		"X12_191",
		"X12_194",
		"X12_195",
		"X12_196",
		"X12_197",
		"X12_198",
		"X12_199",
		"X12_200",
		"X12_201",
		"X12_202",
		"X12_203",
		"X12_204",
		"X12_205",
		"X12_206",
		"X12_210",
		"X12_211",
		"X12_212",
		"X12_213",
		"X12_214",
		"X12_215",
		"X12_216",
		"X12_217",
		"X12_218",
		"X12_219",
		"X12_220",
		"X12_222",
		"X12_223",
		"X12_224",
		"X12_225",
		"X12_227",
		"X12_228",
		"X12_240",
		"X12_242",
		"X12_244",
		"X12_245",
		"X12_248",
		"X12_249",
		"X12_250",
		"X12_251",
		"X12_252",
		"X12_255",
		"X12_256",
		"X12_259",
		"X12_260",
		"X12_261",
		"X12_262",
		"X12_263",
		"X12_264",
		"X12_265",
		"X12_266",
		"X12_267",
		"X12_268",
		"X12_269",
		"X12_270",
		"X12_271",
		"X12_272",
		"X12_273",
		"X12_274",
		"X12_275",
		"X12_276",
		"X12_277",
		"X12_278",
		"X12_280",
		"X12_283",
		"X12_284",
		"X12_285",
		"X12_286",
		"X12_288",
		"X12_290",
		"X12_300",
		"X12_301",
		"X12_303",
		"X12_304",
		"X12_309",
		"X12_310",
		"X12_311",
		"X12_312",
		"X12_313",
		"X12_315",
		"X12_317",
		"X12_319",
		"X12_322",
		"X12_323",
		"X12_324",
		"X12_325",
		"X12_326",
		"X12_350",
		"X12_352",
		"X12_353",
		"X12_354",
		"X12_355",
		"X12_356",
		"X12_357",
		"X12_358",
		"X12_361",
		"X12_362",
		"X12_404",
		"X12_410",
		"X12_412",
		"X12_414",
		"X12_417",
		"X12_418",
		"X12_419",
		"X12_420",
		"X12_421",
		"X12_422",
		"X12_423",
		"X12_424",
		"X12_425",
		"X12_426",
		"X12_429",
		"X12_431",
		"X12_432",
		"X12_433",
		"X12_434",
		"X12_435",
		"X12_436",
		"X12_437",
		"X12_440",
		"X12_451",
		"X12_452",
		"X12_453",
		"X12_455",
		"X12_456",
		"X12_460",
		"X12_463",
		"X12_466",
		"X12_468",
		"X12_470",
		"X12_475",
		"X12_485",
		"X12_486",
		"X12_490",
		"X12_492",
		"X12_494",
		"X12_500",
		"X12_501",
		"X12_503",
		"X12_504",
		"X12_511",
		"X12_517",
		"X12_521",
		"X12_527",
		"X12_536",
		"X12_540",
		"X12_561",
		"X12_567",
		"X12_568",
		"X12_601",
		"X12_602",
		"X12_620",
		"X12_625",
		"X12_650",
		"X12_715",
		"X12_753",
		"X12_754",
		"X12_805",
		"X12_806",
		"X12_810",
		"X12_811",
		"X12_812",
		"X12_813",
		"X12_814",
		"X12_815",
		"X12_816",
		"X12_818",
		"X12_819",
		"X12_820",
		"X12_821",
		"X12_822",
		"X12_823",
		"X12_824",
		"X12_826",
		"X12_827",
		"X12_828",
		"X12_829",
		"X12_830",
		"X12_831",
		"X12_832",
		"X12_833",
		"X12_834",
		"X12_835",
		"X12_836",
		"X12_837",
		"X12_838",
		"X12_839",
		"X12_840",
		"X12_841",
		"X12_842",
		"X12_843",
		"X12_844",
		"X12_845",
		"X12_846",
		"X12_847",
		"X12_848",
		"X12_849",
		"X12_850",
		"X12_851",
		"X12_852",
		"X12_853",
		"X12_854",
		"X12_855",
		"X12_856",
		"X12_857",
		"X12_858",
		"X12_859",
		"X12_860",
		"X12_861",
		"X12_862",
		"X12_863",
		"X12_864",
		"X12_865",
		"X12_866",
		"X12_867",
		"X12_868",
		"X12_869",
		"X12_870",
		"X12_871",
		"X12_872",
		"X12_873",
		"X12_874",
		"X12_875",
		"X12_876",
		"X12_877",
		"X12_878",
		"X12_879",
		"X12_880",
		"X12_881",
		"X12_882",
		"X12_883",
		"X12_884",
		"X12_885",
		"X12_886",
		"X12_887",
		"X12_888",
		"X12_889",
		"X12_891",
		"X12_893",
		"X12_894",
		"X12_895",
		"X12_896",
		"X12_920",
		"X12_924",
		"X12_925",
		"X12_926",
		"X12_928",
		"X12_940",
		"X12_943",
		"X12_944",
		"X12_945",
		"X12_947",
		"X12_980",
		"X12_990",
		"X12_993",
		"X12_996",
		"X12_997",
		"X12_998",
		"X12_999",
		"X12_270_X279",
		"X12_271_X279",
		"X12_275_X210",
		"X12_275_X211",
		"X12_276_X212",
		"X12_277_X212",
		"X12_277_X214",
		"X12_277_X364",
		"X12_278_X217",
		"X12_820_X218",
		"X12_820_X306",
		"X12_824_X186",
		"X12_834_X220",
		"X12_834_X307",
		"X12_834_X318",
		"X12_835_X221",
		"X12_837_X222",
		"X12_837_X223",
		"X12_837_X224",
		"X12_837_X291",
		"X12_837_X292",
		"X12_837_X298",
		"X12_999_X231",
	}
}

type X12Version string

// Enum values for X12Version
const (
	X12VersionVersion4010      X12Version = "VERSION_4010"
	X12VersionVersion4030      X12Version = "VERSION_4030"
	X12VersionVersion4050      X12Version = "VERSION_4050"
	X12VersionVersion4060      X12Version = "VERSION_4060"
	X12VersionVersion5010      X12Version = "VERSION_5010"
	X12VersionVersion5010Hipaa X12Version = "VERSION_5010_HIPAA"
)

// Values returns all known values for X12Version. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (X12Version) Values() []X12Version {
	return []X12Version{
		"VERSION_4010",
		"VERSION_4030",
		"VERSION_4050",
		"VERSION_4060",
		"VERSION_5010",
		"VERSION_5010_HIPAA",
	}
}
