// Code generated by smithy-go-codegen DO NOT EDIT.

package amplifybackend

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Provides project-level details for your Amplify UI project.
func (c *Client) GetBackend(ctx context.Context, params *GetBackendInput, optFns ...func(*Options)) (*GetBackendOutput, error) {
	if params == nil {
		params = &GetBackendInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetBackend", params, optFns, c.addOperationGetBackendMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetBackendOutput)
	out.ResultMetadata = metadata
	return out, nil
}

// The request body for GetBackend.
type GetBackendInput struct {

	// The app ID.
	//
	// This member is required.
	AppId *string

	// The name of the backend environment.
	BackendEnvironmentName *string

	noSmithyDocumentSerde
}

type GetBackendOutput struct {

	// A stringified version of the cli.json file for your Amplify project.
	AmplifyFeatureFlags *string

	// A stringified version of the current configs for your Amplify project.
	AmplifyMetaConfig *string

	// The app ID.
	AppId *string

	// The name of the app.
	AppName *string

	// A list of backend environments in an array.
	BackendEnvironmentList []string

	// The name of the backend environment.
	BackendEnvironmentName *string

	// If the request failed, this is the returned error.
	Error *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetBackendMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetBackend{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetBackend{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetBackendValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetBackend"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
