// Code generated by smithy-go-codegen DO NOT EDIT.

package connect

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/connect/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

// Updates the attached files configuration for the specified Connect Customer
// instance and attachment scope.
//
// If no instance-specific configuration exists, this operation creates one.
// Partial updates are supported—only specified fields are updated, while
// unspecified fields retain their current values.
func (c *Client) UpdateAttachedFilesConfiguration(ctx context.Context, params *UpdateAttachedFilesConfigurationInput, optFns ...func(*Options)) (*UpdateAttachedFilesConfigurationOutput, error) {
	if params == nil {
		params = &UpdateAttachedFilesConfigurationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdateAttachedFilesConfiguration", params, optFns, c.addOperationUpdateAttachedFilesConfigurationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdateAttachedFilesConfigurationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type UpdateAttachedFilesConfigurationInput struct {

	// The scope of the attachment. Valid values are EMAIL , CHAT , CASE , and TASK .
	//
	// This member is required.
	AttachmentScope types.AttachmentScope

	// The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon
	// Resource Name (ARN) of the instance.
	//
	// [find the instance ID]: https://docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
	//
	// This member is required.
	InstanceId *string

	// The configuration for allowed file extensions.
	ExtensionConfiguration *types.ExtensionConfiguration

	// The maximum size limit for attached files in bytes. The minimum value is 1 and
	// the maximum value is 104857600 (100 MB).
	MaximumSizeLimitInBytes *int64

	noSmithyDocumentSerde
}

type UpdateAttachedFilesConfigurationOutput struct {

	// The scope of the attachment.
	//
	// This member is required.
	AttachmentScope types.AttachmentScope

	// The identifier of the Connect Customer instance.
	//
	// This member is required.
	InstanceId *string

	// The configuration for allowed file extensions.
	ExtensionConfiguration *types.ExtensionConfiguration

	// The timestamp when the configuration was last modified.
	LastModifiedTime *time.Time

	// The maximum size limit for attached files in bytes.
	MaximumSizeLimitInBytes *int64

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdateAttachedFilesConfigurationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpUpdateAttachedFilesConfiguration{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpUpdateAttachedFilesConfiguration{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpUpdateAttachedFilesConfigurationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdateAttachedFilesConfiguration"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
