// Code generated by smithy-go-codegen DO NOT EDIT.

package comprehendmedical

import (
	"github.com/aws/aws-sdk-go-v2/service/comprehendmedical/types"
	smithy "github.com/aws/smithy-go"
)

func serializeAttributeList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.Attribute) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeComprehendMedicalAsyncJobPropertiesList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.ComprehendMedicalAsyncJobProperties) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeEntityList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.Entity) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeICD10CMAttributeList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.ICD10CMAttribute) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeICD10CMConceptList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.ICD10CMConcept) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeICD10CMEntityList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.ICD10CMEntity) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeICD10CMTraitList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.ICD10CMTrait) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeRxNormAttributeList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.RxNormAttribute) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeRxNormConceptList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.RxNormConcept) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeRxNormEntityList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.RxNormEntity) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeRxNormTraitList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.RxNormTrait) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeSNOMEDCTAttributeList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.SNOMEDCTAttribute) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeSNOMEDCTConceptList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.SNOMEDCTConcept) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeSNOMEDCTEntityList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.SNOMEDCTEntity) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeSNOMEDCTTraitList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.SNOMEDCTTrait) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeTraitList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.Trait) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func serializeUnmappedAttributeList(s smithy.ShapeSerializer, schema *smithy.Schema, v []types.UnmappedAttribute) {
	if v == nil {
		return
	}
	s.WriteList(schema)
	for _, vv := range v {
		s.WriteStruct(schema.ListMember())
		vv.SerializeMembers(s)
		s.CloseStruct()
	}
	s.CloseList()
}

func deserializeAttributeList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.Attribute) error {
	var vv types.Attribute
	return smithy.ReadList(d, s, func() error {
		vv = types.Attribute{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeComprehendMedicalAsyncJobPropertiesList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.ComprehendMedicalAsyncJobProperties) error {
	var vv types.ComprehendMedicalAsyncJobProperties
	return smithy.ReadList(d, s, func() error {
		vv = types.ComprehendMedicalAsyncJobProperties{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeEntityList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.Entity) error {
	var vv types.Entity
	return smithy.ReadList(d, s, func() error {
		vv = types.Entity{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeICD10CMAttributeList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.ICD10CMAttribute) error {
	var vv types.ICD10CMAttribute
	return smithy.ReadList(d, s, func() error {
		vv = types.ICD10CMAttribute{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeICD10CMConceptList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.ICD10CMConcept) error {
	var vv types.ICD10CMConcept
	return smithy.ReadList(d, s, func() error {
		vv = types.ICD10CMConcept{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeICD10CMEntityList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.ICD10CMEntity) error {
	var vv types.ICD10CMEntity
	return smithy.ReadList(d, s, func() error {
		vv = types.ICD10CMEntity{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeICD10CMTraitList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.ICD10CMTrait) error {
	var vv types.ICD10CMTrait
	return smithy.ReadList(d, s, func() error {
		vv = types.ICD10CMTrait{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeRxNormAttributeList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.RxNormAttribute) error {
	var vv types.RxNormAttribute
	return smithy.ReadList(d, s, func() error {
		vv = types.RxNormAttribute{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeRxNormConceptList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.RxNormConcept) error {
	var vv types.RxNormConcept
	return smithy.ReadList(d, s, func() error {
		vv = types.RxNormConcept{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeRxNormEntityList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.RxNormEntity) error {
	var vv types.RxNormEntity
	return smithy.ReadList(d, s, func() error {
		vv = types.RxNormEntity{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeRxNormTraitList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.RxNormTrait) error {
	var vv types.RxNormTrait
	return smithy.ReadList(d, s, func() error {
		vv = types.RxNormTrait{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeSNOMEDCTAttributeList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.SNOMEDCTAttribute) error {
	var vv types.SNOMEDCTAttribute
	return smithy.ReadList(d, s, func() error {
		vv = types.SNOMEDCTAttribute{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeSNOMEDCTConceptList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.SNOMEDCTConcept) error {
	var vv types.SNOMEDCTConcept
	return smithy.ReadList(d, s, func() error {
		vv = types.SNOMEDCTConcept{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeSNOMEDCTEntityList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.SNOMEDCTEntity) error {
	var vv types.SNOMEDCTEntity
	return smithy.ReadList(d, s, func() error {
		vv = types.SNOMEDCTEntity{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeSNOMEDCTTraitList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.SNOMEDCTTrait) error {
	var vv types.SNOMEDCTTrait
	return smithy.ReadList(d, s, func() error {
		vv = types.SNOMEDCTTrait{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeTraitList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.Trait) error {
	var vv types.Trait
	return smithy.ReadList(d, s, func() error {
		vv = types.Trait{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}

func deserializeUnmappedAttributeList(d smithy.ShapeDeserializer, s *smithy.Schema, v *[]types.UnmappedAttribute) error {
	var vv types.UnmappedAttribute
	return smithy.ReadList(d, s, func() error {
		vv = types.UnmappedAttribute{}
		if err := vv.Deserialize(d); err != nil {
			return err
		}

		*v = append(*v, vv)
		return nil
	})
}
