// Code generated by smithy-go-codegen DO NOT EDIT.

package computeoptimizer

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/computeoptimizer/schemas"
	"github.com/aws/aws-sdk-go-v2/service/computeoptimizer/types"
	smithy "github.com/aws/smithy-go"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Returns license recommendations for Amazon EC2 instances that run on a specific
// license.
//
// Compute Optimizer generates recommendations for licenses that meet a specific
// set of requirements. For more information, see the [Supported resources and requirements]in the Compute Optimizer
// User Guide.
//
// [Supported resources and requirements]: https://docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html
func (c *Client) GetLicenseRecommendations(ctx context.Context, params *GetLicenseRecommendationsInput, optFns ...func(*Options)) (*GetLicenseRecommendationsOutput, error) {
	if params == nil {
		params = &GetLicenseRecommendationsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetLicenseRecommendations", params, optFns, c.addOperationGetLicenseRecommendationsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetLicenseRecommendationsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetLicenseRecommendationsInput struct {

	// The ID of the Amazon Web Services account for which to return license
	// recommendations.
	//
	// If your account is the management account of an organization, use this
	// parameter to specify the member account for which you want to return license
	// recommendations.
	//
	// Only one account ID can be specified per request.
	AccountIds []string

	//  An array of objects to specify a filter that returns a more specific list of
	// license recommendations.
	Filters []types.LicenseRecommendationFilter

	//  The maximum number of license recommendations to return with a single request.
	//
	// To retrieve the remaining results, make another request with the returned
	// nextToken value.
	MaxResults *int32

	//  The token to advance to the next page of license recommendations.
	NextToken *string

	//  The ARN that identifies the Amazon EC2 instance.
	//
	// The following is the format of the ARN:
	//
	//     arn:aws:ec2:region:aws_account_id:instance/instance-id
	ResourceArns []string

	noSmithyDocumentSerde
}

func (v *GetLicenseRecommendationsInput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.GetLicenseRecommendationsRequest)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *GetLicenseRecommendationsInput) SerializeMembers(s smithy.ShapeSerializer) {
	serializeAccountIds(s, schemas.GetLicenseRecommendationsRequest_accountIds, v.AccountIds)
	serializeLicenseRecommendationFilters(s, schemas.GetLicenseRecommendationsRequest_filters, v.Filters)
	if v.MaxResults != nil {
		s.WriteInt32(schemas.GetLicenseRecommendationsRequest_maxResults, *v.MaxResults)
	}
	if v.NextToken != nil {
		s.WriteString(schemas.GetLicenseRecommendationsRequest_nextToken, *v.NextToken)
	}
	serializeResourceArns(s, schemas.GetLicenseRecommendationsRequest_resourceArns, v.ResourceArns)
}

type GetLicenseRecommendationsOutput struct {

	//  An array of objects that describe errors of the request.
	Errors []types.GetRecommendationError

	//  An array of objects that describe license recommendations.
	LicenseRecommendations []types.LicenseRecommendation

	//  The token to use to advance to the next page of license recommendations.
	NextToken *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (v *GetLicenseRecommendationsOutput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.GetLicenseRecommendationsResponse)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *GetLicenseRecommendationsOutput) SerializeMembers(s smithy.ShapeSerializer) {
	serializeGetRecommendationErrors(s, schemas.GetLicenseRecommendationsResponse_errors, v.Errors)
	serializeLicenseRecommendations(s, schemas.GetLicenseRecommendationsResponse_licenseRecommendations, v.LicenseRecommendations)
	if v.NextToken != nil {
		s.WriteString(schemas.GetLicenseRecommendationsResponse_nextToken, *v.NextToken)
	}
}
func (v *GetLicenseRecommendationsOutput) Deserialize(d smithy.ShapeDeserializer) error {
	return smithy.ReadStruct(d, schemas.GetLicenseRecommendationsResponse, func(s *smithy.Schema) error {
		switch s {
		case schemas.GetLicenseRecommendationsResponse_errors:
			return deserializeGetRecommendationErrors(d, schemas.GetLicenseRecommendationsResponse_errors, &v.Errors)
		case schemas.GetLicenseRecommendationsResponse_licenseRecommendations:
			return deserializeLicenseRecommendations(d, schemas.GetLicenseRecommendationsResponse_licenseRecommendations, &v.LicenseRecommendations)
		case schemas.GetLicenseRecommendationsResponse_nextToken:
			v.NextToken = new(string)
			return d.ReadString(schemas.GetLicenseRecommendationsResponse_nextToken, v.NextToken)
		}
		return nil
	})
}
func (c *Client) addOperationGetLicenseRecommendationsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	if err := stack.Serialize.Add(&serializeRequestMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.GetLicenseRecommendations, schemas.GetLicenseRecommendationsRequest, schemas.GetLicenseRecommendationsResponse)}, middleware.After); err != nil {
		return err
	}
	if err := stack.Deserialize.Add(&deserializeResponseMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.GetLicenseRecommendations, schemas.GetLicenseRecommendationsRequest, schemas.GetLicenseRecommendationsResponse), output: &GetLicenseRecommendationsOutput{}}, middleware.After); err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addUserAgentFeatureProtocolRPCV2CBOR(stack, options); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetLicenseRecommendations"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
