// Code generated by smithy-go-codegen DO NOT EDIT.

package amplifybackend

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/amplifybackend/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Updates the AWS resources required to access the Amplify Admin UI.
func (c *Client) UpdateBackendConfig(ctx context.Context, params *UpdateBackendConfigInput, optFns ...func(*Options)) (*UpdateBackendConfigOutput, error) {
	if params == nil {
		params = &UpdateBackendConfigInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdateBackendConfig", params, optFns, c.addOperationUpdateBackendConfigMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdateBackendConfigOutput)
	out.ResultMetadata = metadata
	return out, nil
}

// The request body for UpdateBackendConfig.
type UpdateBackendConfigInput struct {

	// The app ID.
	//
	// This member is required.
	AppId *string

	// Describes the Amazon Cognito configuration for Admin UI access.
	LoginAuthConfig *types.LoginAuthConfigReqObj

	noSmithyDocumentSerde
}

type UpdateBackendConfigOutput struct {

	// The app ID.
	AppId *string

	// The app ID for the backend manager.
	BackendManagerAppId *string

	// If the request fails, this error is returned.
	Error *string

	// Describes the Amazon Cognito configurations for the Admin UI auth resource to
	// log in with.
	LoginAuthConfig *types.LoginAuthConfigReqObj

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdateBackendConfigMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpUpdateBackendConfig{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpUpdateBackendConfig{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpUpdateBackendConfigValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdateBackendConfig"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
