// Code generated by smithy-go-codegen DO NOT EDIT.

package athena

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/athena/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Puts a new capacity assignment configuration for a specified capacity
// reservation. If a capacity assignment configuration already exists for the
// capacity reservation, replaces the existing capacity assignment configuration.
func (c *Client) PutCapacityAssignmentConfiguration(ctx context.Context, params *PutCapacityAssignmentConfigurationInput, optFns ...func(*Options)) (*PutCapacityAssignmentConfigurationOutput, error) {
	if params == nil {
		params = &PutCapacityAssignmentConfigurationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "PutCapacityAssignmentConfiguration", params, optFns, c.addOperationPutCapacityAssignmentConfigurationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*PutCapacityAssignmentConfigurationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type PutCapacityAssignmentConfigurationInput struct {

	// The list of assignments for the capacity assignment configuration.
	//
	// This member is required.
	CapacityAssignments []types.CapacityAssignment

	// The name of the capacity reservation to put a capacity assignment configuration
	// for.
	//
	// This member is required.
	CapacityReservationName *string

	noSmithyDocumentSerde
}

type PutCapacityAssignmentConfigurationOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationPutCapacityAssignmentConfigurationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpPutCapacityAssignmentConfiguration{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpPutCapacityAssignmentConfiguration{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpPutCapacityAssignmentConfigurationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "PutCapacityAssignmentConfiguration"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
