// Code generated by smithy-go-codegen DO NOT EDIT.

// Package clouddirectory provides the API client, operations, and parameter types
// for Amazon CloudDirectory.
//
// # Amazon Cloud Directory
//
// Amazon Cloud Directory is a component of the AWS Directory Service that
// simplifies the development and management of cloud-scale web, mobile, and IoT
// applications. This guide describes the Cloud Directory operations that you can
// call programmatically and includes detailed information on data types and
// errors. For information about Cloud Directory features, see [AWS Directory Service]and the [Amazon Cloud Directory Developer Guide].
//
// [Amazon Cloud Directory Developer Guide]: https://docs.aws.amazon.com/clouddirectory/latest/developerguide/what_is_cloud_directory.html
// [AWS Directory Service]: https://aws.amazon.com/directoryservice/
package clouddirectory
