// Code generated by smithy-go-codegen DO NOT EDIT.

package ec2query

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/internal/protocoltest/ec2query/schemas"
	smithy "github.com/aws/smithy-go"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

func (c *Client) DatetimeOffsets(ctx context.Context, params *DatetimeOffsetsInput, optFns ...func(*Options)) (*DatetimeOffsetsOutput, error) {
	if params == nil {
		params = &DatetimeOffsetsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DatetimeOffsets", params, optFns, c.addOperationDatetimeOffsetsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DatetimeOffsetsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DatetimeOffsetsInput struct {
	noSmithyDocumentSerde
}

func (v *DatetimeOffsetsInput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(nil)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *DatetimeOffsetsInput) SerializeMembers(s smithy.ShapeSerializer) {
}
func (v *DatetimeOffsetsInput) Deserialize(d smithy.ShapeDeserializer) error {
	return smithy.ReadStruct(d, nil, func(s *smithy.Schema) error {
		switch s {
		}
		return nil
	})
}

type DatetimeOffsetsOutput struct {
	Datetime *time.Time

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (v *DatetimeOffsetsOutput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.DatetimeOffsetsOutput)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *DatetimeOffsetsOutput) SerializeMembers(s smithy.ShapeSerializer) {
	if v.Datetime != nil {
		s.WriteTime(schemas.DatetimeOffsetsOutput_datetime, *v.Datetime)
	}
}
func (v *DatetimeOffsetsOutput) Deserialize(d smithy.ShapeDeserializer) error {
	return smithy.ReadStruct(d, schemas.DatetimeOffsetsOutput, func(s *smithy.Schema) error {
		switch s {
		case schemas.DatetimeOffsetsOutput_datetime:
			v.Datetime = new(time.Time)
			return d.ReadTime(schemas.DatetimeOffsetsOutput_datetime, v.Datetime)
		}
		return nil
	})
}
func (c *Client) addOperationDatetimeOffsetsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	if err := stack.Serialize.Add(&serializeRequestMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.DatetimeOffsets, nil, schemas.DatetimeOffsetsOutput)}, middleware.After); err != nil {
		return err
	}
	if err := stack.Deserialize.Add(&deserializeResponseMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.DatetimeOffsets, nil, schemas.DatetimeOffsetsOutput), output: &DatetimeOffsetsOutput{}}, middleware.After); err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DatetimeOffsets"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
