// Code generated by smithy-go-codegen DO NOT EDIT.

// Package computeoptimizer provides the API client, operations, and parameter
// types for AWS Compute Optimizer.
//
// Compute Optimizer is a service that analyzes the configuration and utilization
// metrics of your Amazon Web Services compute resources, such as Amazon EC2
// instances, Amazon EC2 Auto Scaling groups, Lambda functions, Amazon EBS volumes,
// and Amazon ECS services on Fargate. It reports whether your resources are
// optimal, and generates optimization recommendations to reduce the cost and
// improve the performance of your workloads. Compute Optimizer also provides
// recent utilization metric data, in addition to projected utilization metric data
// for the recommendations, which you can use to evaluate which recommendation
// provides the best price-performance trade-off. The analysis of your usage
// patterns can help you decide when to move or resize your running resources, and
// still meet your performance and capacity requirements. For more information
// about Compute Optimizer, including the required permissions to use the service,
// see the [Compute Optimizer User Guide].
//
// [Compute Optimizer User Guide]: https://docs.aws.amazon.com/compute-optimizer/latest/ug/
package computeoptimizer
