// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type ActionPoint string

// Enum values for ActionPoint
const (
	ActionPointPreCreateHostedConfigurationVersion ActionPoint = "PRE_CREATE_HOSTED_CONFIGURATION_VERSION"
	ActionPointPreStartDeployment                  ActionPoint = "PRE_START_DEPLOYMENT"
	ActionPointAtDeploymentTick                    ActionPoint = "AT_DEPLOYMENT_TICK"
	ActionPointOnDeploymentStart                   ActionPoint = "ON_DEPLOYMENT_START"
	ActionPointOnDeploymentStep                    ActionPoint = "ON_DEPLOYMENT_STEP"
	ActionPointOnDeploymentBaking                  ActionPoint = "ON_DEPLOYMENT_BAKING"
	ActionPointOnDeploymentComplete                ActionPoint = "ON_DEPLOYMENT_COMPLETE"
	ActionPointOnDeploymentRolledBack              ActionPoint = "ON_DEPLOYMENT_ROLLED_BACK"
)

// Values returns all known values for ActionPoint. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ActionPoint) Values() []ActionPoint {
	return []ActionPoint{
		"PRE_CREATE_HOSTED_CONFIGURATION_VERSION",
		"PRE_START_DEPLOYMENT",
		"AT_DEPLOYMENT_TICK",
		"ON_DEPLOYMENT_START",
		"ON_DEPLOYMENT_STEP",
		"ON_DEPLOYMENT_BAKING",
		"ON_DEPLOYMENT_COMPLETE",
		"ON_DEPLOYMENT_ROLLED_BACK",
	}
}

type BadRequestReason string

// Enum values for BadRequestReason
const (
	BadRequestReasonInvalidConfiguration BadRequestReason = "InvalidConfiguration"
)

// Values returns all known values for BadRequestReason. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BadRequestReason) Values() []BadRequestReason {
	return []BadRequestReason{
		"InvalidConfiguration",
	}
}

type BytesMeasure string

// Enum values for BytesMeasure
const (
	BytesMeasureKilobytes BytesMeasure = "KILOBYTES"
)

// Values returns all known values for BytesMeasure. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BytesMeasure) Values() []BytesMeasure {
	return []BytesMeasure{
		"KILOBYTES",
	}
}

type DeleteType string

// Enum values for DeleteType
const (
	DeleteTypeArchive DeleteType = "ARCHIVE"
	DeleteTypeDestroy DeleteType = "DESTROY"
)

// Values returns all known values for DeleteType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DeleteType) Values() []DeleteType {
	return []DeleteType{
		"ARCHIVE",
		"DESTROY",
	}
}

type DeletionProtectionCheck string

// Enum values for DeletionProtectionCheck
const (
	DeletionProtectionCheckAccountDefault DeletionProtectionCheck = "ACCOUNT_DEFAULT"
	DeletionProtectionCheckApply          DeletionProtectionCheck = "APPLY"
	DeletionProtectionCheckBypass         DeletionProtectionCheck = "BYPASS"
)

// Values returns all known values for DeletionProtectionCheck. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DeletionProtectionCheck) Values() []DeletionProtectionCheck {
	return []DeletionProtectionCheck{
		"ACCOUNT_DEFAULT",
		"APPLY",
		"BYPASS",
	}
}

type DeploymentEventType string

// Enum values for DeploymentEventType
const (
	DeploymentEventTypePercentageUpdated   DeploymentEventType = "PERCENTAGE_UPDATED"
	DeploymentEventTypeRollbackStarted     DeploymentEventType = "ROLLBACK_STARTED"
	DeploymentEventTypeRollbackCompleted   DeploymentEventType = "ROLLBACK_COMPLETED"
	DeploymentEventTypeBakeTimeStarted     DeploymentEventType = "BAKE_TIME_STARTED"
	DeploymentEventTypeDeploymentStarted   DeploymentEventType = "DEPLOYMENT_STARTED"
	DeploymentEventTypeDeploymentCompleted DeploymentEventType = "DEPLOYMENT_COMPLETED"
	DeploymentEventTypeRevertCompleted     DeploymentEventType = "REVERT_COMPLETED"
)

// Values returns all known values for DeploymentEventType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DeploymentEventType) Values() []DeploymentEventType {
	return []DeploymentEventType{
		"PERCENTAGE_UPDATED",
		"ROLLBACK_STARTED",
		"ROLLBACK_COMPLETED",
		"BAKE_TIME_STARTED",
		"DEPLOYMENT_STARTED",
		"DEPLOYMENT_COMPLETED",
		"REVERT_COMPLETED",
	}
}

type DeploymentState string

// Enum values for DeploymentState
const (
	DeploymentStateBaking      DeploymentState = "BAKING"
	DeploymentStateValidating  DeploymentState = "VALIDATING"
	DeploymentStateDeploying   DeploymentState = "DEPLOYING"
	DeploymentStateComplete    DeploymentState = "COMPLETE"
	DeploymentStateRollingBack DeploymentState = "ROLLING_BACK"
	DeploymentStateRolledBack  DeploymentState = "ROLLED_BACK"
	DeploymentStateReverted    DeploymentState = "REVERTED"
)

// Values returns all known values for DeploymentState. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DeploymentState) Values() []DeploymentState {
	return []DeploymentState{
		"BAKING",
		"VALIDATING",
		"DEPLOYING",
		"COMPLETE",
		"ROLLING_BACK",
		"ROLLED_BACK",
		"REVERTED",
	}
}

type DeploymentType string

// Enum values for DeploymentType
const (
	DeploymentTypeUser    DeploymentType = "USER"
	DeploymentTypeManaged DeploymentType = "MANAGED"
)

// Values returns all known values for DeploymentType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DeploymentType) Values() []DeploymentType {
	return []DeploymentType{
		"USER",
		"MANAGED",
	}
}

type EnvironmentState string

// Enum values for EnvironmentState
const (
	EnvironmentStateReadyForDeployment EnvironmentState = "READY_FOR_DEPLOYMENT"
	EnvironmentStateDeploying          EnvironmentState = "DEPLOYING"
	EnvironmentStateRollingBack        EnvironmentState = "ROLLING_BACK"
	EnvironmentStateRolledBack         EnvironmentState = "ROLLED_BACK"
	EnvironmentStateReverted           EnvironmentState = "REVERTED"
)

// Values returns all known values for EnvironmentState. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EnvironmentState) Values() []EnvironmentState {
	return []EnvironmentState{
		"READY_FOR_DEPLOYMENT",
		"DEPLOYING",
		"ROLLING_BACK",
		"ROLLED_BACK",
		"REVERTED",
	}
}

type ExperimentDefinitionStatus string

// Enum values for ExperimentDefinitionStatus
const (
	ExperimentDefinitionStatusActive   ExperimentDefinitionStatus = "ACTIVE"
	ExperimentDefinitionStatusIdle     ExperimentDefinitionStatus = "IDLE"
	ExperimentDefinitionStatusArchived ExperimentDefinitionStatus = "ARCHIVED"
)

// Values returns all known values for ExperimentDefinitionStatus. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExperimentDefinitionStatus) Values() []ExperimentDefinitionStatus {
	return []ExperimentDefinitionStatus{
		"ACTIVE",
		"IDLE",
		"ARCHIVED",
	}
}

type ExperimentRunEventType string

// Enum values for ExperimentRunEventType
const (
	ExperimentRunEventTypeRunStarted       ExperimentRunEventType = "RUN_STARTED"
	ExperimentRunEventTypeExposureUpdated  ExperimentRunEventType = "EXPOSURE_UPDATED"
	ExperimentRunEventTypeOverridesUpdated ExperimentRunEventType = "OVERRIDES_UPDATED"
	ExperimentRunEventTypeRunStopped       ExperimentRunEventType = "RUN_STOPPED"
)

// Values returns all known values for ExperimentRunEventType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExperimentRunEventType) Values() []ExperimentRunEventType {
	return []ExperimentRunEventType{
		"RUN_STARTED",
		"EXPOSURE_UPDATED",
		"OVERRIDES_UPDATED",
		"RUN_STOPPED",
	}
}

type ExperimentRunStatus string

// Enum values for ExperimentRunStatus
const (
	ExperimentRunStatusRunning ExperimentRunStatus = "RUNNING"
	ExperimentRunStatusDone    ExperimentRunStatus = "DONE"
)

// Values returns all known values for ExperimentRunStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExperimentRunStatus) Values() []ExperimentRunStatus {
	return []ExperimentRunStatus{
		"RUNNING",
		"DONE",
	}
}

type GrowthType string

// Enum values for GrowthType
const (
	GrowthTypeLinear      GrowthType = "LINEAR"
	GrowthTypeExponential GrowthType = "EXPONENTIAL"
)

// Values returns all known values for GrowthType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GrowthType) Values() []GrowthType {
	return []GrowthType{
		"LINEAR",
		"EXPONENTIAL",
	}
}

type ReplicateTo string

// Enum values for ReplicateTo
const (
	ReplicateToNone        ReplicateTo = "NONE"
	ReplicateToSsmDocument ReplicateTo = "SSM_DOCUMENT"
)

// Values returns all known values for ReplicateTo. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ReplicateTo) Values() []ReplicateTo {
	return []ReplicateTo{
		"NONE",
		"SSM_DOCUMENT",
	}
}

type TriggeredBy string

// Enum values for TriggeredBy
const (
	TriggeredByUser            TriggeredBy = "USER"
	TriggeredByAppconfig       TriggeredBy = "APPCONFIG"
	TriggeredByCloudwatchAlarm TriggeredBy = "CLOUDWATCH_ALARM"
	TriggeredByInternalError   TriggeredBy = "INTERNAL_ERROR"
)

// Values returns all known values for TriggeredBy. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TriggeredBy) Values() []TriggeredBy {
	return []TriggeredBy{
		"USER",
		"APPCONFIG",
		"CLOUDWATCH_ALARM",
		"INTERNAL_ERROR",
	}
}

type ValidatorType string

// Enum values for ValidatorType
const (
	ValidatorTypeJsonSchema ValidatorType = "JSON_SCHEMA"
	ValidatorTypeLambda     ValidatorType = "LAMBDA"
)

// Values returns all known values for ValidatorType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ValidatorType) Values() []ValidatorType {
	return []ValidatorType{
		"JSON_SCHEMA",
		"LAMBDA",
	}
}
