// Code generated by smithy-go-codegen DO NOT EDIT.

// Package apigateway provides the API client, operations, and parameter types for
// Amazon API Gateway.
//
// # Amazon API Gateway
//
// Amazon API Gateway helps developers deliver robust, secure, and scalable mobile
// and web application back ends. API Gateway allows developers to securely connect
// mobile and web applications to APIs that run on Lambda, Amazon EC2, or other
// publicly addressable web services that are hosted outside of AWS.
package apigateway
