// Code generated by smithy-go-codegen DO NOT EDIT.

package apigateway

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Rejects a domain name access association with a private custom domain name.
//
// To reject a domain name access association with an access association source in
// another AWS account, use this operation. To remove a domain name access
// association with an access association source in your own account, use the
// DeleteDomainNameAccessAssociation operation.
func (c *Client) RejectDomainNameAccessAssociation(ctx context.Context, params *RejectDomainNameAccessAssociationInput, optFns ...func(*Options)) (*RejectDomainNameAccessAssociationOutput, error) {
	if params == nil {
		params = &RejectDomainNameAccessAssociationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "RejectDomainNameAccessAssociation", params, optFns, c.addOperationRejectDomainNameAccessAssociationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*RejectDomainNameAccessAssociationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type RejectDomainNameAccessAssociationInput struct {

	// The ARN of the domain name access association resource.
	//
	// This member is required.
	DomainNameAccessAssociationArn *string

	//  The ARN of the domain name.
	//
	// This member is required.
	DomainNameArn *string

	noSmithyDocumentSerde
}

type RejectDomainNameAccessAssociationOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationRejectDomainNameAccessAssociationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpRejectDomainNameAccessAssociation{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpRejectDomainNameAccessAssociation{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpRejectDomainNameAccessAssociationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "RejectDomainNameAccessAssociation"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addAcceptHeader(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
