// Code generated by smithy-go-codegen DO NOT EDIT.

package bedrockdataautomation

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/bedrockdataautomation/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Gets an existing Amazon Bedrock Data Automation Library
func (c *Client) GetDataAutomationLibrary(ctx context.Context, params *GetDataAutomationLibraryInput, optFns ...func(*Options)) (*GetDataAutomationLibraryOutput, error) {
	if params == nil {
		params = &GetDataAutomationLibraryInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetDataAutomationLibrary", params, optFns, c.addOperationGetDataAutomationLibraryMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetDataAutomationLibraryOutput)
	out.ResultMetadata = metadata
	return out, nil
}

// Get DataAutomationLibrary Request
type GetDataAutomationLibraryInput struct {

	// ARN generated at the server side when a DataAutomationLibrary is created
	//
	// This member is required.
	LibraryArn *string

	noSmithyDocumentSerde
}

// Get DataAutomationLibrary Response
type GetDataAutomationLibraryOutput struct {

	// Contains the information of a DataAutomationLibrary.
	Library *types.DataAutomationLibrary

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetDataAutomationLibraryMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetDataAutomationLibrary{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetDataAutomationLibrary{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetDataAutomationLibraryValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetDataAutomationLibrary"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
