// Code generated by smithy-go-codegen DO NOT EDIT.

package bedrockagentcore

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Deletes a memory record from an AgentCore Memory resource. When you delete a
// memory record, it is permanently removed.
//
// To use this operation, you must have the bedrock-agentcore:DeleteMemoryRecord
// permission.
func (c *Client) DeleteMemoryRecord(ctx context.Context, params *DeleteMemoryRecordInput, optFns ...func(*Options)) (*DeleteMemoryRecordOutput, error) {
	if params == nil {
		params = &DeleteMemoryRecordInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeleteMemoryRecord", params, optFns, c.addOperationDeleteMemoryRecordMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeleteMemoryRecordOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DeleteMemoryRecordInput struct {

	// The identifier of the AgentCore Memory resource from which to delete the memory
	// record.
	//
	// This member is required.
	MemoryId *string

	// The identifier of the memory record to delete.
	//
	// This member is required.
	MemoryRecordId *string

	noSmithyDocumentSerde
}

type DeleteMemoryRecordOutput struct {

	// The identifier of the memory record that was deleted.
	//
	// This member is required.
	MemoryRecordId *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeleteMemoryRecordMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpDeleteMemoryRecord{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpDeleteMemoryRecord{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDeleteMemoryRecordValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeleteMemoryRecord"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
