// Code generated by smithy-go-codegen DO NOT EDIT.

package connect

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/connect/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Get the hours of operations with the effective override applied.
func (c *Client) GetEffectiveHoursOfOperations(ctx context.Context, params *GetEffectiveHoursOfOperationsInput, optFns ...func(*Options)) (*GetEffectiveHoursOfOperationsOutput, error) {
	if params == nil {
		params = &GetEffectiveHoursOfOperationsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetEffectiveHoursOfOperations", params, optFns, c.addOperationGetEffectiveHoursOfOperationsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetEffectiveHoursOfOperationsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetEffectiveHoursOfOperationsInput struct {

	// The date from when the hours of operation are listed.
	//
	// This member is required.
	FromDate *string

	// The identifier for the hours of operation.
	//
	// This member is required.
	HoursOfOperationId *string

	// The identifier of the Connect Customer instance.
	//
	// This member is required.
	InstanceId *string

	// The date until when the hours of operation are listed.
	//
	// This member is required.
	ToDate *string

	noSmithyDocumentSerde
}

type GetEffectiveHoursOfOperationsOutput struct {

	// Information about the effective hours of operations.
	EffectiveHoursOfOperationList []types.EffectiveHoursOfOperations

	// Information about override configurations applied to the base hours of
	// operation to calculate the effective hours.
	//
	// For more information about how override types are applied, see [Build your list of overrides] in the
	// Administrator Guide.
	//
	// [Build your list of overrides]: https://docs.aws.amazon.com/connect/latest/adminguide/hours-of-operation-overrides.html
	EffectiveOverrideHoursList []types.EffectiveOverrideHours

	// The time zone for the hours of operation.
	TimeZone *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetEffectiveHoursOfOperationsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetEffectiveHoursOfOperations{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetEffectiveHoursOfOperations{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetEffectiveHoursOfOperationsValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetEffectiveHoursOfOperations"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
