// Code generated by smithy-go-codegen DO NOT EDIT.

package types

import (
	"fmt"
	"github.com/aws/aws-sdk-go-v2/internal/kitchensinktest/schemas"
	smithy "github.com/aws/smithy-go"
)

type ItemNotFound struct {
	Message *string

	ErrorCodeOverride *string

	noSmithyDocumentSerde
}

func (e *ItemNotFound) Error() string {
	return fmt.Sprintf("%s: %s", e.ErrorCode(), e.ErrorMessage())
}
func (e *ItemNotFound) ErrorMessage() string {
	if e.Message == nil {
		return ""
	}
	return *e.Message
}
func (e *ItemNotFound) ErrorCode() string {
	if e == nil || e.ErrorCodeOverride == nil {
		return "ItemNotFound"
	}
	return *e.ErrorCodeOverride
}
func (e *ItemNotFound) ErrorFault() smithy.ErrorFault { return smithy.FaultClient }
func (v *ItemNotFound) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.ItemNotFound)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *ItemNotFound) SerializeMembers(s smithy.ShapeSerializer) {
}
func (v *ItemNotFound) Deserialize(d smithy.ShapeDeserializer) error {
	return smithy.ReadStruct(d, schemas.ItemNotFound, func(s *smithy.Schema) error {
		switch s {
		}
		return nil
	})
}
