// Code generated by smithy-go-codegen DO NOT EDIT.

// Package bedrockagentcorecontrol provides the API client, operations, and
// parameter types for Amazon Bedrock AgentCore Control.
//
// Welcome to the Amazon Bedrock AgentCore Control plane API reference. Control
// plane actions configure, create, modify, and monitor Amazon Web Services
// resources.
package bedrockagentcorecontrol
