// Code generated by smithy-go-codegen DO NOT EDIT.

package cloudformation

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/cloudformation/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Returns Hook-related information for the change set and a list of changes that
// CloudFormation makes when you run the change set.
func (c *Client) DescribeChangeSetHooks(ctx context.Context, params *DescribeChangeSetHooksInput, optFns ...func(*Options)) (*DescribeChangeSetHooksOutput, error) {
	if params == nil {
		params = &DescribeChangeSetHooksInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DescribeChangeSetHooks", params, optFns, c.addOperationDescribeChangeSetHooksMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DescribeChangeSetHooksOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DescribeChangeSetHooksInput struct {

	// The name or Amazon Resource Name (ARN) of the change set that you want to
	// describe.
	//
	// This member is required.
	ChangeSetName *string

	// If specified, lists only the Hooks related to the specified LogicalResourceId .
	LogicalResourceId *string

	// The token for the next set of items to return. (You received this token from a
	// previous call.)
	NextToken *string

	// If you specified the name of a change set, specify the stack name or stack ID
	// (ARN) of the change set you want to describe.
	StackName *string

	noSmithyDocumentSerde
}

type DescribeChangeSetHooksOutput struct {

	// The change set identifier (stack ID).
	ChangeSetId *string

	// The change set name.
	ChangeSetName *string

	// List of Hook objects.
	Hooks []types.ChangeSetHook

	// Pagination token, null or empty if no more results.
	NextToken *string

	// The stack identifier (stack ID).
	StackId *string

	// The stack name.
	StackName *string

	// Provides the status of the change set Hook.
	Status types.ChangeSetHooksStatus

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDescribeChangeSetHooksMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsquery_serializeOpDescribeChangeSetHooks{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsquery_deserializeOpDescribeChangeSetHooks{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDescribeChangeSetHooksValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DescribeChangeSetHooks"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
