// Code generated by smithy-go-codegen DO NOT EDIT.

package applicationsignals

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/applicationsignals/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Creates or updates the grouping configuration for this account. This operation
// allows you to define custom grouping attributes that determine how services are
// logically grouped based on telemetry attributes, Amazon Web Services tags, or
// predefined mappings. These grouping attributes can then be used to organize and
// filter services in the Application Signals console and APIs.
func (c *Client) PutGroupingConfiguration(ctx context.Context, params *PutGroupingConfigurationInput, optFns ...func(*Options)) (*PutGroupingConfigurationOutput, error) {
	if params == nil {
		params = &PutGroupingConfigurationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "PutGroupingConfiguration", params, optFns, c.addOperationPutGroupingConfigurationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*PutGroupingConfigurationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type PutGroupingConfigurationInput struct {

	// An array of grouping attribute definitions that specify how services should be
	// grouped. Each definition includes a friendly name, source keys to derive the
	// grouping value from, and an optional default value.
	//
	// This member is required.
	GroupingAttributeDefinitions []types.GroupingAttributeDefinition

	noSmithyDocumentSerde
}

type PutGroupingConfigurationOutput struct {

	// A structure containing the updated grouping configuration, including all
	// grouping attribute definitions and the timestamp when it was last updated.
	//
	// This member is required.
	GroupingConfiguration *types.GroupingConfiguration

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationPutGroupingConfigurationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpPutGroupingConfiguration{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpPutGroupingConfiguration{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpPutGroupingConfigurationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "PutGroupingConfiguration"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
