// Code generated by smithy-go-codegen DO NOT EDIT.

package bedrockagentcorecontrol

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/bedrockagentcorecontrol/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

// Sets the customer master key (CMK) for a token vault.
func (c *Client) SetTokenVaultCMK(ctx context.Context, params *SetTokenVaultCMKInput, optFns ...func(*Options)) (*SetTokenVaultCMKOutput, error) {
	if params == nil {
		params = &SetTokenVaultCMKInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "SetTokenVaultCMK", params, optFns, c.addOperationSetTokenVaultCMKMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*SetTokenVaultCMKOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type SetTokenVaultCMKInput struct {

	// The KMS configuration for the token vault, including the key type and KMS key
	// ARN.
	//
	// This member is required.
	KmsConfiguration *types.KmsConfiguration

	// The unique identifier of the token vault to update.
	TokenVaultId *string

	noSmithyDocumentSerde
}

type SetTokenVaultCMKOutput struct {

	// The KMS configuration for the token vault.
	//
	// This member is required.
	KmsConfiguration *types.KmsConfiguration

	// The timestamp when the token vault was last modified.
	//
	// This member is required.
	LastModifiedDate *time.Time

	// The ID of the token vault.
	//
	// This member is required.
	TokenVaultId *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationSetTokenVaultCMKMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpSetTokenVaultCMK{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpSetTokenVaultCMK{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpSetTokenVaultCMKValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "SetTokenVaultCMK"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
