// Code generated by smithy-go-codegen DO NOT EDIT.

// Package apigatewaymanagementapi provides the API client, operations, and
// parameter types for AmazonApiGatewayManagementApi.
//
// The Amazon API Gateway Management API allows you to directly manage runtime
// aspects of your deployed APIs. To use it, you must explicitly set the SDK's
// endpoint to point to the endpoint of your deployed API. The endpoint will be of
// the form https://{api-id}.execute-api.{region}.amazonaws.com/{stage}, or will be
// the endpoint corresponding to your API's custom domain and base path, if
// applicable.
package apigatewaymanagementapi
