// Code generated by smithy-go-codegen DO NOT EDIT.

package apigatewayv2

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/apigatewayv2/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

// Updates a product page of a portal product.
func (c *Client) UpdateProductPage(ctx context.Context, params *UpdateProductPageInput, optFns ...func(*Options)) (*UpdateProductPageOutput, error) {
	if params == nil {
		params = &UpdateProductPageInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdateProductPage", params, optFns, c.addOperationUpdateProductPageMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdateProductPageOutput)
	out.ResultMetadata = metadata
	return out, nil
}

// The request body for the patch operation.
type UpdateProductPageInput struct {

	// The portal product identifier.
	//
	// This member is required.
	PortalProductId *string

	// The portal product identifier.
	//
	// This member is required.
	ProductPageId *string

	// The content of the product page.
	DisplayContent *types.DisplayContent

	noSmithyDocumentSerde
}

type UpdateProductPageOutput struct {

	// The content of the product page.
	DisplayContent *types.DisplayContent

	// The timestamp when the product page was last modified.
	LastModified *time.Time

	// The ARN of the product page.
	ProductPageArn *string

	// The product page identifier.
	ProductPageId *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdateProductPageMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpUpdateProductPage{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpUpdateProductPage{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpUpdateProductPageValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdateProductPage"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
