// Code generated by smithy-go-codegen DO NOT EDIT.

package connect

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/connect/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Submits a contact evaluation in the specified Connect Customer instance.
// Answers included in the request are merged with existing answers for the given
// evaluation. If no answers or notes are passed, the evaluation is submitted with
// the existing answers and notes. You can delete an answer or note by passing an
// empty object ( {} ) to the question identifier.
//
// If a contact evaluation is already in submitted state, this operation will
// trigger a resubmission.
func (c *Client) SubmitContactEvaluation(ctx context.Context, params *SubmitContactEvaluationInput, optFns ...func(*Options)) (*SubmitContactEvaluationOutput, error) {
	if params == nil {
		params = &SubmitContactEvaluationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "SubmitContactEvaluation", params, optFns, c.addOperationSubmitContactEvaluationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*SubmitContactEvaluationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type SubmitContactEvaluationInput struct {

	// A unique identifier for the contact evaluation.
	//
	// This member is required.
	EvaluationId *string

	// The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon
	// Resource Name (ARN) of the instance.
	//
	// [find the instance ID]: https://docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
	//
	// This member is required.
	InstanceId *string

	// A map of question identifiers to answer value.
	Answers map[string]types.EvaluationAnswerInput

	// A map of question identifiers to note value.
	Notes map[string]types.EvaluationNote

	// The ID of the user who submitted the contact evaluation.
	SubmittedBy types.EvaluatorUserUnion

	noSmithyDocumentSerde
}

type SubmitContactEvaluationOutput struct {

	// The Amazon Resource Name (ARN) for the contact evaluation resource.
	//
	// This member is required.
	EvaluationArn *string

	// A unique identifier for the contact evaluation.
	//
	// This member is required.
	EvaluationId *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationSubmitContactEvaluationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpSubmitContactEvaluation{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpSubmitContactEvaluation{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpSubmitContactEvaluationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "SubmitContactEvaluation"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
