// Code generated by smithy-go-codegen DO NOT EDIT.

package chimesdkmessaging

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/chimesdkmessaging/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Gets the membership preferences of an AppInstanceUser or AppInstanceBot for the
// specified channel. A user or a bot must be a member of the channel and own the
// membership in order to retrieve membership preferences. Users or bots in the
// AppInstanceAdmin and channel moderator roles can't retrieve preferences for
// other users or bots. Banned users or bots can't retrieve membership preferences
// for the channel from which they are banned.
//
// The x-amz-chime-bearer request header is mandatory. Use the ARN of the
// AppInstanceUser or AppInstanceBot that makes the API call as the value in the
// header.
func (c *Client) GetChannelMembershipPreferences(ctx context.Context, params *GetChannelMembershipPreferencesInput, optFns ...func(*Options)) (*GetChannelMembershipPreferencesOutput, error) {
	if params == nil {
		params = &GetChannelMembershipPreferencesInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetChannelMembershipPreferences", params, optFns, c.addOperationGetChannelMembershipPreferencesMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetChannelMembershipPreferencesOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetChannelMembershipPreferencesInput struct {

	// The ARN of the channel.
	//
	// This member is required.
	ChannelArn *string

	// The ARN of the AppInstanceUser or AppInstanceBot that makes the API call.
	//
	// This member is required.
	ChimeBearer *string

	// The AppInstanceUserArn of the member retrieving the preferences.
	//
	// This member is required.
	MemberArn *string

	noSmithyDocumentSerde
}

type GetChannelMembershipPreferencesOutput struct {

	// The ARN of the channel.
	ChannelArn *string

	// The details of a user.
	Member *types.Identity

	// The channel membership preferences for an AppInstanceUser .
	Preferences *types.ChannelMembershipPreferences

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetChannelMembershipPreferencesMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetChannelMembershipPreferences{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetChannelMembershipPreferences{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetChannelMembershipPreferencesValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetChannelMembershipPreferences"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
