// Code generated by smithy-go-codegen DO NOT EDIT.

package bedrock

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Deregisters an endpoint for a model from Amazon Bedrock Marketplace. This
// operation removes the endpoint's association with Amazon Bedrock but does not
// delete the underlying Amazon SageMaker endpoint.
func (c *Client) DeregisterMarketplaceModelEndpoint(ctx context.Context, params *DeregisterMarketplaceModelEndpointInput, optFns ...func(*Options)) (*DeregisterMarketplaceModelEndpointOutput, error) {
	if params == nil {
		params = &DeregisterMarketplaceModelEndpointInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeregisterMarketplaceModelEndpoint", params, optFns, c.addOperationDeregisterMarketplaceModelEndpointMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeregisterMarketplaceModelEndpointOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DeregisterMarketplaceModelEndpointInput struct {

	// The Amazon Resource Name (ARN) of the endpoint you want to deregister.
	//
	// This member is required.
	EndpointArn *string

	noSmithyDocumentSerde
}

type DeregisterMarketplaceModelEndpointOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeregisterMarketplaceModelEndpointMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpDeregisterMarketplaceModelEndpoint{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpDeregisterMarketplaceModelEndpoint{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDeregisterMarketplaceModelEndpointValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeregisterMarketplaceModelEndpoint"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
