// Code generated by smithy-go-codegen DO NOT EDIT.

package cleanrooms

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/cleanrooms/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Creates a new collaboration.
func (c *Client) CreateCollaboration(ctx context.Context, params *CreateCollaborationInput, optFns ...func(*Options)) (*CreateCollaborationOutput, error) {
	if params == nil {
		params = &CreateCollaborationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "CreateCollaboration", params, optFns, c.addOperationCreateCollaborationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*CreateCollaborationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type CreateCollaborationInput struct {

	// The display name of the collaboration creator.
	//
	// This member is required.
	CreatorDisplayName *string

	// The abilities granted to the collaboration creator.
	//
	// This member is required.
	CreatorMemberAbilities []types.MemberAbility

	// A list of initial members, not including the creator. This list is immutable.
	//
	// This member is required.
	Members []types.MemberSpecification

	// The display name for a collaboration.
	//
	// This member is required.
	Name *string

	// An indicator as to whether query logging has been enabled or disabled for the
	// collaboration.
	//
	// When ENABLED , Clean Rooms logs details about queries run within this
	// collaboration and those logs can be viewed in Amazon CloudWatch Logs. The
	// default value is DISABLED .
	//
	// This member is required.
	QueryLogStatus types.CollaborationQueryLogStatus

	// The Amazon Web Services Regions where collaboration query results can be
	// stored. When specified, results can only be written to these Regions. This
	// parameter enables you to meet your compliance and data governance requirements,
	// and implement regional data governance policies.
	AllowedResultRegions []types.SupportedS3Region

	//  The analytics engine.
	//
	// After July 16, 2025, the CLEAN_ROOMS_SQL parameter will no longer be available.
	AnalyticsEngine types.AnalyticsEngine

	// The types of change requests that are automatically approved for this
	// collaboration.
	AutoApprovedChangeRequestTypes []types.AutoApprovedChangeType

	// The ML abilities granted to the collaboration creator.
	CreatorMLMemberAbilities *types.MLMemberAbilities

	// The collaboration creator's payment responsibilities set by the collaboration
	// creator.
	//
	// If the collaboration creator hasn't specified anyone as the member paying for
	// query compute costs, then the member who can query is the default payer.
	CreatorPaymentConfiguration *types.PaymentConfiguration

	// The settings for client-side encryption with Cryptographic Computing for Clean
	// Rooms.
	DataEncryptionMetadata *types.DataEncryptionMetadata

	// A description of the collaboration provided by the collaboration owner.
	Description *string

	// An indicator as to whether metrics have been enabled or disabled for the
	// collaboration.
	//
	// When true , collaboration members can opt in to Amazon CloudWatch metrics for
	// their membership queries. The default value is false .
	IsMetricsEnabled *bool

	// Specifies whether job logs are enabled for this collaboration.
	//
	// When ENABLED , Clean Rooms logs details about jobs run within this
	// collaboration; those logs can be viewed in Amazon CloudWatch Logs. The default
	// value is DISABLED .
	JobLogStatus types.CollaborationJobLogStatus

	// An optional label that you can assign to a resource when you create it. Each
	// tag consists of a key and an optional value, both of which you define. When you
	// use tagging, you can also use tag-based access control in IAM policies to
	// control access to this resource.
	Tags map[string]string

	noSmithyDocumentSerde
}

type CreateCollaborationOutput struct {

	// The collaboration.
	//
	// This member is required.
	Collaboration *types.Collaboration

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationCreateCollaborationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpCreateCollaboration{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpCreateCollaboration{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpCreateCollaborationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "CreateCollaboration"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
