// Code generated by smithy-go-codegen DO NOT EDIT.

package appsync

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/appsync/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Lists the API keys for a given API.
//
// API keys are deleted automatically 60 days after they expire. However, they may
// still be included in the response until they have actually been deleted. You can
// safely call DeleteApiKey to manually delete a key before it's automatically
// deleted.
func (c *Client) ListApiKeys(ctx context.Context, params *ListApiKeysInput, optFns ...func(*Options)) (*ListApiKeysOutput, error) {
	if params == nil {
		params = &ListApiKeysInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "ListApiKeys", params, optFns, c.addOperationListApiKeysMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*ListApiKeysOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type ListApiKeysInput struct {

	// The API ID.
	//
	// This member is required.
	ApiId *string

	// The maximum number of results that you want the request to return.
	MaxResults int32

	// An identifier that was returned from the previous call to this operation, which
	// you can use to return the next set of items in the list.
	NextToken *string

	noSmithyDocumentSerde
}

type ListApiKeysOutput struct {

	// The ApiKey objects.
	ApiKeys []types.ApiKey

	// An identifier to pass in the next request to this operation to return the next
	// set of items in the list.
	NextToken *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationListApiKeysMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpListApiKeys{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpListApiKeys{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpListApiKeysValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "ListApiKeys"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

// ListApiKeysPaginatorOptions is the paginator options for ListApiKeys
type ListApiKeysPaginatorOptions struct {
	// The maximum number of results that you want the request to return.
	Limit int32

	// Set to true if pagination should stop if the service returns a pagination token
	// that matches the most recent token provided to the service.
	StopOnDuplicateToken bool
}

// ListApiKeysPaginator is a paginator for ListApiKeys
type ListApiKeysPaginator struct {
	options   ListApiKeysPaginatorOptions
	client    ListApiKeysAPIClient
	params    *ListApiKeysInput
	nextToken *string
	firstPage bool
}

// NewListApiKeysPaginator returns a new ListApiKeysPaginator
func NewListApiKeysPaginator(client ListApiKeysAPIClient, params *ListApiKeysInput, optFns ...func(*ListApiKeysPaginatorOptions)) *ListApiKeysPaginator {
	if params == nil {
		params = &ListApiKeysInput{}
	}

	options := ListApiKeysPaginatorOptions{}
	if params.MaxResults != 0 {
		options.Limit = params.MaxResults
	}

	for _, fn := range optFns {
		fn(&options)
	}

	return &ListApiKeysPaginator{
		options:   options,
		client:    client,
		params:    params,
		firstPage: true,
		nextToken: params.NextToken,
	}
}

// HasMorePages returns a boolean indicating whether more pages are available
func (p *ListApiKeysPaginator) HasMorePages() bool {
	return p.firstPage || (p.nextToken != nil && len(*p.nextToken) != 0)
}

// NextPage retrieves the next ListApiKeys page.
func (p *ListApiKeysPaginator) NextPage(ctx context.Context, optFns ...func(*Options)) (*ListApiKeysOutput, error) {
	if !p.HasMorePages() {
		return nil, fmt.Errorf("no more pages available")
	}

	params := *p.params
	params.NextToken = p.nextToken

	params.MaxResults = p.options.Limit

	optFns = append([]func(*Options){
		addIsPaginatorUserAgent,
	}, optFns...)
	result, err := p.client.ListApiKeys(ctx, &params, optFns...)
	if err != nil {
		return nil, err
	}
	p.firstPage = false

	prevToken := p.nextToken
	p.nextToken = result.NextToken

	if p.options.StopOnDuplicateToken &&
		prevToken != nil &&
		p.nextToken != nil &&
		*prevToken == *p.nextToken {
		p.nextToken = nil
	}

	return result, nil
}

// ListApiKeysAPIClient is a client that implements the ListApiKeys operation.
type ListApiKeysAPIClient interface {
	ListApiKeys(context.Context, *ListApiKeysInput, ...func(*Options)) (*ListApiKeysOutput, error)
}

var _ ListApiKeysAPIClient = (*Client)(nil)
