// Code generated by smithy-go-codegen DO NOT EDIT.

// Package cloudwatchevents provides the API client, operations, and parameter
// types for Amazon CloudWatch Events.
//
// Amazon EventBridge helps you to respond to state changes in your Amazon Web
// Services resources. When your resources change state, they automatically send
// events to an event stream. You can create rules that match selected events in
// the stream and route them to targets to take action. You can also use rules to
// take action on a predetermined schedule. For example, you can configure rules
// to:
//
//   - Automatically invoke an Lambda function to update DNS entries when an event
//     notifies you that Amazon EC2 instance enters the running state.
//
//   - Direct specific API records from CloudTrail to an Amazon Kinesis data
//     stream for detailed analysis of potential security or availability risks.
//
//   - Periodically invoke a built-in target to create a snapshot of an Amazon EBS
//     volume.
//
// For more information about the features of Amazon EventBridge, see the [Amazon EventBridge User Guide].
//
// [Amazon EventBridge User Guide]: https://docs.aws.amazon.com/eventbridge/latest/userguide
package cloudwatchevents
