// Code generated by smithy-go-codegen DO NOT EDIT.

package codecatalyst

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Verifies whether the calling user has a valid Amazon CodeCatalyst login and
// session. If successful, this returns the ID of the user in Amazon CodeCatalyst.
func (c *Client) VerifySession(ctx context.Context, params *VerifySessionInput, optFns ...func(*Options)) (*VerifySessionOutput, error) {
	if params == nil {
		params = &VerifySessionInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "VerifySession", params, optFns, c.addOperationVerifySessionMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*VerifySessionOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type VerifySessionInput struct {
	noSmithyDocumentSerde
}

type VerifySessionOutput struct {

	// The system-generated unique ID of the user in Amazon CodeCatalyst.
	Identity *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationVerifySessionMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpVerifySession{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpVerifySession{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "VerifySession"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
