// Code generated by smithy-go-codegen DO NOT EDIT.

package connect

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/connect/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Associates a set of email addresses with a queue to enable agents to select
// different "From" (system) email addresses when replying to inbound email
// contacts or initiating outbound email contacts. This allows agents to handle
// email contacts across different brands and business units within the same queue.
//
// Important things to know
//
//   - You can associate up to 49 additional email addresses with a single queue,
//     plus 1 default outbound email address, for a total of 50.
//
//   - The email addresses must already exist in the Connect Customer instance
//     before they can be associated with a queue.
//
//   - Agents will be able to select from these associated email addresses when
//     handling email contacts in the queue.
//
//   - For inbound email contacts, agents can select from email addresses
//     associated with the queue where the contact was accepted.
//
//   - For outbound email contacts, agents can select from email addresses
//     associated with their default outbound queue configured in their routing
//     profile.
func (c *Client) AssociateQueueEmailAddresses(ctx context.Context, params *AssociateQueueEmailAddressesInput, optFns ...func(*Options)) (*AssociateQueueEmailAddressesOutput, error) {
	if params == nil {
		params = &AssociateQueueEmailAddressesInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "AssociateQueueEmailAddresses", params, optFns, c.addOperationAssociateQueueEmailAddressesMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*AssociateQueueEmailAddressesOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type AssociateQueueEmailAddressesInput struct {

	// Configuration list containing the email addresses to associate with the queue.
	// Each configuration specifies an email address ID that should be linked to this
	// queue for routing purposes.
	//
	// This member is required.
	EmailAddressesConfig []types.EmailAddressConfig

	// The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon
	// Resource Name (ARN) of the instance.
	//
	// [find the instance ID]: https://docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
	//
	// This member is required.
	InstanceId *string

	// The identifier for the queue.
	//
	// This member is required.
	QueueId *string

	// A unique, case-sensitive identifier that you provide to ensure the idempotency
	// of the request. If not provided, the Amazon Web Services SDK populates this
	// field. For more information about idempotency, see [Making retries safe with idempotent APIs].
	//
	// [Making retries safe with idempotent APIs]: https://aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/
	ClientToken *string

	noSmithyDocumentSerde
}

type AssociateQueueEmailAddressesOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationAssociateQueueEmailAddressesMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpAssociateQueueEmailAddresses{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpAssociateQueueEmailAddresses{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addIdempotencyToken_opAssociateQueueEmailAddressesMiddleware(stack, options); err != nil {
		return err
	}
	if err = addOpAssociateQueueEmailAddressesValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "AssociateQueueEmailAddresses"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

type idempotencyToken_initializeOpAssociateQueueEmailAddresses struct {
	tokenProvider IdempotencyTokenProvider
}

func (*idempotencyToken_initializeOpAssociateQueueEmailAddresses) ID() string {
	return "OperationIdempotencyTokenAutoFill"
}

func (m *idempotencyToken_initializeOpAssociateQueueEmailAddresses) HandleInitialize(ctx context.Context, in middleware.InitializeInput, next middleware.InitializeHandler) (
	out middleware.InitializeOutput, metadata middleware.Metadata, err error,
) {
	if m.tokenProvider == nil {
		return next.HandleInitialize(ctx, in)
	}

	input, ok := in.Parameters.(*AssociateQueueEmailAddressesInput)
	if !ok {
		return out, metadata, fmt.Errorf("expected middleware input to be of type *AssociateQueueEmailAddressesInput ")
	}

	if input.ClientToken == nil {
		t, err := m.tokenProvider.GetIdempotencyToken()
		if err != nil {
			return out, metadata, err
		}
		input.ClientToken = &t
	}
	return next.HandleInitialize(ctx, in)
}
func addIdempotencyToken_opAssociateQueueEmailAddressesMiddleware(stack *middleware.Stack, cfg Options) error {
	return stack.Initialize.Add(&idempotencyToken_initializeOpAssociateQueueEmailAddresses{tokenProvider: cfg.IdempotencyTokenProvider}, middleware.Before)
}
