// Code generated by smithy-go-codegen DO NOT EDIT.

// Package backupgateway provides the API client, operations, and parameter types
// for AWS Backup Gateway.
//
// # Backup gateway
//
// Backup gateway connects Backup to your hypervisor, so you can create, store,
// and restore backups of your virtual machines (VMs) anywhere, whether on-premises
// or in the VMware Cloud (VMC) on Amazon Web Services.
//
// Add on-premises resources by connecting to a hypervisor through a gateway.
// Backup will automatically discover the resources in your hypervisor.
//
// Use Backup to assign virtual or on-premises resources to a backup plan, or run
// on-demand backups. Once you have backed up your resources, you can view them and
// restore them like any resource supported by Backup.
//
// To download the Amazon Web Services software to get started, navigate to the
// Backup console, choose Gateways, then choose Create gateway.
package backupgateway
