// Code generated by smithy-go-codegen DO NOT EDIT.

package ec2query

import (
	"github.com/aws/aws-sdk-go-v2/internal/protocoltest/ec2query/schemas"
	"github.com/aws/aws-sdk-go-v2/internal/protocoltest/ec2query/types"
	smithy "github.com/aws/smithy-go"
)

// TypeRegistry is the type registry for this service.
var TypeRegistry = &smithy.TypeRegistry{
	Entries: map[string]*smithy.TypeRegistryEntry{
		"aws.protocoltests.ec2#ComplexError": {
			Schema: schemas.ComplexError,
			New:    func() any { return &types.ComplexError{} },
		},
		"aws.protocoltests.ec2#InvalidGreeting": {
			Schema: schemas.InvalidGreeting,
			New:    func() any { return &types.InvalidGreeting{} },
		},
	},
}
