// Code generated by smithy-go-codegen DO NOT EDIT.

package schemas

import (
	smithy "github.com/aws/smithy-go"
	smithyprelude "github.com/aws/smithy-go/prelude"
	smithytraits "github.com/aws/smithy-go/traits"
)

var DeleteRecommendationPreferences = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "DeleteRecommendationPreferences",
}, smithy.ShapeTypeOperation, 0)

var DescribeRecommendationExportJobs = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "DescribeRecommendationExportJobs",
}, smithy.ShapeTypeOperation, 0)

var ExportAutoScalingGroupRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportAutoScalingGroupRecommendations",
}, smithy.ShapeTypeOperation, 0)

var ExportEBSVolumeRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportEBSVolumeRecommendations",
}, smithy.ShapeTypeOperation, 0)

var ExportEC2InstanceRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportEC2InstanceRecommendations",
}, smithy.ShapeTypeOperation, 0)

var ExportECSServiceRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportECSServiceRecommendations",
}, smithy.ShapeTypeOperation, 0)

var ExportIdleRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportIdleRecommendations",
}, smithy.ShapeTypeOperation, 0)

var ExportLambdaFunctionRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportLambdaFunctionRecommendations",
}, smithy.ShapeTypeOperation, 0)

var ExportLicenseRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportLicenseRecommendations",
}, smithy.ShapeTypeOperation, 0)

var ExportRDSDatabaseRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportRDSDatabaseRecommendations",
}, smithy.ShapeTypeOperation, 0)

var GetAutoScalingGroupRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetAutoScalingGroupRecommendations",
}, smithy.ShapeTypeOperation, 0)

var GetEBSVolumeRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEBSVolumeRecommendations",
}, smithy.ShapeTypeOperation, 0)

var GetEC2InstanceRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEC2InstanceRecommendations",
}, smithy.ShapeTypeOperation, 0)

var GetEC2RecommendationProjectedMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEC2RecommendationProjectedMetrics",
}, smithy.ShapeTypeOperation, 0)

var GetECSServiceRecommendationProjectedMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetECSServiceRecommendationProjectedMetrics",
}, smithy.ShapeTypeOperation, 0)

var GetECSServiceRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetECSServiceRecommendations",
}, smithy.ShapeTypeOperation, 0)

var GetEffectiveRecommendationPreferences = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEffectiveRecommendationPreferences",
}, smithy.ShapeTypeOperation, 0)

var GetEnrollmentStatus = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEnrollmentStatus",
}, smithy.ShapeTypeOperation, 0)

var GetEnrollmentStatusesForOrganization = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEnrollmentStatusesForOrganization",
}, smithy.ShapeTypeOperation, 0)

var GetIdleRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetIdleRecommendations",
}, smithy.ShapeTypeOperation, 0)

var GetLambdaFunctionRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetLambdaFunctionRecommendations",
}, smithy.ShapeTypeOperation, 0)

var GetLicenseRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetLicenseRecommendations",
}, smithy.ShapeTypeOperation, 0)

var GetRDSDatabaseRecommendationProjectedMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetRDSDatabaseRecommendationProjectedMetrics",
}, smithy.ShapeTypeOperation, 0)

var GetRDSDatabaseRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetRDSDatabaseRecommendations",
}, smithy.ShapeTypeOperation, 0)

var GetRecommendationPreferences = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetRecommendationPreferences",
}, smithy.ShapeTypeOperation, 0)

var GetRecommendationSummaries = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetRecommendationSummaries",
}, smithy.ShapeTypeOperation, 0)

var PutRecommendationPreferences = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "PutRecommendationPreferences",
}, smithy.ShapeTypeOperation, 0)

var UpdateEnrollmentStatus = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "UpdateEnrollmentStatus",
}, smithy.ShapeTypeOperation, 0)

var _ComputeOptimizerService = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ComputeOptimizerService",
}, smithy.ShapeTypeService, 0)

var ComputeOptimizerService = smithy.NewServiceSchema(_ComputeOptimizerService, "2019-11-01")

var AccessDeniedException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AccessDeniedException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 403})
var AccessDeniedException_message *smithy.Schema

var AccountEnrollmentStatus = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AccountEnrollmentStatus",
}, smithy.ShapeTypeStructure, 4)
var AccountEnrollmentStatus_accountId *smithy.Schema

var AccountEnrollmentStatus_status *smithy.Schema

var AccountEnrollmentStatus_statusReason *smithy.Schema

var AccountEnrollmentStatus_lastUpdatedTimestamp *smithy.Schema

var _AccountEnrollmentStatuses = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AccountEnrollmentStatuses",
}, smithy.ShapeTypeList, 1)
var _AccountEnrollmentStatuses_member *smithy.Schema

var _AccountId = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AccountId",
}, smithy.ShapeTypeString, 0)

var _AccountIds = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AccountIds",
}, smithy.ShapeTypeList, 1)
var _AccountIds_member *smithy.Schema

var _AllocatedStorage = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AllocatedStorage",
}, smithy.ShapeTypeInteger, 0)

var AllocationStrategy = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AllocationStrategy",
}, smithy.ShapeTypeEnum, 2)
var AllocationStrategy_PRIORITIZED *smithy.Schema

var AllocationStrategy_LOWEST_PRICE *smithy.Schema

var AsgType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AsgType",
}, smithy.ShapeTypeEnum, 2)
var AsgType_SINGLE_INSTANCE_TYPE *smithy.Schema

var AsgType_MIXED_INSTANCE_TYPE *smithy.Schema

var AutoScalingConfiguration = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AutoScalingConfiguration",
}, smithy.ShapeTypeEnum, 2)
var AutoScalingConfiguration_TARGET_TRACKING_SCALING_CPU *smithy.Schema

var AutoScalingConfiguration_TARGET_TRACKING_SCALING_MEMORY *smithy.Schema

var _AutoScalingGroupArn = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AutoScalingGroupArn",
}, smithy.ShapeTypeString, 0)

var _AutoScalingGroupArns = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AutoScalingGroupArns",
}, smithy.ShapeTypeList, 1)
var _AutoScalingGroupArns_member *smithy.Schema

var AutoScalingGroupConfiguration = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AutoScalingGroupConfiguration",
}, smithy.ShapeTypeStructure, 8)
var AutoScalingGroupConfiguration_desiredCapacity *smithy.Schema

var AutoScalingGroupConfiguration_minSize *smithy.Schema

var AutoScalingGroupConfiguration_maxSize *smithy.Schema

var AutoScalingGroupConfiguration_instanceType *smithy.Schema

var AutoScalingGroupConfiguration_allocationStrategy *smithy.Schema

var AutoScalingGroupConfiguration_estimatedInstanceHourReductionPercentage *smithy.Schema

var AutoScalingGroupConfiguration_type *smithy.Schema

var AutoScalingGroupConfiguration_mixedInstanceTypes *smithy.Schema

var AutoScalingGroupEstimatedMonthlySavings = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AutoScalingGroupEstimatedMonthlySavings",
}, smithy.ShapeTypeStructure, 2)
var AutoScalingGroupEstimatedMonthlySavings_currency *smithy.Schema

var AutoScalingGroupEstimatedMonthlySavings_value *smithy.Schema

var _AutoScalingGroupName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AutoScalingGroupName",
}, smithy.ShapeTypeString, 0)

var AutoScalingGroupRecommendation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AutoScalingGroupRecommendation",
}, smithy.ShapeTypeStructure, 13)
var AutoScalingGroupRecommendation_accountId *smithy.Schema

var AutoScalingGroupRecommendation_autoScalingGroupArn *smithy.Schema

var AutoScalingGroupRecommendation_autoScalingGroupName *smithy.Schema

var AutoScalingGroupRecommendation_finding *smithy.Schema

var AutoScalingGroupRecommendation_utilizationMetrics *smithy.Schema

var AutoScalingGroupRecommendation_lookBackPeriodInDays *smithy.Schema

var AutoScalingGroupRecommendation_currentConfiguration *smithy.Schema

var AutoScalingGroupRecommendation_currentInstanceGpuInfo *smithy.Schema

var AutoScalingGroupRecommendation_recommendationOptions *smithy.Schema

var AutoScalingGroupRecommendation_lastRefreshTimestamp *smithy.Schema

var AutoScalingGroupRecommendation_currentPerformanceRisk *smithy.Schema

var AutoScalingGroupRecommendation_effectiveRecommendationPreferences *smithy.Schema

var AutoScalingGroupRecommendation_inferredWorkloadTypes *smithy.Schema

var AutoScalingGroupRecommendationOption = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AutoScalingGroupRecommendationOption",
}, smithy.ShapeTypeStructure, 8)
var AutoScalingGroupRecommendationOption_configuration *smithy.Schema

var AutoScalingGroupRecommendationOption_instanceGpuInfo *smithy.Schema

var AutoScalingGroupRecommendationOption_projectedUtilizationMetrics *smithy.Schema

var AutoScalingGroupRecommendationOption_performanceRisk *smithy.Schema

var AutoScalingGroupRecommendationOption_rank *smithy.Schema

var AutoScalingGroupRecommendationOption_savingsOpportunity *smithy.Schema

var AutoScalingGroupRecommendationOption_savingsOpportunityAfterDiscounts *smithy.Schema

var AutoScalingGroupRecommendationOption_migrationEffort *smithy.Schema

var _AutoScalingGroupRecommendationOptions = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AutoScalingGroupRecommendationOptions",
}, smithy.ShapeTypeList, 1)
var _AutoScalingGroupRecommendationOptions_member *smithy.Schema

var _AutoScalingGroupRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AutoScalingGroupRecommendations",
}, smithy.ShapeTypeList, 1)
var _AutoScalingGroupRecommendations_member *smithy.Schema

var AutoScalingGroupSavingsOpportunityAfterDiscounts = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "AutoScalingGroupSavingsOpportunityAfterDiscounts",
}, smithy.ShapeTypeStructure, 2)
var AutoScalingGroupSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage *smithy.Schema

var AutoScalingGroupSavingsOpportunityAfterDiscounts_estimatedMonthlySavings *smithy.Schema

var _Code = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Code",
}, smithy.ShapeTypeString, 0)

var ContainerConfiguration = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ContainerConfiguration",
}, smithy.ShapeTypeStructure, 3)
var ContainerConfiguration_containerName *smithy.Schema

var ContainerConfiguration_memorySizeConfiguration *smithy.Schema

var ContainerConfiguration_cpu *smithy.Schema

var _ContainerConfigurations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ContainerConfigurations",
}, smithy.ShapeTypeList, 1)
var _ContainerConfigurations_member *smithy.Schema

var _ContainerName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ContainerName",
}, smithy.ShapeTypeString, 0)

var ContainerRecommendation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ContainerRecommendation",
}, smithy.ShapeTypeStructure, 3)
var ContainerRecommendation_containerName *smithy.Schema

var ContainerRecommendation_memorySizeConfiguration *smithy.Schema

var ContainerRecommendation_cpu *smithy.Schema

var _ContainerRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ContainerRecommendations",
}, smithy.ShapeTypeList, 1)
var _ContainerRecommendations_member *smithy.Schema

var _CpuSize = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "CpuSize",
}, smithy.ShapeTypeInteger, 0)

var CpuVendorArchitecture = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "CpuVendorArchitecture",
}, smithy.ShapeTypeEnum, 2)
var CpuVendorArchitecture_AWS_ARM64 *smithy.Schema

var CpuVendorArchitecture_CURRENT *smithy.Schema

var _CpuVendorArchitectures = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "CpuVendorArchitectures",
}, smithy.ShapeTypeList, 1)
var _CpuVendorArchitectures_member *smithy.Schema

var _CreationTimestamp = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "CreationTimestamp",
}, smithy.ShapeTypeTimestamp, 0)

var Currency = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Currency",
}, smithy.ShapeTypeEnum, 2)
var Currency_USD *smithy.Schema

var Currency_CNY *smithy.Schema

var _CurrentDBInstanceClass = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "CurrentDBInstanceClass",
}, smithy.ShapeTypeString, 0)

var _CurrentInstanceType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "CurrentInstanceType",
}, smithy.ShapeTypeString, 0)

var CurrentPerformanceRisk = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "CurrentPerformanceRisk",
}, smithy.ShapeTypeEnum, 4)
var CurrentPerformanceRisk_VERY_LOW *smithy.Schema

var CurrentPerformanceRisk_LOW *smithy.Schema

var CurrentPerformanceRisk_MEDIUM *smithy.Schema

var CurrentPerformanceRisk_HIGH *smithy.Schema

var CurrentPerformanceRiskRatings = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "CurrentPerformanceRiskRatings",
}, smithy.ShapeTypeStructure, 4)
var CurrentPerformanceRiskRatings_high *smithy.Schema

var CurrentPerformanceRiskRatings_medium *smithy.Schema

var CurrentPerformanceRiskRatings_low *smithy.Schema

var CurrentPerformanceRiskRatings_veryLow *smithy.Schema

var CustomizableMetricHeadroom = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "CustomizableMetricHeadroom",
}, smithy.ShapeTypeEnum, 4)
var CustomizableMetricHeadroom_PERCENT_30 *smithy.Schema

var CustomizableMetricHeadroom_PERCENT_20 *smithy.Schema

var CustomizableMetricHeadroom_PERCENT_10 *smithy.Schema

var CustomizableMetricHeadroom_PERCENT_0 *smithy.Schema

var CustomizableMetricName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "CustomizableMetricName",
}, smithy.ShapeTypeEnum, 2)
var CustomizableMetricName_CPU_UTILIZATION *smithy.Schema

var CustomizableMetricName_MEMORY_UTILIZATION *smithy.Schema

var CustomizableMetricParameters = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "CustomizableMetricParameters",
}, smithy.ShapeTypeStructure, 2)
var CustomizableMetricParameters_threshold *smithy.Schema

var CustomizableMetricParameters_headroom *smithy.Schema

var CustomizableMetricThreshold = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "CustomizableMetricThreshold",
}, smithy.ShapeTypeEnum, 3)
var CustomizableMetricThreshold_P90 *smithy.Schema

var CustomizableMetricThreshold_P95 *smithy.Schema

var CustomizableMetricThreshold_P99_5 *smithy.Schema

var _DBClusterIdentifier = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "DBClusterIdentifier",
}, smithy.ShapeTypeString, 0)

var _DBInstanceClass = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "DBInstanceClass",
}, smithy.ShapeTypeString, 0)

var DBStorageConfiguration = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "DBStorageConfiguration",
}, smithy.ShapeTypeStructure, 5)
var DBStorageConfiguration_storageType *smithy.Schema

var DBStorageConfiguration_allocatedStorage *smithy.Schema

var DBStorageConfiguration_iops *smithy.Schema

var DBStorageConfiguration_maxAllocatedStorage *smithy.Schema

var DBStorageConfiguration_storageThroughput *smithy.Schema

var _DesiredCapacity = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "DesiredCapacity",
}, smithy.ShapeTypeInteger, 0)

var _DestinationBucket = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "DestinationBucket",
}, smithy.ShapeTypeString, 0)

var _DestinationKey = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "DestinationKey",
}, smithy.ShapeTypeString, 0)

var _DestinationKeyPrefix = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "DestinationKeyPrefix",
}, smithy.ShapeTypeString, 0)

var Dimension = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Dimension",
}, smithy.ShapeTypeEnum, 2)
var Dimension_SAVINGS_VALUE *smithy.Schema

var Dimension_SAVINGS_VALUE_AFTER_DISCOUNT *smithy.Schema

var EBSEffectiveRecommendationPreferences = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EBSEffectiveRecommendationPreferences",
}, smithy.ShapeTypeStructure, 2)
var EBSEffectiveRecommendationPreferences_savingsEstimationMode *smithy.Schema

var EBSEffectiveRecommendationPreferences_lookBackPeriod *smithy.Schema

var EBSEstimatedMonthlySavings = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EBSEstimatedMonthlySavings",
}, smithy.ShapeTypeStructure, 2)
var EBSEstimatedMonthlySavings_currency *smithy.Schema

var EBSEstimatedMonthlySavings_value *smithy.Schema

var EBSFilter = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EBSFilter",
}, smithy.ShapeTypeStructure, 2)
var EBSFilter_name *smithy.Schema

var EBSFilter_values *smithy.Schema

var EBSFilterName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EBSFilterName",
}, smithy.ShapeTypeEnum, 1)
var EBSFilterName_FINDING *smithy.Schema

var _EBSFilters = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EBSFilters",
}, smithy.ShapeTypeList, 1)
var _EBSFilters_member *smithy.Schema

var EBSFinding = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EBSFinding",
}, smithy.ShapeTypeEnum, 2)
var EBSFinding_OPTIMIZED *smithy.Schema

var EBSFinding_NOT_OPTIMIZED *smithy.Schema

var EBSMetricName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EBSMetricName",
}, smithy.ShapeTypeEnum, 6)
var EBSMetricName_VOLUME_READ_OPS_PER_SECOND *smithy.Schema

var EBSMetricName_VOLUME_WRITE_OPS_PER_SECOND *smithy.Schema

var EBSMetricName_VOLUME_READ_BYTES_PER_SECOND *smithy.Schema

var EBSMetricName_VOLUME_WRITE_BYTES_PER_SECOND *smithy.Schema

var EBSMetricName_VOLUME_IOPS_EXCEEDED *smithy.Schema

var EBSMetricName_VOLUME_THROUGHPUT_EXCEEDED *smithy.Schema

var EBSSavingsEstimationMode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EBSSavingsEstimationMode",
}, smithy.ShapeTypeStructure, 1)
var EBSSavingsEstimationMode_source *smithy.Schema

var EBSSavingsEstimationModeSource = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EBSSavingsEstimationModeSource",
}, smithy.ShapeTypeEnum, 3)
var EBSSavingsEstimationModeSource_PUBLIC_PRICING *smithy.Schema

var EBSSavingsEstimationModeSource_COST_EXPLORER_RIGHTSIZING *smithy.Schema

var EBSSavingsEstimationModeSource_COST_OPTIMIZATION_HUB *smithy.Schema

var EBSSavingsOpportunityAfterDiscounts = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EBSSavingsOpportunityAfterDiscounts",
}, smithy.ShapeTypeStructure, 2)
var EBSSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage *smithy.Schema

var EBSSavingsOpportunityAfterDiscounts_estimatedMonthlySavings *smithy.Schema

var EBSUtilizationMetric = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EBSUtilizationMetric",
}, smithy.ShapeTypeStructure, 3)
var EBSUtilizationMetric_name *smithy.Schema

var EBSUtilizationMetric_statistic *smithy.Schema

var EBSUtilizationMetric_value *smithy.Schema

var _EBSUtilizationMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EBSUtilizationMetrics",
}, smithy.ShapeTypeList, 1)
var _EBSUtilizationMetrics_member *smithy.Schema

var ECSEffectiveRecommendationPreferences = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSEffectiveRecommendationPreferences",
}, smithy.ShapeTypeStructure, 2)
var ECSEffectiveRecommendationPreferences_savingsEstimationMode *smithy.Schema

var ECSEffectiveRecommendationPreferences_lookBackPeriod *smithy.Schema

var ECSEstimatedMonthlySavings = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSEstimatedMonthlySavings",
}, smithy.ShapeTypeStructure, 2)
var ECSEstimatedMonthlySavings_currency *smithy.Schema

var ECSEstimatedMonthlySavings_value *smithy.Schema

var ECSSavingsEstimationMode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSSavingsEstimationMode",
}, smithy.ShapeTypeStructure, 1)
var ECSSavingsEstimationMode_source *smithy.Schema

var ECSSavingsEstimationModeSource = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSSavingsEstimationModeSource",
}, smithy.ShapeTypeEnum, 3)
var ECSSavingsEstimationModeSource_PUBLIC_PRICING *smithy.Schema

var ECSSavingsEstimationModeSource_COST_EXPLORER_RIGHTSIZING *smithy.Schema

var ECSSavingsEstimationModeSource_COST_OPTIMIZATION_HUB *smithy.Schema

var ECSSavingsOpportunityAfterDiscounts = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSSavingsOpportunityAfterDiscounts",
}, smithy.ShapeTypeStructure, 2)
var ECSSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage *smithy.Schema

var ECSSavingsOpportunityAfterDiscounts_estimatedMonthlySavings *smithy.Schema

var ECSServiceLaunchType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceLaunchType",
}, smithy.ShapeTypeEnum, 2)
var ECSServiceLaunchType_EC2 *smithy.Schema

var ECSServiceLaunchType_FARGATE *smithy.Schema

var ECSServiceMetricName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceMetricName",
}, smithy.ShapeTypeEnum, 2)
var ECSServiceMetricName_CPU *smithy.Schema

var ECSServiceMetricName_MEMORY *smithy.Schema

var ECSServiceMetricStatistic = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceMetricStatistic",
}, smithy.ShapeTypeEnum, 2)
var ECSServiceMetricStatistic_MAXIMUM *smithy.Schema

var ECSServiceMetricStatistic_AVERAGE *smithy.Schema

var ECSServiceProjectedMetric = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceProjectedMetric",
}, smithy.ShapeTypeStructure, 4)
var ECSServiceProjectedMetric_name *smithy.Schema

var ECSServiceProjectedMetric_timestamps *smithy.Schema

var ECSServiceProjectedMetric_upperBoundValues *smithy.Schema

var ECSServiceProjectedMetric_lowerBoundValues *smithy.Schema

var _ECSServiceProjectedMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceProjectedMetrics",
}, smithy.ShapeTypeList, 1)
var _ECSServiceProjectedMetrics_member *smithy.Schema

var ECSServiceProjectedUtilizationMetric = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceProjectedUtilizationMetric",
}, smithy.ShapeTypeStructure, 4)
var ECSServiceProjectedUtilizationMetric_name *smithy.Schema

var ECSServiceProjectedUtilizationMetric_statistic *smithy.Schema

var ECSServiceProjectedUtilizationMetric_lowerBoundValue *smithy.Schema

var ECSServiceProjectedUtilizationMetric_upperBoundValue *smithy.Schema

var _ECSServiceProjectedUtilizationMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceProjectedUtilizationMetrics",
}, smithy.ShapeTypeList, 1)
var _ECSServiceProjectedUtilizationMetrics_member *smithy.Schema

var ECSServiceRecommendation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceRecommendation",
}, smithy.ShapeTypeStructure, 13)
var ECSServiceRecommendation_serviceArn *smithy.Schema

var ECSServiceRecommendation_accountId *smithy.Schema

var ECSServiceRecommendation_currentServiceConfiguration *smithy.Schema

var ECSServiceRecommendation_utilizationMetrics *smithy.Schema

var ECSServiceRecommendation_lookbackPeriodInDays *smithy.Schema

var ECSServiceRecommendation_launchType *smithy.Schema

var ECSServiceRecommendation_lastRefreshTimestamp *smithy.Schema

var ECSServiceRecommendation_finding *smithy.Schema

var ECSServiceRecommendation_findingReasonCodes *smithy.Schema

var ECSServiceRecommendation_serviceRecommendationOptions *smithy.Schema

var ECSServiceRecommendation_currentPerformanceRisk *smithy.Schema

var ECSServiceRecommendation_effectiveRecommendationPreferences *smithy.Schema

var ECSServiceRecommendation_tags *smithy.Schema

var ECSServiceRecommendationFilter = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceRecommendationFilter",
}, smithy.ShapeTypeStructure, 2)
var ECSServiceRecommendationFilter_name *smithy.Schema

var ECSServiceRecommendationFilter_values *smithy.Schema

var ECSServiceRecommendationFilterName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceRecommendationFilterName",
}, smithy.ShapeTypeEnum, 2)
var ECSServiceRecommendationFilterName_FINDING *smithy.Schema

var ECSServiceRecommendationFilterName_FINDING_REASON_CODE *smithy.Schema

var _ECSServiceRecommendationFilters = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceRecommendationFilters",
}, smithy.ShapeTypeList, 1)
var _ECSServiceRecommendationFilters_member *smithy.Schema

var ECSServiceRecommendationFinding = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceRecommendationFinding",
}, smithy.ShapeTypeEnum, 3)
var ECSServiceRecommendationFinding_OPTIMIZED *smithy.Schema

var ECSServiceRecommendationFinding_UNDER_PROVISIONED *smithy.Schema

var ECSServiceRecommendationFinding_OVER_PROVISIONED *smithy.Schema

var ECSServiceRecommendationFindingReasonCode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceRecommendationFindingReasonCode",
}, smithy.ShapeTypeEnum, 4)
var ECSServiceRecommendationFindingReasonCode_MEMORY_OVER_PROVISIONED *smithy.Schema

var ECSServiceRecommendationFindingReasonCode_MEMORY_UNDER_PROVISIONED *smithy.Schema

var ECSServiceRecommendationFindingReasonCode_CPU_OVER_PROVISIONED *smithy.Schema

var ECSServiceRecommendationFindingReasonCode_CPU_UNDER_PROVISIONED *smithy.Schema

var _ECSServiceRecommendationFindingReasonCodes = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceRecommendationFindingReasonCodes",
}, smithy.ShapeTypeList, 1)
var _ECSServiceRecommendationFindingReasonCodes_member *smithy.Schema

var ECSServiceRecommendationOption = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceRecommendationOption",
}, smithy.ShapeTypeStructure, 6)
var ECSServiceRecommendationOption_memory *smithy.Schema

var ECSServiceRecommendationOption_cpu *smithy.Schema

var ECSServiceRecommendationOption_savingsOpportunity *smithy.Schema

var ECSServiceRecommendationOption_savingsOpportunityAfterDiscounts *smithy.Schema

var ECSServiceRecommendationOption_projectedUtilizationMetrics *smithy.Schema

var ECSServiceRecommendationOption_containerRecommendations *smithy.Schema

var _ECSServiceRecommendationOptions = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceRecommendationOptions",
}, smithy.ShapeTypeList, 1)
var _ECSServiceRecommendationOptions_member *smithy.Schema

var _ECSServiceRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceRecommendations",
}, smithy.ShapeTypeList, 1)
var _ECSServiceRecommendations_member *smithy.Schema

var ECSServiceRecommendedOptionProjectedMetric = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceRecommendedOptionProjectedMetric",
}, smithy.ShapeTypeStructure, 3)
var ECSServiceRecommendedOptionProjectedMetric_recommendedCpuUnits *smithy.Schema

var ECSServiceRecommendedOptionProjectedMetric_recommendedMemorySize *smithy.Schema

var ECSServiceRecommendedOptionProjectedMetric_projectedMetrics *smithy.Schema

var _ECSServiceRecommendedOptionProjectedMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceRecommendedOptionProjectedMetrics",
}, smithy.ShapeTypeList, 1)
var _ECSServiceRecommendedOptionProjectedMetrics_member *smithy.Schema

var ECSServiceUtilizationMetric = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceUtilizationMetric",
}, smithy.ShapeTypeStructure, 3)
var ECSServiceUtilizationMetric_name *smithy.Schema

var ECSServiceUtilizationMetric_statistic *smithy.Schema

var ECSServiceUtilizationMetric_value *smithy.Schema

var _ECSServiceUtilizationMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ECSServiceUtilizationMetrics",
}, smithy.ShapeTypeList, 1)
var _ECSServiceUtilizationMetrics_member *smithy.Schema

var EffectivePreferredResource = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EffectivePreferredResource",
}, smithy.ShapeTypeStructure, 4)
var EffectivePreferredResource_name *smithy.Schema

var EffectivePreferredResource_includeList *smithy.Schema

var EffectivePreferredResource_effectiveIncludeList *smithy.Schema

var EffectivePreferredResource_excludeList *smithy.Schema

var _EffectivePreferredResources = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EffectivePreferredResources",
}, smithy.ShapeTypeList, 1)
var _EffectivePreferredResources_member *smithy.Schema

var EffectiveRecommendationPreferences = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EffectiveRecommendationPreferences",
}, smithy.ShapeTypeStructure, 8)
var EffectiveRecommendationPreferences_cpuVendorArchitectures *smithy.Schema

var EffectiveRecommendationPreferences_enhancedInfrastructureMetrics *smithy.Schema

var EffectiveRecommendationPreferences_inferredWorkloadTypes *smithy.Schema

var EffectiveRecommendationPreferences_externalMetricsPreference *smithy.Schema

var EffectiveRecommendationPreferences_lookBackPeriod *smithy.Schema

var EffectiveRecommendationPreferences_utilizationPreferences *smithy.Schema

var EffectiveRecommendationPreferences_preferredResources *smithy.Schema

var EffectiveRecommendationPreferences_savingsEstimationMode *smithy.Schema

var _Engine = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Engine",
}, smithy.ShapeTypeString, 0)

var _EngineVersion = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EngineVersion",
}, smithy.ShapeTypeString, 0)

var EnhancedInfrastructureMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EnhancedInfrastructureMetrics",
}, smithy.ShapeTypeEnum, 2)
var EnhancedInfrastructureMetrics_ACTIVE *smithy.Schema

var EnhancedInfrastructureMetrics_INACTIVE *smithy.Schema

var EnrollmentFilter = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EnrollmentFilter",
}, smithy.ShapeTypeStructure, 2)
var EnrollmentFilter_name *smithy.Schema

var EnrollmentFilter_values *smithy.Schema

var EnrollmentFilterName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EnrollmentFilterName",
}, smithy.ShapeTypeEnum, 1)
var EnrollmentFilterName_STATUS *smithy.Schema

var _EnrollmentFilters = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EnrollmentFilters",
}, smithy.ShapeTypeList, 1)
var _EnrollmentFilters_member *smithy.Schema

var _ErrorMessage = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ErrorMessage",
}, smithy.ShapeTypeString, 0)

var EstimatedMonthlySavings = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "EstimatedMonthlySavings",
}, smithy.ShapeTypeStructure, 2)
var EstimatedMonthlySavings_currency *smithy.Schema

var EstimatedMonthlySavings_value *smithy.Schema

var ExportableAutoScalingGroupField = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableAutoScalingGroupField",
}, smithy.ShapeTypeEnum, 73)
var ExportableAutoScalingGroupField_ACCOUNT_ID *smithy.Schema

var ExportableAutoScalingGroupField_AUTO_SCALING_GROUP_ARN *smithy.Schema

var ExportableAutoScalingGroupField_AUTO_SCALING_GROUP_NAME *smithy.Schema

var ExportableAutoScalingGroupField_FINDING *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_CPU_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_MEMORY_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_EBS_READ_OPS_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_EBS_WRITE_OPS_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_EBS_READ_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_EBS_WRITE_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_DISK_READ_OPS_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_DISK_WRITE_OPS_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_DISK_READ_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_DISK_WRITE_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_NETWORK_IN_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_NETWORK_OUT_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_NETWORK_PACKETS_IN_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_NETWORK_PACKETS_OUT_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_LOOKBACK_PERIOD_IN_DAYS *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_CONFIGURATION_INSTANCE_TYPE *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_CONFIGURATION_DESIRED_CAPACITY *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_CONFIGURATION_MIN_SIZE *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_CONFIGURATION_MAX_SIZE *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_CONFIGURATION_ALLOCATION_STRATEGY *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_CONFIGURATION_MIXED_INSTANCE_TYPES *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_CONFIGURATION_TYPE *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_ON_DEMAND_PRICE *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_STANDARD_ONE_YEAR_NO_UPFRONT_RESERVED_PRICE *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_STANDARD_THREE_YEAR_NO_UPFRONT_RESERVED_PRICE *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_VCPUS *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_MEMORY *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_STORAGE *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_NETWORK *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_INSTANCE_TYPE *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_DESIRED_CAPACITY *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_MIN_SIZE *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_MAX_SIZE *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_ESTIMATED_INSTANCE_HOUR_REDUCTION_PERCENTAGE *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_ALLOCATION_STRATEGY *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_MIXED_INSTANCE_TYPES *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_TYPE *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_CPU_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_MEMORY_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_PERFORMANCE_RISK *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_ON_DEMAND_PRICE *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_STANDARD_ONE_YEAR_NO_UPFRONT_RESERVED_PRICE *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_STANDARD_THREE_YEAR_NO_UPFRONT_RESERVED_PRICE *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_VCPUS *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_MEMORY *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_STORAGE *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_NETWORK *smithy.Schema

var ExportableAutoScalingGroupField_LAST_REFRESH_TIMESTAMP *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_PERFORMANCE_RISK *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE *smithy.Schema

var ExportableAutoScalingGroupField_EFFECTIVE_RECOMMENDATION_PREFERENCES_CPU_VENDOR_ARCHITECTURES *smithy.Schema

var ExportableAutoScalingGroupField_EFFECTIVE_RECOMMENDATION_PREFERENCES_ENHANCED_INFRASTRUCTURE_METRICS *smithy.Schema

var ExportableAutoScalingGroupField_EFFECTIVE_RECOMMENDATION_PREFERENCES_INFERRED_WORKLOAD_TYPES *smithy.Schema

var ExportableAutoScalingGroupField_EFFECTIVE_RECOMMENDATION_PREFERENCES_PREFERRED_RESOURCES *smithy.Schema

var ExportableAutoScalingGroupField_EFFECTIVE_RECOMMENDATION_PREFERENCES_LOOKBACK_PERIOD *smithy.Schema

var ExportableAutoScalingGroupField_INFERRED_WORKLOAD_TYPES *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_MIGRATION_EFFORT *smithy.Schema

var ExportableAutoScalingGroupField_CURRENT_INSTANCE_GPU_INFO *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_INSTANCE_GPU_INFO *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_GPU_PERCENTAGE_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_UTILIZATION_METRICS_GPU_MEMORY_PERCENTAGE_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_GPU_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_GPU_MEMORY_MAXIMUM *smithy.Schema

var ExportableAutoScalingGroupField_EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS *smithy.Schema

var ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS *smithy.Schema

var _ExportableAutoScalingGroupFields = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableAutoScalingGroupFields",
}, smithy.ShapeTypeList, 1)
var _ExportableAutoScalingGroupFields_member *smithy.Schema

var ExportableECSServiceField = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableECSServiceField",
}, smithy.ShapeTypeEnum, 29)
var ExportableECSServiceField_ACCOUNT_ID *smithy.Schema

var ExportableECSServiceField_SERVICE_ARN *smithy.Schema

var ExportableECSServiceField_LOOKBACK_PERIOD_IN_DAYS *smithy.Schema

var ExportableECSServiceField_LAST_REFRESH_TIMESTAMP *smithy.Schema

var ExportableECSServiceField_LAUNCH_TYPE *smithy.Schema

var ExportableECSServiceField_CURRENT_PERFORMANCE_RISK *smithy.Schema

var ExportableECSServiceField_CURRENT_SERVICE_CONFIGURATION_MEMORY *smithy.Schema

var ExportableECSServiceField_CURRENT_SERVICE_CONFIGURATION_CPU *smithy.Schema

var ExportableECSServiceField_CURRENT_SERVICE_CONFIGURATION_TASK_DEFINITION_ARN *smithy.Schema

var ExportableECSServiceField_CURRENT_SERVICE_CONFIGURATION_AUTO_SCALING_CONFIGURATION *smithy.Schema

var ExportableECSServiceField_CURRENT_SERVICE_CONTAINER_CONFIGURATIONS *smithy.Schema

var ExportableECSServiceField_UTILIZATION_METRICS_CPU_MAXIMUM *smithy.Schema

var ExportableECSServiceField_UTILIZATION_METRICS_MEMORY_MAXIMUM *smithy.Schema

var ExportableECSServiceField_FINDING *smithy.Schema

var ExportableECSServiceField_FINDING_REASON_CODES *smithy.Schema

var ExportableECSServiceField_RECOMMENDATION_OPTIONS_MEMORY *smithy.Schema

var ExportableECSServiceField_RECOMMENDATION_OPTIONS_CPU *smithy.Schema

var ExportableECSServiceField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE *smithy.Schema

var ExportableECSServiceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY *smithy.Schema

var ExportableECSServiceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE *smithy.Schema

var ExportableECSServiceField_RECOMMENDATION_OPTIONS_CONTAINER_RECOMMENDATIONS *smithy.Schema

var ExportableECSServiceField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_CPU_MAXIMUM *smithy.Schema

var ExportableECSServiceField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_MEMORY_MAXIMUM *smithy.Schema

var ExportableECSServiceField_TAGS *smithy.Schema

var ExportableECSServiceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE *smithy.Schema

var ExportableECSServiceField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE *smithy.Schema

var ExportableECSServiceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS *smithy.Schema

var ExportableECSServiceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS *smithy.Schema

var ExportableECSServiceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_LOOKBACK_PERIOD *smithy.Schema

var _ExportableECSServiceFields = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableECSServiceFields",
}, smithy.ShapeTypeList, 1)
var _ExportableECSServiceFields_member *smithy.Schema

var ExportableIdleField = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableIdleField",
}, smithy.ShapeTypeEnum, 39)
var ExportableIdleField_ACCOUNT_ID *smithy.Schema

var ExportableIdleField_RESOURCE_ARN *smithy.Schema

var ExportableIdleField_RESOURCE_ID *smithy.Schema

var ExportableIdleField_RESOURCE_TYPE *smithy.Schema

var ExportableIdleField_LAST_REFRESH_TIMESTAMP *smithy.Schema

var ExportableIdleField_LOOKBACK_PERIOD_IN_DAYS *smithy.Schema

var ExportableIdleField_SAVINGS_OPPORTUNITY *smithy.Schema

var ExportableIdleField_SAVINGS_OPPORTUNITY_AFTER_DISCOUNT *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_CPU_MAXIMUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_MEMORY_MAXIMUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_NETWORK_OUT_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_NETWORK_IN_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_DATABASE_CONNECTIONS_MAXIMUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_EBS_VOLUME_READ_IOPS_MAXIMUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_EBS_VOLUME_WRITE_IOPS_MAXIMUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_VOLUME_READ_OPS_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_VOLUME_WRITE_OPS_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_ACTIVE_CONNECTION_COUNT_MAXIMUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_PACKETS_IN_FROM_SOURCE_MAXIMUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_PACKETS_IN_FROM_DESTINATION_MAXIMUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_CONSUMED_READ_CAPACITY_UNITS_SUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_CONSUMED_WRITE_CAPACITY_UNITS_SUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_NEW_CONNECTIONS_SUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_ENGINE_CPU_UTILIZATION_MAXIMUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_CACHE_HITS_SUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_CACHE_MISSES_SUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_KEYSPACE_HITS_SUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_KEYSPACE_MISSES_SUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_IS_IDLE_MINIMUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_USER_CONNECTED_SUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_INVOCATIONS_SUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_GET_TYPE_CMDS_SUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_SET_TYPE_CMDS_SUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_ELASTI_CACHE_PROCESSING_UNITS_SUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_CURR_CONNECTIONS_SUM *smithy.Schema

var ExportableIdleField_UTILIZATION_METRICS_DATABASE_CONNECTIONS_SUM *smithy.Schema

var ExportableIdleField_FINDING *smithy.Schema

var ExportableIdleField_FINDING_DESCRIPTION *smithy.Schema

var ExportableIdleField_TAGS *smithy.Schema

var _ExportableIdleFields = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableIdleFields",
}, smithy.ShapeTypeList, 1)
var _ExportableIdleFields_member *smithy.Schema

var ExportableInstanceField = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableInstanceField",
}, smithy.ShapeTypeEnum, 71)
var ExportableInstanceField_ACCOUNT_ID *smithy.Schema

var ExportableInstanceField_INSTANCE_ARN *smithy.Schema

var ExportableInstanceField_INSTANCE_NAME *smithy.Schema

var ExportableInstanceField_FINDING *smithy.Schema

var ExportableInstanceField_Finding_Reason_Codes *smithy.Schema

var ExportableInstanceField_LOOKBACK_PERIOD_IN_DAYS *smithy.Schema

var ExportableInstanceField_CURRENT_INSTANCE_TYPE *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_CPU_MAXIMUM *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_MEMORY_MAXIMUM *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_EBS_READ_OPS_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_EBS_WRITE_OPS_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_EBS_READ_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_EBS_WRITE_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_DISK_READ_OPS_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_DISK_WRITE_OPS_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_DISK_READ_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_DISK_WRITE_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_NETWORK_IN_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_NETWORK_OUT_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_NETWORK_PACKETS_IN_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_NETWORK_PACKETS_OUT_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableInstanceField_CURRENT_ON_DEMAND_PRICE *smithy.Schema

var ExportableInstanceField_CURRENT_STANDARD_ONE_YEAR_NO_UPFRONT_RESERVED_PRICE *smithy.Schema

var ExportableInstanceField_CURRENT_STANDARD_THREE_YEAR_NO_UPFRONT_RESERVED_PRICE *smithy.Schema

var ExportableInstanceField_CURRENT_VCPUS *smithy.Schema

var ExportableInstanceField_CURRENT_MEMORY *smithy.Schema

var ExportableInstanceField_CURRENT_STORAGE *smithy.Schema

var ExportableInstanceField_CURRENT_NETWORK *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_INSTANCE_TYPE *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_CPU_MAXIMUM *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_MEMORY_MAXIMUM *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_PLATFORM_DIFFERENCES *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_PERFORMANCE_RISK *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_VCPUS *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_MEMORY *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_STORAGE *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_NETWORK *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_ON_DEMAND_PRICE *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_STANDARD_ONE_YEAR_NO_UPFRONT_RESERVED_PRICE *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_STANDARD_THREE_YEAR_NO_UPFRONT_RESERVED_PRICE *smithy.Schema

var ExportableInstanceField_RECOMMENDATIONS_SOURCES_RECOMMENDATION_SOURCE_ARN *smithy.Schema

var ExportableInstanceField_RECOMMENDATIONS_SOURCES_RECOMMENDATION_SOURCE_TYPE *smithy.Schema

var ExportableInstanceField_LAST_REFRESH_TIMESTAMP *smithy.Schema

var ExportableInstanceField_CURRENT_PERFORMANCE_RISK *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE *smithy.Schema

var ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_CPU_VENDOR_ARCHITECTURES *smithy.Schema

var ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_ENHANCED_INFRASTRUCTURE_METRICS *smithy.Schema

var ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_INFERRED_WORKLOAD_TYPES *smithy.Schema

var ExportableInstanceField_INFERRED_WORKLOAD_TYPES *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_MIGRATION_EFFORT *smithy.Schema

var ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_EXTERNAL_METRICS_SOURCE *smithy.Schema

var ExportableInstanceField_TAGS *smithy.Schema

var ExportableInstanceField_INSTANCE_STATE *smithy.Schema

var ExportableInstanceField_EXTERNAL_METRIC_STATUS_CODE *smithy.Schema

var ExportableInstanceField_EXTERNAL_METRIC_STATUS_REASON *smithy.Schema

var ExportableInstanceField_CURRENT_INSTANCE_GPU_INFO *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_INSTANCE_GPU_INFO *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_GPU_PERCENTAGE_MAXIMUM *smithy.Schema

var ExportableInstanceField_UTILIZATION_METRICS_GPU_MEMORY_PERCENTAGE_MAXIMUM *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_GPU_PERCENTAGE_MAXIMUM *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_GPU_MEMORY_PERCENTAGE_MAXIMUM *smithy.Schema

var ExportableInstanceField_IDLE *smithy.Schema

var ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_PREFERRED_RESOURCES *smithy.Schema

var ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_LOOKBACK_PERIOD *smithy.Schema

var ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_UTILIZATION_PREFERENCES *smithy.Schema

var ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS *smithy.Schema

var ExportableInstanceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS *smithy.Schema

var _ExportableInstanceFields = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableInstanceFields",
}, smithy.ShapeTypeList, 1)
var _ExportableInstanceFields_member *smithy.Schema

var ExportableLambdaFunctionField = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableLambdaFunctionField",
}, smithy.ShapeTypeEnum, 31)
var ExportableLambdaFunctionField_ACCOUNT_ID *smithy.Schema

var ExportableLambdaFunctionField_FUNCTION_ARN *smithy.Schema

var ExportableLambdaFunctionField_FUNCTION_VERSION *smithy.Schema

var ExportableLambdaFunctionField_FINDING *smithy.Schema

var ExportableLambdaFunctionField_FINDING_REASON_CODES *smithy.Schema

var ExportableLambdaFunctionField_NUMBER_OF_INVOCATIONS *smithy.Schema

var ExportableLambdaFunctionField_UTILIZATION_METRICS_DURATION_MAXIMUM *smithy.Schema

var ExportableLambdaFunctionField_UTILIZATION_METRICS_DURATION_AVERAGE *smithy.Schema

var ExportableLambdaFunctionField_UTILIZATION_METRICS_MEMORY_MAXIMUM *smithy.Schema

var ExportableLambdaFunctionField_UTILIZATION_METRICS_MEMORY_AVERAGE *smithy.Schema

var ExportableLambdaFunctionField_LOOKBACK_PERIOD_IN_DAYS *smithy.Schema

var ExportableLambdaFunctionField_CURRENT_CONFIGURATION_MEMORY_SIZE *smithy.Schema

var ExportableLambdaFunctionField_CURRENT_CONFIGURATION_TIMEOUT *smithy.Schema

var ExportableLambdaFunctionField_CURRENT_COST_TOTAL *smithy.Schema

var ExportableLambdaFunctionField_CURRENT_COST_AVERAGE *smithy.Schema

var ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_CONFIGURATION_MEMORY_SIZE *smithy.Schema

var ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_COST_LOW *smithy.Schema

var ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_COST_HIGH *smithy.Schema

var ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_DURATION_LOWER_BOUND *smithy.Schema

var ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_DURATION_UPPER_BOUND *smithy.Schema

var ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_DURATION_EXPECTED *smithy.Schema

var ExportableLambdaFunctionField_LAST_REFRESH_TIMESTAMP *smithy.Schema

var ExportableLambdaFunctionField_CURRENT_PERFORMANCE_RISK *smithy.Schema

var ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE *smithy.Schema

var ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY *smithy.Schema

var ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE *smithy.Schema

var ExportableLambdaFunctionField_TAGS *smithy.Schema

var ExportableLambdaFunctionField_EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE *smithy.Schema

var ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE *smithy.Schema

var ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS *smithy.Schema

var ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS *smithy.Schema

var _ExportableLambdaFunctionFields = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableLambdaFunctionFields",
}, smithy.ShapeTypeList, 1)
var _ExportableLambdaFunctionFields_member *smithy.Schema

var ExportableLicenseField = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableLicenseField",
}, smithy.ShapeTypeEnum, 21)
var ExportableLicenseField_ACCOUNT_ID *smithy.Schema

var ExportableLicenseField_RESOURCE_ARN *smithy.Schema

var ExportableLicenseField_LOOKBACK_PERIOD_IN_DAYS *smithy.Schema

var ExportableLicenseField_LAST_REFRESH_TIMESTAMP *smithy.Schema

var ExportableLicenseField_LICENSE_FINDING *smithy.Schema

var ExportableLicenseField_LICENSE_FINDING_REASON_CODES *smithy.Schema

var ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_NUMBER_OF_CORES *smithy.Schema

var ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_INSTANCE_TYPE *smithy.Schema

var ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_OPERATING_SYSTEM *smithy.Schema

var ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_LICENSE_NAME *smithy.Schema

var ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_LICENSE_EDITION *smithy.Schema

var ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_LICENSE_MODEL *smithy.Schema

var ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_LICENSE_VERSION *smithy.Schema

var ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_METRICS_SOURCE *smithy.Schema

var ExportableLicenseField_RECOMMENDATION_OPTIONS_OPERATING_SYSTEM *smithy.Schema

var ExportableLicenseField_RECOMMENDATION_OPTIONS_LICENSE_EDITION *smithy.Schema

var ExportableLicenseField_RECOMMENDATION_OPTIONS_LICENSE_MODEL *smithy.Schema

var ExportableLicenseField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE *smithy.Schema

var ExportableLicenseField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY *smithy.Schema

var ExportableLicenseField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE *smithy.Schema

var ExportableLicenseField_TAGS *smithy.Schema

var _ExportableLicenseFields = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableLicenseFields",
}, smithy.ShapeTypeList, 1)
var _ExportableLicenseFields_member *smithy.Schema

var ExportableRDSDBField = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableRDSDBField",
}, smithy.ShapeTypeEnum, 82)
var ExportableRDSDBField_RESOURCE_ARN *smithy.Schema

var ExportableRDSDBField_ACCOUNT_ID *smithy.Schema

var ExportableRDSDBField_ENGINE *smithy.Schema

var ExportableRDSDBField_ENGINE_VERSION *smithy.Schema

var ExportableRDSDBField_IDLE *smithy.Schema

var ExportableRDSDBField_MULTI_AZ_DB_INSTANCE *smithy.Schema

var ExportableRDSDBField_CLUSTER_WRITER *smithy.Schema

var ExportableRDSDBField_CURRENT_DB_INSTANCE_CLASS *smithy.Schema

var ExportableRDSDBField_CURRENT_STORAGE_CONFIGURATION_STORAGE_TYPE *smithy.Schema

var ExportableRDSDBField_CURRENT_STORAGE_CONFIGURATION_ALLOCATED_STORAGE *smithy.Schema

var ExportableRDSDBField_CURRENT_STORAGE_CONFIGURATION_MAX_ALLOCATED_STORAGE *smithy.Schema

var ExportableRDSDBField_CURRENT_STORAGE_CONFIGURATION_IOPS *smithy.Schema

var ExportableRDSDBField_CURRENT_STORAGE_CONFIGURATION_STORAGE_THROUGHPUT *smithy.Schema

var ExportableRDSDBField_CURRENT_STORAGE_ESTIMATED_MONTHLY_VOLUME_IOPS_COST_VARIATION *smithy.Schema

var ExportableRDSDBField_CURRENT_INSTANCE_ON_DEMAND_HOURLY_PRICE *smithy.Schema

var ExportableRDSDBField_CURRENT_STORAGE_ON_DEMAND_MONTHLY_PRICE *smithy.Schema

var ExportableRDSDBField_LOOKBACK_PERIOD_IN_DAYS *smithy.Schema

var ExportableRDSDBField_CURRENT_STORAGE_ESTIMATED_CLUSTER_INSTANCE_ON_DEMAND_MONTHLY_COST *smithy.Schema

var ExportableRDSDBField_CURRENT_STORAGE_ESTIMATED_CLUSTER_STORAGE_ON_DEMAND_MONTHLY_COST *smithy.Schema

var ExportableRDSDBField_CURRENT_STORAGE_ESTIMATED_CLUSTER_STORAGE_IO_ON_DEMAND_MONTHLY_COST *smithy.Schema

var ExportableRDSDBField_CURRENT_INSTANCE_PERFORMANCE_RISK *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_CPU_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_MEMORY_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_EBS_VOLUME_STORAGE_SPACE_UTILIZATION_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_NETWORK_RECEIVE_THROUGHPUT_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_NETWORK_TRANSMIT_THROUGHPUT_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_EBS_VOLUME_READ_IOPS_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_EBS_VOLUME_WRITE_IOPS_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_EBS_VOLUME_READ_THROUGHPUT_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_EBS_VOLUME_WRITE_THROUGHPUT_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_DATABASE_CONNECTIONS_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_STORAGE_NETWORK_RECEIVE_THROUGHPUT_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_STORAGE_NETWORK_TRANSMIT_THROUGHPUT_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_AURORA_MEMORY_HEALTH_STATE_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_AURORA_MEMORY_NUM_DECLINED_SQL_TOTAL_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_AURORA_MEMORY_NUM_KILL_CONN_TOTAL_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_AURORA_MEMORY_NUM_KILL_QUERY_TOTAL_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_READ_IOPS_EPHEMERAL_STORAGE_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_WRITE_IOPS_EPHEMERAL_STORAGE_MAXIMUM *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_VOLUME_BYTES_USED_AVERAGE *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_VOLUME_READ_IOPS_AVERAGE *smithy.Schema

var ExportableRDSDBField_UTILIZATION_METRICS_VOLUME_WRITE_IOPS_AVERAGE *smithy.Schema

var ExportableRDSDBField_INSTANCE_FINDING *smithy.Schema

var ExportableRDSDBField_INSTANCE_FINDING_REASON_CODES *smithy.Schema

var ExportableRDSDBField_STORAGE_FINDING *smithy.Schema

var ExportableRDSDBField_STORAGE_FINDING_REASON_CODES *smithy.Schema

var ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_DB_INSTANCE_CLASS *smithy.Schema

var ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_RANK *smithy.Schema

var ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_PERFORMANCE_RISK *smithy.Schema

var ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_CPU_MAXIMUM *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_STORAGE_TYPE *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ALLOCATED_STORAGE *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_MAX_ALLOCATED_STORAGE *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_IOPS *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_STORAGE_THROUGHPUT *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_RANK *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_VOLUME_IOPS_COST_VARIATION *smithy.Schema

var ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_INSTANCE_ON_DEMAND_HOURLY_PRICE *smithy.Schema

var ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE *smithy.Schema

var ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY *smithy.Schema

var ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE *smithy.Schema

var ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE *smithy.Schema

var ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS *smithy.Schema

var ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ON_DEMAND_MONTHLY_PRICE *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_CLUSTER_INSTANCE_ON_DEMAND_MONTHLY_COST *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_CLUSTER_STORAGE_ON_DEMAND_MONTHLY_COST *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_CLUSTER_STORAGE_IO_ON_DEMAND_MONTHLY_COST *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS *smithy.Schema

var ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS *smithy.Schema

var ExportableRDSDBField_EFFECTIVE_RECOMMENDATION_PREFERENCES_CPU_VENDOR_ARCHITECTURES *smithy.Schema

var ExportableRDSDBField_EFFECTIVE_RECOMMENDATION_PREFERENCES_ENHANCED_INFRASTRUCTURE_METRICS *smithy.Schema

var ExportableRDSDBField_EFFECTIVE_RECOMMENDATION_PREFERENCES_LOOKBACK_PERIOD *smithy.Schema

var ExportableRDSDBField_EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE *smithy.Schema

var ExportableRDSDBField_LAST_REFRESH_TIMESTAMP *smithy.Schema

var ExportableRDSDBField_TAGS *smithy.Schema

var ExportableRDSDBField_DB_CLUSTER_IDENTIFIER *smithy.Schema

var ExportableRDSDBField_PROMOTION_TIER *smithy.Schema

var _ExportableRDSDBFields = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableRDSDBFields",
}, smithy.ShapeTypeList, 1)
var _ExportableRDSDBFields_member *smithy.Schema

var ExportableVolumeField = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableVolumeField",
}, smithy.ShapeTypeEnum, 38)
var ExportableVolumeField_ACCOUNT_ID *smithy.Schema

var ExportableVolumeField_VOLUME_ARN *smithy.Schema

var ExportableVolumeField_FINDING *smithy.Schema

var ExportableVolumeField_UTILIZATION_METRICS_VOLUME_READ_OPS_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableVolumeField_UTILIZATION_METRICS_VOLUME_WRITE_OPS_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableVolumeField_UTILIZATION_METRICS_VOLUME_READ_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableVolumeField_UTILIZATION_METRICS_VOLUME_WRITE_BYTES_PER_SECOND_MAXIMUM *smithy.Schema

var ExportableVolumeField_UTILIZATION_METRICS_VOLUME_IOPS_EXCEEDED_MAXIMUM *smithy.Schema

var ExportableVolumeField_UTILIZATION_METRICS_VOLUME_THROUGHPUT_EXCEEDED_MAXIMUM *smithy.Schema

var ExportableVolumeField_LOOKBACK_PERIOD_IN_DAYS *smithy.Schema

var ExportableVolumeField_CURRENT_CONFIGURATION_VOLUME_TYPE *smithy.Schema

var ExportableVolumeField_CURRENT_CONFIGURATION_VOLUME_BASELINE_IOPS *smithy.Schema

var ExportableVolumeField_CURRENT_CONFIGURATION_VOLUME_BASELINE_THROUGHPUT *smithy.Schema

var ExportableVolumeField_CURRENT_CONFIGURATION_VOLUME_BURST_IOPS *smithy.Schema

var ExportableVolumeField_CURRENT_CONFIGURATION_VOLUME_BURST_THROUGHPUT *smithy.Schema

var ExportableVolumeField_CURRENT_CONFIGURATION_VOLUME_SIZE *smithy.Schema

var ExportableVolumeField_CURRENT_MONTHLY_PRICE *smithy.Schema

var ExportableVolumeField_RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_TYPE *smithy.Schema

var ExportableVolumeField_RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_BASELINE_IOPS *smithy.Schema

var ExportableVolumeField_RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_BASELINE_THROUGHPUT *smithy.Schema

var ExportableVolumeField_RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_BURST_IOPS *smithy.Schema

var ExportableVolumeField_RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_BURST_THROUGHPUT *smithy.Schema

var ExportableVolumeField_RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_SIZE *smithy.Schema

var ExportableVolumeField_RECOMMENDATION_OPTIONS_MONTHLY_PRICE *smithy.Schema

var ExportableVolumeField_RECOMMENDATION_OPTIONS_PERFORMANCE_RISK *smithy.Schema

var ExportableVolumeField_LAST_REFRESH_TIMESTAMP *smithy.Schema

var ExportableVolumeField_CURRENT_PERFORMANCE_RISK *smithy.Schema

var ExportableVolumeField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE *smithy.Schema

var ExportableVolumeField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY *smithy.Schema

var ExportableVolumeField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE *smithy.Schema

var ExportableVolumeField_TAGS *smithy.Schema

var ExportableVolumeField_ROOT_VOLUME *smithy.Schema

var ExportableVolumeField_CURRENT_CONFIGURATION_ROOT_VOLUME *smithy.Schema

var ExportableVolumeField_EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE *smithy.Schema

var ExportableVolumeField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE *smithy.Schema

var ExportableVolumeField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS *smithy.Schema

var ExportableVolumeField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS *smithy.Schema

var ExportableVolumeField_EFFECTIVE_RECOMMENDATION_PREFERENCES_LOOKBACK_PERIOD *smithy.Schema

var _ExportableVolumeFields = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportableVolumeFields",
}, smithy.ShapeTypeList, 1)
var _ExportableVolumeFields_member *smithy.Schema

var ExportDestination = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportDestination",
}, smithy.ShapeTypeStructure, 1)
var ExportDestination_s3 *smithy.Schema

var ExternalMetricsPreference = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExternalMetricsPreference",
}, smithy.ShapeTypeStructure, 1)
var ExternalMetricsPreference_source *smithy.Schema

var ExternalMetricsSource = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExternalMetricsSource",
}, smithy.ShapeTypeEnum, 4)
var ExternalMetricsSource_DATADOG *smithy.Schema

var ExternalMetricsSource_DYNATRACE *smithy.Schema

var ExternalMetricsSource_NEWRELIC *smithy.Schema

var ExternalMetricsSource_INSTANA *smithy.Schema

var ExternalMetricStatus = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExternalMetricStatus",
}, smithy.ShapeTypeStructure, 2)
var ExternalMetricStatus_statusCode *smithy.Schema

var ExternalMetricStatus_statusReason *smithy.Schema

var ExternalMetricStatusCode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExternalMetricStatusCode",
}, smithy.ShapeTypeEnum, 10)
var ExternalMetricStatusCode_NO_EXTERNAL_METRIC_SET *smithy.Schema

var ExternalMetricStatusCode_INTEGRATION_SUCCESS *smithy.Schema

var ExternalMetricStatusCode_DATADOG_INTEGRATION_ERROR *smithy.Schema

var ExternalMetricStatusCode_DYNATRACE_INTEGRATION_ERROR *smithy.Schema

var ExternalMetricStatusCode_NEWRELIC_INTEGRATION_ERROR *smithy.Schema

var ExternalMetricStatusCode_INSTANA_INTEGRATION_ERROR *smithy.Schema

var ExternalMetricStatusCode_INSUFFICIENT_DATADOG_METRICS *smithy.Schema

var ExternalMetricStatusCode_INSUFFICIENT_DYNATRACE_METRICS *smithy.Schema

var ExternalMetricStatusCode_INSUFFICIENT_NEWRELIC_METRICS *smithy.Schema

var ExternalMetricStatusCode_INSUFFICIENT_INSTANA_METRICS *smithy.Schema

var _ExternalMetricStatusReason = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExternalMetricStatusReason",
}, smithy.ShapeTypeString, 0)

var _FailureReason = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "FailureReason",
}, smithy.ShapeTypeString, 0)

var FileFormat = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "FileFormat",
}, smithy.ShapeTypeEnum, 1)
var FileFormat_CSV *smithy.Schema

var Filter = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Filter",
}, smithy.ShapeTypeStructure, 2)
var Filter_name *smithy.Schema

var Filter_values *smithy.Schema

var FilterName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "FilterName",
}, smithy.ShapeTypeEnum, 4)
var FilterName_FINDING *smithy.Schema

var FilterName_FINDING_REASON_CODES *smithy.Schema

var FilterName_RECOMMENDATION_SOURCE_TYPE *smithy.Schema

var FilterName_INFERRED_WORKLOAD_TYPES *smithy.Schema

var _Filters = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Filters",
}, smithy.ShapeTypeList, 1)
var _Filters_member *smithy.Schema

var _FilterValue = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "FilterValue",
}, smithy.ShapeTypeString, 0)

var _FilterValues = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "FilterValues",
}, smithy.ShapeTypeList, 1)
var _FilterValues_member *smithy.Schema

var Finding = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Finding",
}, smithy.ShapeTypeEnum, 4)
var Finding_UNDER_PROVISIONED *smithy.Schema

var Finding_OVER_PROVISIONED *smithy.Schema

var Finding_OPTIMIZED *smithy.Schema

var Finding_NOT_OPTIMIZED *smithy.Schema

var FindingReasonCode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "FindingReasonCode",
}, smithy.ShapeTypeEnum, 2)
var FindingReasonCode_MEMORY_OVER_PROVISIONED *smithy.Schema

var FindingReasonCode_MEMORY_UNDER_PROVISIONED *smithy.Schema

var _FunctionArn = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "FunctionArn",
}, smithy.ShapeTypeString, 0)

var _FunctionArns = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "FunctionArns",
}, smithy.ShapeTypeList, 1)
var _FunctionArns_member *smithy.Schema

var _FunctionVersion = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "FunctionVersion",
}, smithy.ShapeTypeString, 0)

var GetRecommendationError = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetRecommendationError",
}, smithy.ShapeTypeStructure, 3)
var GetRecommendationError_identifier *smithy.Schema

var GetRecommendationError_code *smithy.Schema

var GetRecommendationError_message *smithy.Schema

var _GetRecommendationErrors = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetRecommendationErrors",
}, smithy.ShapeTypeList, 1)
var _GetRecommendationErrors_member *smithy.Schema

var Gpu = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Gpu",
}, smithy.ShapeTypeStructure, 2)
var Gpu_gpuCount *smithy.Schema

var Gpu_gpuMemorySizeInMiB *smithy.Schema

var _GpuCount = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GpuCount",
}, smithy.ShapeTypeInteger, 0)

var GpuInfo = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GpuInfo",
}, smithy.ShapeTypeStructure, 1)
var GpuInfo_gpus *smithy.Schema

var _GpuMemorySizeInMiB = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GpuMemorySizeInMiB",
}, smithy.ShapeTypeInteger, 0)

var _Gpus = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Gpus",
}, smithy.ShapeTypeList, 1)
var _Gpus_member *smithy.Schema

var _High = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "High",
}, smithy.ShapeTypeLong, 0)

var _Identifier = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Identifier",
}, smithy.ShapeTypeString, 0)

var Idle = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Idle",
}, smithy.ShapeTypeEnum, 2)
var Idle_TRUE *smithy.Schema

var Idle_FALSE *smithy.Schema

var IdleDimension = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleDimension",
}, smithy.ShapeTypeStructure, 2)
var IdleDimension_key *smithy.Schema

var IdleDimension_values *smithy.Schema

var _IdleDimensionKey = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleDimensionKey",
}, smithy.ShapeTypeString, 0)

var _IdleDimensions = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleDimensions",
}, smithy.ShapeTypeList, 1)
var _IdleDimensions_member *smithy.Schema

var _IdleDimensionValue = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleDimensionValue",
}, smithy.ShapeTypeString, 0)

var _IdleDimensionValues = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleDimensionValues",
}, smithy.ShapeTypeList, 1)
var _IdleDimensionValues_member *smithy.Schema

var IdleEstimatedMonthlySavings = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleEstimatedMonthlySavings",
}, smithy.ShapeTypeStructure, 2)
var IdleEstimatedMonthlySavings_currency *smithy.Schema

var IdleEstimatedMonthlySavings_value *smithy.Schema

var IdleFinding = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleFinding",
}, smithy.ShapeTypeEnum, 3)
var IdleFinding_IDLE *smithy.Schema

var IdleFinding_UNATTACHED *smithy.Schema

var IdleFinding_UNUSED *smithy.Schema

var _IdleFindingDescription = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleFindingDescription",
}, smithy.ShapeTypeString, 0)

var _IdleMaxResults = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleMaxResults",
}, smithy.ShapeTypeInteger, 0)

var IdleMetricName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleMetricName",
}, smithy.ShapeTypeEnum, 28)
var IdleMetricName_CPU *smithy.Schema

var IdleMetricName_MEMORY *smithy.Schema

var IdleMetricName_NETWORK_OUT_BYTES_PER_SECOND *smithy.Schema

var IdleMetricName_NETWORK_IN_BYTES_PER_SECOND *smithy.Schema

var IdleMetricName_DATABASE_CONNECTIONS *smithy.Schema

var IdleMetricName_EBS_VOLUME_READ_IOPS *smithy.Schema

var IdleMetricName_EBS_VOLUME_WRITE_IOPS *smithy.Schema

var IdleMetricName_VOLUME_READ_OPS_PER_SECOND *smithy.Schema

var IdleMetricName_VOLUME_WRITE_OPS_PER_SECOND *smithy.Schema

var IdleMetricName_ACTIVE_CONNECTION_COUNT *smithy.Schema

var IdleMetricName_PACKETS_IN_FROM_SOURCE *smithy.Schema

var IdleMetricName_PACKETS_IN_FROM_DESTINATION *smithy.Schema

var IdleMetricName_CONSUMED_READ_CAPACITY_UNITS *smithy.Schema

var IdleMetricName_CONSUMED_WRITE_CAPACITY_UNITS *smithy.Schema

var IdleMetricName_CONSUMED_CHANGE_DATA_CAPTURE_UNITS *smithy.Schema

var IdleMetricName_NEW_CONNECTIONS *smithy.Schema

var IdleMetricName_ENGINE_CPU_UTILIZATION *smithy.Schema

var IdleMetricName_CACHE_HITS *smithy.Schema

var IdleMetricName_CACHE_MISSES *smithy.Schema

var IdleMetricName_KEYSPACE_HITS *smithy.Schema

var IdleMetricName_KEYSPACE_MISSES *smithy.Schema

var IdleMetricName_IS_IDLE *smithy.Schema

var IdleMetricName_USER_CONNECTED *smithy.Schema

var IdleMetricName_INVOCATIONS *smithy.Schema

var IdleMetricName_GET_TYPE_CMDS *smithy.Schema

var IdleMetricName_SET_TYPE_CMDS *smithy.Schema

var IdleMetricName_ELASTI_CACHE_PROCESSING_UNITS *smithy.Schema

var IdleMetricName_CURR_CONNECTIONS *smithy.Schema

var IdleRecommendation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleRecommendation",
}, smithy.ShapeTypeStructure, 12)
var IdleRecommendation_resourceArn *smithy.Schema

var IdleRecommendation_resourceId *smithy.Schema

var IdleRecommendation_resourceType *smithy.Schema

var IdleRecommendation_accountId *smithy.Schema

var IdleRecommendation_finding *smithy.Schema

var IdleRecommendation_findingDescription *smithy.Schema

var IdleRecommendation_savingsOpportunity *smithy.Schema

var IdleRecommendation_savingsOpportunityAfterDiscounts *smithy.Schema

var IdleRecommendation_utilizationMetrics *smithy.Schema

var IdleRecommendation_lookBackPeriodInDays *smithy.Schema

var IdleRecommendation_lastRefreshTimestamp *smithy.Schema

var IdleRecommendation_tags *smithy.Schema

var IdleRecommendationError = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleRecommendationError",
}, smithy.ShapeTypeStructure, 4)
var IdleRecommendationError_identifier *smithy.Schema

var IdleRecommendationError_code *smithy.Schema

var IdleRecommendationError_message *smithy.Schema

var IdleRecommendationError_resourceType *smithy.Schema

var _IdleRecommendationErrors = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleRecommendationErrors",
}, smithy.ShapeTypeList, 1)
var _IdleRecommendationErrors_member *smithy.Schema

var IdleRecommendationFilter = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleRecommendationFilter",
}, smithy.ShapeTypeStructure, 2)
var IdleRecommendationFilter_name *smithy.Schema

var IdleRecommendationFilter_values *smithy.Schema

var IdleRecommendationFilterName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleRecommendationFilterName",
}, smithy.ShapeTypeEnum, 2)
var IdleRecommendationFilterName_FINDING *smithy.Schema

var IdleRecommendationFilterName_RESOURCE_TYPE *smithy.Schema

var _IdleRecommendationFilters = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleRecommendationFilters",
}, smithy.ShapeTypeList, 1)
var _IdleRecommendationFilters_member *smithy.Schema

var IdleRecommendationResourceType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleRecommendationResourceType",
}, smithy.ShapeTypeEnum, 12)
var IdleRecommendationResourceType_EC2_INSTANCE *smithy.Schema

var IdleRecommendationResourceType_AUTO_SCALING_GROUP *smithy.Schema

var IdleRecommendationResourceType_EBS_VOLUME *smithy.Schema

var IdleRecommendationResourceType_ECS_SERVICE *smithy.Schema

var IdleRecommendationResourceType_RDS_DB_INSTANCE *smithy.Schema

var IdleRecommendationResourceType_NAT_GATEWAY *smithy.Schema

var IdleRecommendationResourceType_DYNAMO_DB_TABLE *smithy.Schema

var IdleRecommendationResourceType_ELASTI_CACHE_CLUSTER *smithy.Schema

var IdleRecommendationResourceType_MEMORY_DB_CLUSTER *smithy.Schema

var IdleRecommendationResourceType_DOCUMENT_DB_CLUSTER *smithy.Schema

var IdleRecommendationResourceType_WORKSPACES *smithy.Schema

var IdleRecommendationResourceType_SAGE_MAKER_ENDPOINT *smithy.Schema

var _IdleRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleRecommendations",
}, smithy.ShapeTypeList, 1)
var _IdleRecommendations_member *smithy.Schema

var IdleSavingsOpportunity = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleSavingsOpportunity",
}, smithy.ShapeTypeStructure, 2)
var IdleSavingsOpportunity_savingsOpportunityPercentage *smithy.Schema

var IdleSavingsOpportunity_estimatedMonthlySavings *smithy.Schema

var IdleSavingsOpportunityAfterDiscounts = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleSavingsOpportunityAfterDiscounts",
}, smithy.ShapeTypeStructure, 2)
var IdleSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage *smithy.Schema

var IdleSavingsOpportunityAfterDiscounts_estimatedMonthlySavings *smithy.Schema

var _IdleSummaries = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleSummaries",
}, smithy.ShapeTypeList, 1)
var _IdleSummaries_member *smithy.Schema

var IdleSummary = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleSummary",
}, smithy.ShapeTypeStructure, 2)
var IdleSummary_name *smithy.Schema

var IdleSummary_value *smithy.Schema

var IdleUtilizationMetric = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleUtilizationMetric",
}, smithy.ShapeTypeStructure, 4)
var IdleUtilizationMetric_name *smithy.Schema

var IdleUtilizationMetric_statistic *smithy.Schema

var IdleUtilizationMetric_value *smithy.Schema

var IdleUtilizationMetric_dimensions *smithy.Schema

var _IdleUtilizationMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IdleUtilizationMetrics",
}, smithy.ShapeTypeList, 1)
var _IdleUtilizationMetrics_member *smithy.Schema

var _IncludeMemberAccounts = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "IncludeMemberAccounts",
}, smithy.ShapeTypeBoolean, 0)

var InferredWorkloadSaving = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InferredWorkloadSaving",
}, smithy.ShapeTypeStructure, 2)
var InferredWorkloadSaving_inferredWorkloadTypes *smithy.Schema

var InferredWorkloadSaving_estimatedMonthlySavings *smithy.Schema

var _InferredWorkloadSavings = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InferredWorkloadSavings",
}, smithy.ShapeTypeList, 1)
var _InferredWorkloadSavings_member *smithy.Schema

var InferredWorkloadType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InferredWorkloadType",
}, smithy.ShapeTypeEnum, 9)
var InferredWorkloadType_AMAZON_EMR *smithy.Schema

var InferredWorkloadType_APACHE_CASSANDRA *smithy.Schema

var InferredWorkloadType_APACHE_HADOOP *smithy.Schema

var InferredWorkloadType_MEMCACHED *smithy.Schema

var InferredWorkloadType_NGINX *smithy.Schema

var InferredWorkloadType_POSTGRE_SQL *smithy.Schema

var InferredWorkloadType_REDIS *smithy.Schema

var InferredWorkloadType_KAFKA *smithy.Schema

var InferredWorkloadType_SQLSERVER *smithy.Schema

var _InferredWorkloadTypes = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InferredWorkloadTypes",
}, smithy.ShapeTypeList, 1)
var _InferredWorkloadTypes_member *smithy.Schema

var InferredWorkloadTypesPreference = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InferredWorkloadTypesPreference",
}, smithy.ShapeTypeEnum, 2)
var InferredWorkloadTypesPreference_ACTIVE *smithy.Schema

var InferredWorkloadTypesPreference_INACTIVE *smithy.Schema

var _InstanceArn = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InstanceArn",
}, smithy.ShapeTypeString, 0)

var _InstanceArns = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InstanceArns",
}, smithy.ShapeTypeList, 1)
var _InstanceArns_member *smithy.Schema

var InstanceEstimatedMonthlySavings = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InstanceEstimatedMonthlySavings",
}, smithy.ShapeTypeStructure, 2)
var InstanceEstimatedMonthlySavings_currency *smithy.Schema

var InstanceEstimatedMonthlySavings_value *smithy.Schema

var InstanceIdle = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InstanceIdle",
}, smithy.ShapeTypeEnum, 2)
var InstanceIdle_TRUE *smithy.Schema

var InstanceIdle_FALSE *smithy.Schema

var _InstanceName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InstanceName",
}, smithy.ShapeTypeString, 0)

var InstanceRecommendation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InstanceRecommendation",
}, smithy.ShapeTypeStructure, 19)
var InstanceRecommendation_instanceArn *smithy.Schema

var InstanceRecommendation_accountId *smithy.Schema

var InstanceRecommendation_instanceName *smithy.Schema

var InstanceRecommendation_currentInstanceType *smithy.Schema

var InstanceRecommendation_finding *smithy.Schema

var InstanceRecommendation_findingReasonCodes *smithy.Schema

var InstanceRecommendation_utilizationMetrics *smithy.Schema

var InstanceRecommendation_lookBackPeriodInDays *smithy.Schema

var InstanceRecommendation_recommendationOptions *smithy.Schema

var InstanceRecommendation_recommendationSources *smithy.Schema

var InstanceRecommendation_lastRefreshTimestamp *smithy.Schema

var InstanceRecommendation_currentPerformanceRisk *smithy.Schema

var InstanceRecommendation_effectiveRecommendationPreferences *smithy.Schema

var InstanceRecommendation_inferredWorkloadTypes *smithy.Schema

var InstanceRecommendation_instanceState *smithy.Schema

var InstanceRecommendation_tags *smithy.Schema

var InstanceRecommendation_externalMetricStatus *smithy.Schema

var InstanceRecommendation_currentInstanceGpuInfo *smithy.Schema

var InstanceRecommendation_idle *smithy.Schema

var InstanceRecommendationFindingReasonCode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InstanceRecommendationFindingReasonCode",
}, smithy.ShapeTypeEnum, 20)
var InstanceRecommendationFindingReasonCode_CPU_OVER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_CPU_UNDER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_MEMORY_OVER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_MEMORY_UNDER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_EBS_THROUGHPUT_OVER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_EBS_THROUGHPUT_UNDER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_EBS_IOPS_OVER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_EBS_IOPS_UNDER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_NETWORK_BANDWIDTH_OVER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_NETWORK_BANDWIDTH_UNDER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_NETWORK_PPS_OVER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_NETWORK_PPS_UNDER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_DISK_IOPS_OVER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_DISK_IOPS_UNDER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_DISK_THROUGHPUT_OVER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_DISK_THROUGHPUT_UNDER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_GPU_UNDER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_GPU_OVER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_GPU_MEMORY_UNDER_PROVISIONED *smithy.Schema

var InstanceRecommendationFindingReasonCode_GPU_MEMORY_OVER_PROVISIONED *smithy.Schema

var _InstanceRecommendationFindingReasonCodes = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InstanceRecommendationFindingReasonCodes",
}, smithy.ShapeTypeList, 1)
var _InstanceRecommendationFindingReasonCodes_member *smithy.Schema

var InstanceRecommendationOption = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InstanceRecommendationOption",
}, smithy.ShapeTypeStructure, 9)
var InstanceRecommendationOption_instanceType *smithy.Schema

var InstanceRecommendationOption_instanceGpuInfo *smithy.Schema

var InstanceRecommendationOption_projectedUtilizationMetrics *smithy.Schema

var InstanceRecommendationOption_platformDifferences *smithy.Schema

var InstanceRecommendationOption_performanceRisk *smithy.Schema

var InstanceRecommendationOption_rank *smithy.Schema

var InstanceRecommendationOption_savingsOpportunity *smithy.Schema

var InstanceRecommendationOption_savingsOpportunityAfterDiscounts *smithy.Schema

var InstanceRecommendationOption_migrationEffort *smithy.Schema

var _InstanceRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InstanceRecommendations",
}, smithy.ShapeTypeList, 1)
var _InstanceRecommendations_member *smithy.Schema

var InstanceSavingsEstimationMode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InstanceSavingsEstimationMode",
}, smithy.ShapeTypeStructure, 1)
var InstanceSavingsEstimationMode_source *smithy.Schema

var InstanceSavingsEstimationModeSource = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InstanceSavingsEstimationModeSource",
}, smithy.ShapeTypeEnum, 3)
var InstanceSavingsEstimationModeSource_PUBLIC_PRICING *smithy.Schema

var InstanceSavingsEstimationModeSource_COST_EXPLORER_RIGHTSIZING *smithy.Schema

var InstanceSavingsEstimationModeSource_COST_OPTIMIZATION_HUB *smithy.Schema

var InstanceSavingsOpportunityAfterDiscounts = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InstanceSavingsOpportunityAfterDiscounts",
}, smithy.ShapeTypeStructure, 2)
var InstanceSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage *smithy.Schema

var InstanceSavingsOpportunityAfterDiscounts_estimatedMonthlySavings *smithy.Schema

var InstanceState = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InstanceState",
}, smithy.ShapeTypeEnum, 6)
var InstanceState_PENDING *smithy.Schema

var InstanceState_RUNNING *smithy.Schema

var InstanceState_SHUTTING_DOWN *smithy.Schema

var InstanceState_TERMINATED *smithy.Schema

var InstanceState_STOPPING *smithy.Schema

var InstanceState_STOPPED *smithy.Schema

var _InstanceType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InstanceType",
}, smithy.ShapeTypeString, 0)

var InternalServerException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InternalServerException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 500})
var InternalServerException_message *smithy.Schema

var InvalidParameterValueException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "InvalidParameterValueException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 400})
var InvalidParameterValueException_message *smithy.Schema

var JobFilter = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "JobFilter",
}, smithy.ShapeTypeStructure, 2)
var JobFilter_name *smithy.Schema

var JobFilter_values *smithy.Schema

var JobFilterName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "JobFilterName",
}, smithy.ShapeTypeEnum, 2)
var JobFilterName_RESOURCE_TYPE *smithy.Schema

var JobFilterName_JOB_STATUS *smithy.Schema

var _JobFilters = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "JobFilters",
}, smithy.ShapeTypeList, 1)
var _JobFilters_member *smithy.Schema

var _JobId = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "JobId",
}, smithy.ShapeTypeString, 0)

var _JobIds = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "JobIds",
}, smithy.ShapeTypeList, 1)
var _JobIds_member *smithy.Schema

var JobStatus = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "JobStatus",
}, smithy.ShapeTypeEnum, 4)
var JobStatus_QUEUED *smithy.Schema

var JobStatus_IN_PROGRESS *smithy.Schema

var JobStatus_COMPLETE *smithy.Schema

var JobStatus_FAILED *smithy.Schema

var LambdaEffectiveRecommendationPreferences = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaEffectiveRecommendationPreferences",
}, smithy.ShapeTypeStructure, 1)
var LambdaEffectiveRecommendationPreferences_savingsEstimationMode *smithy.Schema

var LambdaEstimatedMonthlySavings = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaEstimatedMonthlySavings",
}, smithy.ShapeTypeStructure, 2)
var LambdaEstimatedMonthlySavings_currency *smithy.Schema

var LambdaEstimatedMonthlySavings_value *smithy.Schema

var LambdaFunctionMemoryMetricName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionMemoryMetricName",
}, smithy.ShapeTypeEnum, 1)
var LambdaFunctionMemoryMetricName_DURATION *smithy.Schema

var LambdaFunctionMemoryMetricStatistic = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionMemoryMetricStatistic",
}, smithy.ShapeTypeEnum, 3)
var LambdaFunctionMemoryMetricStatistic_LOWER_BOUND *smithy.Schema

var LambdaFunctionMemoryMetricStatistic_UPPER_BOUND *smithy.Schema

var LambdaFunctionMemoryMetricStatistic_EXPECTED *smithy.Schema

var LambdaFunctionMemoryProjectedMetric = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionMemoryProjectedMetric",
}, smithy.ShapeTypeStructure, 3)
var LambdaFunctionMemoryProjectedMetric_name *smithy.Schema

var LambdaFunctionMemoryProjectedMetric_statistic *smithy.Schema

var LambdaFunctionMemoryProjectedMetric_value *smithy.Schema

var _LambdaFunctionMemoryProjectedMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionMemoryProjectedMetrics",
}, smithy.ShapeTypeList, 1)
var _LambdaFunctionMemoryProjectedMetrics_member *smithy.Schema

var LambdaFunctionMemoryRecommendationOption = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionMemoryRecommendationOption",
}, smithy.ShapeTypeStructure, 5)
var LambdaFunctionMemoryRecommendationOption_rank *smithy.Schema

var LambdaFunctionMemoryRecommendationOption_memorySize *smithy.Schema

var LambdaFunctionMemoryRecommendationOption_projectedUtilizationMetrics *smithy.Schema

var LambdaFunctionMemoryRecommendationOption_savingsOpportunity *smithy.Schema

var LambdaFunctionMemoryRecommendationOption_savingsOpportunityAfterDiscounts *smithy.Schema

var _LambdaFunctionMemoryRecommendationOptions = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionMemoryRecommendationOptions",
}, smithy.ShapeTypeList, 1)
var _LambdaFunctionMemoryRecommendationOptions_member *smithy.Schema

var LambdaFunctionMetricName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionMetricName",
}, smithy.ShapeTypeEnum, 2)
var LambdaFunctionMetricName_DURATION *smithy.Schema

var LambdaFunctionMetricName_MEMORY *smithy.Schema

var LambdaFunctionMetricStatistic = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionMetricStatistic",
}, smithy.ShapeTypeEnum, 2)
var LambdaFunctionMetricStatistic_MAXIMUM *smithy.Schema

var LambdaFunctionMetricStatistic_AVERAGE *smithy.Schema

var LambdaFunctionRecommendation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionRecommendation",
}, smithy.ShapeTypeStructure, 14)
var LambdaFunctionRecommendation_functionArn *smithy.Schema

var LambdaFunctionRecommendation_functionVersion *smithy.Schema

var LambdaFunctionRecommendation_accountId *smithy.Schema

var LambdaFunctionRecommendation_currentMemorySize *smithy.Schema

var LambdaFunctionRecommendation_numberOfInvocations *smithy.Schema

var LambdaFunctionRecommendation_utilizationMetrics *smithy.Schema

var LambdaFunctionRecommendation_lookbackPeriodInDays *smithy.Schema

var LambdaFunctionRecommendation_lastRefreshTimestamp *smithy.Schema

var LambdaFunctionRecommendation_finding *smithy.Schema

var LambdaFunctionRecommendation_findingReasonCodes *smithy.Schema

var LambdaFunctionRecommendation_memorySizeRecommendationOptions *smithy.Schema

var LambdaFunctionRecommendation_currentPerformanceRisk *smithy.Schema

var LambdaFunctionRecommendation_effectiveRecommendationPreferences *smithy.Schema

var LambdaFunctionRecommendation_tags *smithy.Schema

var LambdaFunctionRecommendationFilter = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionRecommendationFilter",
}, smithy.ShapeTypeStructure, 2)
var LambdaFunctionRecommendationFilter_name *smithy.Schema

var LambdaFunctionRecommendationFilter_values *smithy.Schema

var LambdaFunctionRecommendationFilterName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionRecommendationFilterName",
}, smithy.ShapeTypeEnum, 2)
var LambdaFunctionRecommendationFilterName_FINDING *smithy.Schema

var LambdaFunctionRecommendationFilterName_FINDING_REASON_CODE *smithy.Schema

var _LambdaFunctionRecommendationFilters = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionRecommendationFilters",
}, smithy.ShapeTypeList, 1)
var _LambdaFunctionRecommendationFilters_member *smithy.Schema

var LambdaFunctionRecommendationFinding = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionRecommendationFinding",
}, smithy.ShapeTypeEnum, 3)
var LambdaFunctionRecommendationFinding_OPTIMIZED *smithy.Schema

var LambdaFunctionRecommendationFinding_NOT_OPTIMIZED *smithy.Schema

var LambdaFunctionRecommendationFinding_UNAVAILABLE *smithy.Schema

var LambdaFunctionRecommendationFindingReasonCode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionRecommendationFindingReasonCode",
}, smithy.ShapeTypeEnum, 4)
var LambdaFunctionRecommendationFindingReasonCode_MEMORY_OVER_PROVISIONED *smithy.Schema

var LambdaFunctionRecommendationFindingReasonCode_MEMORY_UNDER_PROVISIONED *smithy.Schema

var LambdaFunctionRecommendationFindingReasonCode_INSUFFICIENT_DATA *smithy.Schema

var LambdaFunctionRecommendationFindingReasonCode_INCONCLUSIVE *smithy.Schema

var _LambdaFunctionRecommendationFindingReasonCodes = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionRecommendationFindingReasonCodes",
}, smithy.ShapeTypeList, 1)
var _LambdaFunctionRecommendationFindingReasonCodes_member *smithy.Schema

var _LambdaFunctionRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionRecommendations",
}, smithy.ShapeTypeList, 1)
var _LambdaFunctionRecommendations_member *smithy.Schema

var LambdaFunctionUtilizationMetric = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionUtilizationMetric",
}, smithy.ShapeTypeStructure, 3)
var LambdaFunctionUtilizationMetric_name *smithy.Schema

var LambdaFunctionUtilizationMetric_statistic *smithy.Schema

var LambdaFunctionUtilizationMetric_value *smithy.Schema

var _LambdaFunctionUtilizationMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaFunctionUtilizationMetrics",
}, smithy.ShapeTypeList, 1)
var _LambdaFunctionUtilizationMetrics_member *smithy.Schema

var LambdaSavingsEstimationMode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaSavingsEstimationMode",
}, smithy.ShapeTypeStructure, 1)
var LambdaSavingsEstimationMode_source *smithy.Schema

var LambdaSavingsEstimationModeSource = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaSavingsEstimationModeSource",
}, smithy.ShapeTypeEnum, 3)
var LambdaSavingsEstimationModeSource_PUBLIC_PRICING *smithy.Schema

var LambdaSavingsEstimationModeSource_COST_EXPLORER_RIGHTSIZING *smithy.Schema

var LambdaSavingsEstimationModeSource_COST_OPTIMIZATION_HUB *smithy.Schema

var LambdaSavingsOpportunityAfterDiscounts = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LambdaSavingsOpportunityAfterDiscounts",
}, smithy.ShapeTypeStructure, 2)
var LambdaSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage *smithy.Schema

var LambdaSavingsOpportunityAfterDiscounts_estimatedMonthlySavings *smithy.Schema

var _LastRefreshTimestamp = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LastRefreshTimestamp",
}, smithy.ShapeTypeTimestamp, 0)

var _LastUpdatedTimestamp = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LastUpdatedTimestamp",
}, smithy.ShapeTypeTimestamp, 0)

var LicenseConfiguration = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LicenseConfiguration",
}, smithy.ShapeTypeStructure, 8)
var LicenseConfiguration_numberOfCores *smithy.Schema

var LicenseConfiguration_instanceType *smithy.Schema

var LicenseConfiguration_operatingSystem *smithy.Schema

var LicenseConfiguration_licenseEdition *smithy.Schema

var LicenseConfiguration_licenseName *smithy.Schema

var LicenseConfiguration_licenseModel *smithy.Schema

var LicenseConfiguration_licenseVersion *smithy.Schema

var LicenseConfiguration_metricsSource *smithy.Schema

var LicenseEdition = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LicenseEdition",
}, smithy.ShapeTypeEnum, 4)
var LicenseEdition_ENTERPRISE *smithy.Schema

var LicenseEdition_STANDARD *smithy.Schema

var LicenseEdition_FREE *smithy.Schema

var LicenseEdition_NO_LICENSE_EDITION_FOUND *smithy.Schema

var LicenseFinding = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LicenseFinding",
}, smithy.ShapeTypeEnum, 3)
var LicenseFinding_INSUFFICIENT_METRICS *smithy.Schema

var LicenseFinding_OPTIMIZED *smithy.Schema

var LicenseFinding_NOT_OPTIMIZED *smithy.Schema

var LicenseFindingReasonCode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LicenseFindingReasonCode",
}, smithy.ShapeTypeEnum, 4)
var LicenseFindingReasonCode_CW_APP_INSIGHTS_DISABLED *smithy.Schema

var LicenseFindingReasonCode_CW_APP_INSIGHTS_ERROR *smithy.Schema

var LicenseFindingReasonCode_LICENSE_OVER_PROVISIONED *smithy.Schema

var LicenseFindingReasonCode_OPTIMIZED *smithy.Schema

var _LicenseFindingReasonCodes = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LicenseFindingReasonCodes",
}, smithy.ShapeTypeList, 1)
var _LicenseFindingReasonCodes_member *smithy.Schema

var LicenseModel = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LicenseModel",
}, smithy.ShapeTypeEnum, 2)
var LicenseModel_LICENSE_INCLUDED *smithy.Schema

var LicenseModel_BRING_YOUR_OWN_LICENSE *smithy.Schema

var LicenseName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LicenseName",
}, smithy.ShapeTypeEnum, 1)
var LicenseName_SQLSERVER *smithy.Schema

var LicenseRecommendation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LicenseRecommendation",
}, smithy.ShapeTypeStructure, 9)
var LicenseRecommendation_resourceArn *smithy.Schema

var LicenseRecommendation_accountId *smithy.Schema

var LicenseRecommendation_currentLicenseConfiguration *smithy.Schema

var LicenseRecommendation_lookbackPeriodInDays *smithy.Schema

var LicenseRecommendation_lastRefreshTimestamp *smithy.Schema

var LicenseRecommendation_finding *smithy.Schema

var LicenseRecommendation_findingReasonCodes *smithy.Schema

var LicenseRecommendation_licenseRecommendationOptions *smithy.Schema

var LicenseRecommendation_tags *smithy.Schema

var LicenseRecommendationFilter = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LicenseRecommendationFilter",
}, smithy.ShapeTypeStructure, 2)
var LicenseRecommendationFilter_name *smithy.Schema

var LicenseRecommendationFilter_values *smithy.Schema

var LicenseRecommendationFilterName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LicenseRecommendationFilterName",
}, smithy.ShapeTypeEnum, 3)
var LicenseRecommendationFilterName_LICENSE_FINDING *smithy.Schema

var LicenseRecommendationFilterName_LICENSE_FINDING_REASON_CODE *smithy.Schema

var LicenseRecommendationFilterName_LICENSE_NAME *smithy.Schema

var _LicenseRecommendationFilters = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LicenseRecommendationFilters",
}, smithy.ShapeTypeList, 1)
var _LicenseRecommendationFilters_member *smithy.Schema

var LicenseRecommendationOption = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LicenseRecommendationOption",
}, smithy.ShapeTypeStructure, 5)
var LicenseRecommendationOption_rank *smithy.Schema

var LicenseRecommendationOption_operatingSystem *smithy.Schema

var LicenseRecommendationOption_licenseEdition *smithy.Schema

var LicenseRecommendationOption_licenseModel *smithy.Schema

var LicenseRecommendationOption_savingsOpportunity *smithy.Schema

var _LicenseRecommendationOptions = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LicenseRecommendationOptions",
}, smithy.ShapeTypeList, 1)
var _LicenseRecommendationOptions_member *smithy.Schema

var _LicenseRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LicenseRecommendations",
}, smithy.ShapeTypeList, 1)
var _LicenseRecommendations_member *smithy.Schema

var _LicenseVersion = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LicenseVersion",
}, smithy.ShapeTypeString, 0)

var LimitExceededException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LimitExceededException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 400})
var LimitExceededException_message *smithy.Schema

var _LookBackPeriodInDays = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LookBackPeriodInDays",
}, smithy.ShapeTypeDouble, 0)

var LookBackPeriodPreference = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LookBackPeriodPreference",
}, smithy.ShapeTypeEnum, 3)
var LookBackPeriodPreference_DAYS_14 *smithy.Schema

var LookBackPeriodPreference_DAYS_32 *smithy.Schema

var LookBackPeriodPreference_DAYS_93 *smithy.Schema

var _Low = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Low",
}, smithy.ShapeTypeLong, 0)

var _LowerBoundValue = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "LowerBoundValue",
}, smithy.ShapeTypeDouble, 0)

var _MaxResults = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MaxResults",
}, smithy.ShapeTypeInteger, 0)

var _MaxSize = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MaxSize",
}, smithy.ShapeTypeInteger, 0)

var _Medium = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Medium",
}, smithy.ShapeTypeLong, 0)

var _MemberAccountsEnrolled = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MemberAccountsEnrolled",
}, smithy.ShapeTypeBoolean, 0)

var _MemorySize = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MemorySize",
}, smithy.ShapeTypeInteger, 0)

var MemorySizeConfiguration = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MemorySizeConfiguration",
}, smithy.ShapeTypeStructure, 2)
var MemorySizeConfiguration_memory *smithy.Schema

var MemorySizeConfiguration_memoryReservation *smithy.Schema

var _Message = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Message",
}, smithy.ShapeTypeString, 0)

var _MetadataKey = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MetadataKey",
}, smithy.ShapeTypeString, 0)

var MetricName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MetricName",
}, smithy.ShapeTypeEnum, 16)
var MetricName_CPU *smithy.Schema

var MetricName_MEMORY *smithy.Schema

var MetricName_EBS_READ_OPS_PER_SECOND *smithy.Schema

var MetricName_EBS_WRITE_OPS_PER_SECOND *smithy.Schema

var MetricName_EBS_READ_BYTES_PER_SECOND *smithy.Schema

var MetricName_EBS_WRITE_BYTES_PER_SECOND *smithy.Schema

var MetricName_DISK_READ_OPS_PER_SECOND *smithy.Schema

var MetricName_DISK_WRITE_OPS_PER_SECOND *smithy.Schema

var MetricName_DISK_READ_BYTES_PER_SECOND *smithy.Schema

var MetricName_DISK_WRITE_BYTES_PER_SECOND *smithy.Schema

var MetricName_NETWORK_IN_BYTES_PER_SECOND *smithy.Schema

var MetricName_NETWORK_OUT_BYTES_PER_SECOND *smithy.Schema

var MetricName_NETWORK_PACKETS_IN_PER_SECOND *smithy.Schema

var MetricName_NETWORK_PACKETS_OUT_PER_SECOND *smithy.Schema

var MetricName_GPU_PERCENTAGE *smithy.Schema

var MetricName_GPU_MEMORY_PERCENTAGE *smithy.Schema

var _MetricProviderArn = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MetricProviderArn",
}, smithy.ShapeTypeString, 0)

var MetricSource = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MetricSource",
}, smithy.ShapeTypeStructure, 2)
var MetricSource_provider *smithy.Schema

var MetricSource_providerArn *smithy.Schema

var MetricSourceProvider = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MetricSourceProvider",
}, smithy.ShapeTypeEnum, 1)
var MetricSourceProvider_CloudWatchAppInsights *smithy.Schema

var _MetricsSource = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MetricsSource",
}, smithy.ShapeTypeList, 1)
var _MetricsSource_member *smithy.Schema

var MetricStatistic = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MetricStatistic",
}, smithy.ShapeTypeEnum, 2)
var MetricStatistic_MAXIMUM *smithy.Schema

var MetricStatistic_AVERAGE *smithy.Schema

var _MetricValue = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MetricValue",
}, smithy.ShapeTypeDouble, 0)

var _MetricValues = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MetricValues",
}, smithy.ShapeTypeList, 1)
var _MetricValues_member *smithy.Schema

var MigrationEffort = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MigrationEffort",
}, smithy.ShapeTypeEnum, 4)
var MigrationEffort_VERY_LOW *smithy.Schema

var MigrationEffort_LOW *smithy.Schema

var MigrationEffort_MEDIUM *smithy.Schema

var MigrationEffort_HIGH *smithy.Schema

var _MinSize = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MinSize",
}, smithy.ShapeTypeInteger, 0)

var MissingAuthenticationToken = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MissingAuthenticationToken",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 403})
var MissingAuthenticationToken_message *smithy.Schema

var _MixedInstanceType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MixedInstanceType",
}, smithy.ShapeTypeString, 0)

var _MixedInstanceTypes = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "MixedInstanceTypes",
}, smithy.ShapeTypeList, 1)
var _MixedInstanceTypes_member *smithy.Schema

var _NextToken = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "NextToken",
}, smithy.ShapeTypeString, 0)

var _NullableCpu = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "NullableCpu",
}, smithy.ShapeTypeInteger, 0)

var _NullableEstimatedInstanceHourReductionPercentage = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "NullableEstimatedInstanceHourReductionPercentage",
}, smithy.ShapeTypeDouble, 0)

var _NullableInstanceType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "NullableInstanceType",
}, smithy.ShapeTypeString, 0)

var _NullableIOPS = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "NullableIOPS",
}, smithy.ShapeTypeInteger, 0)

var _NullableMaxAllocatedStorage = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "NullableMaxAllocatedStorage",
}, smithy.ShapeTypeInteger, 0)

var _NullableMemory = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "NullableMemory",
}, smithy.ShapeTypeInteger, 0)

var _NullableMemoryReservation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "NullableMemoryReservation",
}, smithy.ShapeTypeInteger, 0)

var _NullableStorageThroughput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "NullableStorageThroughput",
}, smithy.ShapeTypeInteger, 0)

var _NumberOfCores = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "NumberOfCores",
}, smithy.ShapeTypeInteger, 0)

var _NumberOfInvocations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "NumberOfInvocations",
}, smithy.ShapeTypeLong, 0)

var _NumberOfMemberAccountsOptedIn = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "NumberOfMemberAccountsOptedIn",
}, smithy.ShapeTypeInteger, 0)

var _OperatingSystem = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "OperatingSystem",
}, smithy.ShapeTypeString, 0)

var OptInRequiredException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "OptInRequiredException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 403})
var OptInRequiredException_message *smithy.Schema

var Order = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Order",
}, smithy.ShapeTypeEnum, 2)
var Order_ASC *smithy.Schema

var Order_DESC *smithy.Schema

var OrderBy = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "OrderBy",
}, smithy.ShapeTypeStructure, 2)
var OrderBy_dimension *smithy.Schema

var OrderBy_order *smithy.Schema

var _PerformanceRisk = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "PerformanceRisk",
}, smithy.ShapeTypeDouble, 0)

var _Period = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Period",
}, smithy.ShapeTypeInteger, 0)

var PlatformDifference = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "PlatformDifference",
}, smithy.ShapeTypeEnum, 6)
var PlatformDifference_HYPERVISOR *smithy.Schema

var PlatformDifference_NETWORK_INTERFACE *smithy.Schema

var PlatformDifference_STORAGE_INTERFACE *smithy.Schema

var PlatformDifference_INSTANCE_STORE_AVAILABILITY *smithy.Schema

var PlatformDifference_VIRTUALIZATION_TYPE *smithy.Schema

var PlatformDifference_ARCHITECTURE *smithy.Schema

var _PlatformDifferences = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "PlatformDifferences",
}, smithy.ShapeTypeList, 1)
var _PlatformDifferences_member *smithy.Schema

var PreferredResource = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "PreferredResource",
}, smithy.ShapeTypeStructure, 3)
var PreferredResource_name *smithy.Schema

var PreferredResource_includeList *smithy.Schema

var PreferredResource_excludeList *smithy.Schema

var PreferredResourceName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "PreferredResourceName",
}, smithy.ShapeTypeEnum, 1)
var PreferredResourceName_EC2_INSTANCE_TYPES *smithy.Schema

var _PreferredResources = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "PreferredResources",
}, smithy.ShapeTypeList, 1)
var _PreferredResources_member *smithy.Schema

var _PreferredResourceValue = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "PreferredResourceValue",
}, smithy.ShapeTypeString, 0)

var _PreferredResourceValues = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "PreferredResourceValues",
}, smithy.ShapeTypeList, 1)
var _PreferredResourceValues_member *smithy.Schema

var ProjectedMetric = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ProjectedMetric",
}, smithy.ShapeTypeStructure, 3)
var ProjectedMetric_name *smithy.Schema

var ProjectedMetric_timestamps *smithy.Schema

var ProjectedMetric_values *smithy.Schema

var _ProjectedMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ProjectedMetrics",
}, smithy.ShapeTypeList, 1)
var _ProjectedMetrics_member *smithy.Schema

var _ProjectedUtilizationMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ProjectedUtilizationMetrics",
}, smithy.ShapeTypeList, 1)
var _ProjectedUtilizationMetrics_member *smithy.Schema

var _PromotionTier = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "PromotionTier",
}, smithy.ShapeTypeInteger, 0)

var _Rank = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Rank",
}, smithy.ShapeTypeInteger, 0)

var RDSCurrentInstancePerformanceRisk = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSCurrentInstancePerformanceRisk",
}, smithy.ShapeTypeEnum, 4)
var RDSCurrentInstancePerformanceRisk_VERY_LOW *smithy.Schema

var RDSCurrentInstancePerformanceRisk_LOW *smithy.Schema

var RDSCurrentInstancePerformanceRisk_MEDIUM *smithy.Schema

var RDSCurrentInstancePerformanceRisk_HIGH *smithy.Schema

var RDSDatabaseProjectedMetric = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDatabaseProjectedMetric",
}, smithy.ShapeTypeStructure, 3)
var RDSDatabaseProjectedMetric_name *smithy.Schema

var RDSDatabaseProjectedMetric_timestamps *smithy.Schema

var RDSDatabaseProjectedMetric_values *smithy.Schema

var _RDSDatabaseProjectedMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDatabaseProjectedMetrics",
}, smithy.ShapeTypeList, 1)
var _RDSDatabaseProjectedMetrics_member *smithy.Schema

var RDSDatabaseRecommendedOptionProjectedMetric = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDatabaseRecommendedOptionProjectedMetric",
}, smithy.ShapeTypeStructure, 3)
var RDSDatabaseRecommendedOptionProjectedMetric_recommendedDBInstanceClass *smithy.Schema

var RDSDatabaseRecommendedOptionProjectedMetric_rank *smithy.Schema

var RDSDatabaseRecommendedOptionProjectedMetric_projectedMetrics *smithy.Schema

var _RDSDatabaseRecommendedOptionProjectedMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDatabaseRecommendedOptionProjectedMetrics",
}, smithy.ShapeTypeList, 1)
var _RDSDatabaseRecommendedOptionProjectedMetrics_member *smithy.Schema

var RDSDBInstanceRecommendationOption = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDBInstanceRecommendationOption",
}, smithy.ShapeTypeStructure, 6)
var RDSDBInstanceRecommendationOption_dbInstanceClass *smithy.Schema

var RDSDBInstanceRecommendationOption_projectedUtilizationMetrics *smithy.Schema

var RDSDBInstanceRecommendationOption_performanceRisk *smithy.Schema

var RDSDBInstanceRecommendationOption_rank *smithy.Schema

var RDSDBInstanceRecommendationOption_savingsOpportunity *smithy.Schema

var RDSDBInstanceRecommendationOption_savingsOpportunityAfterDiscounts *smithy.Schema

var _RDSDBInstanceRecommendationOptions = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDBInstanceRecommendationOptions",
}, smithy.ShapeTypeList, 1)
var _RDSDBInstanceRecommendationOptions_member *smithy.Schema

var RDSDBMetricName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDBMetricName",
}, smithy.ShapeTypeEnum, 21)
var RDSDBMetricName_CPU *smithy.Schema

var RDSDBMetricName_MEMORY *smithy.Schema

var RDSDBMetricName_EBS_VOLUME_STORAGE_SPACE_UTILIZATION *smithy.Schema

var RDSDBMetricName_NETWORK_RECEIVE_THROUGHPUT *smithy.Schema

var RDSDBMetricName_NETWORK_TRANSMIT_THROUGHPUT *smithy.Schema

var RDSDBMetricName_EBS_VOLUME_READ_IOPS *smithy.Schema

var RDSDBMetricName_EBS_VOLUME_WRITE_IOPS *smithy.Schema

var RDSDBMetricName_EBS_VOLUME_READ_THROUGHPUT *smithy.Schema

var RDSDBMetricName_EBS_VOLUME_WRITE_THROUGHPUT *smithy.Schema

var RDSDBMetricName_DATABASE_CONNECTIONS *smithy.Schema

var RDSDBMetricName_STORAGE_NETWORK_RECEIVE_THROUGHPUT *smithy.Schema

var RDSDBMetricName_STORAGE_NETWORK_TRANSMIT_THROUGHPUT *smithy.Schema

var RDSDBMetricName_AURORA_MEMORY_HEALTH_STATE *smithy.Schema

var RDSDBMetricName_AURORA_MEMORY_NUM_DECLINED_SQL *smithy.Schema

var RDSDBMetricName_AURORA_MEMORY_NUM_KILL_CONN_TOTAL *smithy.Schema

var RDSDBMetricName_AURORA_MEMORY_NUM_KILL_QUERY_TOTAL *smithy.Schema

var RDSDBMetricName_READ_IOPS_EPHEMERAL_STORAGE *smithy.Schema

var RDSDBMetricName_WRITE_IOPS_EPHEMERAL_STORAGE *smithy.Schema

var RDSDBMetricName_VOLUME_READ_IOPS *smithy.Schema

var RDSDBMetricName_VOLUME_BYTES_USED *smithy.Schema

var RDSDBMetricName_VOLUME_WRITE_IOPS *smithy.Schema

var RDSDBMetricStatistic = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDBMetricStatistic",
}, smithy.ShapeTypeEnum, 3)
var RDSDBMetricStatistic_MAXIMUM *smithy.Schema

var RDSDBMetricStatistic_MINIMUM *smithy.Schema

var RDSDBMetricStatistic_AVERAGE *smithy.Schema

var _RDSDBProjectedUtilizationMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDBProjectedUtilizationMetrics",
}, smithy.ShapeTypeList, 1)
var _RDSDBProjectedUtilizationMetrics_member *smithy.Schema

var RDSDBRecommendation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDBRecommendation",
}, smithy.ShapeTypeStructure, 22)
var RDSDBRecommendation_resourceArn *smithy.Schema

var RDSDBRecommendation_accountId *smithy.Schema

var RDSDBRecommendation_engine *smithy.Schema

var RDSDBRecommendation_engineVersion *smithy.Schema

var RDSDBRecommendation_promotionTier *smithy.Schema

var RDSDBRecommendation_currentDBInstanceClass *smithy.Schema

var RDSDBRecommendation_currentStorageConfiguration *smithy.Schema

var RDSDBRecommendation_dbClusterIdentifier *smithy.Schema

var RDSDBRecommendation_idle *smithy.Schema

var RDSDBRecommendation_instanceFinding *smithy.Schema

var RDSDBRecommendation_storageFinding *smithy.Schema

var RDSDBRecommendation_instanceFindingReasonCodes *smithy.Schema

var RDSDBRecommendation_currentInstancePerformanceRisk *smithy.Schema

var RDSDBRecommendation_currentStorageEstimatedMonthlyVolumeIOPsCostVariation *smithy.Schema

var RDSDBRecommendation_storageFindingReasonCodes *smithy.Schema

var RDSDBRecommendation_instanceRecommendationOptions *smithy.Schema

var RDSDBRecommendation_storageRecommendationOptions *smithy.Schema

var RDSDBRecommendation_utilizationMetrics *smithy.Schema

var RDSDBRecommendation_effectiveRecommendationPreferences *smithy.Schema

var RDSDBRecommendation_lookbackPeriodInDays *smithy.Schema

var RDSDBRecommendation_lastRefreshTimestamp *smithy.Schema

var RDSDBRecommendation_tags *smithy.Schema

var RDSDBRecommendationFilter = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDBRecommendationFilter",
}, smithy.ShapeTypeStructure, 2)
var RDSDBRecommendationFilter_name *smithy.Schema

var RDSDBRecommendationFilter_values *smithy.Schema

var RDSDBRecommendationFilterName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDBRecommendationFilterName",
}, smithy.ShapeTypeEnum, 5)
var RDSDBRecommendationFilterName_INSTANCE_FINDING *smithy.Schema

var RDSDBRecommendationFilterName_INSTANCE_FINDING_REASON_CODE *smithy.Schema

var RDSDBRecommendationFilterName_STORAGE_FINDING *smithy.Schema

var RDSDBRecommendationFilterName_STORAGE_FINDING_REASON_CODE *smithy.Schema

var RDSDBRecommendationFilterName_IDLE *smithy.Schema

var _RDSDBRecommendationFilters = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDBRecommendationFilters",
}, smithy.ShapeTypeList, 1)
var _RDSDBRecommendationFilters_member *smithy.Schema

var _RDSDBRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDBRecommendations",
}, smithy.ShapeTypeList, 1)
var _RDSDBRecommendations_member *smithy.Schema

var RDSDBStorageRecommendationOption = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDBStorageRecommendationOption",
}, smithy.ShapeTypeStructure, 5)
var RDSDBStorageRecommendationOption_storageConfiguration *smithy.Schema

var RDSDBStorageRecommendationOption_rank *smithy.Schema

var RDSDBStorageRecommendationOption_savingsOpportunity *smithy.Schema

var RDSDBStorageRecommendationOption_savingsOpportunityAfterDiscounts *smithy.Schema

var RDSDBStorageRecommendationOption_estimatedMonthlyVolumeIOPsCostVariation *smithy.Schema

var _RDSDBStorageRecommendationOptions = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDBStorageRecommendationOptions",
}, smithy.ShapeTypeList, 1)
var _RDSDBStorageRecommendationOptions_member *smithy.Schema

var RDSDBUtilizationMetric = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDBUtilizationMetric",
}, smithy.ShapeTypeStructure, 3)
var RDSDBUtilizationMetric_name *smithy.Schema

var RDSDBUtilizationMetric_statistic *smithy.Schema

var RDSDBUtilizationMetric_value *smithy.Schema

var _RDSDBUtilizationMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSDBUtilizationMetrics",
}, smithy.ShapeTypeList, 1)
var _RDSDBUtilizationMetrics_member *smithy.Schema

var RDSEffectiveRecommendationPreferences = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSEffectiveRecommendationPreferences",
}, smithy.ShapeTypeStructure, 4)
var RDSEffectiveRecommendationPreferences_cpuVendorArchitectures *smithy.Schema

var RDSEffectiveRecommendationPreferences_enhancedInfrastructureMetrics *smithy.Schema

var RDSEffectiveRecommendationPreferences_lookBackPeriod *smithy.Schema

var RDSEffectiveRecommendationPreferences_savingsEstimationMode *smithy.Schema

var RDSEstimatedMonthlyVolumeIOPsCostVariation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSEstimatedMonthlyVolumeIOPsCostVariation",
}, smithy.ShapeTypeEnum, 4)
var RDSEstimatedMonthlyVolumeIOPsCostVariation_NONE *smithy.Schema

var RDSEstimatedMonthlyVolumeIOPsCostVariation_LOW *smithy.Schema

var RDSEstimatedMonthlyVolumeIOPsCostVariation_MEDIUM *smithy.Schema

var RDSEstimatedMonthlyVolumeIOPsCostVariation_HIGH *smithy.Schema

var RDSInstanceEstimatedMonthlySavings = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSInstanceEstimatedMonthlySavings",
}, smithy.ShapeTypeStructure, 2)
var RDSInstanceEstimatedMonthlySavings_currency *smithy.Schema

var RDSInstanceEstimatedMonthlySavings_value *smithy.Schema

var RDSInstanceFinding = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSInstanceFinding",
}, smithy.ShapeTypeEnum, 3)
var RDSInstanceFinding_OPTIMIZED *smithy.Schema

var RDSInstanceFinding_UNDER_PROVISIONED *smithy.Schema

var RDSInstanceFinding_OVER_PROVISIONED *smithy.Schema

var RDSInstanceFindingReasonCode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSInstanceFindingReasonCode",
}, smithy.ShapeTypeEnum, 14)
var RDSInstanceFindingReasonCode_CPU_OVER_PROVISIONED *smithy.Schema

var RDSInstanceFindingReasonCode_NETWORK_BANDWIDTH_OVER_PROVISIONED *smithy.Schema

var RDSInstanceFindingReasonCode_EBS_IOPS_OVER_PROVISIONED *smithy.Schema

var RDSInstanceFindingReasonCode_EBS_IOPS_UNDER_PROVISIONED *smithy.Schema

var RDSInstanceFindingReasonCode_EBS_THROUGHPUT_OVER_PROVISIONED *smithy.Schema

var RDSInstanceFindingReasonCode_CPU_UNDER_PROVISIONED *smithy.Schema

var RDSInstanceFindingReasonCode_NETWORK_BANDWIDTH_UNDER_PROVISIONED *smithy.Schema

var RDSInstanceFindingReasonCode_EBS_THROUGHPUT_UNDER_PROVISIONED *smithy.Schema

var RDSInstanceFindingReasonCode_NEW_GENERATION_DB_INSTANCE_CLASS_AVAILABLE *smithy.Schema

var RDSInstanceFindingReasonCode_NEW_ENGINE_VERSION_AVAILABLE *smithy.Schema

var RDSInstanceFindingReasonCode_DB_CLUSTER_WRITER_UNDER_PROVISIONED *smithy.Schema

var RDSInstanceFindingReasonCode_MEMORY_UNDER_PROVISIONED *smithy.Schema

var RDSInstanceFindingReasonCode_INSTANCE_STORAGE_READ_IOPS_UNDER_PROVISIONED *smithy.Schema

var RDSInstanceFindingReasonCode_INSTANCE_STORAGE_WRITE_IOPS_UNDER_PROVISIONED *smithy.Schema

var _RDSInstanceFindingReasonCodes = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSInstanceFindingReasonCodes",
}, smithy.ShapeTypeList, 1)
var _RDSInstanceFindingReasonCodes_member *smithy.Schema

var RDSInstanceSavingsOpportunityAfterDiscounts = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSInstanceSavingsOpportunityAfterDiscounts",
}, smithy.ShapeTypeStructure, 2)
var RDSInstanceSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage *smithy.Schema

var RDSInstanceSavingsOpportunityAfterDiscounts_estimatedMonthlySavings *smithy.Schema

var RDSSavingsEstimationMode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSSavingsEstimationMode",
}, smithy.ShapeTypeStructure, 1)
var RDSSavingsEstimationMode_source *smithy.Schema

var RDSSavingsEstimationModeSource = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSSavingsEstimationModeSource",
}, smithy.ShapeTypeEnum, 3)
var RDSSavingsEstimationModeSource_PUBLIC_PRICING *smithy.Schema

var RDSSavingsEstimationModeSource_COST_EXPLORER_RIGHTSIZING *smithy.Schema

var RDSSavingsEstimationModeSource_COST_OPTIMIZATION_HUB *smithy.Schema

var RDSStorageEstimatedMonthlySavings = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSStorageEstimatedMonthlySavings",
}, smithy.ShapeTypeStructure, 2)
var RDSStorageEstimatedMonthlySavings_currency *smithy.Schema

var RDSStorageEstimatedMonthlySavings_value *smithy.Schema

var RDSStorageFinding = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSStorageFinding",
}, smithy.ShapeTypeEnum, 4)
var RDSStorageFinding_OPTIMIZED *smithy.Schema

var RDSStorageFinding_UNDER_PROVISIONED *smithy.Schema

var RDSStorageFinding_OVER_PROVISIONED *smithy.Schema

var RDSStorageFinding_NOT_OPTIMIZED *smithy.Schema

var RDSStorageFindingReasonCode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSStorageFindingReasonCode",
}, smithy.ShapeTypeEnum, 7)
var RDSStorageFindingReasonCode_EBS_VOLUME_ALLOCATED_STORAGE_UNDER_PROVISIONED *smithy.Schema

var RDSStorageFindingReasonCode_EBS_VOLUME_THROUGHPUT_UNDER_PROVISIONED *smithy.Schema

var RDSStorageFindingReasonCode_EBS_VOLUME_IOPS_OVER_PROVISIONED *smithy.Schema

var RDSStorageFindingReasonCode_EBS_VOLUME_THROUGHPUT_OVER_PROVISIONED *smithy.Schema

var RDSStorageFindingReasonCode_NEW_GENERATION_STORAGE_TYPE_AVAILABLE *smithy.Schema

var RDSStorageFindingReasonCode_DB_CLUSTER_STORAGE_OPTION_AVAILABLE *smithy.Schema

var RDSStorageFindingReasonCode_DB_CLUSTER_STORAGE_SAVINGS_AVAILABLE *smithy.Schema

var _RDSStorageFindingReasonCodes = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSStorageFindingReasonCodes",
}, smithy.ShapeTypeList, 1)
var _RDSStorageFindingReasonCodes_member *smithy.Schema

var RDSStorageSavingsOpportunityAfterDiscounts = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RDSStorageSavingsOpportunityAfterDiscounts",
}, smithy.ShapeTypeStructure, 2)
var RDSStorageSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage *smithy.Schema

var RDSStorageSavingsOpportunityAfterDiscounts_estimatedMonthlySavings *smithy.Schema

var _ReasonCodeSummaries = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ReasonCodeSummaries",
}, smithy.ShapeTypeList, 1)
var _ReasonCodeSummaries_member *smithy.Schema

var ReasonCodeSummary = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ReasonCodeSummary",
}, smithy.ShapeTypeStructure, 2)
var ReasonCodeSummary_name *smithy.Schema

var ReasonCodeSummary_value *smithy.Schema

var RecommendationExportJob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendationExportJob",
}, smithy.ShapeTypeStructure, 7)
var RecommendationExportJob_jobId *smithy.Schema

var RecommendationExportJob_destination *smithy.Schema

var RecommendationExportJob_resourceType *smithy.Schema

var RecommendationExportJob_status *smithy.Schema

var RecommendationExportJob_creationTimestamp *smithy.Schema

var RecommendationExportJob_lastUpdatedTimestamp *smithy.Schema

var RecommendationExportJob_failureReason *smithy.Schema

var _RecommendationExportJobs = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendationExportJobs",
}, smithy.ShapeTypeList, 1)
var _RecommendationExportJobs_member *smithy.Schema

var _RecommendationOptions = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendationOptions",
}, smithy.ShapeTypeList, 1)
var _RecommendationOptions_member *smithy.Schema

var RecommendationPreferenceName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendationPreferenceName",
}, smithy.ShapeTypeEnum, 6)
var RecommendationPreferenceName_ENHANCED_INFRASTRUCTURE_METRICS *smithy.Schema

var RecommendationPreferenceName_INFERRED_WORKLOAD_TYPES *smithy.Schema

var RecommendationPreferenceName_EXTERNAL_METRICS_PREFERENCE *smithy.Schema

var RecommendationPreferenceName_LOOKBACK_PERIOD_PREFERENCE *smithy.Schema

var RecommendationPreferenceName_PREFERRED_RESOURCES *smithy.Schema

var RecommendationPreferenceName_UTILIZATION_PREFERENCES *smithy.Schema

var _RecommendationPreferenceNames = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendationPreferenceNames",
}, smithy.ShapeTypeList, 1)
var _RecommendationPreferenceNames_member *smithy.Schema

var RecommendationPreferences = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendationPreferences",
}, smithy.ShapeTypeStructure, 1)
var RecommendationPreferences_cpuVendorArchitectures *smithy.Schema

var RecommendationPreferencesDetail = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendationPreferencesDetail",
}, smithy.ShapeTypeStructure, 9)
var RecommendationPreferencesDetail_scope *smithy.Schema

var RecommendationPreferencesDetail_resourceType *smithy.Schema

var RecommendationPreferencesDetail_enhancedInfrastructureMetrics *smithy.Schema

var RecommendationPreferencesDetail_inferredWorkloadTypes *smithy.Schema

var RecommendationPreferencesDetail_externalMetricsPreference *smithy.Schema

var RecommendationPreferencesDetail_lookBackPeriod *smithy.Schema

var RecommendationPreferencesDetail_utilizationPreferences *smithy.Schema

var RecommendationPreferencesDetail_preferredResources *smithy.Schema

var RecommendationPreferencesDetail_savingsEstimationMode *smithy.Schema

var _RecommendationPreferencesDetails = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendationPreferencesDetails",
}, smithy.ShapeTypeList, 1)
var _RecommendationPreferencesDetails_member *smithy.Schema

var RecommendationSource = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendationSource",
}, smithy.ShapeTypeStructure, 2)
var RecommendationSource_recommendationSourceArn *smithy.Schema

var RecommendationSource_recommendationSourceType *smithy.Schema

var _RecommendationSourceArn = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendationSourceArn",
}, smithy.ShapeTypeString, 0)

var _RecommendationSources = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendationSources",
}, smithy.ShapeTypeList, 1)
var _RecommendationSources_member *smithy.Schema

var RecommendationSourceType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendationSourceType",
}, smithy.ShapeTypeEnum, 16)
var RecommendationSourceType_EC2_INSTANCE *smithy.Schema

var RecommendationSourceType_AUTO_SCALING_GROUP *smithy.Schema

var RecommendationSourceType_EBS_VOLUME *smithy.Schema

var RecommendationSourceType_LAMBDA_FUNCTION *smithy.Schema

var RecommendationSourceType_ECS_SERVICE *smithy.Schema

var RecommendationSourceType_LICENSE *smithy.Schema

var RecommendationSourceType_RDS_DB_INSTANCE *smithy.Schema

var RecommendationSourceType_RDS_DB_INSTANCE_STORAGE *smithy.Schema

var RecommendationSourceType_AURORA_DB_CLUSTER_STORAGE *smithy.Schema

var RecommendationSourceType_NAT_GATEWAY *smithy.Schema

var RecommendationSourceType_DYNAMO_DB_TABLE *smithy.Schema

var RecommendationSourceType_ELASTI_CACHE_CLUSTER *smithy.Schema

var RecommendationSourceType_MEMORY_DB_CLUSTER *smithy.Schema

var RecommendationSourceType_DOCUMENT_DB_CLUSTER *smithy.Schema

var RecommendationSourceType_WORKSPACES *smithy.Schema

var RecommendationSourceType_SAGE_MAKER_ENDPOINT *smithy.Schema

var _RecommendationSummaries = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendationSummaries",
}, smithy.ShapeTypeList, 1)
var _RecommendationSummaries_member *smithy.Schema

var RecommendationSummary = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendationSummary",
}, smithy.ShapeTypeStructure, 9)
var RecommendationSummary_summaries *smithy.Schema

var RecommendationSummary_idleSummaries *smithy.Schema

var RecommendationSummary_recommendationResourceType *smithy.Schema

var RecommendationSummary_accountId *smithy.Schema

var RecommendationSummary_savingsOpportunity *smithy.Schema

var RecommendationSummary_idleSavingsOpportunity *smithy.Schema

var RecommendationSummary_aggregatedSavingsOpportunity *smithy.Schema

var RecommendationSummary_currentPerformanceRiskRatings *smithy.Schema

var RecommendationSummary_inferredWorkloadSavings *smithy.Schema

var _RecommendedDBInstanceClass = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendedDBInstanceClass",
}, smithy.ShapeTypeString, 0)

var _RecommendedInstanceType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendedInstanceType",
}, smithy.ShapeTypeString, 0)

var RecommendedOptionProjectedMetric = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendedOptionProjectedMetric",
}, smithy.ShapeTypeStructure, 3)
var RecommendedOptionProjectedMetric_recommendedInstanceType *smithy.Schema

var RecommendedOptionProjectedMetric_rank *smithy.Schema

var RecommendedOptionProjectedMetric_projectedMetrics *smithy.Schema

var _RecommendedOptionProjectedMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RecommendedOptionProjectedMetrics",
}, smithy.ShapeTypeList, 1)
var _RecommendedOptionProjectedMetrics_member *smithy.Schema

var _ResourceArn = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ResourceArn",
}, smithy.ShapeTypeString, 0)

var _ResourceArns = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ResourceArns",
}, smithy.ShapeTypeList, 1)
var _ResourceArns_member *smithy.Schema

var _ResourceId = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ResourceId",
}, smithy.ShapeTypeString, 0)

var ResourceNotFoundException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ResourceNotFoundException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 404})
var ResourceNotFoundException_message *smithy.Schema

var ResourceType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ResourceType",
}, smithy.ShapeTypeEnum, 10)
var ResourceType_EC2_INSTANCE *smithy.Schema

var ResourceType_AUTO_SCALING_GROUP *smithy.Schema

var ResourceType_EBS_VOLUME *smithy.Schema

var ResourceType_LAMBDA_FUNCTION *smithy.Schema

var ResourceType_NOT_APPLICABLE *smithy.Schema

var ResourceType_ECS_SERVICE *smithy.Schema

var ResourceType_LICENSE *smithy.Schema

var ResourceType_RDS_DB_INSTANCE *smithy.Schema

var ResourceType_AURORA_DB_CLUSTER_STORAGE *smithy.Schema

var ResourceType_IDLE *smithy.Schema

var _RootVolume = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "RootVolume",
}, smithy.ShapeTypeBoolean, 0)

var S3Destination = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "S3Destination",
}, smithy.ShapeTypeStructure, 3)
var S3Destination_bucket *smithy.Schema

var S3Destination_key *smithy.Schema

var S3Destination_metadataKey *smithy.Schema

var S3DestinationConfig = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "S3DestinationConfig",
}, smithy.ShapeTypeStructure, 2)
var S3DestinationConfig_bucket *smithy.Schema

var S3DestinationConfig_keyPrefix *smithy.Schema

var SavingsEstimationMode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "SavingsEstimationMode",
}, smithy.ShapeTypeEnum, 2)
var SavingsEstimationMode_AFTER_DISCOUNTS *smithy.Schema

var SavingsEstimationMode_BEFORE_DISCOUNTS *smithy.Schema

var SavingsOpportunity = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "SavingsOpportunity",
}, smithy.ShapeTypeStructure, 2)
var SavingsOpportunity_savingsOpportunityPercentage *smithy.Schema

var SavingsOpportunity_estimatedMonthlySavings *smithy.Schema

var _SavingsOpportunityPercentage = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "SavingsOpportunityPercentage",
}, smithy.ShapeTypeDouble, 0)

var Scope = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Scope",
}, smithy.ShapeTypeStructure, 2)
var Scope_name *smithy.Schema

var Scope_value *smithy.Schema

var ScopeName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ScopeName",
}, smithy.ShapeTypeEnum, 3)
var ScopeName_ORGANIZATION *smithy.Schema

var ScopeName_ACCOUNT_ID *smithy.Schema

var ScopeName_RESOURCE_ARN *smithy.Schema

var _ScopeValue = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ScopeValue",
}, smithy.ShapeTypeString, 0)

var _ServiceArn = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ServiceArn",
}, smithy.ShapeTypeString, 0)

var _ServiceArns = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ServiceArns",
}, smithy.ShapeTypeList, 1)
var _ServiceArns_member *smithy.Schema

var ServiceConfiguration = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ServiceConfiguration",
}, smithy.ShapeTypeStructure, 5)
var ServiceConfiguration_memory *smithy.Schema

var ServiceConfiguration_cpu *smithy.Schema

var ServiceConfiguration_containerConfigurations *smithy.Schema

var ServiceConfiguration_autoScalingConfiguration *smithy.Schema

var ServiceConfiguration_taskDefinitionArn *smithy.Schema

var ServiceUnavailableException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ServiceUnavailableException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 503})
var ServiceUnavailableException_message *smithy.Schema

var Status = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Status",
}, smithy.ShapeTypeEnum, 4)
var Status_ACTIVE *smithy.Schema

var Status_INACTIVE *smithy.Schema

var Status_PENDING *smithy.Schema

var Status_FAILED *smithy.Schema

var _StatusReason = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "StatusReason",
}, smithy.ShapeTypeString, 0)

var _StorageType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "StorageType",
}, smithy.ShapeTypeString, 0)

var _Summaries = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Summaries",
}, smithy.ShapeTypeList, 1)
var _Summaries_member *smithy.Schema

var Summary = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Summary",
}, smithy.ShapeTypeStructure, 3)
var Summary_name *smithy.Schema

var Summary_value *smithy.Schema

var Summary_reasonCodeSummaries *smithy.Schema

var _SummaryValue = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "SummaryValue",
}, smithy.ShapeTypeDouble, 0)

var Tag = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Tag",
}, smithy.ShapeTypeStructure, 2)
var Tag_key *smithy.Schema

var Tag_value *smithy.Schema

var _TagKey = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "TagKey",
}, smithy.ShapeTypeString, 0)

var _Tags = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Tags",
}, smithy.ShapeTypeList, 1)
var _Tags_member *smithy.Schema

var _TagValue = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "TagValue",
}, smithy.ShapeTypeString, 0)

var _TaskDefinitionArn = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "TaskDefinitionArn",
}, smithy.ShapeTypeString, 0)

var ThrottlingException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ThrottlingException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 429})
var ThrottlingException_message *smithy.Schema

var _Timestamp = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Timestamp",
}, smithy.ShapeTypeTimestamp, 0)

var _Timestamps = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Timestamps",
}, smithy.ShapeTypeList, 1)
var _Timestamps_member *smithy.Schema

var _UpperBoundValue = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "UpperBoundValue",
}, smithy.ShapeTypeDouble, 0)

var UtilizationMetric = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "UtilizationMetric",
}, smithy.ShapeTypeStructure, 3)
var UtilizationMetric_name *smithy.Schema

var UtilizationMetric_statistic *smithy.Schema

var UtilizationMetric_value *smithy.Schema

var _UtilizationMetrics = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "UtilizationMetrics",
}, smithy.ShapeTypeList, 1)
var _UtilizationMetrics_member *smithy.Schema

var UtilizationPreference = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "UtilizationPreference",
}, smithy.ShapeTypeStructure, 2)
var UtilizationPreference_metricName *smithy.Schema

var UtilizationPreference_metricParameters *smithy.Schema

var _UtilizationPreferences = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "UtilizationPreferences",
}, smithy.ShapeTypeList, 1)
var _UtilizationPreferences_member *smithy.Schema

var _Value = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "Value",
}, smithy.ShapeTypeDouble, 0)

var _VeryLow = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "VeryLow",
}, smithy.ShapeTypeLong, 0)

var _VolumeArn = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "VolumeArn",
}, smithy.ShapeTypeString, 0)

var _VolumeArns = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "VolumeArns",
}, smithy.ShapeTypeList, 1)
var _VolumeArns_member *smithy.Schema

var _VolumeBaselineIOPS = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "VolumeBaselineIOPS",
}, smithy.ShapeTypeInteger, 0)

var _VolumeBaselineThroughput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "VolumeBaselineThroughput",
}, smithy.ShapeTypeInteger, 0)

var _VolumeBurstIOPS = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "VolumeBurstIOPS",
}, smithy.ShapeTypeInteger, 0)

var _VolumeBurstThroughput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "VolumeBurstThroughput",
}, smithy.ShapeTypeInteger, 0)

var VolumeConfiguration = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "VolumeConfiguration",
}, smithy.ShapeTypeStructure, 7)
var VolumeConfiguration_volumeType *smithy.Schema

var VolumeConfiguration_volumeSize *smithy.Schema

var VolumeConfiguration_volumeBaselineIOPS *smithy.Schema

var VolumeConfiguration_volumeBurstIOPS *smithy.Schema

var VolumeConfiguration_volumeBaselineThroughput *smithy.Schema

var VolumeConfiguration_volumeBurstThroughput *smithy.Schema

var VolumeConfiguration_rootVolume *smithy.Schema

var VolumeRecommendation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "VolumeRecommendation",
}, smithy.ShapeTypeStructure, 11)
var VolumeRecommendation_volumeArn *smithy.Schema

var VolumeRecommendation_accountId *smithy.Schema

var VolumeRecommendation_currentConfiguration *smithy.Schema

var VolumeRecommendation_finding *smithy.Schema

var VolumeRecommendation_utilizationMetrics *smithy.Schema

var VolumeRecommendation_lookBackPeriodInDays *smithy.Schema

var VolumeRecommendation_volumeRecommendationOptions *smithy.Schema

var VolumeRecommendation_lastRefreshTimestamp *smithy.Schema

var VolumeRecommendation_currentPerformanceRisk *smithy.Schema

var VolumeRecommendation_effectiveRecommendationPreferences *smithy.Schema

var VolumeRecommendation_tags *smithy.Schema

var VolumeRecommendationOption = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "VolumeRecommendationOption",
}, smithy.ShapeTypeStructure, 5)
var VolumeRecommendationOption_configuration *smithy.Schema

var VolumeRecommendationOption_performanceRisk *smithy.Schema

var VolumeRecommendationOption_rank *smithy.Schema

var VolumeRecommendationOption_savingsOpportunity *smithy.Schema

var VolumeRecommendationOption_savingsOpportunityAfterDiscounts *smithy.Schema

var _VolumeRecommendationOptions = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "VolumeRecommendationOptions",
}, smithy.ShapeTypeList, 1)
var _VolumeRecommendationOptions_member *smithy.Schema

var _VolumeRecommendations = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "VolumeRecommendations",
}, smithy.ShapeTypeList, 1)
var _VolumeRecommendations_member *smithy.Schema

var _VolumeSize = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "VolumeSize",
}, smithy.ShapeTypeInteger, 0)

var _VolumeType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "VolumeType",
}, smithy.ShapeTypeString, 0)

var DeleteRecommendationPreferencesRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "DeleteRecommendationPreferencesRequest",
}, smithy.ShapeTypeStructure, 3)
var DeleteRecommendationPreferencesRequest_resourceType *smithy.Schema

var DeleteRecommendationPreferencesRequest_scope *smithy.Schema

var DeleteRecommendationPreferencesRequest_recommendationPreferenceNames *smithy.Schema

var DeleteRecommendationPreferencesResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "DeleteRecommendationPreferencesResponse",
}, smithy.ShapeTypeStructure, 0)

var DescribeRecommendationExportJobsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "DescribeRecommendationExportJobsRequest",
}, smithy.ShapeTypeStructure, 4)
var DescribeRecommendationExportJobsRequest_jobIds *smithy.Schema

var DescribeRecommendationExportJobsRequest_filters *smithy.Schema

var DescribeRecommendationExportJobsRequest_nextToken *smithy.Schema

var DescribeRecommendationExportJobsRequest_maxResults *smithy.Schema

var DescribeRecommendationExportJobsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "DescribeRecommendationExportJobsResponse",
}, smithy.ShapeTypeStructure, 2)
var DescribeRecommendationExportJobsResponse_recommendationExportJobs *smithy.Schema

var DescribeRecommendationExportJobsResponse_nextToken *smithy.Schema

var ExportAutoScalingGroupRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportAutoScalingGroupRecommendationsRequest",
}, smithy.ShapeTypeStructure, 7)
var ExportAutoScalingGroupRecommendationsRequest_accountIds *smithy.Schema

var ExportAutoScalingGroupRecommendationsRequest_filters *smithy.Schema

var ExportAutoScalingGroupRecommendationsRequest_fieldsToExport *smithy.Schema

var ExportAutoScalingGroupRecommendationsRequest_s3DestinationConfig *smithy.Schema

var ExportAutoScalingGroupRecommendationsRequest_fileFormat *smithy.Schema

var ExportAutoScalingGroupRecommendationsRequest_includeMemberAccounts *smithy.Schema

var ExportAutoScalingGroupRecommendationsRequest_recommendationPreferences *smithy.Schema

var ExportAutoScalingGroupRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportAutoScalingGroupRecommendationsResponse",
}, smithy.ShapeTypeStructure, 2)
var ExportAutoScalingGroupRecommendationsResponse_jobId *smithy.Schema

var ExportAutoScalingGroupRecommendationsResponse_s3Destination *smithy.Schema

var ExportEBSVolumeRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportEBSVolumeRecommendationsRequest",
}, smithy.ShapeTypeStructure, 6)
var ExportEBSVolumeRecommendationsRequest_accountIds *smithy.Schema

var ExportEBSVolumeRecommendationsRequest_filters *smithy.Schema

var ExportEBSVolumeRecommendationsRequest_fieldsToExport *smithy.Schema

var ExportEBSVolumeRecommendationsRequest_s3DestinationConfig *smithy.Schema

var ExportEBSVolumeRecommendationsRequest_fileFormat *smithy.Schema

var ExportEBSVolumeRecommendationsRequest_includeMemberAccounts *smithy.Schema

var ExportEBSVolumeRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportEBSVolumeRecommendationsResponse",
}, smithy.ShapeTypeStructure, 2)
var ExportEBSVolumeRecommendationsResponse_jobId *smithy.Schema

var ExportEBSVolumeRecommendationsResponse_s3Destination *smithy.Schema

var ExportEC2InstanceRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportEC2InstanceRecommendationsRequest",
}, smithy.ShapeTypeStructure, 7)
var ExportEC2InstanceRecommendationsRequest_accountIds *smithy.Schema

var ExportEC2InstanceRecommendationsRequest_filters *smithy.Schema

var ExportEC2InstanceRecommendationsRequest_fieldsToExport *smithy.Schema

var ExportEC2InstanceRecommendationsRequest_s3DestinationConfig *smithy.Schema

var ExportEC2InstanceRecommendationsRequest_fileFormat *smithy.Schema

var ExportEC2InstanceRecommendationsRequest_includeMemberAccounts *smithy.Schema

var ExportEC2InstanceRecommendationsRequest_recommendationPreferences *smithy.Schema

var ExportEC2InstanceRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportEC2InstanceRecommendationsResponse",
}, smithy.ShapeTypeStructure, 2)
var ExportEC2InstanceRecommendationsResponse_jobId *smithy.Schema

var ExportEC2InstanceRecommendationsResponse_s3Destination *smithy.Schema

var ExportECSServiceRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportECSServiceRecommendationsRequest",
}, smithy.ShapeTypeStructure, 6)
var ExportECSServiceRecommendationsRequest_accountIds *smithy.Schema

var ExportECSServiceRecommendationsRequest_filters *smithy.Schema

var ExportECSServiceRecommendationsRequest_fieldsToExport *smithy.Schema

var ExportECSServiceRecommendationsRequest_s3DestinationConfig *smithy.Schema

var ExportECSServiceRecommendationsRequest_fileFormat *smithy.Schema

var ExportECSServiceRecommendationsRequest_includeMemberAccounts *smithy.Schema

var ExportECSServiceRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportECSServiceRecommendationsResponse",
}, smithy.ShapeTypeStructure, 2)
var ExportECSServiceRecommendationsResponse_jobId *smithy.Schema

var ExportECSServiceRecommendationsResponse_s3Destination *smithy.Schema

var ExportIdleRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportIdleRecommendationsRequest",
}, smithy.ShapeTypeStructure, 6)
var ExportIdleRecommendationsRequest_accountIds *smithy.Schema

var ExportIdleRecommendationsRequest_filters *smithy.Schema

var ExportIdleRecommendationsRequest_fieldsToExport *smithy.Schema

var ExportIdleRecommendationsRequest_s3DestinationConfig *smithy.Schema

var ExportIdleRecommendationsRequest_fileFormat *smithy.Schema

var ExportIdleRecommendationsRequest_includeMemberAccounts *smithy.Schema

var ExportIdleRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportIdleRecommendationsResponse",
}, smithy.ShapeTypeStructure, 2)
var ExportIdleRecommendationsResponse_jobId *smithy.Schema

var ExportIdleRecommendationsResponse_s3Destination *smithy.Schema

var ExportLambdaFunctionRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportLambdaFunctionRecommendationsRequest",
}, smithy.ShapeTypeStructure, 6)
var ExportLambdaFunctionRecommendationsRequest_accountIds *smithy.Schema

var ExportLambdaFunctionRecommendationsRequest_filters *smithy.Schema

var ExportLambdaFunctionRecommendationsRequest_fieldsToExport *smithy.Schema

var ExportLambdaFunctionRecommendationsRequest_s3DestinationConfig *smithy.Schema

var ExportLambdaFunctionRecommendationsRequest_fileFormat *smithy.Schema

var ExportLambdaFunctionRecommendationsRequest_includeMemberAccounts *smithy.Schema

var ExportLambdaFunctionRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportLambdaFunctionRecommendationsResponse",
}, smithy.ShapeTypeStructure, 2)
var ExportLambdaFunctionRecommendationsResponse_jobId *smithy.Schema

var ExportLambdaFunctionRecommendationsResponse_s3Destination *smithy.Schema

var ExportLicenseRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportLicenseRecommendationsRequest",
}, smithy.ShapeTypeStructure, 6)
var ExportLicenseRecommendationsRequest_accountIds *smithy.Schema

var ExportLicenseRecommendationsRequest_filters *smithy.Schema

var ExportLicenseRecommendationsRequest_fieldsToExport *smithy.Schema

var ExportLicenseRecommendationsRequest_s3DestinationConfig *smithy.Schema

var ExportLicenseRecommendationsRequest_fileFormat *smithy.Schema

var ExportLicenseRecommendationsRequest_includeMemberAccounts *smithy.Schema

var ExportLicenseRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportLicenseRecommendationsResponse",
}, smithy.ShapeTypeStructure, 2)
var ExportLicenseRecommendationsResponse_jobId *smithy.Schema

var ExportLicenseRecommendationsResponse_s3Destination *smithy.Schema

var ExportRDSDatabaseRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportRDSDatabaseRecommendationsRequest",
}, smithy.ShapeTypeStructure, 7)
var ExportRDSDatabaseRecommendationsRequest_accountIds *smithy.Schema

var ExportRDSDatabaseRecommendationsRequest_filters *smithy.Schema

var ExportRDSDatabaseRecommendationsRequest_fieldsToExport *smithy.Schema

var ExportRDSDatabaseRecommendationsRequest_s3DestinationConfig *smithy.Schema

var ExportRDSDatabaseRecommendationsRequest_fileFormat *smithy.Schema

var ExportRDSDatabaseRecommendationsRequest_includeMemberAccounts *smithy.Schema

var ExportRDSDatabaseRecommendationsRequest_recommendationPreferences *smithy.Schema

var ExportRDSDatabaseRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "ExportRDSDatabaseRecommendationsResponse",
}, smithy.ShapeTypeStructure, 2)
var ExportRDSDatabaseRecommendationsResponse_jobId *smithy.Schema

var ExportRDSDatabaseRecommendationsResponse_s3Destination *smithy.Schema

var GetAutoScalingGroupRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetAutoScalingGroupRecommendationsRequest",
}, smithy.ShapeTypeStructure, 6)
var GetAutoScalingGroupRecommendationsRequest_accountIds *smithy.Schema

var GetAutoScalingGroupRecommendationsRequest_autoScalingGroupArns *smithy.Schema

var GetAutoScalingGroupRecommendationsRequest_nextToken *smithy.Schema

var GetAutoScalingGroupRecommendationsRequest_maxResults *smithy.Schema

var GetAutoScalingGroupRecommendationsRequest_filters *smithy.Schema

var GetAutoScalingGroupRecommendationsRequest_recommendationPreferences *smithy.Schema

var GetAutoScalingGroupRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetAutoScalingGroupRecommendationsResponse",
}, smithy.ShapeTypeStructure, 3)
var GetAutoScalingGroupRecommendationsResponse_nextToken *smithy.Schema

var GetAutoScalingGroupRecommendationsResponse_autoScalingGroupRecommendations *smithy.Schema

var GetAutoScalingGroupRecommendationsResponse_errors *smithy.Schema

var GetEBSVolumeRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEBSVolumeRecommendationsRequest",
}, smithy.ShapeTypeStructure, 5)
var GetEBSVolumeRecommendationsRequest_volumeArns *smithy.Schema

var GetEBSVolumeRecommendationsRequest_nextToken *smithy.Schema

var GetEBSVolumeRecommendationsRequest_maxResults *smithy.Schema

var GetEBSVolumeRecommendationsRequest_filters *smithy.Schema

var GetEBSVolumeRecommendationsRequest_accountIds *smithy.Schema

var GetEBSVolumeRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEBSVolumeRecommendationsResponse",
}, smithy.ShapeTypeStructure, 3)
var GetEBSVolumeRecommendationsResponse_nextToken *smithy.Schema

var GetEBSVolumeRecommendationsResponse_volumeRecommendations *smithy.Schema

var GetEBSVolumeRecommendationsResponse_errors *smithy.Schema

var GetEC2InstanceRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEC2InstanceRecommendationsRequest",
}, smithy.ShapeTypeStructure, 6)
var GetEC2InstanceRecommendationsRequest_instanceArns *smithy.Schema

var GetEC2InstanceRecommendationsRequest_nextToken *smithy.Schema

var GetEC2InstanceRecommendationsRequest_maxResults *smithy.Schema

var GetEC2InstanceRecommendationsRequest_filters *smithy.Schema

var GetEC2InstanceRecommendationsRequest_accountIds *smithy.Schema

var GetEC2InstanceRecommendationsRequest_recommendationPreferences *smithy.Schema

var GetEC2InstanceRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEC2InstanceRecommendationsResponse",
}, smithy.ShapeTypeStructure, 3)
var GetEC2InstanceRecommendationsResponse_nextToken *smithy.Schema

var GetEC2InstanceRecommendationsResponse_instanceRecommendations *smithy.Schema

var GetEC2InstanceRecommendationsResponse_errors *smithy.Schema

var GetEC2RecommendationProjectedMetricsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEC2RecommendationProjectedMetricsRequest",
}, smithy.ShapeTypeStructure, 6)
var GetEC2RecommendationProjectedMetricsRequest_instanceArn *smithy.Schema

var GetEC2RecommendationProjectedMetricsRequest_stat *smithy.Schema

var GetEC2RecommendationProjectedMetricsRequest_period *smithy.Schema

var GetEC2RecommendationProjectedMetricsRequest_startTime *smithy.Schema

var GetEC2RecommendationProjectedMetricsRequest_endTime *smithy.Schema

var GetEC2RecommendationProjectedMetricsRequest_recommendationPreferences *smithy.Schema

var GetEC2RecommendationProjectedMetricsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEC2RecommendationProjectedMetricsResponse",
}, smithy.ShapeTypeStructure, 1)
var GetEC2RecommendationProjectedMetricsResponse_recommendedOptionProjectedMetrics *smithy.Schema

var GetECSServiceRecommendationProjectedMetricsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetECSServiceRecommendationProjectedMetricsRequest",
}, smithy.ShapeTypeStructure, 5)
var GetECSServiceRecommendationProjectedMetricsRequest_serviceArn *smithy.Schema

var GetECSServiceRecommendationProjectedMetricsRequest_stat *smithy.Schema

var GetECSServiceRecommendationProjectedMetricsRequest_period *smithy.Schema

var GetECSServiceRecommendationProjectedMetricsRequest_startTime *smithy.Schema

var GetECSServiceRecommendationProjectedMetricsRequest_endTime *smithy.Schema

var GetECSServiceRecommendationProjectedMetricsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetECSServiceRecommendationProjectedMetricsResponse",
}, smithy.ShapeTypeStructure, 1)
var GetECSServiceRecommendationProjectedMetricsResponse_recommendedOptionProjectedMetrics *smithy.Schema

var GetECSServiceRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetECSServiceRecommendationsRequest",
}, smithy.ShapeTypeStructure, 5)
var GetECSServiceRecommendationsRequest_serviceArns *smithy.Schema

var GetECSServiceRecommendationsRequest_nextToken *smithy.Schema

var GetECSServiceRecommendationsRequest_maxResults *smithy.Schema

var GetECSServiceRecommendationsRequest_filters *smithy.Schema

var GetECSServiceRecommendationsRequest_accountIds *smithy.Schema

var GetECSServiceRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetECSServiceRecommendationsResponse",
}, smithy.ShapeTypeStructure, 3)
var GetECSServiceRecommendationsResponse_nextToken *smithy.Schema

var GetECSServiceRecommendationsResponse_ecsServiceRecommendations *smithy.Schema

var GetECSServiceRecommendationsResponse_errors *smithy.Schema

var GetEffectiveRecommendationPreferencesRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEffectiveRecommendationPreferencesRequest",
}, smithy.ShapeTypeStructure, 1)
var GetEffectiveRecommendationPreferencesRequest_resourceArn *smithy.Schema

var GetEffectiveRecommendationPreferencesResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEffectiveRecommendationPreferencesResponse",
}, smithy.ShapeTypeStructure, 5)
var GetEffectiveRecommendationPreferencesResponse_enhancedInfrastructureMetrics *smithy.Schema

var GetEffectiveRecommendationPreferencesResponse_externalMetricsPreference *smithy.Schema

var GetEffectiveRecommendationPreferencesResponse_lookBackPeriod *smithy.Schema

var GetEffectiveRecommendationPreferencesResponse_utilizationPreferences *smithy.Schema

var GetEffectiveRecommendationPreferencesResponse_preferredResources *smithy.Schema

var GetEnrollmentStatusesForOrganizationRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEnrollmentStatusesForOrganizationRequest",
}, smithy.ShapeTypeStructure, 3)
var GetEnrollmentStatusesForOrganizationRequest_filters *smithy.Schema

var GetEnrollmentStatusesForOrganizationRequest_nextToken *smithy.Schema

var GetEnrollmentStatusesForOrganizationRequest_maxResults *smithy.Schema

var GetEnrollmentStatusesForOrganizationResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEnrollmentStatusesForOrganizationResponse",
}, smithy.ShapeTypeStructure, 2)
var GetEnrollmentStatusesForOrganizationResponse_accountEnrollmentStatuses *smithy.Schema

var GetEnrollmentStatusesForOrganizationResponse_nextToken *smithy.Schema

var GetEnrollmentStatusRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEnrollmentStatusRequest",
}, smithy.ShapeTypeStructure, 0)

var GetEnrollmentStatusResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetEnrollmentStatusResponse",
}, smithy.ShapeTypeStructure, 5)
var GetEnrollmentStatusResponse_status *smithy.Schema

var GetEnrollmentStatusResponse_statusReason *smithy.Schema

var GetEnrollmentStatusResponse_memberAccountsEnrolled *smithy.Schema

var GetEnrollmentStatusResponse_lastUpdatedTimestamp *smithy.Schema

var GetEnrollmentStatusResponse_numberOfMemberAccountsOptedIn *smithy.Schema

var GetIdleRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetIdleRecommendationsRequest",
}, smithy.ShapeTypeStructure, 6)
var GetIdleRecommendationsRequest_resourceArns *smithy.Schema

var GetIdleRecommendationsRequest_nextToken *smithy.Schema

var GetIdleRecommendationsRequest_maxResults *smithy.Schema

var GetIdleRecommendationsRequest_filters *smithy.Schema

var GetIdleRecommendationsRequest_accountIds *smithy.Schema

var GetIdleRecommendationsRequest_orderBy *smithy.Schema

var GetIdleRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetIdleRecommendationsResponse",
}, smithy.ShapeTypeStructure, 3)
var GetIdleRecommendationsResponse_nextToken *smithy.Schema

var GetIdleRecommendationsResponse_idleRecommendations *smithy.Schema

var GetIdleRecommendationsResponse_errors *smithy.Schema

var GetLambdaFunctionRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetLambdaFunctionRecommendationsRequest",
}, smithy.ShapeTypeStructure, 5)
var GetLambdaFunctionRecommendationsRequest_functionArns *smithy.Schema

var GetLambdaFunctionRecommendationsRequest_accountIds *smithy.Schema

var GetLambdaFunctionRecommendationsRequest_filters *smithy.Schema

var GetLambdaFunctionRecommendationsRequest_nextToken *smithy.Schema

var GetLambdaFunctionRecommendationsRequest_maxResults *smithy.Schema

var GetLambdaFunctionRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetLambdaFunctionRecommendationsResponse",
}, smithy.ShapeTypeStructure, 2)
var GetLambdaFunctionRecommendationsResponse_nextToken *smithy.Schema

var GetLambdaFunctionRecommendationsResponse_lambdaFunctionRecommendations *smithy.Schema

var GetLicenseRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetLicenseRecommendationsRequest",
}, smithy.ShapeTypeStructure, 5)
var GetLicenseRecommendationsRequest_resourceArns *smithy.Schema

var GetLicenseRecommendationsRequest_nextToken *smithy.Schema

var GetLicenseRecommendationsRequest_maxResults *smithy.Schema

var GetLicenseRecommendationsRequest_filters *smithy.Schema

var GetLicenseRecommendationsRequest_accountIds *smithy.Schema

var GetLicenseRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetLicenseRecommendationsResponse",
}, smithy.ShapeTypeStructure, 3)
var GetLicenseRecommendationsResponse_nextToken *smithy.Schema

var GetLicenseRecommendationsResponse_licenseRecommendations *smithy.Schema

var GetLicenseRecommendationsResponse_errors *smithy.Schema

var GetRDSDatabaseRecommendationProjectedMetricsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetRDSDatabaseRecommendationProjectedMetricsRequest",
}, smithy.ShapeTypeStructure, 6)
var GetRDSDatabaseRecommendationProjectedMetricsRequest_resourceArn *smithy.Schema

var GetRDSDatabaseRecommendationProjectedMetricsRequest_stat *smithy.Schema

var GetRDSDatabaseRecommendationProjectedMetricsRequest_period *smithy.Schema

var GetRDSDatabaseRecommendationProjectedMetricsRequest_startTime *smithy.Schema

var GetRDSDatabaseRecommendationProjectedMetricsRequest_endTime *smithy.Schema

var GetRDSDatabaseRecommendationProjectedMetricsRequest_recommendationPreferences *smithy.Schema

var GetRDSDatabaseRecommendationProjectedMetricsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetRDSDatabaseRecommendationProjectedMetricsResponse",
}, smithy.ShapeTypeStructure, 1)
var GetRDSDatabaseRecommendationProjectedMetricsResponse_recommendedOptionProjectedMetrics *smithy.Schema

var GetRDSDatabaseRecommendationsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetRDSDatabaseRecommendationsRequest",
}, smithy.ShapeTypeStructure, 6)
var GetRDSDatabaseRecommendationsRequest_resourceArns *smithy.Schema

var GetRDSDatabaseRecommendationsRequest_nextToken *smithy.Schema

var GetRDSDatabaseRecommendationsRequest_maxResults *smithy.Schema

var GetRDSDatabaseRecommendationsRequest_filters *smithy.Schema

var GetRDSDatabaseRecommendationsRequest_accountIds *smithy.Schema

var GetRDSDatabaseRecommendationsRequest_recommendationPreferences *smithy.Schema

var GetRDSDatabaseRecommendationsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetRDSDatabaseRecommendationsResponse",
}, smithy.ShapeTypeStructure, 3)
var GetRDSDatabaseRecommendationsResponse_nextToken *smithy.Schema

var GetRDSDatabaseRecommendationsResponse_rdsDBRecommendations *smithy.Schema

var GetRDSDatabaseRecommendationsResponse_errors *smithy.Schema

var GetRecommendationPreferencesRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetRecommendationPreferencesRequest",
}, smithy.ShapeTypeStructure, 4)
var GetRecommendationPreferencesRequest_resourceType *smithy.Schema

var GetRecommendationPreferencesRequest_scope *smithy.Schema

var GetRecommendationPreferencesRequest_nextToken *smithy.Schema

var GetRecommendationPreferencesRequest_maxResults *smithy.Schema

var GetRecommendationPreferencesResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetRecommendationPreferencesResponse",
}, smithy.ShapeTypeStructure, 2)
var GetRecommendationPreferencesResponse_nextToken *smithy.Schema

var GetRecommendationPreferencesResponse_recommendationPreferencesDetails *smithy.Schema

var GetRecommendationSummariesRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetRecommendationSummariesRequest",
}, smithy.ShapeTypeStructure, 3)
var GetRecommendationSummariesRequest_accountIds *smithy.Schema

var GetRecommendationSummariesRequest_nextToken *smithy.Schema

var GetRecommendationSummariesRequest_maxResults *smithy.Schema

var GetRecommendationSummariesResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "GetRecommendationSummariesResponse",
}, smithy.ShapeTypeStructure, 2)
var GetRecommendationSummariesResponse_nextToken *smithy.Schema

var GetRecommendationSummariesResponse_recommendationSummaries *smithy.Schema

var PutRecommendationPreferencesRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "PutRecommendationPreferencesRequest",
}, smithy.ShapeTypeStructure, 9)
var PutRecommendationPreferencesRequest_resourceType *smithy.Schema

var PutRecommendationPreferencesRequest_scope *smithy.Schema

var PutRecommendationPreferencesRequest_enhancedInfrastructureMetrics *smithy.Schema

var PutRecommendationPreferencesRequest_inferredWorkloadTypes *smithy.Schema

var PutRecommendationPreferencesRequest_externalMetricsPreference *smithy.Schema

var PutRecommendationPreferencesRequest_lookBackPeriod *smithy.Schema

var PutRecommendationPreferencesRequest_utilizationPreferences *smithy.Schema

var PutRecommendationPreferencesRequest_preferredResources *smithy.Schema

var PutRecommendationPreferencesRequest_savingsEstimationMode *smithy.Schema

var PutRecommendationPreferencesResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "PutRecommendationPreferencesResponse",
}, smithy.ShapeTypeStructure, 0)

var UpdateEnrollmentStatusRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "UpdateEnrollmentStatusRequest",
}, smithy.ShapeTypeStructure, 2)
var UpdateEnrollmentStatusRequest_status *smithy.Schema

var UpdateEnrollmentStatusRequest_includeMemberAccounts *smithy.Schema

var UpdateEnrollmentStatusResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.computeoptimizer",
	Name:      "UpdateEnrollmentStatusResponse",
}, smithy.ShapeTypeStructure, 2)
var UpdateEnrollmentStatusResponse_status *smithy.Schema

var UpdateEnrollmentStatusResponse_statusReason *smithy.Schema

// Initialize schema members after all schemas are declared to avoid
// initialization cycles
func init() {
	AccessDeniedException_message = AccessDeniedException.AddMember("message", _ErrorMessage)

	Status_ACTIVE = Status.AddMember("ACTIVE", smithyprelude.Unit)

	Status_INACTIVE = Status.AddMember("INACTIVE", smithyprelude.Unit)

	Status_PENDING = Status.AddMember("PENDING", smithyprelude.Unit)

	Status_FAILED = Status.AddMember("FAILED", smithyprelude.Unit)

	AccountEnrollmentStatus_accountId = AccountEnrollmentStatus.AddMember("accountId", _AccountId)

	AccountEnrollmentStatus_status = AccountEnrollmentStatus.AddMember("status", Status)

	AccountEnrollmentStatus_statusReason = AccountEnrollmentStatus.AddMember("statusReason", _StatusReason)

	AccountEnrollmentStatus_lastUpdatedTimestamp = AccountEnrollmentStatus.AddMember("lastUpdatedTimestamp", _LastUpdatedTimestamp)

	_AccountEnrollmentStatuses_member = _AccountEnrollmentStatuses.AddMember("member", AccountEnrollmentStatus)

	_AccountIds_member = _AccountIds.AddMember("member", _AccountId)

	AllocationStrategy_PRIORITIZED = AllocationStrategy.AddMember("PRIORITIZED", smithyprelude.Unit)

	AllocationStrategy_LOWEST_PRICE = AllocationStrategy.AddMember("LOWEST_PRICE", smithyprelude.Unit)

	AsgType_SINGLE_INSTANCE_TYPE = AsgType.AddMember("SINGLE_INSTANCE_TYPE", smithyprelude.Unit)

	AsgType_MIXED_INSTANCE_TYPE = AsgType.AddMember("MIXED_INSTANCE_TYPE", smithyprelude.Unit)

	AutoScalingConfiguration_TARGET_TRACKING_SCALING_CPU = AutoScalingConfiguration.AddMember("TARGET_TRACKING_SCALING_CPU", smithyprelude.Unit)

	AutoScalingConfiguration_TARGET_TRACKING_SCALING_MEMORY = AutoScalingConfiguration.AddMember("TARGET_TRACKING_SCALING_MEMORY", smithyprelude.Unit)

	_AutoScalingGroupArns_member = _AutoScalingGroupArns.AddMember("member", _AutoScalingGroupArn)

	_MixedInstanceTypes_member = _MixedInstanceTypes.AddMember("member", _MixedInstanceType)

	AutoScalingGroupConfiguration_desiredCapacity = AutoScalingGroupConfiguration.AddMember("desiredCapacity", _DesiredCapacity)

	AutoScalingGroupConfiguration_minSize = AutoScalingGroupConfiguration.AddMember("minSize", _MinSize)

	AutoScalingGroupConfiguration_maxSize = AutoScalingGroupConfiguration.AddMember("maxSize", _MaxSize)

	AutoScalingGroupConfiguration_instanceType = AutoScalingGroupConfiguration.AddMember("instanceType", _NullableInstanceType)

	AutoScalingGroupConfiguration_allocationStrategy = AutoScalingGroupConfiguration.AddMember("allocationStrategy", AllocationStrategy)

	AutoScalingGroupConfiguration_estimatedInstanceHourReductionPercentage = AutoScalingGroupConfiguration.AddMember("estimatedInstanceHourReductionPercentage", _NullableEstimatedInstanceHourReductionPercentage)

	AutoScalingGroupConfiguration_type = AutoScalingGroupConfiguration.AddMember("type", AsgType)

	AutoScalingGroupConfiguration_mixedInstanceTypes = AutoScalingGroupConfiguration.AddMember("mixedInstanceTypes", _MixedInstanceTypes)

	Currency_USD = Currency.AddMember("USD", smithyprelude.Unit)

	Currency_CNY = Currency.AddMember("CNY", smithyprelude.Unit)

	AutoScalingGroupEstimatedMonthlySavings_currency = AutoScalingGroupEstimatedMonthlySavings.AddMember("currency", Currency)

	AutoScalingGroupEstimatedMonthlySavings_value = AutoScalingGroupEstimatedMonthlySavings.AddMember("value", _Value)

	Finding_UNDER_PROVISIONED = Finding.AddMember("UNDER_PROVISIONED", smithyprelude.Unit)

	Finding_OVER_PROVISIONED = Finding.AddMember("OVER_PROVISIONED", smithyprelude.Unit)

	Finding_OPTIMIZED = Finding.AddMember("OPTIMIZED", smithyprelude.Unit)

	Finding_NOT_OPTIMIZED = Finding.AddMember("NOT_OPTIMIZED", smithyprelude.Unit)

	MetricName_CPU = MetricName.AddMember("CPU", smithyprelude.Unit)

	MetricName_MEMORY = MetricName.AddMember("MEMORY", smithyprelude.Unit)

	MetricName_EBS_READ_OPS_PER_SECOND = MetricName.AddMember("EBS_READ_OPS_PER_SECOND", smithyprelude.Unit)

	MetricName_EBS_WRITE_OPS_PER_SECOND = MetricName.AddMember("EBS_WRITE_OPS_PER_SECOND", smithyprelude.Unit)

	MetricName_EBS_READ_BYTES_PER_SECOND = MetricName.AddMember("EBS_READ_BYTES_PER_SECOND", smithyprelude.Unit)

	MetricName_EBS_WRITE_BYTES_PER_SECOND = MetricName.AddMember("EBS_WRITE_BYTES_PER_SECOND", smithyprelude.Unit)

	MetricName_DISK_READ_OPS_PER_SECOND = MetricName.AddMember("DISK_READ_OPS_PER_SECOND", smithyprelude.Unit)

	MetricName_DISK_WRITE_OPS_PER_SECOND = MetricName.AddMember("DISK_WRITE_OPS_PER_SECOND", smithyprelude.Unit)

	MetricName_DISK_READ_BYTES_PER_SECOND = MetricName.AddMember("DISK_READ_BYTES_PER_SECOND", smithyprelude.Unit)

	MetricName_DISK_WRITE_BYTES_PER_SECOND = MetricName.AddMember("DISK_WRITE_BYTES_PER_SECOND", smithyprelude.Unit)

	MetricName_NETWORK_IN_BYTES_PER_SECOND = MetricName.AddMember("NETWORK_IN_BYTES_PER_SECOND", smithyprelude.Unit)

	MetricName_NETWORK_OUT_BYTES_PER_SECOND = MetricName.AddMember("NETWORK_OUT_BYTES_PER_SECOND", smithyprelude.Unit)

	MetricName_NETWORK_PACKETS_IN_PER_SECOND = MetricName.AddMember("NETWORK_PACKETS_IN_PER_SECOND", smithyprelude.Unit)

	MetricName_NETWORK_PACKETS_OUT_PER_SECOND = MetricName.AddMember("NETWORK_PACKETS_OUT_PER_SECOND", smithyprelude.Unit)

	MetricName_GPU_PERCENTAGE = MetricName.AddMember("GPU_PERCENTAGE", smithyprelude.Unit)

	MetricName_GPU_MEMORY_PERCENTAGE = MetricName.AddMember("GPU_MEMORY_PERCENTAGE", smithyprelude.Unit)

	MetricStatistic_MAXIMUM = MetricStatistic.AddMember("MAXIMUM", smithyprelude.Unit)

	MetricStatistic_AVERAGE = MetricStatistic.AddMember("AVERAGE", smithyprelude.Unit)

	UtilizationMetric_name = UtilizationMetric.AddMember("name", MetricName)

	UtilizationMetric_statistic = UtilizationMetric.AddMember("statistic", MetricStatistic)

	UtilizationMetric_value = UtilizationMetric.AddMember("value", _MetricValue)

	_UtilizationMetrics_member = _UtilizationMetrics.AddMember("member", UtilizationMetric)

	Gpu_gpuCount = Gpu.AddMember("gpuCount", _GpuCount)

	Gpu_gpuMemorySizeInMiB = Gpu.AddMember("gpuMemorySizeInMiB", _GpuMemorySizeInMiB)

	_Gpus_member = _Gpus.AddMember("member", Gpu)

	GpuInfo_gpus = GpuInfo.AddMember("gpus", _Gpus)

	_ProjectedUtilizationMetrics_member = _ProjectedUtilizationMetrics.AddMember("member", UtilizationMetric)

	EstimatedMonthlySavings_currency = EstimatedMonthlySavings.AddMember("currency", Currency)

	EstimatedMonthlySavings_value = EstimatedMonthlySavings.AddMember("value", _Value)

	SavingsOpportunity_savingsOpportunityPercentage = SavingsOpportunity.AddMember("savingsOpportunityPercentage", _SavingsOpportunityPercentage)

	SavingsOpportunity_estimatedMonthlySavings = SavingsOpportunity.AddMember("estimatedMonthlySavings", EstimatedMonthlySavings)

	AutoScalingGroupSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage = AutoScalingGroupSavingsOpportunityAfterDiscounts.AddMember("savingsOpportunityPercentage", _SavingsOpportunityPercentage)

	AutoScalingGroupSavingsOpportunityAfterDiscounts_estimatedMonthlySavings = AutoScalingGroupSavingsOpportunityAfterDiscounts.AddMember("estimatedMonthlySavings", AutoScalingGroupEstimatedMonthlySavings)

	MigrationEffort_VERY_LOW = MigrationEffort.AddMember("VERY_LOW", smithyprelude.Unit)

	MigrationEffort_LOW = MigrationEffort.AddMember("LOW", smithyprelude.Unit)

	MigrationEffort_MEDIUM = MigrationEffort.AddMember("MEDIUM", smithyprelude.Unit)

	MigrationEffort_HIGH = MigrationEffort.AddMember("HIGH", smithyprelude.Unit)

	AutoScalingGroupRecommendationOption_configuration = AutoScalingGroupRecommendationOption.AddMember("configuration", AutoScalingGroupConfiguration)

	AutoScalingGroupRecommendationOption_instanceGpuInfo = AutoScalingGroupRecommendationOption.AddMember("instanceGpuInfo", GpuInfo)

	AutoScalingGroupRecommendationOption_projectedUtilizationMetrics = AutoScalingGroupRecommendationOption.AddMember("projectedUtilizationMetrics", _ProjectedUtilizationMetrics)

	AutoScalingGroupRecommendationOption_performanceRisk = AutoScalingGroupRecommendationOption.AddMember("performanceRisk", _PerformanceRisk)

	AutoScalingGroupRecommendationOption_rank = AutoScalingGroupRecommendationOption.AddMember("rank", _Rank)

	AutoScalingGroupRecommendationOption_savingsOpportunity = AutoScalingGroupRecommendationOption.AddMember("savingsOpportunity", SavingsOpportunity)

	AutoScalingGroupRecommendationOption_savingsOpportunityAfterDiscounts = AutoScalingGroupRecommendationOption.AddMember("savingsOpportunityAfterDiscounts", AutoScalingGroupSavingsOpportunityAfterDiscounts)

	AutoScalingGroupRecommendationOption_migrationEffort = AutoScalingGroupRecommendationOption.AddMember("migrationEffort", MigrationEffort)

	_AutoScalingGroupRecommendationOptions_member = _AutoScalingGroupRecommendationOptions.AddMember("member", AutoScalingGroupRecommendationOption)

	CurrentPerformanceRisk_VERY_LOW = CurrentPerformanceRisk.AddMember("VERY_LOW", smithyprelude.Unit)

	CurrentPerformanceRisk_LOW = CurrentPerformanceRisk.AddMember("LOW", smithyprelude.Unit)

	CurrentPerformanceRisk_MEDIUM = CurrentPerformanceRisk.AddMember("MEDIUM", smithyprelude.Unit)

	CurrentPerformanceRisk_HIGH = CurrentPerformanceRisk.AddMember("HIGH", smithyprelude.Unit)

	CpuVendorArchitecture_AWS_ARM64 = CpuVendorArchitecture.AddMember("AWS_ARM64", smithyprelude.Unit)

	CpuVendorArchitecture_CURRENT = CpuVendorArchitecture.AddMember("CURRENT", smithyprelude.Unit)

	_CpuVendorArchitectures_member = _CpuVendorArchitectures.AddMember("member", CpuVendorArchitecture)

	EnhancedInfrastructureMetrics_ACTIVE = EnhancedInfrastructureMetrics.AddMember("ACTIVE", smithyprelude.Unit)

	EnhancedInfrastructureMetrics_INACTIVE = EnhancedInfrastructureMetrics.AddMember("INACTIVE", smithyprelude.Unit)

	InferredWorkloadTypesPreference_ACTIVE = InferredWorkloadTypesPreference.AddMember("ACTIVE", smithyprelude.Unit)

	InferredWorkloadTypesPreference_INACTIVE = InferredWorkloadTypesPreference.AddMember("INACTIVE", smithyprelude.Unit)

	ExternalMetricsSource_DATADOG = ExternalMetricsSource.AddMember("DATADOG", smithyprelude.Unit)

	ExternalMetricsSource_DYNATRACE = ExternalMetricsSource.AddMember("DYNATRACE", smithyprelude.Unit)

	ExternalMetricsSource_NEWRELIC = ExternalMetricsSource.AddMember("NEWRELIC", smithyprelude.Unit)

	ExternalMetricsSource_INSTANA = ExternalMetricsSource.AddMember("INSTANA", smithyprelude.Unit)

	ExternalMetricsPreference_source = ExternalMetricsPreference.AddMember("source", ExternalMetricsSource)

	LookBackPeriodPreference_DAYS_14 = LookBackPeriodPreference.AddMember("DAYS_14", smithyprelude.Unit)

	LookBackPeriodPreference_DAYS_32 = LookBackPeriodPreference.AddMember("DAYS_32", smithyprelude.Unit)

	LookBackPeriodPreference_DAYS_93 = LookBackPeriodPreference.AddMember("DAYS_93", smithyprelude.Unit)

	CustomizableMetricName_CPU_UTILIZATION = CustomizableMetricName.AddMember("CPU_UTILIZATION", smithyprelude.Unit)

	CustomizableMetricName_MEMORY_UTILIZATION = CustomizableMetricName.AddMember("MEMORY_UTILIZATION", smithyprelude.Unit)

	CustomizableMetricThreshold_P90 = CustomizableMetricThreshold.AddMember("P90", smithyprelude.Unit)

	CustomizableMetricThreshold_P95 = CustomizableMetricThreshold.AddMember("P95", smithyprelude.Unit)

	CustomizableMetricThreshold_P99_5 = CustomizableMetricThreshold.AddMember("P99_5", smithyprelude.Unit)

	CustomizableMetricHeadroom_PERCENT_30 = CustomizableMetricHeadroom.AddMember("PERCENT_30", smithyprelude.Unit)

	CustomizableMetricHeadroom_PERCENT_20 = CustomizableMetricHeadroom.AddMember("PERCENT_20", smithyprelude.Unit)

	CustomizableMetricHeadroom_PERCENT_10 = CustomizableMetricHeadroom.AddMember("PERCENT_10", smithyprelude.Unit)

	CustomizableMetricHeadroom_PERCENT_0 = CustomizableMetricHeadroom.AddMember("PERCENT_0", smithyprelude.Unit)

	CustomizableMetricParameters_threshold = CustomizableMetricParameters.AddMember("threshold", CustomizableMetricThreshold)

	CustomizableMetricParameters_headroom = CustomizableMetricParameters.AddMember("headroom", CustomizableMetricHeadroom)

	UtilizationPreference_metricName = UtilizationPreference.AddMember("metricName", CustomizableMetricName)

	UtilizationPreference_metricParameters = UtilizationPreference.AddMember("metricParameters", CustomizableMetricParameters)

	_UtilizationPreferences_member = _UtilizationPreferences.AddMember("member", UtilizationPreference)

	PreferredResourceName_EC2_INSTANCE_TYPES = PreferredResourceName.AddMember("EC2_INSTANCE_TYPES", smithyprelude.Unit)

	_PreferredResourceValues_member = _PreferredResourceValues.AddMember("member", _PreferredResourceValue)

	EffectivePreferredResource_name = EffectivePreferredResource.AddMember("name", PreferredResourceName)

	EffectivePreferredResource_includeList = EffectivePreferredResource.AddMember("includeList", _PreferredResourceValues)

	EffectivePreferredResource_effectiveIncludeList = EffectivePreferredResource.AddMember("effectiveIncludeList", _PreferredResourceValues)

	EffectivePreferredResource_excludeList = EffectivePreferredResource.AddMember("excludeList", _PreferredResourceValues)

	_EffectivePreferredResources_member = _EffectivePreferredResources.AddMember("member", EffectivePreferredResource)

	InstanceSavingsEstimationModeSource_PUBLIC_PRICING = InstanceSavingsEstimationModeSource.AddMember("PUBLIC_PRICING", smithyprelude.Unit)

	InstanceSavingsEstimationModeSource_COST_EXPLORER_RIGHTSIZING = InstanceSavingsEstimationModeSource.AddMember("COST_EXPLORER_RIGHTSIZING", smithyprelude.Unit)

	InstanceSavingsEstimationModeSource_COST_OPTIMIZATION_HUB = InstanceSavingsEstimationModeSource.AddMember("COST_OPTIMIZATION_HUB", smithyprelude.Unit)

	InstanceSavingsEstimationMode_source = InstanceSavingsEstimationMode.AddMember("source", InstanceSavingsEstimationModeSource)

	EffectiveRecommendationPreferences_cpuVendorArchitectures = EffectiveRecommendationPreferences.AddMember("cpuVendorArchitectures", _CpuVendorArchitectures)

	EffectiveRecommendationPreferences_enhancedInfrastructureMetrics = EffectiveRecommendationPreferences.AddMember("enhancedInfrastructureMetrics", EnhancedInfrastructureMetrics)

	EffectiveRecommendationPreferences_inferredWorkloadTypes = EffectiveRecommendationPreferences.AddMember("inferredWorkloadTypes", InferredWorkloadTypesPreference)

	EffectiveRecommendationPreferences_externalMetricsPreference = EffectiveRecommendationPreferences.AddMember("externalMetricsPreference", ExternalMetricsPreference)

	EffectiveRecommendationPreferences_lookBackPeriod = EffectiveRecommendationPreferences.AddMember("lookBackPeriod", LookBackPeriodPreference)

	EffectiveRecommendationPreferences_utilizationPreferences = EffectiveRecommendationPreferences.AddMember("utilizationPreferences", _UtilizationPreferences)

	EffectiveRecommendationPreferences_preferredResources = EffectiveRecommendationPreferences.AddMember("preferredResources", _EffectivePreferredResources)

	EffectiveRecommendationPreferences_savingsEstimationMode = EffectiveRecommendationPreferences.AddMember("savingsEstimationMode", InstanceSavingsEstimationMode)

	InferredWorkloadType_AMAZON_EMR = InferredWorkloadType.AddMember("AMAZON_EMR", smithyprelude.Unit)

	InferredWorkloadType_APACHE_CASSANDRA = InferredWorkloadType.AddMember("APACHE_CASSANDRA", smithyprelude.Unit)

	InferredWorkloadType_APACHE_HADOOP = InferredWorkloadType.AddMember("APACHE_HADOOP", smithyprelude.Unit)

	InferredWorkloadType_MEMCACHED = InferredWorkloadType.AddMember("MEMCACHED", smithyprelude.Unit)

	InferredWorkloadType_NGINX = InferredWorkloadType.AddMember("NGINX", smithyprelude.Unit)

	InferredWorkloadType_POSTGRE_SQL = InferredWorkloadType.AddMember("POSTGRE_SQL", smithyprelude.Unit)

	InferredWorkloadType_REDIS = InferredWorkloadType.AddMember("REDIS", smithyprelude.Unit)

	InferredWorkloadType_KAFKA = InferredWorkloadType.AddMember("KAFKA", smithyprelude.Unit)

	InferredWorkloadType_SQLSERVER = InferredWorkloadType.AddMember("SQLSERVER", smithyprelude.Unit)

	_InferredWorkloadTypes_member = _InferredWorkloadTypes.AddMember("member", InferredWorkloadType)

	AutoScalingGroupRecommendation_accountId = AutoScalingGroupRecommendation.AddMember("accountId", _AccountId)

	AutoScalingGroupRecommendation_autoScalingGroupArn = AutoScalingGroupRecommendation.AddMember("autoScalingGroupArn", _AutoScalingGroupArn)

	AutoScalingGroupRecommendation_autoScalingGroupName = AutoScalingGroupRecommendation.AddMember("autoScalingGroupName", _AutoScalingGroupName)

	AutoScalingGroupRecommendation_finding = AutoScalingGroupRecommendation.AddMember("finding", Finding)

	AutoScalingGroupRecommendation_utilizationMetrics = AutoScalingGroupRecommendation.AddMember("utilizationMetrics", _UtilizationMetrics)

	AutoScalingGroupRecommendation_lookBackPeriodInDays = AutoScalingGroupRecommendation.AddMember("lookBackPeriodInDays", _LookBackPeriodInDays)

	AutoScalingGroupRecommendation_currentConfiguration = AutoScalingGroupRecommendation.AddMember("currentConfiguration", AutoScalingGroupConfiguration)

	AutoScalingGroupRecommendation_currentInstanceGpuInfo = AutoScalingGroupRecommendation.AddMember("currentInstanceGpuInfo", GpuInfo)

	AutoScalingGroupRecommendation_recommendationOptions = AutoScalingGroupRecommendation.AddMember("recommendationOptions", _AutoScalingGroupRecommendationOptions)

	AutoScalingGroupRecommendation_lastRefreshTimestamp = AutoScalingGroupRecommendation.AddMember("lastRefreshTimestamp", _LastRefreshTimestamp)

	AutoScalingGroupRecommendation_currentPerformanceRisk = AutoScalingGroupRecommendation.AddMember("currentPerformanceRisk", CurrentPerformanceRisk)

	AutoScalingGroupRecommendation_effectiveRecommendationPreferences = AutoScalingGroupRecommendation.AddMember("effectiveRecommendationPreferences", EffectiveRecommendationPreferences)

	AutoScalingGroupRecommendation_inferredWorkloadTypes = AutoScalingGroupRecommendation.AddMember("inferredWorkloadTypes", _InferredWorkloadTypes)

	_AutoScalingGroupRecommendations_member = _AutoScalingGroupRecommendations.AddMember("member", AutoScalingGroupRecommendation)

	MemorySizeConfiguration_memory = MemorySizeConfiguration.AddMember("memory", _NullableMemory)

	MemorySizeConfiguration_memoryReservation = MemorySizeConfiguration.AddMember("memoryReservation", _NullableMemoryReservation)

	ContainerConfiguration_containerName = ContainerConfiguration.AddMember("containerName", _ContainerName)

	ContainerConfiguration_memorySizeConfiguration = ContainerConfiguration.AddMember("memorySizeConfiguration", MemorySizeConfiguration)

	ContainerConfiguration_cpu = ContainerConfiguration.AddMember("cpu", _NullableCpu)

	_ContainerConfigurations_member = _ContainerConfigurations.AddMember("member", ContainerConfiguration)

	ContainerRecommendation_containerName = ContainerRecommendation.AddMember("containerName", _ContainerName)

	ContainerRecommendation_memorySizeConfiguration = ContainerRecommendation.AddMember("memorySizeConfiguration", MemorySizeConfiguration)

	ContainerRecommendation_cpu = ContainerRecommendation.AddMember("cpu", _NullableCpu)

	_ContainerRecommendations_member = _ContainerRecommendations.AddMember("member", ContainerRecommendation)

	CurrentPerformanceRiskRatings_high = CurrentPerformanceRiskRatings.AddMember("high", _High)

	CurrentPerformanceRiskRatings_medium = CurrentPerformanceRiskRatings.AddMember("medium", _Medium)

	CurrentPerformanceRiskRatings_low = CurrentPerformanceRiskRatings.AddMember("low", _Low)

	CurrentPerformanceRiskRatings_veryLow = CurrentPerformanceRiskRatings.AddMember("veryLow", _VeryLow)

	DBStorageConfiguration_storageType = DBStorageConfiguration.AddMember("storageType", _StorageType)

	DBStorageConfiguration_allocatedStorage = DBStorageConfiguration.AddMember("allocatedStorage", _AllocatedStorage)

	DBStorageConfiguration_iops = DBStorageConfiguration.AddMember("iops", _NullableIOPS)

	DBStorageConfiguration_maxAllocatedStorage = DBStorageConfiguration.AddMember("maxAllocatedStorage", _NullableMaxAllocatedStorage)

	DBStorageConfiguration_storageThroughput = DBStorageConfiguration.AddMember("storageThroughput", _NullableStorageThroughput)

	Dimension_SAVINGS_VALUE = Dimension.AddMember("SAVINGS_VALUE", smithyprelude.Unit)

	Dimension_SAVINGS_VALUE_AFTER_DISCOUNT = Dimension.AddMember("SAVINGS_VALUE_AFTER_DISCOUNT", smithyprelude.Unit)

	EBSSavingsEstimationModeSource_PUBLIC_PRICING = EBSSavingsEstimationModeSource.AddMember("PUBLIC_PRICING", smithyprelude.Unit)

	EBSSavingsEstimationModeSource_COST_EXPLORER_RIGHTSIZING = EBSSavingsEstimationModeSource.AddMember("COST_EXPLORER_RIGHTSIZING", smithyprelude.Unit)

	EBSSavingsEstimationModeSource_COST_OPTIMIZATION_HUB = EBSSavingsEstimationModeSource.AddMember("COST_OPTIMIZATION_HUB", smithyprelude.Unit)

	EBSSavingsEstimationMode_source = EBSSavingsEstimationMode.AddMember("source", EBSSavingsEstimationModeSource)

	EBSEffectiveRecommendationPreferences_savingsEstimationMode = EBSEffectiveRecommendationPreferences.AddMember("savingsEstimationMode", EBSSavingsEstimationMode)

	EBSEffectiveRecommendationPreferences_lookBackPeriod = EBSEffectiveRecommendationPreferences.AddMember("lookBackPeriod", LookBackPeriodPreference)

	EBSEstimatedMonthlySavings_currency = EBSEstimatedMonthlySavings.AddMember("currency", Currency)

	EBSEstimatedMonthlySavings_value = EBSEstimatedMonthlySavings.AddMember("value", _Value)

	EBSFilterName_FINDING = EBSFilterName.AddMember("FINDING", smithyprelude.Unit)

	_FilterValues_member = _FilterValues.AddMember("member", _FilterValue)

	EBSFilter_name = EBSFilter.AddMember("name", EBSFilterName)

	EBSFilter_values = EBSFilter.AddMember("values", _FilterValues)

	_EBSFilters_member = _EBSFilters.AddMember("member", EBSFilter)

	EBSFinding_OPTIMIZED = EBSFinding.AddMember("OPTIMIZED", smithyprelude.Unit)

	EBSFinding_NOT_OPTIMIZED = EBSFinding.AddMember("NOT_OPTIMIZED", smithyprelude.Unit)

	EBSMetricName_VOLUME_READ_OPS_PER_SECOND = EBSMetricName.AddMember("VOLUME_READ_OPS_PER_SECOND", smithyprelude.Unit)

	EBSMetricName_VOLUME_WRITE_OPS_PER_SECOND = EBSMetricName.AddMember("VOLUME_WRITE_OPS_PER_SECOND", smithyprelude.Unit)

	EBSMetricName_VOLUME_READ_BYTES_PER_SECOND = EBSMetricName.AddMember("VOLUME_READ_BYTES_PER_SECOND", smithyprelude.Unit)

	EBSMetricName_VOLUME_WRITE_BYTES_PER_SECOND = EBSMetricName.AddMember("VOLUME_WRITE_BYTES_PER_SECOND", smithyprelude.Unit)

	EBSMetricName_VOLUME_IOPS_EXCEEDED = EBSMetricName.AddMember("VOLUME_IOPS_EXCEEDED", smithyprelude.Unit)

	EBSMetricName_VOLUME_THROUGHPUT_EXCEEDED = EBSMetricName.AddMember("VOLUME_THROUGHPUT_EXCEEDED", smithyprelude.Unit)

	EBSSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage = EBSSavingsOpportunityAfterDiscounts.AddMember("savingsOpportunityPercentage", _SavingsOpportunityPercentage)

	EBSSavingsOpportunityAfterDiscounts_estimatedMonthlySavings = EBSSavingsOpportunityAfterDiscounts.AddMember("estimatedMonthlySavings", EBSEstimatedMonthlySavings)

	EBSUtilizationMetric_name = EBSUtilizationMetric.AddMember("name", EBSMetricName)

	EBSUtilizationMetric_statistic = EBSUtilizationMetric.AddMember("statistic", MetricStatistic)

	EBSUtilizationMetric_value = EBSUtilizationMetric.AddMember("value", _MetricValue)

	_EBSUtilizationMetrics_member = _EBSUtilizationMetrics.AddMember("member", EBSUtilizationMetric)

	ECSSavingsEstimationModeSource_PUBLIC_PRICING = ECSSavingsEstimationModeSource.AddMember("PUBLIC_PRICING", smithyprelude.Unit)

	ECSSavingsEstimationModeSource_COST_EXPLORER_RIGHTSIZING = ECSSavingsEstimationModeSource.AddMember("COST_EXPLORER_RIGHTSIZING", smithyprelude.Unit)

	ECSSavingsEstimationModeSource_COST_OPTIMIZATION_HUB = ECSSavingsEstimationModeSource.AddMember("COST_OPTIMIZATION_HUB", smithyprelude.Unit)

	ECSSavingsEstimationMode_source = ECSSavingsEstimationMode.AddMember("source", ECSSavingsEstimationModeSource)

	ECSEffectiveRecommendationPreferences_savingsEstimationMode = ECSEffectiveRecommendationPreferences.AddMember("savingsEstimationMode", ECSSavingsEstimationMode)

	ECSEffectiveRecommendationPreferences_lookBackPeriod = ECSEffectiveRecommendationPreferences.AddMember("lookBackPeriod", LookBackPeriodPreference)

	ECSEstimatedMonthlySavings_currency = ECSEstimatedMonthlySavings.AddMember("currency", Currency)

	ECSEstimatedMonthlySavings_value = ECSEstimatedMonthlySavings.AddMember("value", _Value)

	ECSSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage = ECSSavingsOpportunityAfterDiscounts.AddMember("savingsOpportunityPercentage", _SavingsOpportunityPercentage)

	ECSSavingsOpportunityAfterDiscounts_estimatedMonthlySavings = ECSSavingsOpportunityAfterDiscounts.AddMember("estimatedMonthlySavings", ECSEstimatedMonthlySavings)

	ECSServiceLaunchType_EC2 = ECSServiceLaunchType.AddMember("EC2", smithyprelude.Unit)

	ECSServiceLaunchType_FARGATE = ECSServiceLaunchType.AddMember("FARGATE", smithyprelude.Unit)

	ECSServiceMetricName_CPU = ECSServiceMetricName.AddMember("CPU", smithyprelude.Unit)

	ECSServiceMetricName_MEMORY = ECSServiceMetricName.AddMember("MEMORY", smithyprelude.Unit)

	ECSServiceMetricStatistic_MAXIMUM = ECSServiceMetricStatistic.AddMember("MAXIMUM", smithyprelude.Unit)

	ECSServiceMetricStatistic_AVERAGE = ECSServiceMetricStatistic.AddMember("AVERAGE", smithyprelude.Unit)

	_Timestamps_member = _Timestamps.AddMember("member", _Timestamp)

	_MetricValues_member = _MetricValues.AddMember("member", _MetricValue)

	ECSServiceProjectedMetric_name = ECSServiceProjectedMetric.AddMember("name", ECSServiceMetricName)

	ECSServiceProjectedMetric_timestamps = ECSServiceProjectedMetric.AddMember("timestamps", _Timestamps)

	ECSServiceProjectedMetric_upperBoundValues = ECSServiceProjectedMetric.AddMember("upperBoundValues", _MetricValues)

	ECSServiceProjectedMetric_lowerBoundValues = ECSServiceProjectedMetric.AddMember("lowerBoundValues", _MetricValues)

	_ECSServiceProjectedMetrics_member = _ECSServiceProjectedMetrics.AddMember("member", ECSServiceProjectedMetric)

	ECSServiceProjectedUtilizationMetric_name = ECSServiceProjectedUtilizationMetric.AddMember("name", ECSServiceMetricName)

	ECSServiceProjectedUtilizationMetric_statistic = ECSServiceProjectedUtilizationMetric.AddMember("statistic", ECSServiceMetricStatistic)

	ECSServiceProjectedUtilizationMetric_lowerBoundValue = ECSServiceProjectedUtilizationMetric.AddMember("lowerBoundValue", _LowerBoundValue)

	ECSServiceProjectedUtilizationMetric_upperBoundValue = ECSServiceProjectedUtilizationMetric.AddMember("upperBoundValue", _UpperBoundValue)

	_ECSServiceProjectedUtilizationMetrics_member = _ECSServiceProjectedUtilizationMetrics.AddMember("member", ECSServiceProjectedUtilizationMetric)

	ServiceConfiguration_memory = ServiceConfiguration.AddMember("memory", _NullableMemory)

	ServiceConfiguration_cpu = ServiceConfiguration.AddMember("cpu", _NullableCpu)

	ServiceConfiguration_containerConfigurations = ServiceConfiguration.AddMember("containerConfigurations", _ContainerConfigurations)

	ServiceConfiguration_autoScalingConfiguration = ServiceConfiguration.AddMember("autoScalingConfiguration", AutoScalingConfiguration)

	ServiceConfiguration_taskDefinitionArn = ServiceConfiguration.AddMember("taskDefinitionArn", _TaskDefinitionArn)

	ECSServiceUtilizationMetric_name = ECSServiceUtilizationMetric.AddMember("name", ECSServiceMetricName)

	ECSServiceUtilizationMetric_statistic = ECSServiceUtilizationMetric.AddMember("statistic", ECSServiceMetricStatistic)

	ECSServiceUtilizationMetric_value = ECSServiceUtilizationMetric.AddMember("value", _MetricValue)

	_ECSServiceUtilizationMetrics_member = _ECSServiceUtilizationMetrics.AddMember("member", ECSServiceUtilizationMetric)

	ECSServiceRecommendationFinding_OPTIMIZED = ECSServiceRecommendationFinding.AddMember("OPTIMIZED", smithyprelude.Unit)

	ECSServiceRecommendationFinding_UNDER_PROVISIONED = ECSServiceRecommendationFinding.AddMember("UNDER_PROVISIONED", smithyprelude.Unit)

	ECSServiceRecommendationFinding_OVER_PROVISIONED = ECSServiceRecommendationFinding.AddMember("OVER_PROVISIONED", smithyprelude.Unit)

	ECSServiceRecommendationFindingReasonCode_MEMORY_OVER_PROVISIONED = ECSServiceRecommendationFindingReasonCode.AddMember("MEMORY_OVER_PROVISIONED", smithyprelude.Unit)

	ECSServiceRecommendationFindingReasonCode_MEMORY_UNDER_PROVISIONED = ECSServiceRecommendationFindingReasonCode.AddMember("MEMORY_UNDER_PROVISIONED", smithyprelude.Unit)

	ECSServiceRecommendationFindingReasonCode_CPU_OVER_PROVISIONED = ECSServiceRecommendationFindingReasonCode.AddMember("CPU_OVER_PROVISIONED", smithyprelude.Unit)

	ECSServiceRecommendationFindingReasonCode_CPU_UNDER_PROVISIONED = ECSServiceRecommendationFindingReasonCode.AddMember("CPU_UNDER_PROVISIONED", smithyprelude.Unit)

	_ECSServiceRecommendationFindingReasonCodes_member = _ECSServiceRecommendationFindingReasonCodes.AddMember("member", ECSServiceRecommendationFindingReasonCode)

	ECSServiceRecommendationOption_memory = ECSServiceRecommendationOption.AddMember("memory", _NullableMemory)

	ECSServiceRecommendationOption_cpu = ECSServiceRecommendationOption.AddMember("cpu", _NullableCpu)

	ECSServiceRecommendationOption_savingsOpportunity = ECSServiceRecommendationOption.AddMember("savingsOpportunity", SavingsOpportunity)

	ECSServiceRecommendationOption_savingsOpportunityAfterDiscounts = ECSServiceRecommendationOption.AddMember("savingsOpportunityAfterDiscounts", ECSSavingsOpportunityAfterDiscounts)

	ECSServiceRecommendationOption_projectedUtilizationMetrics = ECSServiceRecommendationOption.AddMember("projectedUtilizationMetrics", _ECSServiceProjectedUtilizationMetrics)

	ECSServiceRecommendationOption_containerRecommendations = ECSServiceRecommendationOption.AddMember("containerRecommendations", _ContainerRecommendations)

	_ECSServiceRecommendationOptions_member = _ECSServiceRecommendationOptions.AddMember("member", ECSServiceRecommendationOption)

	Tag_key = Tag.AddMember("key", _TagKey)

	Tag_value = Tag.AddMember("value", _TagValue)

	_Tags_member = _Tags.AddMember("member", Tag)

	ECSServiceRecommendation_serviceArn = ECSServiceRecommendation.AddMember("serviceArn", _ServiceArn)

	ECSServiceRecommendation_accountId = ECSServiceRecommendation.AddMember("accountId", _AccountId)

	ECSServiceRecommendation_currentServiceConfiguration = ECSServiceRecommendation.AddMember("currentServiceConfiguration", ServiceConfiguration)

	ECSServiceRecommendation_utilizationMetrics = ECSServiceRecommendation.AddMember("utilizationMetrics", _ECSServiceUtilizationMetrics)

	ECSServiceRecommendation_lookbackPeriodInDays = ECSServiceRecommendation.AddMember("lookbackPeriodInDays", _LookBackPeriodInDays)

	ECSServiceRecommendation_launchType = ECSServiceRecommendation.AddMember("launchType", ECSServiceLaunchType)

	ECSServiceRecommendation_lastRefreshTimestamp = ECSServiceRecommendation.AddMember("lastRefreshTimestamp", _LastRefreshTimestamp)

	ECSServiceRecommendation_finding = ECSServiceRecommendation.AddMember("finding", ECSServiceRecommendationFinding)

	ECSServiceRecommendation_findingReasonCodes = ECSServiceRecommendation.AddMember("findingReasonCodes", _ECSServiceRecommendationFindingReasonCodes)

	ECSServiceRecommendation_serviceRecommendationOptions = ECSServiceRecommendation.AddMember("serviceRecommendationOptions", _ECSServiceRecommendationOptions)

	ECSServiceRecommendation_currentPerformanceRisk = ECSServiceRecommendation.AddMember("currentPerformanceRisk", CurrentPerformanceRisk)

	ECSServiceRecommendation_effectiveRecommendationPreferences = ECSServiceRecommendation.AddMember("effectiveRecommendationPreferences", ECSEffectiveRecommendationPreferences)

	ECSServiceRecommendation_tags = ECSServiceRecommendation.AddMember("tags", _Tags)

	ECSServiceRecommendationFilterName_FINDING = ECSServiceRecommendationFilterName.AddMember("FINDING", smithyprelude.Unit)

	ECSServiceRecommendationFilterName_FINDING_REASON_CODE = ECSServiceRecommendationFilterName.AddMember("FINDING_REASON_CODE", smithyprelude.Unit)

	ECSServiceRecommendationFilter_name = ECSServiceRecommendationFilter.AddMember("name", ECSServiceRecommendationFilterName)

	ECSServiceRecommendationFilter_values = ECSServiceRecommendationFilter.AddMember("values", _FilterValues)

	_ECSServiceRecommendationFilters_member = _ECSServiceRecommendationFilters.AddMember("member", ECSServiceRecommendationFilter)

	_ECSServiceRecommendations_member = _ECSServiceRecommendations.AddMember("member", ECSServiceRecommendation)

	ECSServiceRecommendedOptionProjectedMetric_recommendedCpuUnits = ECSServiceRecommendedOptionProjectedMetric.AddMember("recommendedCpuUnits", _CpuSize)

	ECSServiceRecommendedOptionProjectedMetric_recommendedMemorySize = ECSServiceRecommendedOptionProjectedMetric.AddMember("recommendedMemorySize", _MemorySize)

	ECSServiceRecommendedOptionProjectedMetric_projectedMetrics = ECSServiceRecommendedOptionProjectedMetric.AddMember("projectedMetrics", _ECSServiceProjectedMetrics)

	_ECSServiceRecommendedOptionProjectedMetrics_member = _ECSServiceRecommendedOptionProjectedMetrics.AddMember("member", ECSServiceRecommendedOptionProjectedMetric)

	EnrollmentFilterName_STATUS = EnrollmentFilterName.AddMember("STATUS", smithyprelude.Unit)

	EnrollmentFilter_name = EnrollmentFilter.AddMember("name", EnrollmentFilterName)

	EnrollmentFilter_values = EnrollmentFilter.AddMember("values", _FilterValues)

	_EnrollmentFilters_member = _EnrollmentFilters.AddMember("member", EnrollmentFilter)

	ExportableAutoScalingGroupField_ACCOUNT_ID = ExportableAutoScalingGroupField.AddMember("ACCOUNT_ID", smithyprelude.Unit)

	ExportableAutoScalingGroupField_AUTO_SCALING_GROUP_ARN = ExportableAutoScalingGroupField.AddMember("AUTO_SCALING_GROUP_ARN", smithyprelude.Unit)

	ExportableAutoScalingGroupField_AUTO_SCALING_GROUP_NAME = ExportableAutoScalingGroupField.AddMember("AUTO_SCALING_GROUP_NAME", smithyprelude.Unit)

	ExportableAutoScalingGroupField_FINDING = ExportableAutoScalingGroupField.AddMember("FINDING", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_CPU_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_CPU_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_MEMORY_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_MEMORY_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_EBS_READ_OPS_PER_SECOND_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_EBS_READ_OPS_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_EBS_WRITE_OPS_PER_SECOND_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_EBS_WRITE_OPS_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_EBS_READ_BYTES_PER_SECOND_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_EBS_READ_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_EBS_WRITE_BYTES_PER_SECOND_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_EBS_WRITE_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_DISK_READ_OPS_PER_SECOND_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_DISK_READ_OPS_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_DISK_WRITE_OPS_PER_SECOND_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_DISK_WRITE_OPS_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_DISK_READ_BYTES_PER_SECOND_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_DISK_READ_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_DISK_WRITE_BYTES_PER_SECOND_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_DISK_WRITE_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_NETWORK_IN_BYTES_PER_SECOND_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_NETWORK_IN_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_NETWORK_OUT_BYTES_PER_SECOND_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_NETWORK_OUT_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_NETWORK_PACKETS_IN_PER_SECOND_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_NETWORK_PACKETS_IN_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_NETWORK_PACKETS_OUT_PER_SECOND_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_NETWORK_PACKETS_OUT_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_LOOKBACK_PERIOD_IN_DAYS = ExportableAutoScalingGroupField.AddMember("LOOKBACK_PERIOD_IN_DAYS", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_CONFIGURATION_INSTANCE_TYPE = ExportableAutoScalingGroupField.AddMember("CURRENT_CONFIGURATION_INSTANCE_TYPE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_CONFIGURATION_DESIRED_CAPACITY = ExportableAutoScalingGroupField.AddMember("CURRENT_CONFIGURATION_DESIRED_CAPACITY", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_CONFIGURATION_MIN_SIZE = ExportableAutoScalingGroupField.AddMember("CURRENT_CONFIGURATION_MIN_SIZE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_CONFIGURATION_MAX_SIZE = ExportableAutoScalingGroupField.AddMember("CURRENT_CONFIGURATION_MAX_SIZE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_CONFIGURATION_ALLOCATION_STRATEGY = ExportableAutoScalingGroupField.AddMember("CURRENT_CONFIGURATION_ALLOCATION_STRATEGY", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_CONFIGURATION_MIXED_INSTANCE_TYPES = ExportableAutoScalingGroupField.AddMember("CURRENT_CONFIGURATION_MIXED_INSTANCE_TYPES", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_CONFIGURATION_TYPE = ExportableAutoScalingGroupField.AddMember("CURRENT_CONFIGURATION_TYPE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_ON_DEMAND_PRICE = ExportableAutoScalingGroupField.AddMember("CURRENT_ON_DEMAND_PRICE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_STANDARD_ONE_YEAR_NO_UPFRONT_RESERVED_PRICE = ExportableAutoScalingGroupField.AddMember("CURRENT_STANDARD_ONE_YEAR_NO_UPFRONT_RESERVED_PRICE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_STANDARD_THREE_YEAR_NO_UPFRONT_RESERVED_PRICE = ExportableAutoScalingGroupField.AddMember("CURRENT_STANDARD_THREE_YEAR_NO_UPFRONT_RESERVED_PRICE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_VCPUS = ExportableAutoScalingGroupField.AddMember("CURRENT_VCPUS", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_MEMORY = ExportableAutoScalingGroupField.AddMember("CURRENT_MEMORY", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_STORAGE = ExportableAutoScalingGroupField.AddMember("CURRENT_STORAGE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_NETWORK = ExportableAutoScalingGroupField.AddMember("CURRENT_NETWORK", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_INSTANCE_TYPE = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_CONFIGURATION_INSTANCE_TYPE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_DESIRED_CAPACITY = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_CONFIGURATION_DESIRED_CAPACITY", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_MIN_SIZE = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_CONFIGURATION_MIN_SIZE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_MAX_SIZE = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_CONFIGURATION_MAX_SIZE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_ESTIMATED_INSTANCE_HOUR_REDUCTION_PERCENTAGE = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_CONFIGURATION_ESTIMATED_INSTANCE_HOUR_REDUCTION_PERCENTAGE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_ALLOCATION_STRATEGY = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_CONFIGURATION_ALLOCATION_STRATEGY", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_MIXED_INSTANCE_TYPES = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_CONFIGURATION_MIXED_INSTANCE_TYPES", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_CONFIGURATION_TYPE = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_CONFIGURATION_TYPE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_CPU_MAXIMUM = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_CPU_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_MEMORY_MAXIMUM = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_MEMORY_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_PERFORMANCE_RISK = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_PERFORMANCE_RISK", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_ON_DEMAND_PRICE = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_ON_DEMAND_PRICE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_STANDARD_ONE_YEAR_NO_UPFRONT_RESERVED_PRICE = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_STANDARD_ONE_YEAR_NO_UPFRONT_RESERVED_PRICE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_STANDARD_THREE_YEAR_NO_UPFRONT_RESERVED_PRICE = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_STANDARD_THREE_YEAR_NO_UPFRONT_RESERVED_PRICE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_VCPUS = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_VCPUS", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_MEMORY = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_MEMORY", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_STORAGE = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_STORAGE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_NETWORK = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_NETWORK", smithyprelude.Unit)

	ExportableAutoScalingGroupField_LAST_REFRESH_TIMESTAMP = ExportableAutoScalingGroupField.AddMember("LAST_REFRESH_TIMESTAMP", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_PERFORMANCE_RISK = ExportableAutoScalingGroupField.AddMember("CURRENT_PERFORMANCE_RISK", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_EFFECTIVE_RECOMMENDATION_PREFERENCES_CPU_VENDOR_ARCHITECTURES = ExportableAutoScalingGroupField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_CPU_VENDOR_ARCHITECTURES", smithyprelude.Unit)

	ExportableAutoScalingGroupField_EFFECTIVE_RECOMMENDATION_PREFERENCES_ENHANCED_INFRASTRUCTURE_METRICS = ExportableAutoScalingGroupField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_ENHANCED_INFRASTRUCTURE_METRICS", smithyprelude.Unit)

	ExportableAutoScalingGroupField_EFFECTIVE_RECOMMENDATION_PREFERENCES_INFERRED_WORKLOAD_TYPES = ExportableAutoScalingGroupField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_INFERRED_WORKLOAD_TYPES", smithyprelude.Unit)

	ExportableAutoScalingGroupField_EFFECTIVE_RECOMMENDATION_PREFERENCES_PREFERRED_RESOURCES = ExportableAutoScalingGroupField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_PREFERRED_RESOURCES", smithyprelude.Unit)

	ExportableAutoScalingGroupField_EFFECTIVE_RECOMMENDATION_PREFERENCES_LOOKBACK_PERIOD = ExportableAutoScalingGroupField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_LOOKBACK_PERIOD", smithyprelude.Unit)

	ExportableAutoScalingGroupField_INFERRED_WORKLOAD_TYPES = ExportableAutoScalingGroupField.AddMember("INFERRED_WORKLOAD_TYPES", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_MIGRATION_EFFORT = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_MIGRATION_EFFORT", smithyprelude.Unit)

	ExportableAutoScalingGroupField_CURRENT_INSTANCE_GPU_INFO = ExportableAutoScalingGroupField.AddMember("CURRENT_INSTANCE_GPU_INFO", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_INSTANCE_GPU_INFO = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_INSTANCE_GPU_INFO", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_GPU_PERCENTAGE_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_GPU_PERCENTAGE_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_UTILIZATION_METRICS_GPU_MEMORY_PERCENTAGE_MAXIMUM = ExportableAutoScalingGroupField.AddMember("UTILIZATION_METRICS_GPU_MEMORY_PERCENTAGE_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_GPU_MAXIMUM = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_GPU_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_GPU_MEMORY_MAXIMUM = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_GPU_MEMORY_MAXIMUM", smithyprelude.Unit)

	ExportableAutoScalingGroupField_EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE = ExportableAutoScalingGroupField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS", smithyprelude.Unit)

	ExportableAutoScalingGroupField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS = ExportableAutoScalingGroupField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS", smithyprelude.Unit)

	_ExportableAutoScalingGroupFields_member = _ExportableAutoScalingGroupFields.AddMember("member", ExportableAutoScalingGroupField)

	ExportableECSServiceField_ACCOUNT_ID = ExportableECSServiceField.AddMember("ACCOUNT_ID", smithyprelude.Unit)

	ExportableECSServiceField_SERVICE_ARN = ExportableECSServiceField.AddMember("SERVICE_ARN", smithyprelude.Unit)

	ExportableECSServiceField_LOOKBACK_PERIOD_IN_DAYS = ExportableECSServiceField.AddMember("LOOKBACK_PERIOD_IN_DAYS", smithyprelude.Unit)

	ExportableECSServiceField_LAST_REFRESH_TIMESTAMP = ExportableECSServiceField.AddMember("LAST_REFRESH_TIMESTAMP", smithyprelude.Unit)

	ExportableECSServiceField_LAUNCH_TYPE = ExportableECSServiceField.AddMember("LAUNCH_TYPE", smithyprelude.Unit)

	ExportableECSServiceField_CURRENT_PERFORMANCE_RISK = ExportableECSServiceField.AddMember("CURRENT_PERFORMANCE_RISK", smithyprelude.Unit)

	ExportableECSServiceField_CURRENT_SERVICE_CONFIGURATION_MEMORY = ExportableECSServiceField.AddMember("CURRENT_SERVICE_CONFIGURATION_MEMORY", smithyprelude.Unit)

	ExportableECSServiceField_CURRENT_SERVICE_CONFIGURATION_CPU = ExportableECSServiceField.AddMember("CURRENT_SERVICE_CONFIGURATION_CPU", smithyprelude.Unit)

	ExportableECSServiceField_CURRENT_SERVICE_CONFIGURATION_TASK_DEFINITION_ARN = ExportableECSServiceField.AddMember("CURRENT_SERVICE_CONFIGURATION_TASK_DEFINITION_ARN", smithyprelude.Unit)

	ExportableECSServiceField_CURRENT_SERVICE_CONFIGURATION_AUTO_SCALING_CONFIGURATION = ExportableECSServiceField.AddMember("CURRENT_SERVICE_CONFIGURATION_AUTO_SCALING_CONFIGURATION", smithyprelude.Unit)

	ExportableECSServiceField_CURRENT_SERVICE_CONTAINER_CONFIGURATIONS = ExportableECSServiceField.AddMember("CURRENT_SERVICE_CONTAINER_CONFIGURATIONS", smithyprelude.Unit)

	ExportableECSServiceField_UTILIZATION_METRICS_CPU_MAXIMUM = ExportableECSServiceField.AddMember("UTILIZATION_METRICS_CPU_MAXIMUM", smithyprelude.Unit)

	ExportableECSServiceField_UTILIZATION_METRICS_MEMORY_MAXIMUM = ExportableECSServiceField.AddMember("UTILIZATION_METRICS_MEMORY_MAXIMUM", smithyprelude.Unit)

	ExportableECSServiceField_FINDING = ExportableECSServiceField.AddMember("FINDING", smithyprelude.Unit)

	ExportableECSServiceField_FINDING_REASON_CODES = ExportableECSServiceField.AddMember("FINDING_REASON_CODES", smithyprelude.Unit)

	ExportableECSServiceField_RECOMMENDATION_OPTIONS_MEMORY = ExportableECSServiceField.AddMember("RECOMMENDATION_OPTIONS_MEMORY", smithyprelude.Unit)

	ExportableECSServiceField_RECOMMENDATION_OPTIONS_CPU = ExportableECSServiceField.AddMember("RECOMMENDATION_OPTIONS_CPU", smithyprelude.Unit)

	ExportableECSServiceField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE = ExportableECSServiceField.AddMember("RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE", smithyprelude.Unit)

	ExportableECSServiceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY = ExportableECSServiceField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY", smithyprelude.Unit)

	ExportableECSServiceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE = ExportableECSServiceField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE", smithyprelude.Unit)

	ExportableECSServiceField_RECOMMENDATION_OPTIONS_CONTAINER_RECOMMENDATIONS = ExportableECSServiceField.AddMember("RECOMMENDATION_OPTIONS_CONTAINER_RECOMMENDATIONS", smithyprelude.Unit)

	ExportableECSServiceField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_CPU_MAXIMUM = ExportableECSServiceField.AddMember("RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_CPU_MAXIMUM", smithyprelude.Unit)

	ExportableECSServiceField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_MEMORY_MAXIMUM = ExportableECSServiceField.AddMember("RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_MEMORY_MAXIMUM", smithyprelude.Unit)

	ExportableECSServiceField_TAGS = ExportableECSServiceField.AddMember("TAGS", smithyprelude.Unit)

	ExportableECSServiceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE = ExportableECSServiceField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE", smithyprelude.Unit)

	ExportableECSServiceField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE = ExportableECSServiceField.AddMember("RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE", smithyprelude.Unit)

	ExportableECSServiceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS = ExportableECSServiceField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS", smithyprelude.Unit)

	ExportableECSServiceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS = ExportableECSServiceField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS", smithyprelude.Unit)

	ExportableECSServiceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_LOOKBACK_PERIOD = ExportableECSServiceField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_LOOKBACK_PERIOD", smithyprelude.Unit)

	_ExportableECSServiceFields_member = _ExportableECSServiceFields.AddMember("member", ExportableECSServiceField)

	ExportableIdleField_ACCOUNT_ID = ExportableIdleField.AddMember("ACCOUNT_ID", smithyprelude.Unit)

	ExportableIdleField_RESOURCE_ARN = ExportableIdleField.AddMember("RESOURCE_ARN", smithyprelude.Unit)

	ExportableIdleField_RESOURCE_ID = ExportableIdleField.AddMember("RESOURCE_ID", smithyprelude.Unit)

	ExportableIdleField_RESOURCE_TYPE = ExportableIdleField.AddMember("RESOURCE_TYPE", smithyprelude.Unit)

	ExportableIdleField_LAST_REFRESH_TIMESTAMP = ExportableIdleField.AddMember("LAST_REFRESH_TIMESTAMP", smithyprelude.Unit)

	ExportableIdleField_LOOKBACK_PERIOD_IN_DAYS = ExportableIdleField.AddMember("LOOKBACK_PERIOD_IN_DAYS", smithyprelude.Unit)

	ExportableIdleField_SAVINGS_OPPORTUNITY = ExportableIdleField.AddMember("SAVINGS_OPPORTUNITY", smithyprelude.Unit)

	ExportableIdleField_SAVINGS_OPPORTUNITY_AFTER_DISCOUNT = ExportableIdleField.AddMember("SAVINGS_OPPORTUNITY_AFTER_DISCOUNT", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_CPU_MAXIMUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_CPU_MAXIMUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_MEMORY_MAXIMUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_MEMORY_MAXIMUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_NETWORK_OUT_BYTES_PER_SECOND_MAXIMUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_NETWORK_OUT_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_NETWORK_IN_BYTES_PER_SECOND_MAXIMUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_NETWORK_IN_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_DATABASE_CONNECTIONS_MAXIMUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_DATABASE_CONNECTIONS_MAXIMUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_EBS_VOLUME_READ_IOPS_MAXIMUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_EBS_VOLUME_READ_IOPS_MAXIMUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_EBS_VOLUME_WRITE_IOPS_MAXIMUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_EBS_VOLUME_WRITE_IOPS_MAXIMUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_VOLUME_READ_OPS_PER_SECOND_MAXIMUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_VOLUME_READ_OPS_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_VOLUME_WRITE_OPS_PER_SECOND_MAXIMUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_VOLUME_WRITE_OPS_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_ACTIVE_CONNECTION_COUNT_MAXIMUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_ACTIVE_CONNECTION_COUNT_MAXIMUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_PACKETS_IN_FROM_SOURCE_MAXIMUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_PACKETS_IN_FROM_SOURCE_MAXIMUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_PACKETS_IN_FROM_DESTINATION_MAXIMUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_PACKETS_IN_FROM_DESTINATION_MAXIMUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_CONSUMED_READ_CAPACITY_UNITS_SUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_CONSUMED_READ_CAPACITY_UNITS_SUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_CONSUMED_WRITE_CAPACITY_UNITS_SUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_CONSUMED_WRITE_CAPACITY_UNITS_SUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_NEW_CONNECTIONS_SUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_NEW_CONNECTIONS_SUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_ENGINE_CPU_UTILIZATION_MAXIMUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_ENGINE_CPU_UTILIZATION_MAXIMUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_CACHE_HITS_SUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_CACHE_HITS_SUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_CACHE_MISSES_SUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_CACHE_MISSES_SUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_KEYSPACE_HITS_SUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_KEYSPACE_HITS_SUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_KEYSPACE_MISSES_SUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_KEYSPACE_MISSES_SUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_IS_IDLE_MINIMUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_IS_IDLE_MINIMUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_USER_CONNECTED_SUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_USER_CONNECTED_SUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_INVOCATIONS_SUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_INVOCATIONS_SUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_GET_TYPE_CMDS_SUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_GET_TYPE_CMDS_SUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_SET_TYPE_CMDS_SUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_SET_TYPE_CMDS_SUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_ELASTI_CACHE_PROCESSING_UNITS_SUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_ELASTI_CACHE_PROCESSING_UNITS_SUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_CURR_CONNECTIONS_SUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_CURR_CONNECTIONS_SUM", smithyprelude.Unit)

	ExportableIdleField_UTILIZATION_METRICS_DATABASE_CONNECTIONS_SUM = ExportableIdleField.AddMember("UTILIZATION_METRICS_DATABASE_CONNECTIONS_SUM", smithyprelude.Unit)

	ExportableIdleField_FINDING = ExportableIdleField.AddMember("FINDING", smithyprelude.Unit)

	ExportableIdleField_FINDING_DESCRIPTION = ExportableIdleField.AddMember("FINDING_DESCRIPTION", smithyprelude.Unit)

	ExportableIdleField_TAGS = ExportableIdleField.AddMember("TAGS", smithyprelude.Unit)

	_ExportableIdleFields_member = _ExportableIdleFields.AddMember("member", ExportableIdleField)

	ExportableInstanceField_ACCOUNT_ID = ExportableInstanceField.AddMember("ACCOUNT_ID", smithyprelude.Unit)

	ExportableInstanceField_INSTANCE_ARN = ExportableInstanceField.AddMember("INSTANCE_ARN", smithyprelude.Unit)

	ExportableInstanceField_INSTANCE_NAME = ExportableInstanceField.AddMember("INSTANCE_NAME", smithyprelude.Unit)

	ExportableInstanceField_FINDING = ExportableInstanceField.AddMember("FINDING", smithyprelude.Unit)

	ExportableInstanceField_Finding_Reason_Codes = ExportableInstanceField.AddMember("Finding_Reason_Codes", smithyprelude.Unit)

	ExportableInstanceField_LOOKBACK_PERIOD_IN_DAYS = ExportableInstanceField.AddMember("LOOKBACK_PERIOD_IN_DAYS", smithyprelude.Unit)

	ExportableInstanceField_CURRENT_INSTANCE_TYPE = ExportableInstanceField.AddMember("CURRENT_INSTANCE_TYPE", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_CPU_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_CPU_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_MEMORY_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_MEMORY_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_EBS_READ_OPS_PER_SECOND_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_EBS_READ_OPS_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_EBS_WRITE_OPS_PER_SECOND_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_EBS_WRITE_OPS_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_EBS_READ_BYTES_PER_SECOND_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_EBS_READ_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_EBS_WRITE_BYTES_PER_SECOND_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_EBS_WRITE_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_DISK_READ_OPS_PER_SECOND_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_DISK_READ_OPS_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_DISK_WRITE_OPS_PER_SECOND_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_DISK_WRITE_OPS_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_DISK_READ_BYTES_PER_SECOND_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_DISK_READ_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_DISK_WRITE_BYTES_PER_SECOND_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_DISK_WRITE_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_NETWORK_IN_BYTES_PER_SECOND_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_NETWORK_IN_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_NETWORK_OUT_BYTES_PER_SECOND_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_NETWORK_OUT_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_NETWORK_PACKETS_IN_PER_SECOND_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_NETWORK_PACKETS_IN_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_NETWORK_PACKETS_OUT_PER_SECOND_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_NETWORK_PACKETS_OUT_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_CURRENT_ON_DEMAND_PRICE = ExportableInstanceField.AddMember("CURRENT_ON_DEMAND_PRICE", smithyprelude.Unit)

	ExportableInstanceField_CURRENT_STANDARD_ONE_YEAR_NO_UPFRONT_RESERVED_PRICE = ExportableInstanceField.AddMember("CURRENT_STANDARD_ONE_YEAR_NO_UPFRONT_RESERVED_PRICE", smithyprelude.Unit)

	ExportableInstanceField_CURRENT_STANDARD_THREE_YEAR_NO_UPFRONT_RESERVED_PRICE = ExportableInstanceField.AddMember("CURRENT_STANDARD_THREE_YEAR_NO_UPFRONT_RESERVED_PRICE", smithyprelude.Unit)

	ExportableInstanceField_CURRENT_VCPUS = ExportableInstanceField.AddMember("CURRENT_VCPUS", smithyprelude.Unit)

	ExportableInstanceField_CURRENT_MEMORY = ExportableInstanceField.AddMember("CURRENT_MEMORY", smithyprelude.Unit)

	ExportableInstanceField_CURRENT_STORAGE = ExportableInstanceField.AddMember("CURRENT_STORAGE", smithyprelude.Unit)

	ExportableInstanceField_CURRENT_NETWORK = ExportableInstanceField.AddMember("CURRENT_NETWORK", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_INSTANCE_TYPE = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_INSTANCE_TYPE", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_CPU_MAXIMUM = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_CPU_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_MEMORY_MAXIMUM = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_MEMORY_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_PLATFORM_DIFFERENCES = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_PLATFORM_DIFFERENCES", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_PERFORMANCE_RISK = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_PERFORMANCE_RISK", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_VCPUS = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_VCPUS", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_MEMORY = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_MEMORY", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_STORAGE = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_STORAGE", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_NETWORK = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_NETWORK", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_ON_DEMAND_PRICE = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_ON_DEMAND_PRICE", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_STANDARD_ONE_YEAR_NO_UPFRONT_RESERVED_PRICE = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_STANDARD_ONE_YEAR_NO_UPFRONT_RESERVED_PRICE", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_STANDARD_THREE_YEAR_NO_UPFRONT_RESERVED_PRICE = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_STANDARD_THREE_YEAR_NO_UPFRONT_RESERVED_PRICE", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATIONS_SOURCES_RECOMMENDATION_SOURCE_ARN = ExportableInstanceField.AddMember("RECOMMENDATIONS_SOURCES_RECOMMENDATION_SOURCE_ARN", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATIONS_SOURCES_RECOMMENDATION_SOURCE_TYPE = ExportableInstanceField.AddMember("RECOMMENDATIONS_SOURCES_RECOMMENDATION_SOURCE_TYPE", smithyprelude.Unit)

	ExportableInstanceField_LAST_REFRESH_TIMESTAMP = ExportableInstanceField.AddMember("LAST_REFRESH_TIMESTAMP", smithyprelude.Unit)

	ExportableInstanceField_CURRENT_PERFORMANCE_RISK = ExportableInstanceField.AddMember("CURRENT_PERFORMANCE_RISK", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE", smithyprelude.Unit)

	ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_CPU_VENDOR_ARCHITECTURES = ExportableInstanceField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_CPU_VENDOR_ARCHITECTURES", smithyprelude.Unit)

	ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_ENHANCED_INFRASTRUCTURE_METRICS = ExportableInstanceField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_ENHANCED_INFRASTRUCTURE_METRICS", smithyprelude.Unit)

	ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_INFERRED_WORKLOAD_TYPES = ExportableInstanceField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_INFERRED_WORKLOAD_TYPES", smithyprelude.Unit)

	ExportableInstanceField_INFERRED_WORKLOAD_TYPES = ExportableInstanceField.AddMember("INFERRED_WORKLOAD_TYPES", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_MIGRATION_EFFORT = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_MIGRATION_EFFORT", smithyprelude.Unit)

	ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_EXTERNAL_METRICS_SOURCE = ExportableInstanceField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_EXTERNAL_METRICS_SOURCE", smithyprelude.Unit)

	ExportableInstanceField_TAGS = ExportableInstanceField.AddMember("TAGS", smithyprelude.Unit)

	ExportableInstanceField_INSTANCE_STATE = ExportableInstanceField.AddMember("INSTANCE_STATE", smithyprelude.Unit)

	ExportableInstanceField_EXTERNAL_METRIC_STATUS_CODE = ExportableInstanceField.AddMember("EXTERNAL_METRIC_STATUS_CODE", smithyprelude.Unit)

	ExportableInstanceField_EXTERNAL_METRIC_STATUS_REASON = ExportableInstanceField.AddMember("EXTERNAL_METRIC_STATUS_REASON", smithyprelude.Unit)

	ExportableInstanceField_CURRENT_INSTANCE_GPU_INFO = ExportableInstanceField.AddMember("CURRENT_INSTANCE_GPU_INFO", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_INSTANCE_GPU_INFO = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_INSTANCE_GPU_INFO", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_GPU_PERCENTAGE_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_GPU_PERCENTAGE_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_UTILIZATION_METRICS_GPU_MEMORY_PERCENTAGE_MAXIMUM = ExportableInstanceField.AddMember("UTILIZATION_METRICS_GPU_MEMORY_PERCENTAGE_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_GPU_PERCENTAGE_MAXIMUM = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_GPU_PERCENTAGE_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_GPU_MEMORY_PERCENTAGE_MAXIMUM = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_GPU_MEMORY_PERCENTAGE_MAXIMUM", smithyprelude.Unit)

	ExportableInstanceField_IDLE = ExportableInstanceField.AddMember("IDLE", smithyprelude.Unit)

	ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_PREFERRED_RESOURCES = ExportableInstanceField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_PREFERRED_RESOURCES", smithyprelude.Unit)

	ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_LOOKBACK_PERIOD = ExportableInstanceField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_LOOKBACK_PERIOD", smithyprelude.Unit)

	ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_UTILIZATION_PREFERENCES = ExportableInstanceField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_UTILIZATION_PREFERENCES", smithyprelude.Unit)

	ExportableInstanceField_EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE = ExportableInstanceField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS", smithyprelude.Unit)

	ExportableInstanceField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS = ExportableInstanceField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS", smithyprelude.Unit)

	_ExportableInstanceFields_member = _ExportableInstanceFields.AddMember("member", ExportableInstanceField)

	ExportableLambdaFunctionField_ACCOUNT_ID = ExportableLambdaFunctionField.AddMember("ACCOUNT_ID", smithyprelude.Unit)

	ExportableLambdaFunctionField_FUNCTION_ARN = ExportableLambdaFunctionField.AddMember("FUNCTION_ARN", smithyprelude.Unit)

	ExportableLambdaFunctionField_FUNCTION_VERSION = ExportableLambdaFunctionField.AddMember("FUNCTION_VERSION", smithyprelude.Unit)

	ExportableLambdaFunctionField_FINDING = ExportableLambdaFunctionField.AddMember("FINDING", smithyprelude.Unit)

	ExportableLambdaFunctionField_FINDING_REASON_CODES = ExportableLambdaFunctionField.AddMember("FINDING_REASON_CODES", smithyprelude.Unit)

	ExportableLambdaFunctionField_NUMBER_OF_INVOCATIONS = ExportableLambdaFunctionField.AddMember("NUMBER_OF_INVOCATIONS", smithyprelude.Unit)

	ExportableLambdaFunctionField_UTILIZATION_METRICS_DURATION_MAXIMUM = ExportableLambdaFunctionField.AddMember("UTILIZATION_METRICS_DURATION_MAXIMUM", smithyprelude.Unit)

	ExportableLambdaFunctionField_UTILIZATION_METRICS_DURATION_AVERAGE = ExportableLambdaFunctionField.AddMember("UTILIZATION_METRICS_DURATION_AVERAGE", smithyprelude.Unit)

	ExportableLambdaFunctionField_UTILIZATION_METRICS_MEMORY_MAXIMUM = ExportableLambdaFunctionField.AddMember("UTILIZATION_METRICS_MEMORY_MAXIMUM", smithyprelude.Unit)

	ExportableLambdaFunctionField_UTILIZATION_METRICS_MEMORY_AVERAGE = ExportableLambdaFunctionField.AddMember("UTILIZATION_METRICS_MEMORY_AVERAGE", smithyprelude.Unit)

	ExportableLambdaFunctionField_LOOKBACK_PERIOD_IN_DAYS = ExportableLambdaFunctionField.AddMember("LOOKBACK_PERIOD_IN_DAYS", smithyprelude.Unit)

	ExportableLambdaFunctionField_CURRENT_CONFIGURATION_MEMORY_SIZE = ExportableLambdaFunctionField.AddMember("CURRENT_CONFIGURATION_MEMORY_SIZE", smithyprelude.Unit)

	ExportableLambdaFunctionField_CURRENT_CONFIGURATION_TIMEOUT = ExportableLambdaFunctionField.AddMember("CURRENT_CONFIGURATION_TIMEOUT", smithyprelude.Unit)

	ExportableLambdaFunctionField_CURRENT_COST_TOTAL = ExportableLambdaFunctionField.AddMember("CURRENT_COST_TOTAL", smithyprelude.Unit)

	ExportableLambdaFunctionField_CURRENT_COST_AVERAGE = ExportableLambdaFunctionField.AddMember("CURRENT_COST_AVERAGE", smithyprelude.Unit)

	ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_CONFIGURATION_MEMORY_SIZE = ExportableLambdaFunctionField.AddMember("RECOMMENDATION_OPTIONS_CONFIGURATION_MEMORY_SIZE", smithyprelude.Unit)

	ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_COST_LOW = ExportableLambdaFunctionField.AddMember("RECOMMENDATION_OPTIONS_COST_LOW", smithyprelude.Unit)

	ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_COST_HIGH = ExportableLambdaFunctionField.AddMember("RECOMMENDATION_OPTIONS_COST_HIGH", smithyprelude.Unit)

	ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_DURATION_LOWER_BOUND = ExportableLambdaFunctionField.AddMember("RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_DURATION_LOWER_BOUND", smithyprelude.Unit)

	ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_DURATION_UPPER_BOUND = ExportableLambdaFunctionField.AddMember("RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_DURATION_UPPER_BOUND", smithyprelude.Unit)

	ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_DURATION_EXPECTED = ExportableLambdaFunctionField.AddMember("RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_DURATION_EXPECTED", smithyprelude.Unit)

	ExportableLambdaFunctionField_LAST_REFRESH_TIMESTAMP = ExportableLambdaFunctionField.AddMember("LAST_REFRESH_TIMESTAMP", smithyprelude.Unit)

	ExportableLambdaFunctionField_CURRENT_PERFORMANCE_RISK = ExportableLambdaFunctionField.AddMember("CURRENT_PERFORMANCE_RISK", smithyprelude.Unit)

	ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE = ExportableLambdaFunctionField.AddMember("RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE", smithyprelude.Unit)

	ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY = ExportableLambdaFunctionField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY", smithyprelude.Unit)

	ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE = ExportableLambdaFunctionField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE", smithyprelude.Unit)

	ExportableLambdaFunctionField_TAGS = ExportableLambdaFunctionField.AddMember("TAGS", smithyprelude.Unit)

	ExportableLambdaFunctionField_EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE = ExportableLambdaFunctionField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE", smithyprelude.Unit)

	ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE = ExportableLambdaFunctionField.AddMember("RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE", smithyprelude.Unit)

	ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS = ExportableLambdaFunctionField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS", smithyprelude.Unit)

	ExportableLambdaFunctionField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS = ExportableLambdaFunctionField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS", smithyprelude.Unit)

	_ExportableLambdaFunctionFields_member = _ExportableLambdaFunctionFields.AddMember("member", ExportableLambdaFunctionField)

	ExportableLicenseField_ACCOUNT_ID = ExportableLicenseField.AddMember("ACCOUNT_ID", smithyprelude.Unit)

	ExportableLicenseField_RESOURCE_ARN = ExportableLicenseField.AddMember("RESOURCE_ARN", smithyprelude.Unit)

	ExportableLicenseField_LOOKBACK_PERIOD_IN_DAYS = ExportableLicenseField.AddMember("LOOKBACK_PERIOD_IN_DAYS", smithyprelude.Unit)

	ExportableLicenseField_LAST_REFRESH_TIMESTAMP = ExportableLicenseField.AddMember("LAST_REFRESH_TIMESTAMP", smithyprelude.Unit)

	ExportableLicenseField_LICENSE_FINDING = ExportableLicenseField.AddMember("LICENSE_FINDING", smithyprelude.Unit)

	ExportableLicenseField_LICENSE_FINDING_REASON_CODES = ExportableLicenseField.AddMember("LICENSE_FINDING_REASON_CODES", smithyprelude.Unit)

	ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_NUMBER_OF_CORES = ExportableLicenseField.AddMember("CURRENT_LICENSE_CONFIGURATION_NUMBER_OF_CORES", smithyprelude.Unit)

	ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_INSTANCE_TYPE = ExportableLicenseField.AddMember("CURRENT_LICENSE_CONFIGURATION_INSTANCE_TYPE", smithyprelude.Unit)

	ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_OPERATING_SYSTEM = ExportableLicenseField.AddMember("CURRENT_LICENSE_CONFIGURATION_OPERATING_SYSTEM", smithyprelude.Unit)

	ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_LICENSE_NAME = ExportableLicenseField.AddMember("CURRENT_LICENSE_CONFIGURATION_LICENSE_NAME", smithyprelude.Unit)

	ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_LICENSE_EDITION = ExportableLicenseField.AddMember("CURRENT_LICENSE_CONFIGURATION_LICENSE_EDITION", smithyprelude.Unit)

	ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_LICENSE_MODEL = ExportableLicenseField.AddMember("CURRENT_LICENSE_CONFIGURATION_LICENSE_MODEL", smithyprelude.Unit)

	ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_LICENSE_VERSION = ExportableLicenseField.AddMember("CURRENT_LICENSE_CONFIGURATION_LICENSE_VERSION", smithyprelude.Unit)

	ExportableLicenseField_CURRENT_LICENSE_CONFIGURATION_METRICS_SOURCE = ExportableLicenseField.AddMember("CURRENT_LICENSE_CONFIGURATION_METRICS_SOURCE", smithyprelude.Unit)

	ExportableLicenseField_RECOMMENDATION_OPTIONS_OPERATING_SYSTEM = ExportableLicenseField.AddMember("RECOMMENDATION_OPTIONS_OPERATING_SYSTEM", smithyprelude.Unit)

	ExportableLicenseField_RECOMMENDATION_OPTIONS_LICENSE_EDITION = ExportableLicenseField.AddMember("RECOMMENDATION_OPTIONS_LICENSE_EDITION", smithyprelude.Unit)

	ExportableLicenseField_RECOMMENDATION_OPTIONS_LICENSE_MODEL = ExportableLicenseField.AddMember("RECOMMENDATION_OPTIONS_LICENSE_MODEL", smithyprelude.Unit)

	ExportableLicenseField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE = ExportableLicenseField.AddMember("RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE", smithyprelude.Unit)

	ExportableLicenseField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY = ExportableLicenseField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY", smithyprelude.Unit)

	ExportableLicenseField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE = ExportableLicenseField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE", smithyprelude.Unit)

	ExportableLicenseField_TAGS = ExportableLicenseField.AddMember("TAGS", smithyprelude.Unit)

	_ExportableLicenseFields_member = _ExportableLicenseFields.AddMember("member", ExportableLicenseField)

	ExportableRDSDBField_RESOURCE_ARN = ExportableRDSDBField.AddMember("RESOURCE_ARN", smithyprelude.Unit)

	ExportableRDSDBField_ACCOUNT_ID = ExportableRDSDBField.AddMember("ACCOUNT_ID", smithyprelude.Unit)

	ExportableRDSDBField_ENGINE = ExportableRDSDBField.AddMember("ENGINE", smithyprelude.Unit)

	ExportableRDSDBField_ENGINE_VERSION = ExportableRDSDBField.AddMember("ENGINE_VERSION", smithyprelude.Unit)

	ExportableRDSDBField_IDLE = ExportableRDSDBField.AddMember("IDLE", smithyprelude.Unit)

	ExportableRDSDBField_MULTI_AZ_DB_INSTANCE = ExportableRDSDBField.AddMember("MULTI_AZ_DB_INSTANCE", smithyprelude.Unit)

	ExportableRDSDBField_CLUSTER_WRITER = ExportableRDSDBField.AddMember("CLUSTER_WRITER", smithyprelude.Unit)

	ExportableRDSDBField_CURRENT_DB_INSTANCE_CLASS = ExportableRDSDBField.AddMember("CURRENT_DB_INSTANCE_CLASS", smithyprelude.Unit)

	ExportableRDSDBField_CURRENT_STORAGE_CONFIGURATION_STORAGE_TYPE = ExportableRDSDBField.AddMember("CURRENT_STORAGE_CONFIGURATION_STORAGE_TYPE", smithyprelude.Unit)

	ExportableRDSDBField_CURRENT_STORAGE_CONFIGURATION_ALLOCATED_STORAGE = ExportableRDSDBField.AddMember("CURRENT_STORAGE_CONFIGURATION_ALLOCATED_STORAGE", smithyprelude.Unit)

	ExportableRDSDBField_CURRENT_STORAGE_CONFIGURATION_MAX_ALLOCATED_STORAGE = ExportableRDSDBField.AddMember("CURRENT_STORAGE_CONFIGURATION_MAX_ALLOCATED_STORAGE", smithyprelude.Unit)

	ExportableRDSDBField_CURRENT_STORAGE_CONFIGURATION_IOPS = ExportableRDSDBField.AddMember("CURRENT_STORAGE_CONFIGURATION_IOPS", smithyprelude.Unit)

	ExportableRDSDBField_CURRENT_STORAGE_CONFIGURATION_STORAGE_THROUGHPUT = ExportableRDSDBField.AddMember("CURRENT_STORAGE_CONFIGURATION_STORAGE_THROUGHPUT", smithyprelude.Unit)

	ExportableRDSDBField_CURRENT_STORAGE_ESTIMATED_MONTHLY_VOLUME_IOPS_COST_VARIATION = ExportableRDSDBField.AddMember("CURRENT_STORAGE_ESTIMATED_MONTHLY_VOLUME_IOPS_COST_VARIATION", smithyprelude.Unit)

	ExportableRDSDBField_CURRENT_INSTANCE_ON_DEMAND_HOURLY_PRICE = ExportableRDSDBField.AddMember("CURRENT_INSTANCE_ON_DEMAND_HOURLY_PRICE", smithyprelude.Unit)

	ExportableRDSDBField_CURRENT_STORAGE_ON_DEMAND_MONTHLY_PRICE = ExportableRDSDBField.AddMember("CURRENT_STORAGE_ON_DEMAND_MONTHLY_PRICE", smithyprelude.Unit)

	ExportableRDSDBField_LOOKBACK_PERIOD_IN_DAYS = ExportableRDSDBField.AddMember("LOOKBACK_PERIOD_IN_DAYS", smithyprelude.Unit)

	ExportableRDSDBField_CURRENT_STORAGE_ESTIMATED_CLUSTER_INSTANCE_ON_DEMAND_MONTHLY_COST = ExportableRDSDBField.AddMember("CURRENT_STORAGE_ESTIMATED_CLUSTER_INSTANCE_ON_DEMAND_MONTHLY_COST", smithyprelude.Unit)

	ExportableRDSDBField_CURRENT_STORAGE_ESTIMATED_CLUSTER_STORAGE_ON_DEMAND_MONTHLY_COST = ExportableRDSDBField.AddMember("CURRENT_STORAGE_ESTIMATED_CLUSTER_STORAGE_ON_DEMAND_MONTHLY_COST", smithyprelude.Unit)

	ExportableRDSDBField_CURRENT_STORAGE_ESTIMATED_CLUSTER_STORAGE_IO_ON_DEMAND_MONTHLY_COST = ExportableRDSDBField.AddMember("CURRENT_STORAGE_ESTIMATED_CLUSTER_STORAGE_IO_ON_DEMAND_MONTHLY_COST", smithyprelude.Unit)

	ExportableRDSDBField_CURRENT_INSTANCE_PERFORMANCE_RISK = ExportableRDSDBField.AddMember("CURRENT_INSTANCE_PERFORMANCE_RISK", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_CPU_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_CPU_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_MEMORY_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_MEMORY_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_EBS_VOLUME_STORAGE_SPACE_UTILIZATION_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_EBS_VOLUME_STORAGE_SPACE_UTILIZATION_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_NETWORK_RECEIVE_THROUGHPUT_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_NETWORK_RECEIVE_THROUGHPUT_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_NETWORK_TRANSMIT_THROUGHPUT_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_NETWORK_TRANSMIT_THROUGHPUT_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_EBS_VOLUME_READ_IOPS_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_EBS_VOLUME_READ_IOPS_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_EBS_VOLUME_WRITE_IOPS_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_EBS_VOLUME_WRITE_IOPS_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_EBS_VOLUME_READ_THROUGHPUT_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_EBS_VOLUME_READ_THROUGHPUT_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_EBS_VOLUME_WRITE_THROUGHPUT_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_EBS_VOLUME_WRITE_THROUGHPUT_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_DATABASE_CONNECTIONS_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_DATABASE_CONNECTIONS_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_STORAGE_NETWORK_RECEIVE_THROUGHPUT_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_STORAGE_NETWORK_RECEIVE_THROUGHPUT_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_STORAGE_NETWORK_TRANSMIT_THROUGHPUT_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_STORAGE_NETWORK_TRANSMIT_THROUGHPUT_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_AURORA_MEMORY_HEALTH_STATE_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_AURORA_MEMORY_HEALTH_STATE_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_AURORA_MEMORY_NUM_DECLINED_SQL_TOTAL_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_AURORA_MEMORY_NUM_DECLINED_SQL_TOTAL_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_AURORA_MEMORY_NUM_KILL_CONN_TOTAL_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_AURORA_MEMORY_NUM_KILL_CONN_TOTAL_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_AURORA_MEMORY_NUM_KILL_QUERY_TOTAL_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_AURORA_MEMORY_NUM_KILL_QUERY_TOTAL_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_READ_IOPS_EPHEMERAL_STORAGE_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_READ_IOPS_EPHEMERAL_STORAGE_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_WRITE_IOPS_EPHEMERAL_STORAGE_MAXIMUM = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_WRITE_IOPS_EPHEMERAL_STORAGE_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_VOLUME_BYTES_USED_AVERAGE = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_VOLUME_BYTES_USED_AVERAGE", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_VOLUME_READ_IOPS_AVERAGE = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_VOLUME_READ_IOPS_AVERAGE", smithyprelude.Unit)

	ExportableRDSDBField_UTILIZATION_METRICS_VOLUME_WRITE_IOPS_AVERAGE = ExportableRDSDBField.AddMember("UTILIZATION_METRICS_VOLUME_WRITE_IOPS_AVERAGE", smithyprelude.Unit)

	ExportableRDSDBField_INSTANCE_FINDING = ExportableRDSDBField.AddMember("INSTANCE_FINDING", smithyprelude.Unit)

	ExportableRDSDBField_INSTANCE_FINDING_REASON_CODES = ExportableRDSDBField.AddMember("INSTANCE_FINDING_REASON_CODES", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_FINDING = ExportableRDSDBField.AddMember("STORAGE_FINDING", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_FINDING_REASON_CODES = ExportableRDSDBField.AddMember("STORAGE_FINDING_REASON_CODES", smithyprelude.Unit)

	ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_DB_INSTANCE_CLASS = ExportableRDSDBField.AddMember("INSTANCE_RECOMMENDATION_OPTIONS_DB_INSTANCE_CLASS", smithyprelude.Unit)

	ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_RANK = ExportableRDSDBField.AddMember("INSTANCE_RECOMMENDATION_OPTIONS_RANK", smithyprelude.Unit)

	ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_PERFORMANCE_RISK = ExportableRDSDBField.AddMember("INSTANCE_RECOMMENDATION_OPTIONS_PERFORMANCE_RISK", smithyprelude.Unit)

	ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_CPU_MAXIMUM = ExportableRDSDBField.AddMember("INSTANCE_RECOMMENDATION_OPTIONS_PROJECTED_UTILIZATION_METRICS_CPU_MAXIMUM", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_STORAGE_TYPE = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_STORAGE_TYPE", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ALLOCATED_STORAGE = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_ALLOCATED_STORAGE", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_MAX_ALLOCATED_STORAGE = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_MAX_ALLOCATED_STORAGE", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_IOPS = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_IOPS", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_STORAGE_THROUGHPUT = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_STORAGE_THROUGHPUT", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_RANK = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_RANK", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_VOLUME_IOPS_COST_VARIATION = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_VOLUME_IOPS_COST_VARIATION", smithyprelude.Unit)

	ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_INSTANCE_ON_DEMAND_HOURLY_PRICE = ExportableRDSDBField.AddMember("INSTANCE_RECOMMENDATION_OPTIONS_INSTANCE_ON_DEMAND_HOURLY_PRICE", smithyprelude.Unit)

	ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE = ExportableRDSDBField.AddMember("INSTANCE_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE", smithyprelude.Unit)

	ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY = ExportableRDSDBField.AddMember("INSTANCE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY", smithyprelude.Unit)

	ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE = ExportableRDSDBField.AddMember("INSTANCE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE", smithyprelude.Unit)

	ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE = ExportableRDSDBField.AddMember("INSTANCE_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE", smithyprelude.Unit)

	ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS = ExportableRDSDBField.AddMember("INSTANCE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS", smithyprelude.Unit)

	ExportableRDSDBField_INSTANCE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS = ExportableRDSDBField.AddMember("INSTANCE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ON_DEMAND_MONTHLY_PRICE = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_ON_DEMAND_MONTHLY_PRICE", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_CLUSTER_INSTANCE_ON_DEMAND_MONTHLY_COST = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_CLUSTER_INSTANCE_ON_DEMAND_MONTHLY_COST", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_CLUSTER_STORAGE_ON_DEMAND_MONTHLY_COST = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_CLUSTER_STORAGE_ON_DEMAND_MONTHLY_COST", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_CLUSTER_STORAGE_IO_ON_DEMAND_MONTHLY_COST = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_CLUSTER_STORAGE_IO_ON_DEMAND_MONTHLY_COST", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS", smithyprelude.Unit)

	ExportableRDSDBField_STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS = ExportableRDSDBField.AddMember("STORAGE_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS", smithyprelude.Unit)

	ExportableRDSDBField_EFFECTIVE_RECOMMENDATION_PREFERENCES_CPU_VENDOR_ARCHITECTURES = ExportableRDSDBField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_CPU_VENDOR_ARCHITECTURES", smithyprelude.Unit)

	ExportableRDSDBField_EFFECTIVE_RECOMMENDATION_PREFERENCES_ENHANCED_INFRASTRUCTURE_METRICS = ExportableRDSDBField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_ENHANCED_INFRASTRUCTURE_METRICS", smithyprelude.Unit)

	ExportableRDSDBField_EFFECTIVE_RECOMMENDATION_PREFERENCES_LOOKBACK_PERIOD = ExportableRDSDBField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_LOOKBACK_PERIOD", smithyprelude.Unit)

	ExportableRDSDBField_EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE = ExportableRDSDBField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE", smithyprelude.Unit)

	ExportableRDSDBField_LAST_REFRESH_TIMESTAMP = ExportableRDSDBField.AddMember("LAST_REFRESH_TIMESTAMP", smithyprelude.Unit)

	ExportableRDSDBField_TAGS = ExportableRDSDBField.AddMember("TAGS", smithyprelude.Unit)

	ExportableRDSDBField_DB_CLUSTER_IDENTIFIER = ExportableRDSDBField.AddMember("DB_CLUSTER_IDENTIFIER", smithyprelude.Unit)

	ExportableRDSDBField_PROMOTION_TIER = ExportableRDSDBField.AddMember("PROMOTION_TIER", smithyprelude.Unit)

	_ExportableRDSDBFields_member = _ExportableRDSDBFields.AddMember("member", ExportableRDSDBField)

	ExportableVolumeField_ACCOUNT_ID = ExportableVolumeField.AddMember("ACCOUNT_ID", smithyprelude.Unit)

	ExportableVolumeField_VOLUME_ARN = ExportableVolumeField.AddMember("VOLUME_ARN", smithyprelude.Unit)

	ExportableVolumeField_FINDING = ExportableVolumeField.AddMember("FINDING", smithyprelude.Unit)

	ExportableVolumeField_UTILIZATION_METRICS_VOLUME_READ_OPS_PER_SECOND_MAXIMUM = ExportableVolumeField.AddMember("UTILIZATION_METRICS_VOLUME_READ_OPS_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableVolumeField_UTILIZATION_METRICS_VOLUME_WRITE_OPS_PER_SECOND_MAXIMUM = ExportableVolumeField.AddMember("UTILIZATION_METRICS_VOLUME_WRITE_OPS_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableVolumeField_UTILIZATION_METRICS_VOLUME_READ_BYTES_PER_SECOND_MAXIMUM = ExportableVolumeField.AddMember("UTILIZATION_METRICS_VOLUME_READ_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableVolumeField_UTILIZATION_METRICS_VOLUME_WRITE_BYTES_PER_SECOND_MAXIMUM = ExportableVolumeField.AddMember("UTILIZATION_METRICS_VOLUME_WRITE_BYTES_PER_SECOND_MAXIMUM", smithyprelude.Unit)

	ExportableVolumeField_UTILIZATION_METRICS_VOLUME_IOPS_EXCEEDED_MAXIMUM = ExportableVolumeField.AddMember("UTILIZATION_METRICS_VOLUME_IOPS_EXCEEDED_MAXIMUM", smithyprelude.Unit)

	ExportableVolumeField_UTILIZATION_METRICS_VOLUME_THROUGHPUT_EXCEEDED_MAXIMUM = ExportableVolumeField.AddMember("UTILIZATION_METRICS_VOLUME_THROUGHPUT_EXCEEDED_MAXIMUM", smithyprelude.Unit)

	ExportableVolumeField_LOOKBACK_PERIOD_IN_DAYS = ExportableVolumeField.AddMember("LOOKBACK_PERIOD_IN_DAYS", smithyprelude.Unit)

	ExportableVolumeField_CURRENT_CONFIGURATION_VOLUME_TYPE = ExportableVolumeField.AddMember("CURRENT_CONFIGURATION_VOLUME_TYPE", smithyprelude.Unit)

	ExportableVolumeField_CURRENT_CONFIGURATION_VOLUME_BASELINE_IOPS = ExportableVolumeField.AddMember("CURRENT_CONFIGURATION_VOLUME_BASELINE_IOPS", smithyprelude.Unit)

	ExportableVolumeField_CURRENT_CONFIGURATION_VOLUME_BASELINE_THROUGHPUT = ExportableVolumeField.AddMember("CURRENT_CONFIGURATION_VOLUME_BASELINE_THROUGHPUT", smithyprelude.Unit)

	ExportableVolumeField_CURRENT_CONFIGURATION_VOLUME_BURST_IOPS = ExportableVolumeField.AddMember("CURRENT_CONFIGURATION_VOLUME_BURST_IOPS", smithyprelude.Unit)

	ExportableVolumeField_CURRENT_CONFIGURATION_VOLUME_BURST_THROUGHPUT = ExportableVolumeField.AddMember("CURRENT_CONFIGURATION_VOLUME_BURST_THROUGHPUT", smithyprelude.Unit)

	ExportableVolumeField_CURRENT_CONFIGURATION_VOLUME_SIZE = ExportableVolumeField.AddMember("CURRENT_CONFIGURATION_VOLUME_SIZE", smithyprelude.Unit)

	ExportableVolumeField_CURRENT_MONTHLY_PRICE = ExportableVolumeField.AddMember("CURRENT_MONTHLY_PRICE", smithyprelude.Unit)

	ExportableVolumeField_RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_TYPE = ExportableVolumeField.AddMember("RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_TYPE", smithyprelude.Unit)

	ExportableVolumeField_RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_BASELINE_IOPS = ExportableVolumeField.AddMember("RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_BASELINE_IOPS", smithyprelude.Unit)

	ExportableVolumeField_RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_BASELINE_THROUGHPUT = ExportableVolumeField.AddMember("RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_BASELINE_THROUGHPUT", smithyprelude.Unit)

	ExportableVolumeField_RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_BURST_IOPS = ExportableVolumeField.AddMember("RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_BURST_IOPS", smithyprelude.Unit)

	ExportableVolumeField_RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_BURST_THROUGHPUT = ExportableVolumeField.AddMember("RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_BURST_THROUGHPUT", smithyprelude.Unit)

	ExportableVolumeField_RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_SIZE = ExportableVolumeField.AddMember("RECOMMENDATION_OPTIONS_CONFIGURATION_VOLUME_SIZE", smithyprelude.Unit)

	ExportableVolumeField_RECOMMENDATION_OPTIONS_MONTHLY_PRICE = ExportableVolumeField.AddMember("RECOMMENDATION_OPTIONS_MONTHLY_PRICE", smithyprelude.Unit)

	ExportableVolumeField_RECOMMENDATION_OPTIONS_PERFORMANCE_RISK = ExportableVolumeField.AddMember("RECOMMENDATION_OPTIONS_PERFORMANCE_RISK", smithyprelude.Unit)

	ExportableVolumeField_LAST_REFRESH_TIMESTAMP = ExportableVolumeField.AddMember("LAST_REFRESH_TIMESTAMP", smithyprelude.Unit)

	ExportableVolumeField_CURRENT_PERFORMANCE_RISK = ExportableVolumeField.AddMember("CURRENT_PERFORMANCE_RISK", smithyprelude.Unit)

	ExportableVolumeField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE = ExportableVolumeField.AddMember("RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_PERCENTAGE", smithyprelude.Unit)

	ExportableVolumeField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY = ExportableVolumeField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY", smithyprelude.Unit)

	ExportableVolumeField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE = ExportableVolumeField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE", smithyprelude.Unit)

	ExportableVolumeField_TAGS = ExportableVolumeField.AddMember("TAGS", smithyprelude.Unit)

	ExportableVolumeField_ROOT_VOLUME = ExportableVolumeField.AddMember("ROOT_VOLUME", smithyprelude.Unit)

	ExportableVolumeField_CURRENT_CONFIGURATION_ROOT_VOLUME = ExportableVolumeField.AddMember("CURRENT_CONFIGURATION_ROOT_VOLUME", smithyprelude.Unit)

	ExportableVolumeField_EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE = ExportableVolumeField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_SAVINGS_ESTIMATION_MODE", smithyprelude.Unit)

	ExportableVolumeField_RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE = ExportableVolumeField.AddMember("RECOMMENDATION_OPTIONS_SAVINGS_OPPORTUNITY_AFTER_DISCOUNTS_PERCENTAGE", smithyprelude.Unit)

	ExportableVolumeField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS = ExportableVolumeField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_CURRENCY_AFTER_DISCOUNTS", smithyprelude.Unit)

	ExportableVolumeField_RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS = ExportableVolumeField.AddMember("RECOMMENDATION_OPTIONS_ESTIMATED_MONTHLY_SAVINGS_VALUE_AFTER_DISCOUNTS", smithyprelude.Unit)

	ExportableVolumeField_EFFECTIVE_RECOMMENDATION_PREFERENCES_LOOKBACK_PERIOD = ExportableVolumeField.AddMember("EFFECTIVE_RECOMMENDATION_PREFERENCES_LOOKBACK_PERIOD", smithyprelude.Unit)

	_ExportableVolumeFields_member = _ExportableVolumeFields.AddMember("member", ExportableVolumeField)

	S3Destination_bucket = S3Destination.AddMember("bucket", _DestinationBucket)

	S3Destination_key = S3Destination.AddMember("key", _DestinationKey)

	S3Destination_metadataKey = S3Destination.AddMember("metadataKey", _MetadataKey)

	ExportDestination_s3 = ExportDestination.AddMember("s3", S3Destination)

	ExternalMetricStatusCode_NO_EXTERNAL_METRIC_SET = ExternalMetricStatusCode.AddMember("NO_EXTERNAL_METRIC_SET", smithyprelude.Unit)

	ExternalMetricStatusCode_INTEGRATION_SUCCESS = ExternalMetricStatusCode.AddMember("INTEGRATION_SUCCESS", smithyprelude.Unit)

	ExternalMetricStatusCode_DATADOG_INTEGRATION_ERROR = ExternalMetricStatusCode.AddMember("DATADOG_INTEGRATION_ERROR", smithyprelude.Unit)

	ExternalMetricStatusCode_DYNATRACE_INTEGRATION_ERROR = ExternalMetricStatusCode.AddMember("DYNATRACE_INTEGRATION_ERROR", smithyprelude.Unit)

	ExternalMetricStatusCode_NEWRELIC_INTEGRATION_ERROR = ExternalMetricStatusCode.AddMember("NEWRELIC_INTEGRATION_ERROR", smithyprelude.Unit)

	ExternalMetricStatusCode_INSTANA_INTEGRATION_ERROR = ExternalMetricStatusCode.AddMember("INSTANA_INTEGRATION_ERROR", smithyprelude.Unit)

	ExternalMetricStatusCode_INSUFFICIENT_DATADOG_METRICS = ExternalMetricStatusCode.AddMember("INSUFFICIENT_DATADOG_METRICS", smithyprelude.Unit)

	ExternalMetricStatusCode_INSUFFICIENT_DYNATRACE_METRICS = ExternalMetricStatusCode.AddMember("INSUFFICIENT_DYNATRACE_METRICS", smithyprelude.Unit)

	ExternalMetricStatusCode_INSUFFICIENT_NEWRELIC_METRICS = ExternalMetricStatusCode.AddMember("INSUFFICIENT_NEWRELIC_METRICS", smithyprelude.Unit)

	ExternalMetricStatusCode_INSUFFICIENT_INSTANA_METRICS = ExternalMetricStatusCode.AddMember("INSUFFICIENT_INSTANA_METRICS", smithyprelude.Unit)

	ExternalMetricStatus_statusCode = ExternalMetricStatus.AddMember("statusCode", ExternalMetricStatusCode)

	ExternalMetricStatus_statusReason = ExternalMetricStatus.AddMember("statusReason", _ExternalMetricStatusReason)

	FileFormat_CSV = FileFormat.AddMember("CSV", smithyprelude.Unit)

	FilterName_FINDING = FilterName.AddMember("FINDING", smithyprelude.Unit)

	FilterName_FINDING_REASON_CODES = FilterName.AddMember("FINDING_REASON_CODES", smithyprelude.Unit)

	FilterName_RECOMMENDATION_SOURCE_TYPE = FilterName.AddMember("RECOMMENDATION_SOURCE_TYPE", smithyprelude.Unit)

	FilterName_INFERRED_WORKLOAD_TYPES = FilterName.AddMember("INFERRED_WORKLOAD_TYPES", smithyprelude.Unit)

	Filter_name = Filter.AddMember("name", FilterName)

	Filter_values = Filter.AddMember("values", _FilterValues)

	_Filters_member = _Filters.AddMember("member", Filter)

	FindingReasonCode_MEMORY_OVER_PROVISIONED = FindingReasonCode.AddMember("MEMORY_OVER_PROVISIONED", smithyprelude.Unit)

	FindingReasonCode_MEMORY_UNDER_PROVISIONED = FindingReasonCode.AddMember("MEMORY_UNDER_PROVISIONED", smithyprelude.Unit)

	_FunctionArns_member = _FunctionArns.AddMember("member", _FunctionArn)

	GetRecommendationError_identifier = GetRecommendationError.AddMember("identifier", _Identifier)

	GetRecommendationError_code = GetRecommendationError.AddMember("code", _Code)

	GetRecommendationError_message = GetRecommendationError.AddMember("message", _Message)

	_GetRecommendationErrors_member = _GetRecommendationErrors.AddMember("member", GetRecommendationError)

	Idle_TRUE = Idle.AddMember("TRUE", smithyprelude.Unit)

	Idle_FALSE = Idle.AddMember("FALSE", smithyprelude.Unit)

	_IdleDimensionValues_member = _IdleDimensionValues.AddMember("member", _IdleDimensionValue)

	IdleDimension_key = IdleDimension.AddMember("key", _IdleDimensionKey)

	IdleDimension_values = IdleDimension.AddMember("values", _IdleDimensionValues)

	_IdleDimensions_member = _IdleDimensions.AddMember("member", IdleDimension)

	IdleEstimatedMonthlySavings_currency = IdleEstimatedMonthlySavings.AddMember("currency", Currency)

	IdleEstimatedMonthlySavings_value = IdleEstimatedMonthlySavings.AddMember("value", _Value)

	IdleFinding_IDLE = IdleFinding.AddMember("IDLE", smithyprelude.Unit)

	IdleFinding_UNATTACHED = IdleFinding.AddMember("UNATTACHED", smithyprelude.Unit)

	IdleFinding_UNUSED = IdleFinding.AddMember("UNUSED", smithyprelude.Unit)

	IdleMetricName_CPU = IdleMetricName.AddMember("CPU", smithyprelude.Unit)

	IdleMetricName_MEMORY = IdleMetricName.AddMember("MEMORY", smithyprelude.Unit)

	IdleMetricName_NETWORK_OUT_BYTES_PER_SECOND = IdleMetricName.AddMember("NETWORK_OUT_BYTES_PER_SECOND", smithyprelude.Unit)

	IdleMetricName_NETWORK_IN_BYTES_PER_SECOND = IdleMetricName.AddMember("NETWORK_IN_BYTES_PER_SECOND", smithyprelude.Unit)

	IdleMetricName_DATABASE_CONNECTIONS = IdleMetricName.AddMember("DATABASE_CONNECTIONS", smithyprelude.Unit)

	IdleMetricName_EBS_VOLUME_READ_IOPS = IdleMetricName.AddMember("EBS_VOLUME_READ_IOPS", smithyprelude.Unit)

	IdleMetricName_EBS_VOLUME_WRITE_IOPS = IdleMetricName.AddMember("EBS_VOLUME_WRITE_IOPS", smithyprelude.Unit)

	IdleMetricName_VOLUME_READ_OPS_PER_SECOND = IdleMetricName.AddMember("VOLUME_READ_OPS_PER_SECOND", smithyprelude.Unit)

	IdleMetricName_VOLUME_WRITE_OPS_PER_SECOND = IdleMetricName.AddMember("VOLUME_WRITE_OPS_PER_SECOND", smithyprelude.Unit)

	IdleMetricName_ACTIVE_CONNECTION_COUNT = IdleMetricName.AddMember("ACTIVE_CONNECTION_COUNT", smithyprelude.Unit)

	IdleMetricName_PACKETS_IN_FROM_SOURCE = IdleMetricName.AddMember("PACKETS_IN_FROM_SOURCE", smithyprelude.Unit)

	IdleMetricName_PACKETS_IN_FROM_DESTINATION = IdleMetricName.AddMember("PACKETS_IN_FROM_DESTINATION", smithyprelude.Unit)

	IdleMetricName_CONSUMED_READ_CAPACITY_UNITS = IdleMetricName.AddMember("CONSUMED_READ_CAPACITY_UNITS", smithyprelude.Unit)

	IdleMetricName_CONSUMED_WRITE_CAPACITY_UNITS = IdleMetricName.AddMember("CONSUMED_WRITE_CAPACITY_UNITS", smithyprelude.Unit)

	IdleMetricName_CONSUMED_CHANGE_DATA_CAPTURE_UNITS = IdleMetricName.AddMember("CONSUMED_CHANGE_DATA_CAPTURE_UNITS", smithyprelude.Unit)

	IdleMetricName_NEW_CONNECTIONS = IdleMetricName.AddMember("NEW_CONNECTIONS", smithyprelude.Unit)

	IdleMetricName_ENGINE_CPU_UTILIZATION = IdleMetricName.AddMember("ENGINE_CPU_UTILIZATION", smithyprelude.Unit)

	IdleMetricName_CACHE_HITS = IdleMetricName.AddMember("CACHE_HITS", smithyprelude.Unit)

	IdleMetricName_CACHE_MISSES = IdleMetricName.AddMember("CACHE_MISSES", smithyprelude.Unit)

	IdleMetricName_KEYSPACE_HITS = IdleMetricName.AddMember("KEYSPACE_HITS", smithyprelude.Unit)

	IdleMetricName_KEYSPACE_MISSES = IdleMetricName.AddMember("KEYSPACE_MISSES", smithyprelude.Unit)

	IdleMetricName_IS_IDLE = IdleMetricName.AddMember("IS_IDLE", smithyprelude.Unit)

	IdleMetricName_USER_CONNECTED = IdleMetricName.AddMember("USER_CONNECTED", smithyprelude.Unit)

	IdleMetricName_INVOCATIONS = IdleMetricName.AddMember("INVOCATIONS", smithyprelude.Unit)

	IdleMetricName_GET_TYPE_CMDS = IdleMetricName.AddMember("GET_TYPE_CMDS", smithyprelude.Unit)

	IdleMetricName_SET_TYPE_CMDS = IdleMetricName.AddMember("SET_TYPE_CMDS", smithyprelude.Unit)

	IdleMetricName_ELASTI_CACHE_PROCESSING_UNITS = IdleMetricName.AddMember("ELASTI_CACHE_PROCESSING_UNITS", smithyprelude.Unit)

	IdleMetricName_CURR_CONNECTIONS = IdleMetricName.AddMember("CURR_CONNECTIONS", smithyprelude.Unit)

	IdleRecommendationResourceType_EC2_INSTANCE = IdleRecommendationResourceType.AddMember("EC2_INSTANCE", smithyprelude.Unit)

	IdleRecommendationResourceType_AUTO_SCALING_GROUP = IdleRecommendationResourceType.AddMember("AUTO_SCALING_GROUP", smithyprelude.Unit)

	IdleRecommendationResourceType_EBS_VOLUME = IdleRecommendationResourceType.AddMember("EBS_VOLUME", smithyprelude.Unit)

	IdleRecommendationResourceType_ECS_SERVICE = IdleRecommendationResourceType.AddMember("ECS_SERVICE", smithyprelude.Unit)

	IdleRecommendationResourceType_RDS_DB_INSTANCE = IdleRecommendationResourceType.AddMember("RDS_DB_INSTANCE", smithyprelude.Unit)

	IdleRecommendationResourceType_NAT_GATEWAY = IdleRecommendationResourceType.AddMember("NAT_GATEWAY", smithyprelude.Unit)

	IdleRecommendationResourceType_DYNAMO_DB_TABLE = IdleRecommendationResourceType.AddMember("DYNAMO_DB_TABLE", smithyprelude.Unit)

	IdleRecommendationResourceType_ELASTI_CACHE_CLUSTER = IdleRecommendationResourceType.AddMember("ELASTI_CACHE_CLUSTER", smithyprelude.Unit)

	IdleRecommendationResourceType_MEMORY_DB_CLUSTER = IdleRecommendationResourceType.AddMember("MEMORY_DB_CLUSTER", smithyprelude.Unit)

	IdleRecommendationResourceType_DOCUMENT_DB_CLUSTER = IdleRecommendationResourceType.AddMember("DOCUMENT_DB_CLUSTER", smithyprelude.Unit)

	IdleRecommendationResourceType_WORKSPACES = IdleRecommendationResourceType.AddMember("WORKSPACES", smithyprelude.Unit)

	IdleRecommendationResourceType_SAGE_MAKER_ENDPOINT = IdleRecommendationResourceType.AddMember("SAGE_MAKER_ENDPOINT", smithyprelude.Unit)

	IdleSavingsOpportunity_savingsOpportunityPercentage = IdleSavingsOpportunity.AddMember("savingsOpportunityPercentage", _SavingsOpportunityPercentage)

	IdleSavingsOpportunity_estimatedMonthlySavings = IdleSavingsOpportunity.AddMember("estimatedMonthlySavings", IdleEstimatedMonthlySavings)

	IdleSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage = IdleSavingsOpportunityAfterDiscounts.AddMember("savingsOpportunityPercentage", _SavingsOpportunityPercentage)

	IdleSavingsOpportunityAfterDiscounts_estimatedMonthlySavings = IdleSavingsOpportunityAfterDiscounts.AddMember("estimatedMonthlySavings", IdleEstimatedMonthlySavings)

	IdleUtilizationMetric_name = IdleUtilizationMetric.AddMember("name", IdleMetricName)

	IdleUtilizationMetric_statistic = IdleUtilizationMetric.AddMember("statistic", MetricStatistic)

	IdleUtilizationMetric_value = IdleUtilizationMetric.AddMember("value", _MetricValue)

	IdleUtilizationMetric_dimensions = IdleUtilizationMetric.AddMember("dimensions", _IdleDimensions)

	_IdleUtilizationMetrics_member = _IdleUtilizationMetrics.AddMember("member", IdleUtilizationMetric)

	IdleRecommendation_resourceArn = IdleRecommendation.AddMember("resourceArn", _ResourceArn)

	IdleRecommendation_resourceId = IdleRecommendation.AddMember("resourceId", _ResourceId)

	IdleRecommendation_resourceType = IdleRecommendation.AddMember("resourceType", IdleRecommendationResourceType)

	IdleRecommendation_accountId = IdleRecommendation.AddMember("accountId", _AccountId)

	IdleRecommendation_finding = IdleRecommendation.AddMember("finding", IdleFinding)

	IdleRecommendation_findingDescription = IdleRecommendation.AddMember("findingDescription", _IdleFindingDescription)

	IdleRecommendation_savingsOpportunity = IdleRecommendation.AddMember("savingsOpportunity", IdleSavingsOpportunity)

	IdleRecommendation_savingsOpportunityAfterDiscounts = IdleRecommendation.AddMember("savingsOpportunityAfterDiscounts", IdleSavingsOpportunityAfterDiscounts)

	IdleRecommendation_utilizationMetrics = IdleRecommendation.AddMember("utilizationMetrics", _IdleUtilizationMetrics)

	IdleRecommendation_lookBackPeriodInDays = IdleRecommendation.AddMember("lookBackPeriodInDays", _LookBackPeriodInDays)

	IdleRecommendation_lastRefreshTimestamp = IdleRecommendation.AddMember("lastRefreshTimestamp", _LastRefreshTimestamp)

	IdleRecommendation_tags = IdleRecommendation.AddMember("tags", _Tags)

	IdleRecommendationError_identifier = IdleRecommendationError.AddMember("identifier", _Identifier)

	IdleRecommendationError_code = IdleRecommendationError.AddMember("code", _Code)

	IdleRecommendationError_message = IdleRecommendationError.AddMember("message", _Message)

	IdleRecommendationError_resourceType = IdleRecommendationError.AddMember("resourceType", IdleRecommendationResourceType)

	_IdleRecommendationErrors_member = _IdleRecommendationErrors.AddMember("member", IdleRecommendationError)

	IdleRecommendationFilterName_FINDING = IdleRecommendationFilterName.AddMember("FINDING", smithyprelude.Unit)

	IdleRecommendationFilterName_RESOURCE_TYPE = IdleRecommendationFilterName.AddMember("RESOURCE_TYPE", smithyprelude.Unit)

	IdleRecommendationFilter_name = IdleRecommendationFilter.AddMember("name", IdleRecommendationFilterName)

	IdleRecommendationFilter_values = IdleRecommendationFilter.AddMember("values", _FilterValues)

	_IdleRecommendationFilters_member = _IdleRecommendationFilters.AddMember("member", IdleRecommendationFilter)

	_IdleRecommendations_member = _IdleRecommendations.AddMember("member", IdleRecommendation)

	IdleSummary_name = IdleSummary.AddMember("name", IdleFinding)

	IdleSummary_value = IdleSummary.AddMember("value", _SummaryValue)

	_IdleSummaries_member = _IdleSummaries.AddMember("member", IdleSummary)

	InferredWorkloadSaving_inferredWorkloadTypes = InferredWorkloadSaving.AddMember("inferredWorkloadTypes", _InferredWorkloadTypes)

	InferredWorkloadSaving_estimatedMonthlySavings = InferredWorkloadSaving.AddMember("estimatedMonthlySavings", EstimatedMonthlySavings)

	_InferredWorkloadSavings_member = _InferredWorkloadSavings.AddMember("member", InferredWorkloadSaving)

	_InstanceArns_member = _InstanceArns.AddMember("member", _InstanceArn)

	InstanceEstimatedMonthlySavings_currency = InstanceEstimatedMonthlySavings.AddMember("currency", Currency)

	InstanceEstimatedMonthlySavings_value = InstanceEstimatedMonthlySavings.AddMember("value", _Value)

	InstanceIdle_TRUE = InstanceIdle.AddMember("TRUE", smithyprelude.Unit)

	InstanceIdle_FALSE = InstanceIdle.AddMember("FALSE", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_CPU_OVER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("CPU_OVER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_CPU_UNDER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("CPU_UNDER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_MEMORY_OVER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("MEMORY_OVER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_MEMORY_UNDER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("MEMORY_UNDER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_EBS_THROUGHPUT_OVER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("EBS_THROUGHPUT_OVER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_EBS_THROUGHPUT_UNDER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("EBS_THROUGHPUT_UNDER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_EBS_IOPS_OVER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("EBS_IOPS_OVER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_EBS_IOPS_UNDER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("EBS_IOPS_UNDER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_NETWORK_BANDWIDTH_OVER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("NETWORK_BANDWIDTH_OVER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_NETWORK_BANDWIDTH_UNDER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("NETWORK_BANDWIDTH_UNDER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_NETWORK_PPS_OVER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("NETWORK_PPS_OVER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_NETWORK_PPS_UNDER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("NETWORK_PPS_UNDER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_DISK_IOPS_OVER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("DISK_IOPS_OVER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_DISK_IOPS_UNDER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("DISK_IOPS_UNDER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_DISK_THROUGHPUT_OVER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("DISK_THROUGHPUT_OVER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_DISK_THROUGHPUT_UNDER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("DISK_THROUGHPUT_UNDER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_GPU_UNDER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("GPU_UNDER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_GPU_OVER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("GPU_OVER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_GPU_MEMORY_UNDER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("GPU_MEMORY_UNDER_PROVISIONED", smithyprelude.Unit)

	InstanceRecommendationFindingReasonCode_GPU_MEMORY_OVER_PROVISIONED = InstanceRecommendationFindingReasonCode.AddMember("GPU_MEMORY_OVER_PROVISIONED", smithyprelude.Unit)

	_InstanceRecommendationFindingReasonCodes_member = _InstanceRecommendationFindingReasonCodes.AddMember("member", InstanceRecommendationFindingReasonCode)

	PlatformDifference_HYPERVISOR = PlatformDifference.AddMember("HYPERVISOR", smithyprelude.Unit)

	PlatformDifference_NETWORK_INTERFACE = PlatformDifference.AddMember("NETWORK_INTERFACE", smithyprelude.Unit)

	PlatformDifference_STORAGE_INTERFACE = PlatformDifference.AddMember("STORAGE_INTERFACE", smithyprelude.Unit)

	PlatformDifference_INSTANCE_STORE_AVAILABILITY = PlatformDifference.AddMember("INSTANCE_STORE_AVAILABILITY", smithyprelude.Unit)

	PlatformDifference_VIRTUALIZATION_TYPE = PlatformDifference.AddMember("VIRTUALIZATION_TYPE", smithyprelude.Unit)

	PlatformDifference_ARCHITECTURE = PlatformDifference.AddMember("ARCHITECTURE", smithyprelude.Unit)

	_PlatformDifferences_member = _PlatformDifferences.AddMember("member", PlatformDifference)

	InstanceSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage = InstanceSavingsOpportunityAfterDiscounts.AddMember("savingsOpportunityPercentage", _SavingsOpportunityPercentage)

	InstanceSavingsOpportunityAfterDiscounts_estimatedMonthlySavings = InstanceSavingsOpportunityAfterDiscounts.AddMember("estimatedMonthlySavings", InstanceEstimatedMonthlySavings)

	InstanceRecommendationOption_instanceType = InstanceRecommendationOption.AddMember("instanceType", _InstanceType)

	InstanceRecommendationOption_instanceGpuInfo = InstanceRecommendationOption.AddMember("instanceGpuInfo", GpuInfo)

	InstanceRecommendationOption_projectedUtilizationMetrics = InstanceRecommendationOption.AddMember("projectedUtilizationMetrics", _ProjectedUtilizationMetrics)

	InstanceRecommendationOption_platformDifferences = InstanceRecommendationOption.AddMember("platformDifferences", _PlatformDifferences)

	InstanceRecommendationOption_performanceRisk = InstanceRecommendationOption.AddMember("performanceRisk", _PerformanceRisk)

	InstanceRecommendationOption_rank = InstanceRecommendationOption.AddMember("rank", _Rank)

	InstanceRecommendationOption_savingsOpportunity = InstanceRecommendationOption.AddMember("savingsOpportunity", SavingsOpportunity)

	InstanceRecommendationOption_savingsOpportunityAfterDiscounts = InstanceRecommendationOption.AddMember("savingsOpportunityAfterDiscounts", InstanceSavingsOpportunityAfterDiscounts)

	InstanceRecommendationOption_migrationEffort = InstanceRecommendationOption.AddMember("migrationEffort", MigrationEffort)

	_RecommendationOptions_member = _RecommendationOptions.AddMember("member", InstanceRecommendationOption)

	RecommendationSourceType_EC2_INSTANCE = RecommendationSourceType.AddMember("EC2_INSTANCE", smithyprelude.Unit)

	RecommendationSourceType_AUTO_SCALING_GROUP = RecommendationSourceType.AddMember("AUTO_SCALING_GROUP", smithyprelude.Unit)

	RecommendationSourceType_EBS_VOLUME = RecommendationSourceType.AddMember("EBS_VOLUME", smithyprelude.Unit)

	RecommendationSourceType_LAMBDA_FUNCTION = RecommendationSourceType.AddMember("LAMBDA_FUNCTION", smithyprelude.Unit)

	RecommendationSourceType_ECS_SERVICE = RecommendationSourceType.AddMember("ECS_SERVICE", smithyprelude.Unit)

	RecommendationSourceType_LICENSE = RecommendationSourceType.AddMember("LICENSE", smithyprelude.Unit)

	RecommendationSourceType_RDS_DB_INSTANCE = RecommendationSourceType.AddMember("RDS_DB_INSTANCE", smithyprelude.Unit)

	RecommendationSourceType_RDS_DB_INSTANCE_STORAGE = RecommendationSourceType.AddMember("RDS_DB_INSTANCE_STORAGE", smithyprelude.Unit)

	RecommendationSourceType_AURORA_DB_CLUSTER_STORAGE = RecommendationSourceType.AddMember("AURORA_DB_CLUSTER_STORAGE", smithyprelude.Unit)

	RecommendationSourceType_NAT_GATEWAY = RecommendationSourceType.AddMember("NAT_GATEWAY", smithyprelude.Unit)

	RecommendationSourceType_DYNAMO_DB_TABLE = RecommendationSourceType.AddMember("DYNAMO_DB_TABLE", smithyprelude.Unit)

	RecommendationSourceType_ELASTI_CACHE_CLUSTER = RecommendationSourceType.AddMember("ELASTI_CACHE_CLUSTER", smithyprelude.Unit)

	RecommendationSourceType_MEMORY_DB_CLUSTER = RecommendationSourceType.AddMember("MEMORY_DB_CLUSTER", smithyprelude.Unit)

	RecommendationSourceType_DOCUMENT_DB_CLUSTER = RecommendationSourceType.AddMember("DOCUMENT_DB_CLUSTER", smithyprelude.Unit)

	RecommendationSourceType_WORKSPACES = RecommendationSourceType.AddMember("WORKSPACES", smithyprelude.Unit)

	RecommendationSourceType_SAGE_MAKER_ENDPOINT = RecommendationSourceType.AddMember("SAGE_MAKER_ENDPOINT", smithyprelude.Unit)

	RecommendationSource_recommendationSourceArn = RecommendationSource.AddMember("recommendationSourceArn", _RecommendationSourceArn)

	RecommendationSource_recommendationSourceType = RecommendationSource.AddMember("recommendationSourceType", RecommendationSourceType)

	_RecommendationSources_member = _RecommendationSources.AddMember("member", RecommendationSource)

	InstanceState_PENDING = InstanceState.AddMember("PENDING", smithyprelude.Unit)

	InstanceState_RUNNING = InstanceState.AddMember("RUNNING", smithyprelude.Unit)

	InstanceState_SHUTTING_DOWN = InstanceState.AddMember("SHUTTING_DOWN", smithyprelude.Unit)

	InstanceState_TERMINATED = InstanceState.AddMember("TERMINATED", smithyprelude.Unit)

	InstanceState_STOPPING = InstanceState.AddMember("STOPPING", smithyprelude.Unit)

	InstanceState_STOPPED = InstanceState.AddMember("STOPPED", smithyprelude.Unit)

	InstanceRecommendation_instanceArn = InstanceRecommendation.AddMember("instanceArn", _InstanceArn)

	InstanceRecommendation_accountId = InstanceRecommendation.AddMember("accountId", _AccountId)

	InstanceRecommendation_instanceName = InstanceRecommendation.AddMember("instanceName", _InstanceName)

	InstanceRecommendation_currentInstanceType = InstanceRecommendation.AddMember("currentInstanceType", _CurrentInstanceType)

	InstanceRecommendation_finding = InstanceRecommendation.AddMember("finding", Finding)

	InstanceRecommendation_findingReasonCodes = InstanceRecommendation.AddMember("findingReasonCodes", _InstanceRecommendationFindingReasonCodes)

	InstanceRecommendation_utilizationMetrics = InstanceRecommendation.AddMember("utilizationMetrics", _UtilizationMetrics)

	InstanceRecommendation_lookBackPeriodInDays = InstanceRecommendation.AddMember("lookBackPeriodInDays", _LookBackPeriodInDays)

	InstanceRecommendation_recommendationOptions = InstanceRecommendation.AddMember("recommendationOptions", _RecommendationOptions)

	InstanceRecommendation_recommendationSources = InstanceRecommendation.AddMember("recommendationSources", _RecommendationSources)

	InstanceRecommendation_lastRefreshTimestamp = InstanceRecommendation.AddMember("lastRefreshTimestamp", _LastRefreshTimestamp)

	InstanceRecommendation_currentPerformanceRisk = InstanceRecommendation.AddMember("currentPerformanceRisk", CurrentPerformanceRisk)

	InstanceRecommendation_effectiveRecommendationPreferences = InstanceRecommendation.AddMember("effectiveRecommendationPreferences", EffectiveRecommendationPreferences)

	InstanceRecommendation_inferredWorkloadTypes = InstanceRecommendation.AddMember("inferredWorkloadTypes", _InferredWorkloadTypes)

	InstanceRecommendation_instanceState = InstanceRecommendation.AddMember("instanceState", InstanceState)

	InstanceRecommendation_tags = InstanceRecommendation.AddMember("tags", _Tags)

	InstanceRecommendation_externalMetricStatus = InstanceRecommendation.AddMember("externalMetricStatus", ExternalMetricStatus)

	InstanceRecommendation_currentInstanceGpuInfo = InstanceRecommendation.AddMember("currentInstanceGpuInfo", GpuInfo)

	InstanceRecommendation_idle = InstanceRecommendation.AddMember("idle", InstanceIdle)

	_InstanceRecommendations_member = _InstanceRecommendations.AddMember("member", InstanceRecommendation)

	InternalServerException_message = InternalServerException.AddMember("message", _ErrorMessage)

	InvalidParameterValueException_message = InvalidParameterValueException.AddMember("message", _ErrorMessage)

	JobFilterName_RESOURCE_TYPE = JobFilterName.AddMember("RESOURCE_TYPE", smithyprelude.Unit)

	JobFilterName_JOB_STATUS = JobFilterName.AddMember("JOB_STATUS", smithyprelude.Unit)

	JobFilter_name = JobFilter.AddMember("name", JobFilterName)

	JobFilter_values = JobFilter.AddMember("values", _FilterValues)

	_JobFilters_member = _JobFilters.AddMember("member", JobFilter)

	_JobIds_member = _JobIds.AddMember("member", _JobId)

	JobStatus_QUEUED = JobStatus.AddMember("QUEUED", smithyprelude.Unit)

	JobStatus_IN_PROGRESS = JobStatus.AddMember("IN_PROGRESS", smithyprelude.Unit)

	JobStatus_COMPLETE = JobStatus.AddMember("COMPLETE", smithyprelude.Unit)

	JobStatus_FAILED = JobStatus.AddMember("FAILED", smithyprelude.Unit)

	LambdaSavingsEstimationModeSource_PUBLIC_PRICING = LambdaSavingsEstimationModeSource.AddMember("PUBLIC_PRICING", smithyprelude.Unit)

	LambdaSavingsEstimationModeSource_COST_EXPLORER_RIGHTSIZING = LambdaSavingsEstimationModeSource.AddMember("COST_EXPLORER_RIGHTSIZING", smithyprelude.Unit)

	LambdaSavingsEstimationModeSource_COST_OPTIMIZATION_HUB = LambdaSavingsEstimationModeSource.AddMember("COST_OPTIMIZATION_HUB", smithyprelude.Unit)

	LambdaSavingsEstimationMode_source = LambdaSavingsEstimationMode.AddMember("source", LambdaSavingsEstimationModeSource)

	LambdaEffectiveRecommendationPreferences_savingsEstimationMode = LambdaEffectiveRecommendationPreferences.AddMember("savingsEstimationMode", LambdaSavingsEstimationMode)

	LambdaEstimatedMonthlySavings_currency = LambdaEstimatedMonthlySavings.AddMember("currency", Currency)

	LambdaEstimatedMonthlySavings_value = LambdaEstimatedMonthlySavings.AddMember("value", _Value)

	LambdaFunctionMemoryMetricName_DURATION = LambdaFunctionMemoryMetricName.AddMember("DURATION", smithyprelude.Unit)

	LambdaFunctionMemoryMetricStatistic_LOWER_BOUND = LambdaFunctionMemoryMetricStatistic.AddMember("LOWER_BOUND", smithyprelude.Unit)

	LambdaFunctionMemoryMetricStatistic_UPPER_BOUND = LambdaFunctionMemoryMetricStatistic.AddMember("UPPER_BOUND", smithyprelude.Unit)

	LambdaFunctionMemoryMetricStatistic_EXPECTED = LambdaFunctionMemoryMetricStatistic.AddMember("EXPECTED", smithyprelude.Unit)

	LambdaFunctionMemoryProjectedMetric_name = LambdaFunctionMemoryProjectedMetric.AddMember("name", LambdaFunctionMemoryMetricName)

	LambdaFunctionMemoryProjectedMetric_statistic = LambdaFunctionMemoryProjectedMetric.AddMember("statistic", LambdaFunctionMemoryMetricStatistic)

	LambdaFunctionMemoryProjectedMetric_value = LambdaFunctionMemoryProjectedMetric.AddMember("value", _MetricValue)

	_LambdaFunctionMemoryProjectedMetrics_member = _LambdaFunctionMemoryProjectedMetrics.AddMember("member", LambdaFunctionMemoryProjectedMetric)

	LambdaSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage = LambdaSavingsOpportunityAfterDiscounts.AddMember("savingsOpportunityPercentage", _SavingsOpportunityPercentage)

	LambdaSavingsOpportunityAfterDiscounts_estimatedMonthlySavings = LambdaSavingsOpportunityAfterDiscounts.AddMember("estimatedMonthlySavings", LambdaEstimatedMonthlySavings)

	LambdaFunctionMemoryRecommendationOption_rank = LambdaFunctionMemoryRecommendationOption.AddMember("rank", _Rank)

	LambdaFunctionMemoryRecommendationOption_memorySize = LambdaFunctionMemoryRecommendationOption.AddMember("memorySize", _MemorySize)

	LambdaFunctionMemoryRecommendationOption_projectedUtilizationMetrics = LambdaFunctionMemoryRecommendationOption.AddMember("projectedUtilizationMetrics", _LambdaFunctionMemoryProjectedMetrics)

	LambdaFunctionMemoryRecommendationOption_savingsOpportunity = LambdaFunctionMemoryRecommendationOption.AddMember("savingsOpportunity", SavingsOpportunity)

	LambdaFunctionMemoryRecommendationOption_savingsOpportunityAfterDiscounts = LambdaFunctionMemoryRecommendationOption.AddMember("savingsOpportunityAfterDiscounts", LambdaSavingsOpportunityAfterDiscounts)

	_LambdaFunctionMemoryRecommendationOptions_member = _LambdaFunctionMemoryRecommendationOptions.AddMember("member", LambdaFunctionMemoryRecommendationOption)

	LambdaFunctionMetricName_DURATION = LambdaFunctionMetricName.AddMember("DURATION", smithyprelude.Unit)

	LambdaFunctionMetricName_MEMORY = LambdaFunctionMetricName.AddMember("MEMORY", smithyprelude.Unit)

	LambdaFunctionMetricStatistic_MAXIMUM = LambdaFunctionMetricStatistic.AddMember("MAXIMUM", smithyprelude.Unit)

	LambdaFunctionMetricStatistic_AVERAGE = LambdaFunctionMetricStatistic.AddMember("AVERAGE", smithyprelude.Unit)

	LambdaFunctionUtilizationMetric_name = LambdaFunctionUtilizationMetric.AddMember("name", LambdaFunctionMetricName)

	LambdaFunctionUtilizationMetric_statistic = LambdaFunctionUtilizationMetric.AddMember("statistic", LambdaFunctionMetricStatistic)

	LambdaFunctionUtilizationMetric_value = LambdaFunctionUtilizationMetric.AddMember("value", _MetricValue)

	_LambdaFunctionUtilizationMetrics_member = _LambdaFunctionUtilizationMetrics.AddMember("member", LambdaFunctionUtilizationMetric)

	LambdaFunctionRecommendationFinding_OPTIMIZED = LambdaFunctionRecommendationFinding.AddMember("OPTIMIZED", smithyprelude.Unit)

	LambdaFunctionRecommendationFinding_NOT_OPTIMIZED = LambdaFunctionRecommendationFinding.AddMember("NOT_OPTIMIZED", smithyprelude.Unit)

	LambdaFunctionRecommendationFinding_UNAVAILABLE = LambdaFunctionRecommendationFinding.AddMember("UNAVAILABLE", smithyprelude.Unit)

	LambdaFunctionRecommendationFindingReasonCode_MEMORY_OVER_PROVISIONED = LambdaFunctionRecommendationFindingReasonCode.AddMember("MEMORY_OVER_PROVISIONED", smithyprelude.Unit)

	LambdaFunctionRecommendationFindingReasonCode_MEMORY_UNDER_PROVISIONED = LambdaFunctionRecommendationFindingReasonCode.AddMember("MEMORY_UNDER_PROVISIONED", smithyprelude.Unit)

	LambdaFunctionRecommendationFindingReasonCode_INSUFFICIENT_DATA = LambdaFunctionRecommendationFindingReasonCode.AddMember("INSUFFICIENT_DATA", smithyprelude.Unit)

	LambdaFunctionRecommendationFindingReasonCode_INCONCLUSIVE = LambdaFunctionRecommendationFindingReasonCode.AddMember("INCONCLUSIVE", smithyprelude.Unit)

	_LambdaFunctionRecommendationFindingReasonCodes_member = _LambdaFunctionRecommendationFindingReasonCodes.AddMember("member", LambdaFunctionRecommendationFindingReasonCode)

	LambdaFunctionRecommendation_functionArn = LambdaFunctionRecommendation.AddMember("functionArn", _FunctionArn)

	LambdaFunctionRecommendation_functionVersion = LambdaFunctionRecommendation.AddMember("functionVersion", _FunctionVersion)

	LambdaFunctionRecommendation_accountId = LambdaFunctionRecommendation.AddMember("accountId", _AccountId)

	LambdaFunctionRecommendation_currentMemorySize = LambdaFunctionRecommendation.AddMember("currentMemorySize", _MemorySize)

	LambdaFunctionRecommendation_numberOfInvocations = LambdaFunctionRecommendation.AddMember("numberOfInvocations", _NumberOfInvocations)

	LambdaFunctionRecommendation_utilizationMetrics = LambdaFunctionRecommendation.AddMember("utilizationMetrics", _LambdaFunctionUtilizationMetrics)

	LambdaFunctionRecommendation_lookbackPeriodInDays = LambdaFunctionRecommendation.AddMember("lookbackPeriodInDays", _LookBackPeriodInDays)

	LambdaFunctionRecommendation_lastRefreshTimestamp = LambdaFunctionRecommendation.AddMember("lastRefreshTimestamp", _LastRefreshTimestamp)

	LambdaFunctionRecommendation_finding = LambdaFunctionRecommendation.AddMember("finding", LambdaFunctionRecommendationFinding)

	LambdaFunctionRecommendation_findingReasonCodes = LambdaFunctionRecommendation.AddMember("findingReasonCodes", _LambdaFunctionRecommendationFindingReasonCodes)

	LambdaFunctionRecommendation_memorySizeRecommendationOptions = LambdaFunctionRecommendation.AddMember("memorySizeRecommendationOptions", _LambdaFunctionMemoryRecommendationOptions)

	LambdaFunctionRecommendation_currentPerformanceRisk = LambdaFunctionRecommendation.AddMember("currentPerformanceRisk", CurrentPerformanceRisk)

	LambdaFunctionRecommendation_effectiveRecommendationPreferences = LambdaFunctionRecommendation.AddMember("effectiveRecommendationPreferences", LambdaEffectiveRecommendationPreferences)

	LambdaFunctionRecommendation_tags = LambdaFunctionRecommendation.AddMember("tags", _Tags)

	LambdaFunctionRecommendationFilterName_FINDING = LambdaFunctionRecommendationFilterName.AddMember("FINDING", smithyprelude.Unit)

	LambdaFunctionRecommendationFilterName_FINDING_REASON_CODE = LambdaFunctionRecommendationFilterName.AddMember("FINDING_REASON_CODE", smithyprelude.Unit)

	LambdaFunctionRecommendationFilter_name = LambdaFunctionRecommendationFilter.AddMember("name", LambdaFunctionRecommendationFilterName)

	LambdaFunctionRecommendationFilter_values = LambdaFunctionRecommendationFilter.AddMember("values", _FilterValues)

	_LambdaFunctionRecommendationFilters_member = _LambdaFunctionRecommendationFilters.AddMember("member", LambdaFunctionRecommendationFilter)

	_LambdaFunctionRecommendations_member = _LambdaFunctionRecommendations.AddMember("member", LambdaFunctionRecommendation)

	LicenseEdition_ENTERPRISE = LicenseEdition.AddMember("ENTERPRISE", smithyprelude.Unit)

	LicenseEdition_STANDARD = LicenseEdition.AddMember("STANDARD", smithyprelude.Unit)

	LicenseEdition_FREE = LicenseEdition.AddMember("FREE", smithyprelude.Unit)

	LicenseEdition_NO_LICENSE_EDITION_FOUND = LicenseEdition.AddMember("NO_LICENSE_EDITION_FOUND", smithyprelude.Unit)

	LicenseName_SQLSERVER = LicenseName.AddMember("SQLSERVER", smithyprelude.Unit)

	LicenseModel_LICENSE_INCLUDED = LicenseModel.AddMember("LICENSE_INCLUDED", smithyprelude.Unit)

	LicenseModel_BRING_YOUR_OWN_LICENSE = LicenseModel.AddMember("BRING_YOUR_OWN_LICENSE", smithyprelude.Unit)

	MetricSourceProvider_CloudWatchAppInsights = MetricSourceProvider.AddMember("CloudWatchAppInsights", smithyprelude.Unit)

	MetricSource_provider = MetricSource.AddMember("provider", MetricSourceProvider)

	MetricSource_providerArn = MetricSource.AddMember("providerArn", _MetricProviderArn)

	_MetricsSource_member = _MetricsSource.AddMember("member", MetricSource)

	LicenseConfiguration_numberOfCores = LicenseConfiguration.AddMember("numberOfCores", _NumberOfCores)

	LicenseConfiguration_instanceType = LicenseConfiguration.AddMember("instanceType", _InstanceType)

	LicenseConfiguration_operatingSystem = LicenseConfiguration.AddMember("operatingSystem", _OperatingSystem)

	LicenseConfiguration_licenseEdition = LicenseConfiguration.AddMember("licenseEdition", LicenseEdition)

	LicenseConfiguration_licenseName = LicenseConfiguration.AddMember("licenseName", LicenseName)

	LicenseConfiguration_licenseModel = LicenseConfiguration.AddMember("licenseModel", LicenseModel)

	LicenseConfiguration_licenseVersion = LicenseConfiguration.AddMember("licenseVersion", _LicenseVersion)

	LicenseConfiguration_metricsSource = LicenseConfiguration.AddMember("metricsSource", _MetricsSource)

	LicenseFinding_INSUFFICIENT_METRICS = LicenseFinding.AddMember("INSUFFICIENT_METRICS", smithyprelude.Unit)

	LicenseFinding_OPTIMIZED = LicenseFinding.AddMember("OPTIMIZED", smithyprelude.Unit)

	LicenseFinding_NOT_OPTIMIZED = LicenseFinding.AddMember("NOT_OPTIMIZED", smithyprelude.Unit)

	LicenseFindingReasonCode_CW_APP_INSIGHTS_DISABLED = LicenseFindingReasonCode.AddMember("CW_APP_INSIGHTS_DISABLED", smithyprelude.Unit)

	LicenseFindingReasonCode_CW_APP_INSIGHTS_ERROR = LicenseFindingReasonCode.AddMember("CW_APP_INSIGHTS_ERROR", smithyprelude.Unit)

	LicenseFindingReasonCode_LICENSE_OVER_PROVISIONED = LicenseFindingReasonCode.AddMember("LICENSE_OVER_PROVISIONED", smithyprelude.Unit)

	LicenseFindingReasonCode_OPTIMIZED = LicenseFindingReasonCode.AddMember("OPTIMIZED", smithyprelude.Unit)

	_LicenseFindingReasonCodes_member = _LicenseFindingReasonCodes.AddMember("member", LicenseFindingReasonCode)

	LicenseRecommendationOption_rank = LicenseRecommendationOption.AddMember("rank", _Rank)

	LicenseRecommendationOption_operatingSystem = LicenseRecommendationOption.AddMember("operatingSystem", _OperatingSystem)

	LicenseRecommendationOption_licenseEdition = LicenseRecommendationOption.AddMember("licenseEdition", LicenseEdition)

	LicenseRecommendationOption_licenseModel = LicenseRecommendationOption.AddMember("licenseModel", LicenseModel)

	LicenseRecommendationOption_savingsOpportunity = LicenseRecommendationOption.AddMember("savingsOpportunity", SavingsOpportunity)

	_LicenseRecommendationOptions_member = _LicenseRecommendationOptions.AddMember("member", LicenseRecommendationOption)

	LicenseRecommendation_resourceArn = LicenseRecommendation.AddMember("resourceArn", _ResourceArn)

	LicenseRecommendation_accountId = LicenseRecommendation.AddMember("accountId", _AccountId)

	LicenseRecommendation_currentLicenseConfiguration = LicenseRecommendation.AddMember("currentLicenseConfiguration", LicenseConfiguration)

	LicenseRecommendation_lookbackPeriodInDays = LicenseRecommendation.AddMember("lookbackPeriodInDays", _LookBackPeriodInDays)

	LicenseRecommendation_lastRefreshTimestamp = LicenseRecommendation.AddMember("lastRefreshTimestamp", _LastRefreshTimestamp)

	LicenseRecommendation_finding = LicenseRecommendation.AddMember("finding", LicenseFinding)

	LicenseRecommendation_findingReasonCodes = LicenseRecommendation.AddMember("findingReasonCodes", _LicenseFindingReasonCodes)

	LicenseRecommendation_licenseRecommendationOptions = LicenseRecommendation.AddMember("licenseRecommendationOptions", _LicenseRecommendationOptions)

	LicenseRecommendation_tags = LicenseRecommendation.AddMember("tags", _Tags)

	LicenseRecommendationFilterName_LICENSE_FINDING = LicenseRecommendationFilterName.AddMember("LICENSE_FINDING", smithyprelude.Unit)

	LicenseRecommendationFilterName_LICENSE_FINDING_REASON_CODE = LicenseRecommendationFilterName.AddMember("LICENSE_FINDING_REASON_CODE", smithyprelude.Unit)

	LicenseRecommendationFilterName_LICENSE_NAME = LicenseRecommendationFilterName.AddMember("LICENSE_NAME", smithyprelude.Unit)

	LicenseRecommendationFilter_name = LicenseRecommendationFilter.AddMember("name", LicenseRecommendationFilterName)

	LicenseRecommendationFilter_values = LicenseRecommendationFilter.AddMember("values", _FilterValues)

	_LicenseRecommendationFilters_member = _LicenseRecommendationFilters.AddMember("member", LicenseRecommendationFilter)

	_LicenseRecommendations_member = _LicenseRecommendations.AddMember("member", LicenseRecommendation)

	LimitExceededException_message = LimitExceededException.AddMember("message", _ErrorMessage)

	MissingAuthenticationToken_message = MissingAuthenticationToken.AddMember("message", _ErrorMessage)

	OptInRequiredException_message = OptInRequiredException.AddMember("message", _ErrorMessage)

	Order_ASC = Order.AddMember("ASC", smithyprelude.Unit)

	Order_DESC = Order.AddMember("DESC", smithyprelude.Unit)

	OrderBy_dimension = OrderBy.AddMember("dimension", Dimension)

	OrderBy_order = OrderBy.AddMember("order", Order)

	PreferredResource_name = PreferredResource.AddMember("name", PreferredResourceName)

	PreferredResource_includeList = PreferredResource.AddMember("includeList", _PreferredResourceValues)

	PreferredResource_excludeList = PreferredResource.AddMember("excludeList", _PreferredResourceValues)

	_PreferredResources_member = _PreferredResources.AddMember("member", PreferredResource)

	ProjectedMetric_name = ProjectedMetric.AddMember("name", MetricName)

	ProjectedMetric_timestamps = ProjectedMetric.AddMember("timestamps", _Timestamps)

	ProjectedMetric_values = ProjectedMetric.AddMember("values", _MetricValues)

	_ProjectedMetrics_member = _ProjectedMetrics.AddMember("member", ProjectedMetric)

	RDSCurrentInstancePerformanceRisk_VERY_LOW = RDSCurrentInstancePerformanceRisk.AddMember("VERY_LOW", smithyprelude.Unit)

	RDSCurrentInstancePerformanceRisk_LOW = RDSCurrentInstancePerformanceRisk.AddMember("LOW", smithyprelude.Unit)

	RDSCurrentInstancePerformanceRisk_MEDIUM = RDSCurrentInstancePerformanceRisk.AddMember("MEDIUM", smithyprelude.Unit)

	RDSCurrentInstancePerformanceRisk_HIGH = RDSCurrentInstancePerformanceRisk.AddMember("HIGH", smithyprelude.Unit)

	RDSDBMetricName_CPU = RDSDBMetricName.AddMember("CPU", smithyprelude.Unit)

	RDSDBMetricName_MEMORY = RDSDBMetricName.AddMember("MEMORY", smithyprelude.Unit)

	RDSDBMetricName_EBS_VOLUME_STORAGE_SPACE_UTILIZATION = RDSDBMetricName.AddMember("EBS_VOLUME_STORAGE_SPACE_UTILIZATION", smithyprelude.Unit)

	RDSDBMetricName_NETWORK_RECEIVE_THROUGHPUT = RDSDBMetricName.AddMember("NETWORK_RECEIVE_THROUGHPUT", smithyprelude.Unit)

	RDSDBMetricName_NETWORK_TRANSMIT_THROUGHPUT = RDSDBMetricName.AddMember("NETWORK_TRANSMIT_THROUGHPUT", smithyprelude.Unit)

	RDSDBMetricName_EBS_VOLUME_READ_IOPS = RDSDBMetricName.AddMember("EBS_VOLUME_READ_IOPS", smithyprelude.Unit)

	RDSDBMetricName_EBS_VOLUME_WRITE_IOPS = RDSDBMetricName.AddMember("EBS_VOLUME_WRITE_IOPS", smithyprelude.Unit)

	RDSDBMetricName_EBS_VOLUME_READ_THROUGHPUT = RDSDBMetricName.AddMember("EBS_VOLUME_READ_THROUGHPUT", smithyprelude.Unit)

	RDSDBMetricName_EBS_VOLUME_WRITE_THROUGHPUT = RDSDBMetricName.AddMember("EBS_VOLUME_WRITE_THROUGHPUT", smithyprelude.Unit)

	RDSDBMetricName_DATABASE_CONNECTIONS = RDSDBMetricName.AddMember("DATABASE_CONNECTIONS", smithyprelude.Unit)

	RDSDBMetricName_STORAGE_NETWORK_RECEIVE_THROUGHPUT = RDSDBMetricName.AddMember("STORAGE_NETWORK_RECEIVE_THROUGHPUT", smithyprelude.Unit)

	RDSDBMetricName_STORAGE_NETWORK_TRANSMIT_THROUGHPUT = RDSDBMetricName.AddMember("STORAGE_NETWORK_TRANSMIT_THROUGHPUT", smithyprelude.Unit)

	RDSDBMetricName_AURORA_MEMORY_HEALTH_STATE = RDSDBMetricName.AddMember("AURORA_MEMORY_HEALTH_STATE", smithyprelude.Unit)

	RDSDBMetricName_AURORA_MEMORY_NUM_DECLINED_SQL = RDSDBMetricName.AddMember("AURORA_MEMORY_NUM_DECLINED_SQL", smithyprelude.Unit)

	RDSDBMetricName_AURORA_MEMORY_NUM_KILL_CONN_TOTAL = RDSDBMetricName.AddMember("AURORA_MEMORY_NUM_KILL_CONN_TOTAL", smithyprelude.Unit)

	RDSDBMetricName_AURORA_MEMORY_NUM_KILL_QUERY_TOTAL = RDSDBMetricName.AddMember("AURORA_MEMORY_NUM_KILL_QUERY_TOTAL", smithyprelude.Unit)

	RDSDBMetricName_READ_IOPS_EPHEMERAL_STORAGE = RDSDBMetricName.AddMember("READ_IOPS_EPHEMERAL_STORAGE", smithyprelude.Unit)

	RDSDBMetricName_WRITE_IOPS_EPHEMERAL_STORAGE = RDSDBMetricName.AddMember("WRITE_IOPS_EPHEMERAL_STORAGE", smithyprelude.Unit)

	RDSDBMetricName_VOLUME_READ_IOPS = RDSDBMetricName.AddMember("VOLUME_READ_IOPS", smithyprelude.Unit)

	RDSDBMetricName_VOLUME_BYTES_USED = RDSDBMetricName.AddMember("VOLUME_BYTES_USED", smithyprelude.Unit)

	RDSDBMetricName_VOLUME_WRITE_IOPS = RDSDBMetricName.AddMember("VOLUME_WRITE_IOPS", smithyprelude.Unit)

	RDSDatabaseProjectedMetric_name = RDSDatabaseProjectedMetric.AddMember("name", RDSDBMetricName)

	RDSDatabaseProjectedMetric_timestamps = RDSDatabaseProjectedMetric.AddMember("timestamps", _Timestamps)

	RDSDatabaseProjectedMetric_values = RDSDatabaseProjectedMetric.AddMember("values", _MetricValues)

	_RDSDatabaseProjectedMetrics_member = _RDSDatabaseProjectedMetrics.AddMember("member", RDSDatabaseProjectedMetric)

	RDSDatabaseRecommendedOptionProjectedMetric_recommendedDBInstanceClass = RDSDatabaseRecommendedOptionProjectedMetric.AddMember("recommendedDBInstanceClass", _RecommendedDBInstanceClass)

	RDSDatabaseRecommendedOptionProjectedMetric_rank = RDSDatabaseRecommendedOptionProjectedMetric.AddMember("rank", _Rank)

	RDSDatabaseRecommendedOptionProjectedMetric_projectedMetrics = RDSDatabaseRecommendedOptionProjectedMetric.AddMember("projectedMetrics", _RDSDatabaseProjectedMetrics)

	_RDSDatabaseRecommendedOptionProjectedMetrics_member = _RDSDatabaseRecommendedOptionProjectedMetrics.AddMember("member", RDSDatabaseRecommendedOptionProjectedMetric)

	RDSDBMetricStatistic_MAXIMUM = RDSDBMetricStatistic.AddMember("MAXIMUM", smithyprelude.Unit)

	RDSDBMetricStatistic_MINIMUM = RDSDBMetricStatistic.AddMember("MINIMUM", smithyprelude.Unit)

	RDSDBMetricStatistic_AVERAGE = RDSDBMetricStatistic.AddMember("AVERAGE", smithyprelude.Unit)

	RDSDBUtilizationMetric_name = RDSDBUtilizationMetric.AddMember("name", RDSDBMetricName)

	RDSDBUtilizationMetric_statistic = RDSDBUtilizationMetric.AddMember("statistic", RDSDBMetricStatistic)

	RDSDBUtilizationMetric_value = RDSDBUtilizationMetric.AddMember("value", _MetricValue)

	_RDSDBProjectedUtilizationMetrics_member = _RDSDBProjectedUtilizationMetrics.AddMember("member", RDSDBUtilizationMetric)

	RDSInstanceEstimatedMonthlySavings_currency = RDSInstanceEstimatedMonthlySavings.AddMember("currency", Currency)

	RDSInstanceEstimatedMonthlySavings_value = RDSInstanceEstimatedMonthlySavings.AddMember("value", _Value)

	RDSInstanceSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage = RDSInstanceSavingsOpportunityAfterDiscounts.AddMember("savingsOpportunityPercentage", _SavingsOpportunityPercentage)

	RDSInstanceSavingsOpportunityAfterDiscounts_estimatedMonthlySavings = RDSInstanceSavingsOpportunityAfterDiscounts.AddMember("estimatedMonthlySavings", RDSInstanceEstimatedMonthlySavings)

	RDSDBInstanceRecommendationOption_dbInstanceClass = RDSDBInstanceRecommendationOption.AddMember("dbInstanceClass", _DBInstanceClass)

	RDSDBInstanceRecommendationOption_projectedUtilizationMetrics = RDSDBInstanceRecommendationOption.AddMember("projectedUtilizationMetrics", _RDSDBProjectedUtilizationMetrics)

	RDSDBInstanceRecommendationOption_performanceRisk = RDSDBInstanceRecommendationOption.AddMember("performanceRisk", _PerformanceRisk)

	RDSDBInstanceRecommendationOption_rank = RDSDBInstanceRecommendationOption.AddMember("rank", _Rank)

	RDSDBInstanceRecommendationOption_savingsOpportunity = RDSDBInstanceRecommendationOption.AddMember("savingsOpportunity", SavingsOpportunity)

	RDSDBInstanceRecommendationOption_savingsOpportunityAfterDiscounts = RDSDBInstanceRecommendationOption.AddMember("savingsOpportunityAfterDiscounts", RDSInstanceSavingsOpportunityAfterDiscounts)

	_RDSDBInstanceRecommendationOptions_member = _RDSDBInstanceRecommendationOptions.AddMember("member", RDSDBInstanceRecommendationOption)

	RDSInstanceFinding_OPTIMIZED = RDSInstanceFinding.AddMember("OPTIMIZED", smithyprelude.Unit)

	RDSInstanceFinding_UNDER_PROVISIONED = RDSInstanceFinding.AddMember("UNDER_PROVISIONED", smithyprelude.Unit)

	RDSInstanceFinding_OVER_PROVISIONED = RDSInstanceFinding.AddMember("OVER_PROVISIONED", smithyprelude.Unit)

	RDSStorageFinding_OPTIMIZED = RDSStorageFinding.AddMember("OPTIMIZED", smithyprelude.Unit)

	RDSStorageFinding_UNDER_PROVISIONED = RDSStorageFinding.AddMember("UNDER_PROVISIONED", smithyprelude.Unit)

	RDSStorageFinding_OVER_PROVISIONED = RDSStorageFinding.AddMember("OVER_PROVISIONED", smithyprelude.Unit)

	RDSStorageFinding_NOT_OPTIMIZED = RDSStorageFinding.AddMember("NOT_OPTIMIZED", smithyprelude.Unit)

	RDSInstanceFindingReasonCode_CPU_OVER_PROVISIONED = RDSInstanceFindingReasonCode.AddMember("CPU_OVER_PROVISIONED", smithyprelude.Unit)

	RDSInstanceFindingReasonCode_NETWORK_BANDWIDTH_OVER_PROVISIONED = RDSInstanceFindingReasonCode.AddMember("NETWORK_BANDWIDTH_OVER_PROVISIONED", smithyprelude.Unit)

	RDSInstanceFindingReasonCode_EBS_IOPS_OVER_PROVISIONED = RDSInstanceFindingReasonCode.AddMember("EBS_IOPS_OVER_PROVISIONED", smithyprelude.Unit)

	RDSInstanceFindingReasonCode_EBS_IOPS_UNDER_PROVISIONED = RDSInstanceFindingReasonCode.AddMember("EBS_IOPS_UNDER_PROVISIONED", smithyprelude.Unit)

	RDSInstanceFindingReasonCode_EBS_THROUGHPUT_OVER_PROVISIONED = RDSInstanceFindingReasonCode.AddMember("EBS_THROUGHPUT_OVER_PROVISIONED", smithyprelude.Unit)

	RDSInstanceFindingReasonCode_CPU_UNDER_PROVISIONED = RDSInstanceFindingReasonCode.AddMember("CPU_UNDER_PROVISIONED", smithyprelude.Unit)

	RDSInstanceFindingReasonCode_NETWORK_BANDWIDTH_UNDER_PROVISIONED = RDSInstanceFindingReasonCode.AddMember("NETWORK_BANDWIDTH_UNDER_PROVISIONED", smithyprelude.Unit)

	RDSInstanceFindingReasonCode_EBS_THROUGHPUT_UNDER_PROVISIONED = RDSInstanceFindingReasonCode.AddMember("EBS_THROUGHPUT_UNDER_PROVISIONED", smithyprelude.Unit)

	RDSInstanceFindingReasonCode_NEW_GENERATION_DB_INSTANCE_CLASS_AVAILABLE = RDSInstanceFindingReasonCode.AddMember("NEW_GENERATION_DB_INSTANCE_CLASS_AVAILABLE", smithyprelude.Unit)

	RDSInstanceFindingReasonCode_NEW_ENGINE_VERSION_AVAILABLE = RDSInstanceFindingReasonCode.AddMember("NEW_ENGINE_VERSION_AVAILABLE", smithyprelude.Unit)

	RDSInstanceFindingReasonCode_DB_CLUSTER_WRITER_UNDER_PROVISIONED = RDSInstanceFindingReasonCode.AddMember("DB_CLUSTER_WRITER_UNDER_PROVISIONED", smithyprelude.Unit)

	RDSInstanceFindingReasonCode_MEMORY_UNDER_PROVISIONED = RDSInstanceFindingReasonCode.AddMember("MEMORY_UNDER_PROVISIONED", smithyprelude.Unit)

	RDSInstanceFindingReasonCode_INSTANCE_STORAGE_READ_IOPS_UNDER_PROVISIONED = RDSInstanceFindingReasonCode.AddMember("INSTANCE_STORAGE_READ_IOPS_UNDER_PROVISIONED", smithyprelude.Unit)

	RDSInstanceFindingReasonCode_INSTANCE_STORAGE_WRITE_IOPS_UNDER_PROVISIONED = RDSInstanceFindingReasonCode.AddMember("INSTANCE_STORAGE_WRITE_IOPS_UNDER_PROVISIONED", smithyprelude.Unit)

	_RDSInstanceFindingReasonCodes_member = _RDSInstanceFindingReasonCodes.AddMember("member", RDSInstanceFindingReasonCode)

	RDSEstimatedMonthlyVolumeIOPsCostVariation_NONE = RDSEstimatedMonthlyVolumeIOPsCostVariation.AddMember("NONE", smithyprelude.Unit)

	RDSEstimatedMonthlyVolumeIOPsCostVariation_LOW = RDSEstimatedMonthlyVolumeIOPsCostVariation.AddMember("LOW", smithyprelude.Unit)

	RDSEstimatedMonthlyVolumeIOPsCostVariation_MEDIUM = RDSEstimatedMonthlyVolumeIOPsCostVariation.AddMember("MEDIUM", smithyprelude.Unit)

	RDSEstimatedMonthlyVolumeIOPsCostVariation_HIGH = RDSEstimatedMonthlyVolumeIOPsCostVariation.AddMember("HIGH", smithyprelude.Unit)

	RDSStorageFindingReasonCode_EBS_VOLUME_ALLOCATED_STORAGE_UNDER_PROVISIONED = RDSStorageFindingReasonCode.AddMember("EBS_VOLUME_ALLOCATED_STORAGE_UNDER_PROVISIONED", smithyprelude.Unit)

	RDSStorageFindingReasonCode_EBS_VOLUME_THROUGHPUT_UNDER_PROVISIONED = RDSStorageFindingReasonCode.AddMember("EBS_VOLUME_THROUGHPUT_UNDER_PROVISIONED", smithyprelude.Unit)

	RDSStorageFindingReasonCode_EBS_VOLUME_IOPS_OVER_PROVISIONED = RDSStorageFindingReasonCode.AddMember("EBS_VOLUME_IOPS_OVER_PROVISIONED", smithyprelude.Unit)

	RDSStorageFindingReasonCode_EBS_VOLUME_THROUGHPUT_OVER_PROVISIONED = RDSStorageFindingReasonCode.AddMember("EBS_VOLUME_THROUGHPUT_OVER_PROVISIONED", smithyprelude.Unit)

	RDSStorageFindingReasonCode_NEW_GENERATION_STORAGE_TYPE_AVAILABLE = RDSStorageFindingReasonCode.AddMember("NEW_GENERATION_STORAGE_TYPE_AVAILABLE", smithyprelude.Unit)

	RDSStorageFindingReasonCode_DB_CLUSTER_STORAGE_OPTION_AVAILABLE = RDSStorageFindingReasonCode.AddMember("DB_CLUSTER_STORAGE_OPTION_AVAILABLE", smithyprelude.Unit)

	RDSStorageFindingReasonCode_DB_CLUSTER_STORAGE_SAVINGS_AVAILABLE = RDSStorageFindingReasonCode.AddMember("DB_CLUSTER_STORAGE_SAVINGS_AVAILABLE", smithyprelude.Unit)

	_RDSStorageFindingReasonCodes_member = _RDSStorageFindingReasonCodes.AddMember("member", RDSStorageFindingReasonCode)

	RDSStorageEstimatedMonthlySavings_currency = RDSStorageEstimatedMonthlySavings.AddMember("currency", Currency)

	RDSStorageEstimatedMonthlySavings_value = RDSStorageEstimatedMonthlySavings.AddMember("value", _Value)

	RDSStorageSavingsOpportunityAfterDiscounts_savingsOpportunityPercentage = RDSStorageSavingsOpportunityAfterDiscounts.AddMember("savingsOpportunityPercentage", _SavingsOpportunityPercentage)

	RDSStorageSavingsOpportunityAfterDiscounts_estimatedMonthlySavings = RDSStorageSavingsOpportunityAfterDiscounts.AddMember("estimatedMonthlySavings", RDSStorageEstimatedMonthlySavings)

	RDSDBStorageRecommendationOption_storageConfiguration = RDSDBStorageRecommendationOption.AddMember("storageConfiguration", DBStorageConfiguration)

	RDSDBStorageRecommendationOption_rank = RDSDBStorageRecommendationOption.AddMember("rank", _Rank)

	RDSDBStorageRecommendationOption_savingsOpportunity = RDSDBStorageRecommendationOption.AddMember("savingsOpportunity", SavingsOpportunity)

	RDSDBStorageRecommendationOption_savingsOpportunityAfterDiscounts = RDSDBStorageRecommendationOption.AddMember("savingsOpportunityAfterDiscounts", RDSStorageSavingsOpportunityAfterDiscounts)

	RDSDBStorageRecommendationOption_estimatedMonthlyVolumeIOPsCostVariation = RDSDBStorageRecommendationOption.AddMember("estimatedMonthlyVolumeIOPsCostVariation", RDSEstimatedMonthlyVolumeIOPsCostVariation)

	_RDSDBStorageRecommendationOptions_member = _RDSDBStorageRecommendationOptions.AddMember("member", RDSDBStorageRecommendationOption)

	_RDSDBUtilizationMetrics_member = _RDSDBUtilizationMetrics.AddMember("member", RDSDBUtilizationMetric)

	RDSSavingsEstimationModeSource_PUBLIC_PRICING = RDSSavingsEstimationModeSource.AddMember("PUBLIC_PRICING", smithyprelude.Unit)

	RDSSavingsEstimationModeSource_COST_EXPLORER_RIGHTSIZING = RDSSavingsEstimationModeSource.AddMember("COST_EXPLORER_RIGHTSIZING", smithyprelude.Unit)

	RDSSavingsEstimationModeSource_COST_OPTIMIZATION_HUB = RDSSavingsEstimationModeSource.AddMember("COST_OPTIMIZATION_HUB", smithyprelude.Unit)

	RDSSavingsEstimationMode_source = RDSSavingsEstimationMode.AddMember("source", RDSSavingsEstimationModeSource)

	RDSEffectiveRecommendationPreferences_cpuVendorArchitectures = RDSEffectiveRecommendationPreferences.AddMember("cpuVendorArchitectures", _CpuVendorArchitectures)

	RDSEffectiveRecommendationPreferences_enhancedInfrastructureMetrics = RDSEffectiveRecommendationPreferences.AddMember("enhancedInfrastructureMetrics", EnhancedInfrastructureMetrics)

	RDSEffectiveRecommendationPreferences_lookBackPeriod = RDSEffectiveRecommendationPreferences.AddMember("lookBackPeriod", LookBackPeriodPreference)

	RDSEffectiveRecommendationPreferences_savingsEstimationMode = RDSEffectiveRecommendationPreferences.AddMember("savingsEstimationMode", RDSSavingsEstimationMode)

	RDSDBRecommendation_resourceArn = RDSDBRecommendation.AddMember("resourceArn", _ResourceArn)

	RDSDBRecommendation_accountId = RDSDBRecommendation.AddMember("accountId", _AccountId)

	RDSDBRecommendation_engine = RDSDBRecommendation.AddMember("engine", _Engine)

	RDSDBRecommendation_engineVersion = RDSDBRecommendation.AddMember("engineVersion", _EngineVersion)

	RDSDBRecommendation_promotionTier = RDSDBRecommendation.AddMember("promotionTier", _PromotionTier)

	RDSDBRecommendation_currentDBInstanceClass = RDSDBRecommendation.AddMember("currentDBInstanceClass", _CurrentDBInstanceClass)

	RDSDBRecommendation_currentStorageConfiguration = RDSDBRecommendation.AddMember("currentStorageConfiguration", DBStorageConfiguration)

	RDSDBRecommendation_dbClusterIdentifier = RDSDBRecommendation.AddMember("dbClusterIdentifier", _DBClusterIdentifier)

	RDSDBRecommendation_idle = RDSDBRecommendation.AddMember("idle", Idle)

	RDSDBRecommendation_instanceFinding = RDSDBRecommendation.AddMember("instanceFinding", RDSInstanceFinding)

	RDSDBRecommendation_storageFinding = RDSDBRecommendation.AddMember("storageFinding", RDSStorageFinding)

	RDSDBRecommendation_instanceFindingReasonCodes = RDSDBRecommendation.AddMember("instanceFindingReasonCodes", _RDSInstanceFindingReasonCodes)

	RDSDBRecommendation_currentInstancePerformanceRisk = RDSDBRecommendation.AddMember("currentInstancePerformanceRisk", RDSCurrentInstancePerformanceRisk)

	RDSDBRecommendation_currentStorageEstimatedMonthlyVolumeIOPsCostVariation = RDSDBRecommendation.AddMember("currentStorageEstimatedMonthlyVolumeIOPsCostVariation", RDSEstimatedMonthlyVolumeIOPsCostVariation)

	RDSDBRecommendation_storageFindingReasonCodes = RDSDBRecommendation.AddMember("storageFindingReasonCodes", _RDSStorageFindingReasonCodes)

	RDSDBRecommendation_instanceRecommendationOptions = RDSDBRecommendation.AddMember("instanceRecommendationOptions", _RDSDBInstanceRecommendationOptions)

	RDSDBRecommendation_storageRecommendationOptions = RDSDBRecommendation.AddMember("storageRecommendationOptions", _RDSDBStorageRecommendationOptions)

	RDSDBRecommendation_utilizationMetrics = RDSDBRecommendation.AddMember("utilizationMetrics", _RDSDBUtilizationMetrics)

	RDSDBRecommendation_effectiveRecommendationPreferences = RDSDBRecommendation.AddMember("effectiveRecommendationPreferences", RDSEffectiveRecommendationPreferences)

	RDSDBRecommendation_lookbackPeriodInDays = RDSDBRecommendation.AddMember("lookbackPeriodInDays", _LookBackPeriodInDays)

	RDSDBRecommendation_lastRefreshTimestamp = RDSDBRecommendation.AddMember("lastRefreshTimestamp", _LastRefreshTimestamp)

	RDSDBRecommendation_tags = RDSDBRecommendation.AddMember("tags", _Tags)

	RDSDBRecommendationFilterName_INSTANCE_FINDING = RDSDBRecommendationFilterName.AddMember("INSTANCE_FINDING", smithyprelude.Unit)

	RDSDBRecommendationFilterName_INSTANCE_FINDING_REASON_CODE = RDSDBRecommendationFilterName.AddMember("INSTANCE_FINDING_REASON_CODE", smithyprelude.Unit)

	RDSDBRecommendationFilterName_STORAGE_FINDING = RDSDBRecommendationFilterName.AddMember("STORAGE_FINDING", smithyprelude.Unit)

	RDSDBRecommendationFilterName_STORAGE_FINDING_REASON_CODE = RDSDBRecommendationFilterName.AddMember("STORAGE_FINDING_REASON_CODE", smithyprelude.Unit)

	RDSDBRecommendationFilterName_IDLE = RDSDBRecommendationFilterName.AddMember("IDLE", smithyprelude.Unit)

	RDSDBRecommendationFilter_name = RDSDBRecommendationFilter.AddMember("name", RDSDBRecommendationFilterName)

	RDSDBRecommendationFilter_values = RDSDBRecommendationFilter.AddMember("values", _FilterValues)

	_RDSDBRecommendationFilters_member = _RDSDBRecommendationFilters.AddMember("member", RDSDBRecommendationFilter)

	_RDSDBRecommendations_member = _RDSDBRecommendations.AddMember("member", RDSDBRecommendation)

	ReasonCodeSummary_name = ReasonCodeSummary.AddMember("name", FindingReasonCode)

	ReasonCodeSummary_value = ReasonCodeSummary.AddMember("value", _SummaryValue)

	_ReasonCodeSummaries_member = _ReasonCodeSummaries.AddMember("member", ReasonCodeSummary)

	ResourceType_EC2_INSTANCE = ResourceType.AddMember("EC2_INSTANCE", smithyprelude.Unit)

	ResourceType_AUTO_SCALING_GROUP = ResourceType.AddMember("AUTO_SCALING_GROUP", smithyprelude.Unit)

	ResourceType_EBS_VOLUME = ResourceType.AddMember("EBS_VOLUME", smithyprelude.Unit)

	ResourceType_LAMBDA_FUNCTION = ResourceType.AddMember("LAMBDA_FUNCTION", smithyprelude.Unit)

	ResourceType_NOT_APPLICABLE = ResourceType.AddMember("NOT_APPLICABLE", smithyprelude.Unit)

	ResourceType_ECS_SERVICE = ResourceType.AddMember("ECS_SERVICE", smithyprelude.Unit)

	ResourceType_LICENSE = ResourceType.AddMember("LICENSE", smithyprelude.Unit)

	ResourceType_RDS_DB_INSTANCE = ResourceType.AddMember("RDS_DB_INSTANCE", smithyprelude.Unit)

	ResourceType_AURORA_DB_CLUSTER_STORAGE = ResourceType.AddMember("AURORA_DB_CLUSTER_STORAGE", smithyprelude.Unit)

	ResourceType_IDLE = ResourceType.AddMember("IDLE", smithyprelude.Unit)

	RecommendationExportJob_jobId = RecommendationExportJob.AddMember("jobId", _JobId)

	RecommendationExportJob_destination = RecommendationExportJob.AddMember("destination", ExportDestination)

	RecommendationExportJob_resourceType = RecommendationExportJob.AddMember("resourceType", ResourceType)

	RecommendationExportJob_status = RecommendationExportJob.AddMember("status", JobStatus)

	RecommendationExportJob_creationTimestamp = RecommendationExportJob.AddMember("creationTimestamp", _CreationTimestamp)

	RecommendationExportJob_lastUpdatedTimestamp = RecommendationExportJob.AddMember("lastUpdatedTimestamp", _LastUpdatedTimestamp)

	RecommendationExportJob_failureReason = RecommendationExportJob.AddMember("failureReason", _FailureReason)

	_RecommendationExportJobs_member = _RecommendationExportJobs.AddMember("member", RecommendationExportJob)

	RecommendationPreferenceName_ENHANCED_INFRASTRUCTURE_METRICS = RecommendationPreferenceName.AddMember("ENHANCED_INFRASTRUCTURE_METRICS", smithyprelude.Unit)

	RecommendationPreferenceName_INFERRED_WORKLOAD_TYPES = RecommendationPreferenceName.AddMember("INFERRED_WORKLOAD_TYPES", smithyprelude.Unit)

	RecommendationPreferenceName_EXTERNAL_METRICS_PREFERENCE = RecommendationPreferenceName.AddMember("EXTERNAL_METRICS_PREFERENCE", smithyprelude.Unit)

	RecommendationPreferenceName_LOOKBACK_PERIOD_PREFERENCE = RecommendationPreferenceName.AddMember("LOOKBACK_PERIOD_PREFERENCE", smithyprelude.Unit)

	RecommendationPreferenceName_PREFERRED_RESOURCES = RecommendationPreferenceName.AddMember("PREFERRED_RESOURCES", smithyprelude.Unit)

	RecommendationPreferenceName_UTILIZATION_PREFERENCES = RecommendationPreferenceName.AddMember("UTILIZATION_PREFERENCES", smithyprelude.Unit)

	_RecommendationPreferenceNames_member = _RecommendationPreferenceNames.AddMember("member", RecommendationPreferenceName)

	RecommendationPreferences_cpuVendorArchitectures = RecommendationPreferences.AddMember("cpuVendorArchitectures", _CpuVendorArchitectures)

	ScopeName_ORGANIZATION = ScopeName.AddMember("ORGANIZATION", smithyprelude.Unit)

	ScopeName_ACCOUNT_ID = ScopeName.AddMember("ACCOUNT_ID", smithyprelude.Unit)

	ScopeName_RESOURCE_ARN = ScopeName.AddMember("RESOURCE_ARN", smithyprelude.Unit)

	Scope_name = Scope.AddMember("name", ScopeName)

	Scope_value = Scope.AddMember("value", _ScopeValue)

	SavingsEstimationMode_AFTER_DISCOUNTS = SavingsEstimationMode.AddMember("AFTER_DISCOUNTS", smithyprelude.Unit)

	SavingsEstimationMode_BEFORE_DISCOUNTS = SavingsEstimationMode.AddMember("BEFORE_DISCOUNTS", smithyprelude.Unit)

	RecommendationPreferencesDetail_scope = RecommendationPreferencesDetail.AddMember("scope", Scope)

	RecommendationPreferencesDetail_resourceType = RecommendationPreferencesDetail.AddMember("resourceType", ResourceType)

	RecommendationPreferencesDetail_enhancedInfrastructureMetrics = RecommendationPreferencesDetail.AddMember("enhancedInfrastructureMetrics", EnhancedInfrastructureMetrics)

	RecommendationPreferencesDetail_inferredWorkloadTypes = RecommendationPreferencesDetail.AddMember("inferredWorkloadTypes", InferredWorkloadTypesPreference)

	RecommendationPreferencesDetail_externalMetricsPreference = RecommendationPreferencesDetail.AddMember("externalMetricsPreference", ExternalMetricsPreference)

	RecommendationPreferencesDetail_lookBackPeriod = RecommendationPreferencesDetail.AddMember("lookBackPeriod", LookBackPeriodPreference)

	RecommendationPreferencesDetail_utilizationPreferences = RecommendationPreferencesDetail.AddMember("utilizationPreferences", _UtilizationPreferences)

	RecommendationPreferencesDetail_preferredResources = RecommendationPreferencesDetail.AddMember("preferredResources", _EffectivePreferredResources)

	RecommendationPreferencesDetail_savingsEstimationMode = RecommendationPreferencesDetail.AddMember("savingsEstimationMode", SavingsEstimationMode)

	_RecommendationPreferencesDetails_member = _RecommendationPreferencesDetails.AddMember("member", RecommendationPreferencesDetail)

	Summary_name = Summary.AddMember("name", Finding)

	Summary_value = Summary.AddMember("value", _SummaryValue)

	Summary_reasonCodeSummaries = Summary.AddMember("reasonCodeSummaries", _ReasonCodeSummaries)

	_Summaries_member = _Summaries.AddMember("member", Summary)

	RecommendationSummary_summaries = RecommendationSummary.AddMember("summaries", _Summaries)

	RecommendationSummary_idleSummaries = RecommendationSummary.AddMember("idleSummaries", _IdleSummaries)

	RecommendationSummary_recommendationResourceType = RecommendationSummary.AddMember("recommendationResourceType", RecommendationSourceType)

	RecommendationSummary_accountId = RecommendationSummary.AddMember("accountId", _AccountId)

	RecommendationSummary_savingsOpportunity = RecommendationSummary.AddMember("savingsOpportunity", SavingsOpportunity)

	RecommendationSummary_idleSavingsOpportunity = RecommendationSummary.AddMember("idleSavingsOpportunity", SavingsOpportunity)

	RecommendationSummary_aggregatedSavingsOpportunity = RecommendationSummary.AddMember("aggregatedSavingsOpportunity", SavingsOpportunity)

	RecommendationSummary_currentPerformanceRiskRatings = RecommendationSummary.AddMember("currentPerformanceRiskRatings", CurrentPerformanceRiskRatings)

	RecommendationSummary_inferredWorkloadSavings = RecommendationSummary.AddMember("inferredWorkloadSavings", _InferredWorkloadSavings)

	_RecommendationSummaries_member = _RecommendationSummaries.AddMember("member", RecommendationSummary)

	RecommendedOptionProjectedMetric_recommendedInstanceType = RecommendedOptionProjectedMetric.AddMember("recommendedInstanceType", _RecommendedInstanceType)

	RecommendedOptionProjectedMetric_rank = RecommendedOptionProjectedMetric.AddMember("rank", _Rank)

	RecommendedOptionProjectedMetric_projectedMetrics = RecommendedOptionProjectedMetric.AddMember("projectedMetrics", _ProjectedMetrics)

	_RecommendedOptionProjectedMetrics_member = _RecommendedOptionProjectedMetrics.AddMember("member", RecommendedOptionProjectedMetric)

	_ResourceArns_member = _ResourceArns.AddMember("member", _ResourceArn)

	ResourceNotFoundException_message = ResourceNotFoundException.AddMember("message", _ErrorMessage)

	S3DestinationConfig_bucket = S3DestinationConfig.AddMember("bucket", _DestinationBucket)

	S3DestinationConfig_keyPrefix = S3DestinationConfig.AddMember("keyPrefix", _DestinationKeyPrefix)

	_ServiceArns_member = _ServiceArns.AddMember("member", _ServiceArn)

	ServiceUnavailableException_message = ServiceUnavailableException.AddMember("message", _ErrorMessage)

	ThrottlingException_message = ThrottlingException.AddMember("message", _ErrorMessage)

	_VolumeArns_member = _VolumeArns.AddMember("member", _VolumeArn)

	VolumeConfiguration_volumeType = VolumeConfiguration.AddMember("volumeType", _VolumeType)

	VolumeConfiguration_volumeSize = VolumeConfiguration.AddMember("volumeSize", _VolumeSize)

	VolumeConfiguration_volumeBaselineIOPS = VolumeConfiguration.AddMember("volumeBaselineIOPS", _VolumeBaselineIOPS)

	VolumeConfiguration_volumeBurstIOPS = VolumeConfiguration.AddMember("volumeBurstIOPS", _VolumeBurstIOPS)

	VolumeConfiguration_volumeBaselineThroughput = VolumeConfiguration.AddMember("volumeBaselineThroughput", _VolumeBaselineThroughput)

	VolumeConfiguration_volumeBurstThroughput = VolumeConfiguration.AddMember("volumeBurstThroughput", _VolumeBurstThroughput)

	VolumeConfiguration_rootVolume = VolumeConfiguration.AddMember("rootVolume", _RootVolume)

	VolumeRecommendationOption_configuration = VolumeRecommendationOption.AddMember("configuration", VolumeConfiguration)

	VolumeRecommendationOption_performanceRisk = VolumeRecommendationOption.AddMember("performanceRisk", _PerformanceRisk)

	VolumeRecommendationOption_rank = VolumeRecommendationOption.AddMember("rank", _Rank)

	VolumeRecommendationOption_savingsOpportunity = VolumeRecommendationOption.AddMember("savingsOpportunity", SavingsOpportunity)

	VolumeRecommendationOption_savingsOpportunityAfterDiscounts = VolumeRecommendationOption.AddMember("savingsOpportunityAfterDiscounts", EBSSavingsOpportunityAfterDiscounts)

	_VolumeRecommendationOptions_member = _VolumeRecommendationOptions.AddMember("member", VolumeRecommendationOption)

	VolumeRecommendation_volumeArn = VolumeRecommendation.AddMember("volumeArn", _VolumeArn)

	VolumeRecommendation_accountId = VolumeRecommendation.AddMember("accountId", _AccountId)

	VolumeRecommendation_currentConfiguration = VolumeRecommendation.AddMember("currentConfiguration", VolumeConfiguration)

	VolumeRecommendation_finding = VolumeRecommendation.AddMember("finding", EBSFinding)

	VolumeRecommendation_utilizationMetrics = VolumeRecommendation.AddMember("utilizationMetrics", _EBSUtilizationMetrics)

	VolumeRecommendation_lookBackPeriodInDays = VolumeRecommendation.AddMember("lookBackPeriodInDays", _LookBackPeriodInDays)

	VolumeRecommendation_volumeRecommendationOptions = VolumeRecommendation.AddMember("volumeRecommendationOptions", _VolumeRecommendationOptions)

	VolumeRecommendation_lastRefreshTimestamp = VolumeRecommendation.AddMember("lastRefreshTimestamp", _LastRefreshTimestamp)

	VolumeRecommendation_currentPerformanceRisk = VolumeRecommendation.AddMember("currentPerformanceRisk", CurrentPerformanceRisk)

	VolumeRecommendation_effectiveRecommendationPreferences = VolumeRecommendation.AddMember("effectiveRecommendationPreferences", EBSEffectiveRecommendationPreferences)

	VolumeRecommendation_tags = VolumeRecommendation.AddMember("tags", _Tags)

	_VolumeRecommendations_member = _VolumeRecommendations.AddMember("member", VolumeRecommendation)

	DeleteRecommendationPreferencesRequest_resourceType = DeleteRecommendationPreferencesRequest.AddMember("resourceType", ResourceType)

	DeleteRecommendationPreferencesRequest_scope = DeleteRecommendationPreferencesRequest.AddMember("scope", Scope)

	DeleteRecommendationPreferencesRequest_recommendationPreferenceNames = DeleteRecommendationPreferencesRequest.AddMember("recommendationPreferenceNames", _RecommendationPreferenceNames)

	DescribeRecommendationExportJobsRequest_jobIds = DescribeRecommendationExportJobsRequest.AddMember("jobIds", _JobIds)

	DescribeRecommendationExportJobsRequest_filters = DescribeRecommendationExportJobsRequest.AddMember("filters", _JobFilters)

	DescribeRecommendationExportJobsRequest_nextToken = DescribeRecommendationExportJobsRequest.AddMember("nextToken", _NextToken)

	DescribeRecommendationExportJobsRequest_maxResults = DescribeRecommendationExportJobsRequest.AddMember("maxResults", _MaxResults)

	DescribeRecommendationExportJobsResponse_recommendationExportJobs = DescribeRecommendationExportJobsResponse.AddMember("recommendationExportJobs", _RecommendationExportJobs)

	DescribeRecommendationExportJobsResponse_nextToken = DescribeRecommendationExportJobsResponse.AddMember("nextToken", _NextToken)

	ExportAutoScalingGroupRecommendationsRequest_accountIds = ExportAutoScalingGroupRecommendationsRequest.AddMember("accountIds", _AccountIds)

	ExportAutoScalingGroupRecommendationsRequest_filters = ExportAutoScalingGroupRecommendationsRequest.AddMember("filters", _Filters)

	ExportAutoScalingGroupRecommendationsRequest_fieldsToExport = ExportAutoScalingGroupRecommendationsRequest.AddMember("fieldsToExport", _ExportableAutoScalingGroupFields)

	ExportAutoScalingGroupRecommendationsRequest_s3DestinationConfig = ExportAutoScalingGroupRecommendationsRequest.AddMember("s3DestinationConfig", S3DestinationConfig)

	ExportAutoScalingGroupRecommendationsRequest_fileFormat = ExportAutoScalingGroupRecommendationsRequest.AddMember("fileFormat", FileFormat)

	ExportAutoScalingGroupRecommendationsRequest_includeMemberAccounts = ExportAutoScalingGroupRecommendationsRequest.AddMember("includeMemberAccounts", _IncludeMemberAccounts)

	ExportAutoScalingGroupRecommendationsRequest_recommendationPreferences = ExportAutoScalingGroupRecommendationsRequest.AddMember("recommendationPreferences", RecommendationPreferences)

	ExportAutoScalingGroupRecommendationsResponse_jobId = ExportAutoScalingGroupRecommendationsResponse.AddMember("jobId", _JobId)

	ExportAutoScalingGroupRecommendationsResponse_s3Destination = ExportAutoScalingGroupRecommendationsResponse.AddMember("s3Destination", S3Destination)

	ExportEBSVolumeRecommendationsRequest_accountIds = ExportEBSVolumeRecommendationsRequest.AddMember("accountIds", _AccountIds)

	ExportEBSVolumeRecommendationsRequest_filters = ExportEBSVolumeRecommendationsRequest.AddMember("filters", _EBSFilters)

	ExportEBSVolumeRecommendationsRequest_fieldsToExport = ExportEBSVolumeRecommendationsRequest.AddMember("fieldsToExport", _ExportableVolumeFields)

	ExportEBSVolumeRecommendationsRequest_s3DestinationConfig = ExportEBSVolumeRecommendationsRequest.AddMember("s3DestinationConfig", S3DestinationConfig)

	ExportEBSVolumeRecommendationsRequest_fileFormat = ExportEBSVolumeRecommendationsRequest.AddMember("fileFormat", FileFormat)

	ExportEBSVolumeRecommendationsRequest_includeMemberAccounts = ExportEBSVolumeRecommendationsRequest.AddMember("includeMemberAccounts", _IncludeMemberAccounts)

	ExportEBSVolumeRecommendationsResponse_jobId = ExportEBSVolumeRecommendationsResponse.AddMember("jobId", _JobId)

	ExportEBSVolumeRecommendationsResponse_s3Destination = ExportEBSVolumeRecommendationsResponse.AddMember("s3Destination", S3Destination)

	ExportEC2InstanceRecommendationsRequest_accountIds = ExportEC2InstanceRecommendationsRequest.AddMember("accountIds", _AccountIds)

	ExportEC2InstanceRecommendationsRequest_filters = ExportEC2InstanceRecommendationsRequest.AddMember("filters", _Filters)

	ExportEC2InstanceRecommendationsRequest_fieldsToExport = ExportEC2InstanceRecommendationsRequest.AddMember("fieldsToExport", _ExportableInstanceFields)

	ExportEC2InstanceRecommendationsRequest_s3DestinationConfig = ExportEC2InstanceRecommendationsRequest.AddMember("s3DestinationConfig", S3DestinationConfig)

	ExportEC2InstanceRecommendationsRequest_fileFormat = ExportEC2InstanceRecommendationsRequest.AddMember("fileFormat", FileFormat)

	ExportEC2InstanceRecommendationsRequest_includeMemberAccounts = ExportEC2InstanceRecommendationsRequest.AddMember("includeMemberAccounts", _IncludeMemberAccounts)

	ExportEC2InstanceRecommendationsRequest_recommendationPreferences = ExportEC2InstanceRecommendationsRequest.AddMember("recommendationPreferences", RecommendationPreferences)

	ExportEC2InstanceRecommendationsResponse_jobId = ExportEC2InstanceRecommendationsResponse.AddMember("jobId", _JobId)

	ExportEC2InstanceRecommendationsResponse_s3Destination = ExportEC2InstanceRecommendationsResponse.AddMember("s3Destination", S3Destination)

	ExportECSServiceRecommendationsRequest_accountIds = ExportECSServiceRecommendationsRequest.AddMember("accountIds", _AccountIds)

	ExportECSServiceRecommendationsRequest_filters = ExportECSServiceRecommendationsRequest.AddMember("filters", _ECSServiceRecommendationFilters)

	ExportECSServiceRecommendationsRequest_fieldsToExport = ExportECSServiceRecommendationsRequest.AddMember("fieldsToExport", _ExportableECSServiceFields)

	ExportECSServiceRecommendationsRequest_s3DestinationConfig = ExportECSServiceRecommendationsRequest.AddMember("s3DestinationConfig", S3DestinationConfig)

	ExportECSServiceRecommendationsRequest_fileFormat = ExportECSServiceRecommendationsRequest.AddMember("fileFormat", FileFormat)

	ExportECSServiceRecommendationsRequest_includeMemberAccounts = ExportECSServiceRecommendationsRequest.AddMember("includeMemberAccounts", _IncludeMemberAccounts)

	ExportECSServiceRecommendationsResponse_jobId = ExportECSServiceRecommendationsResponse.AddMember("jobId", _JobId)

	ExportECSServiceRecommendationsResponse_s3Destination = ExportECSServiceRecommendationsResponse.AddMember("s3Destination", S3Destination)

	ExportIdleRecommendationsRequest_accountIds = ExportIdleRecommendationsRequest.AddMember("accountIds", _AccountIds)

	ExportIdleRecommendationsRequest_filters = ExportIdleRecommendationsRequest.AddMember("filters", _IdleRecommendationFilters)

	ExportIdleRecommendationsRequest_fieldsToExport = ExportIdleRecommendationsRequest.AddMember("fieldsToExport", _ExportableIdleFields)

	ExportIdleRecommendationsRequest_s3DestinationConfig = ExportIdleRecommendationsRequest.AddMember("s3DestinationConfig", S3DestinationConfig)

	ExportIdleRecommendationsRequest_fileFormat = ExportIdleRecommendationsRequest.AddMember("fileFormat", FileFormat)

	ExportIdleRecommendationsRequest_includeMemberAccounts = ExportIdleRecommendationsRequest.AddMember("includeMemberAccounts", _IncludeMemberAccounts)

	ExportIdleRecommendationsResponse_jobId = ExportIdleRecommendationsResponse.AddMember("jobId", _JobId)

	ExportIdleRecommendationsResponse_s3Destination = ExportIdleRecommendationsResponse.AddMember("s3Destination", S3Destination)

	ExportLambdaFunctionRecommendationsRequest_accountIds = ExportLambdaFunctionRecommendationsRequest.AddMember("accountIds", _AccountIds)

	ExportLambdaFunctionRecommendationsRequest_filters = ExportLambdaFunctionRecommendationsRequest.AddMember("filters", _LambdaFunctionRecommendationFilters)

	ExportLambdaFunctionRecommendationsRequest_fieldsToExport = ExportLambdaFunctionRecommendationsRequest.AddMember("fieldsToExport", _ExportableLambdaFunctionFields)

	ExportLambdaFunctionRecommendationsRequest_s3DestinationConfig = ExportLambdaFunctionRecommendationsRequest.AddMember("s3DestinationConfig", S3DestinationConfig)

	ExportLambdaFunctionRecommendationsRequest_fileFormat = ExportLambdaFunctionRecommendationsRequest.AddMember("fileFormat", FileFormat)

	ExportLambdaFunctionRecommendationsRequest_includeMemberAccounts = ExportLambdaFunctionRecommendationsRequest.AddMember("includeMemberAccounts", _IncludeMemberAccounts)

	ExportLambdaFunctionRecommendationsResponse_jobId = ExportLambdaFunctionRecommendationsResponse.AddMember("jobId", _JobId)

	ExportLambdaFunctionRecommendationsResponse_s3Destination = ExportLambdaFunctionRecommendationsResponse.AddMember("s3Destination", S3Destination)

	ExportLicenseRecommendationsRequest_accountIds = ExportLicenseRecommendationsRequest.AddMember("accountIds", _AccountIds)

	ExportLicenseRecommendationsRequest_filters = ExportLicenseRecommendationsRequest.AddMember("filters", _LicenseRecommendationFilters)

	ExportLicenseRecommendationsRequest_fieldsToExport = ExportLicenseRecommendationsRequest.AddMember("fieldsToExport", _ExportableLicenseFields)

	ExportLicenseRecommendationsRequest_s3DestinationConfig = ExportLicenseRecommendationsRequest.AddMember("s3DestinationConfig", S3DestinationConfig)

	ExportLicenseRecommendationsRequest_fileFormat = ExportLicenseRecommendationsRequest.AddMember("fileFormat", FileFormat)

	ExportLicenseRecommendationsRequest_includeMemberAccounts = ExportLicenseRecommendationsRequest.AddMember("includeMemberAccounts", _IncludeMemberAccounts)

	ExportLicenseRecommendationsResponse_jobId = ExportLicenseRecommendationsResponse.AddMember("jobId", _JobId)

	ExportLicenseRecommendationsResponse_s3Destination = ExportLicenseRecommendationsResponse.AddMember("s3Destination", S3Destination)

	ExportRDSDatabaseRecommendationsRequest_accountIds = ExportRDSDatabaseRecommendationsRequest.AddMember("accountIds", _AccountIds)

	ExportRDSDatabaseRecommendationsRequest_filters = ExportRDSDatabaseRecommendationsRequest.AddMember("filters", _RDSDBRecommendationFilters)

	ExportRDSDatabaseRecommendationsRequest_fieldsToExport = ExportRDSDatabaseRecommendationsRequest.AddMember("fieldsToExport", _ExportableRDSDBFields)

	ExportRDSDatabaseRecommendationsRequest_s3DestinationConfig = ExportRDSDatabaseRecommendationsRequest.AddMember("s3DestinationConfig", S3DestinationConfig)

	ExportRDSDatabaseRecommendationsRequest_fileFormat = ExportRDSDatabaseRecommendationsRequest.AddMember("fileFormat", FileFormat)

	ExportRDSDatabaseRecommendationsRequest_includeMemberAccounts = ExportRDSDatabaseRecommendationsRequest.AddMember("includeMemberAccounts", _IncludeMemberAccounts)

	ExportRDSDatabaseRecommendationsRequest_recommendationPreferences = ExportRDSDatabaseRecommendationsRequest.AddMember("recommendationPreferences", RecommendationPreferences)

	ExportRDSDatabaseRecommendationsResponse_jobId = ExportRDSDatabaseRecommendationsResponse.AddMember("jobId", _JobId)

	ExportRDSDatabaseRecommendationsResponse_s3Destination = ExportRDSDatabaseRecommendationsResponse.AddMember("s3Destination", S3Destination)

	GetAutoScalingGroupRecommendationsRequest_accountIds = GetAutoScalingGroupRecommendationsRequest.AddMember("accountIds", _AccountIds)

	GetAutoScalingGroupRecommendationsRequest_autoScalingGroupArns = GetAutoScalingGroupRecommendationsRequest.AddMember("autoScalingGroupArns", _AutoScalingGroupArns)

	GetAutoScalingGroupRecommendationsRequest_nextToken = GetAutoScalingGroupRecommendationsRequest.AddMember("nextToken", _NextToken)

	GetAutoScalingGroupRecommendationsRequest_maxResults = GetAutoScalingGroupRecommendationsRequest.AddMember("maxResults", _MaxResults)

	GetAutoScalingGroupRecommendationsRequest_filters = GetAutoScalingGroupRecommendationsRequest.AddMember("filters", _Filters)

	GetAutoScalingGroupRecommendationsRequest_recommendationPreferences = GetAutoScalingGroupRecommendationsRequest.AddMember("recommendationPreferences", RecommendationPreferences)

	GetAutoScalingGroupRecommendationsResponse_nextToken = GetAutoScalingGroupRecommendationsResponse.AddMember("nextToken", _NextToken)

	GetAutoScalingGroupRecommendationsResponse_autoScalingGroupRecommendations = GetAutoScalingGroupRecommendationsResponse.AddMember("autoScalingGroupRecommendations", _AutoScalingGroupRecommendations)

	GetAutoScalingGroupRecommendationsResponse_errors = GetAutoScalingGroupRecommendationsResponse.AddMember("errors", _GetRecommendationErrors)

	GetEBSVolumeRecommendationsRequest_volumeArns = GetEBSVolumeRecommendationsRequest.AddMember("volumeArns", _VolumeArns)

	GetEBSVolumeRecommendationsRequest_nextToken = GetEBSVolumeRecommendationsRequest.AddMember("nextToken", _NextToken)

	GetEBSVolumeRecommendationsRequest_maxResults = GetEBSVolumeRecommendationsRequest.AddMember("maxResults", _MaxResults)

	GetEBSVolumeRecommendationsRequest_filters = GetEBSVolumeRecommendationsRequest.AddMember("filters", _EBSFilters)

	GetEBSVolumeRecommendationsRequest_accountIds = GetEBSVolumeRecommendationsRequest.AddMember("accountIds", _AccountIds)

	GetEBSVolumeRecommendationsResponse_nextToken = GetEBSVolumeRecommendationsResponse.AddMember("nextToken", _NextToken)

	GetEBSVolumeRecommendationsResponse_volumeRecommendations = GetEBSVolumeRecommendationsResponse.AddMember("volumeRecommendations", _VolumeRecommendations)

	GetEBSVolumeRecommendationsResponse_errors = GetEBSVolumeRecommendationsResponse.AddMember("errors", _GetRecommendationErrors)

	GetEC2InstanceRecommendationsRequest_instanceArns = GetEC2InstanceRecommendationsRequest.AddMember("instanceArns", _InstanceArns)

	GetEC2InstanceRecommendationsRequest_nextToken = GetEC2InstanceRecommendationsRequest.AddMember("nextToken", _NextToken)

	GetEC2InstanceRecommendationsRequest_maxResults = GetEC2InstanceRecommendationsRequest.AddMember("maxResults", _MaxResults)

	GetEC2InstanceRecommendationsRequest_filters = GetEC2InstanceRecommendationsRequest.AddMember("filters", _Filters)

	GetEC2InstanceRecommendationsRequest_accountIds = GetEC2InstanceRecommendationsRequest.AddMember("accountIds", _AccountIds)

	GetEC2InstanceRecommendationsRequest_recommendationPreferences = GetEC2InstanceRecommendationsRequest.AddMember("recommendationPreferences", RecommendationPreferences)

	GetEC2InstanceRecommendationsResponse_nextToken = GetEC2InstanceRecommendationsResponse.AddMember("nextToken", _NextToken)

	GetEC2InstanceRecommendationsResponse_instanceRecommendations = GetEC2InstanceRecommendationsResponse.AddMember("instanceRecommendations", _InstanceRecommendations)

	GetEC2InstanceRecommendationsResponse_errors = GetEC2InstanceRecommendationsResponse.AddMember("errors", _GetRecommendationErrors)

	GetEC2RecommendationProjectedMetricsRequest_instanceArn = GetEC2RecommendationProjectedMetricsRequest.AddMember("instanceArn", _InstanceArn)

	GetEC2RecommendationProjectedMetricsRequest_stat = GetEC2RecommendationProjectedMetricsRequest.AddMember("stat", MetricStatistic)

	GetEC2RecommendationProjectedMetricsRequest_period = GetEC2RecommendationProjectedMetricsRequest.AddMember("period", _Period)

	GetEC2RecommendationProjectedMetricsRequest_startTime = GetEC2RecommendationProjectedMetricsRequest.AddMember("startTime", _Timestamp)

	GetEC2RecommendationProjectedMetricsRequest_endTime = GetEC2RecommendationProjectedMetricsRequest.AddMember("endTime", _Timestamp)

	GetEC2RecommendationProjectedMetricsRequest_recommendationPreferences = GetEC2RecommendationProjectedMetricsRequest.AddMember("recommendationPreferences", RecommendationPreferences)

	GetEC2RecommendationProjectedMetricsResponse_recommendedOptionProjectedMetrics = GetEC2RecommendationProjectedMetricsResponse.AddMember("recommendedOptionProjectedMetrics", _RecommendedOptionProjectedMetrics)

	GetECSServiceRecommendationProjectedMetricsRequest_serviceArn = GetECSServiceRecommendationProjectedMetricsRequest.AddMember("serviceArn", _ServiceArn)

	GetECSServiceRecommendationProjectedMetricsRequest_stat = GetECSServiceRecommendationProjectedMetricsRequest.AddMember("stat", MetricStatistic)

	GetECSServiceRecommendationProjectedMetricsRequest_period = GetECSServiceRecommendationProjectedMetricsRequest.AddMember("period", _Period)

	GetECSServiceRecommendationProjectedMetricsRequest_startTime = GetECSServiceRecommendationProjectedMetricsRequest.AddMember("startTime", _Timestamp)

	GetECSServiceRecommendationProjectedMetricsRequest_endTime = GetECSServiceRecommendationProjectedMetricsRequest.AddMember("endTime", _Timestamp)

	GetECSServiceRecommendationProjectedMetricsResponse_recommendedOptionProjectedMetrics = GetECSServiceRecommendationProjectedMetricsResponse.AddMember("recommendedOptionProjectedMetrics", _ECSServiceRecommendedOptionProjectedMetrics)

	GetECSServiceRecommendationsRequest_serviceArns = GetECSServiceRecommendationsRequest.AddMember("serviceArns", _ServiceArns)

	GetECSServiceRecommendationsRequest_nextToken = GetECSServiceRecommendationsRequest.AddMember("nextToken", _NextToken)

	GetECSServiceRecommendationsRequest_maxResults = GetECSServiceRecommendationsRequest.AddMember("maxResults", _MaxResults)

	GetECSServiceRecommendationsRequest_filters = GetECSServiceRecommendationsRequest.AddMember("filters", _ECSServiceRecommendationFilters)

	GetECSServiceRecommendationsRequest_accountIds = GetECSServiceRecommendationsRequest.AddMember("accountIds", _AccountIds)

	GetECSServiceRecommendationsResponse_nextToken = GetECSServiceRecommendationsResponse.AddMember("nextToken", _NextToken)

	GetECSServiceRecommendationsResponse_ecsServiceRecommendations = GetECSServiceRecommendationsResponse.AddMember("ecsServiceRecommendations", _ECSServiceRecommendations)

	GetECSServiceRecommendationsResponse_errors = GetECSServiceRecommendationsResponse.AddMember("errors", _GetRecommendationErrors)

	GetEffectiveRecommendationPreferencesRequest_resourceArn = GetEffectiveRecommendationPreferencesRequest.AddMember("resourceArn", _ResourceArn)

	GetEffectiveRecommendationPreferencesResponse_enhancedInfrastructureMetrics = GetEffectiveRecommendationPreferencesResponse.AddMember("enhancedInfrastructureMetrics", EnhancedInfrastructureMetrics)

	GetEffectiveRecommendationPreferencesResponse_externalMetricsPreference = GetEffectiveRecommendationPreferencesResponse.AddMember("externalMetricsPreference", ExternalMetricsPreference)

	GetEffectiveRecommendationPreferencesResponse_lookBackPeriod = GetEffectiveRecommendationPreferencesResponse.AddMember("lookBackPeriod", LookBackPeriodPreference)

	GetEffectiveRecommendationPreferencesResponse_utilizationPreferences = GetEffectiveRecommendationPreferencesResponse.AddMember("utilizationPreferences", _UtilizationPreferences)

	GetEffectiveRecommendationPreferencesResponse_preferredResources = GetEffectiveRecommendationPreferencesResponse.AddMember("preferredResources", _EffectivePreferredResources)

	GetEnrollmentStatusesForOrganizationRequest_filters = GetEnrollmentStatusesForOrganizationRequest.AddMember("filters", _EnrollmentFilters)

	GetEnrollmentStatusesForOrganizationRequest_nextToken = GetEnrollmentStatusesForOrganizationRequest.AddMember("nextToken", _NextToken)

	GetEnrollmentStatusesForOrganizationRequest_maxResults = GetEnrollmentStatusesForOrganizationRequest.AddMember("maxResults", _MaxResults)

	GetEnrollmentStatusesForOrganizationResponse_accountEnrollmentStatuses = GetEnrollmentStatusesForOrganizationResponse.AddMember("accountEnrollmentStatuses", _AccountEnrollmentStatuses)

	GetEnrollmentStatusesForOrganizationResponse_nextToken = GetEnrollmentStatusesForOrganizationResponse.AddMember("nextToken", _NextToken)

	GetEnrollmentStatusResponse_status = GetEnrollmentStatusResponse.AddMember("status", Status)

	GetEnrollmentStatusResponse_statusReason = GetEnrollmentStatusResponse.AddMember("statusReason", _StatusReason)

	GetEnrollmentStatusResponse_memberAccountsEnrolled = GetEnrollmentStatusResponse.AddMember("memberAccountsEnrolled", _MemberAccountsEnrolled)

	GetEnrollmentStatusResponse_lastUpdatedTimestamp = GetEnrollmentStatusResponse.AddMember("lastUpdatedTimestamp", _LastUpdatedTimestamp)

	GetEnrollmentStatusResponse_numberOfMemberAccountsOptedIn = GetEnrollmentStatusResponse.AddMember("numberOfMemberAccountsOptedIn", _NumberOfMemberAccountsOptedIn)

	GetIdleRecommendationsRequest_resourceArns = GetIdleRecommendationsRequest.AddMember("resourceArns", _ResourceArns)

	GetIdleRecommendationsRequest_nextToken = GetIdleRecommendationsRequest.AddMember("nextToken", _NextToken)

	GetIdleRecommendationsRequest_maxResults = GetIdleRecommendationsRequest.AddMember("maxResults", _IdleMaxResults)

	GetIdleRecommendationsRequest_filters = GetIdleRecommendationsRequest.AddMember("filters", _IdleRecommendationFilters)

	GetIdleRecommendationsRequest_accountIds = GetIdleRecommendationsRequest.AddMember("accountIds", _AccountIds)

	GetIdleRecommendationsRequest_orderBy = GetIdleRecommendationsRequest.AddMember("orderBy", OrderBy)

	GetIdleRecommendationsResponse_nextToken = GetIdleRecommendationsResponse.AddMember("nextToken", _NextToken)

	GetIdleRecommendationsResponse_idleRecommendations = GetIdleRecommendationsResponse.AddMember("idleRecommendations", _IdleRecommendations)

	GetIdleRecommendationsResponse_errors = GetIdleRecommendationsResponse.AddMember("errors", _IdleRecommendationErrors)

	GetLambdaFunctionRecommendationsRequest_functionArns = GetLambdaFunctionRecommendationsRequest.AddMember("functionArns", _FunctionArns)

	GetLambdaFunctionRecommendationsRequest_accountIds = GetLambdaFunctionRecommendationsRequest.AddMember("accountIds", _AccountIds)

	GetLambdaFunctionRecommendationsRequest_filters = GetLambdaFunctionRecommendationsRequest.AddMember("filters", _LambdaFunctionRecommendationFilters)

	GetLambdaFunctionRecommendationsRequest_nextToken = GetLambdaFunctionRecommendationsRequest.AddMember("nextToken", _NextToken)

	GetLambdaFunctionRecommendationsRequest_maxResults = GetLambdaFunctionRecommendationsRequest.AddMember("maxResults", _MaxResults)

	GetLambdaFunctionRecommendationsResponse_nextToken = GetLambdaFunctionRecommendationsResponse.AddMember("nextToken", _NextToken)

	GetLambdaFunctionRecommendationsResponse_lambdaFunctionRecommendations = GetLambdaFunctionRecommendationsResponse.AddMember("lambdaFunctionRecommendations", _LambdaFunctionRecommendations)

	GetLicenseRecommendationsRequest_resourceArns = GetLicenseRecommendationsRequest.AddMember("resourceArns", _ResourceArns)

	GetLicenseRecommendationsRequest_nextToken = GetLicenseRecommendationsRequest.AddMember("nextToken", _NextToken)

	GetLicenseRecommendationsRequest_maxResults = GetLicenseRecommendationsRequest.AddMember("maxResults", _MaxResults)

	GetLicenseRecommendationsRequest_filters = GetLicenseRecommendationsRequest.AddMember("filters", _LicenseRecommendationFilters)

	GetLicenseRecommendationsRequest_accountIds = GetLicenseRecommendationsRequest.AddMember("accountIds", _AccountIds)

	GetLicenseRecommendationsResponse_nextToken = GetLicenseRecommendationsResponse.AddMember("nextToken", _NextToken)

	GetLicenseRecommendationsResponse_licenseRecommendations = GetLicenseRecommendationsResponse.AddMember("licenseRecommendations", _LicenseRecommendations)

	GetLicenseRecommendationsResponse_errors = GetLicenseRecommendationsResponse.AddMember("errors", _GetRecommendationErrors)

	GetRDSDatabaseRecommendationProjectedMetricsRequest_resourceArn = GetRDSDatabaseRecommendationProjectedMetricsRequest.AddMember("resourceArn", _ResourceArn)

	GetRDSDatabaseRecommendationProjectedMetricsRequest_stat = GetRDSDatabaseRecommendationProjectedMetricsRequest.AddMember("stat", MetricStatistic)

	GetRDSDatabaseRecommendationProjectedMetricsRequest_period = GetRDSDatabaseRecommendationProjectedMetricsRequest.AddMember("period", _Period)

	GetRDSDatabaseRecommendationProjectedMetricsRequest_startTime = GetRDSDatabaseRecommendationProjectedMetricsRequest.AddMember("startTime", _Timestamp)

	GetRDSDatabaseRecommendationProjectedMetricsRequest_endTime = GetRDSDatabaseRecommendationProjectedMetricsRequest.AddMember("endTime", _Timestamp)

	GetRDSDatabaseRecommendationProjectedMetricsRequest_recommendationPreferences = GetRDSDatabaseRecommendationProjectedMetricsRequest.AddMember("recommendationPreferences", RecommendationPreferences)

	GetRDSDatabaseRecommendationProjectedMetricsResponse_recommendedOptionProjectedMetrics = GetRDSDatabaseRecommendationProjectedMetricsResponse.AddMember("recommendedOptionProjectedMetrics", _RDSDatabaseRecommendedOptionProjectedMetrics)

	GetRDSDatabaseRecommendationsRequest_resourceArns = GetRDSDatabaseRecommendationsRequest.AddMember("resourceArns", _ResourceArns)

	GetRDSDatabaseRecommendationsRequest_nextToken = GetRDSDatabaseRecommendationsRequest.AddMember("nextToken", _NextToken)

	GetRDSDatabaseRecommendationsRequest_maxResults = GetRDSDatabaseRecommendationsRequest.AddMember("maxResults", _MaxResults)

	GetRDSDatabaseRecommendationsRequest_filters = GetRDSDatabaseRecommendationsRequest.AddMember("filters", _RDSDBRecommendationFilters)

	GetRDSDatabaseRecommendationsRequest_accountIds = GetRDSDatabaseRecommendationsRequest.AddMember("accountIds", _AccountIds)

	GetRDSDatabaseRecommendationsRequest_recommendationPreferences = GetRDSDatabaseRecommendationsRequest.AddMember("recommendationPreferences", RecommendationPreferences)

	GetRDSDatabaseRecommendationsResponse_nextToken = GetRDSDatabaseRecommendationsResponse.AddMember("nextToken", _NextToken)

	GetRDSDatabaseRecommendationsResponse_rdsDBRecommendations = GetRDSDatabaseRecommendationsResponse.AddMember("rdsDBRecommendations", _RDSDBRecommendations)

	GetRDSDatabaseRecommendationsResponse_errors = GetRDSDatabaseRecommendationsResponse.AddMember("errors", _GetRecommendationErrors)

	GetRecommendationPreferencesRequest_resourceType = GetRecommendationPreferencesRequest.AddMember("resourceType", ResourceType)

	GetRecommendationPreferencesRequest_scope = GetRecommendationPreferencesRequest.AddMember("scope", Scope)

	GetRecommendationPreferencesRequest_nextToken = GetRecommendationPreferencesRequest.AddMember("nextToken", _NextToken)

	GetRecommendationPreferencesRequest_maxResults = GetRecommendationPreferencesRequest.AddMember("maxResults", _MaxResults)

	GetRecommendationPreferencesResponse_nextToken = GetRecommendationPreferencesResponse.AddMember("nextToken", _NextToken)

	GetRecommendationPreferencesResponse_recommendationPreferencesDetails = GetRecommendationPreferencesResponse.AddMember("recommendationPreferencesDetails", _RecommendationPreferencesDetails)

	GetRecommendationSummariesRequest_accountIds = GetRecommendationSummariesRequest.AddMember("accountIds", _AccountIds)

	GetRecommendationSummariesRequest_nextToken = GetRecommendationSummariesRequest.AddMember("nextToken", _NextToken)

	GetRecommendationSummariesRequest_maxResults = GetRecommendationSummariesRequest.AddMember("maxResults", _MaxResults)

	GetRecommendationSummariesResponse_nextToken = GetRecommendationSummariesResponse.AddMember("nextToken", _NextToken)

	GetRecommendationSummariesResponse_recommendationSummaries = GetRecommendationSummariesResponse.AddMember("recommendationSummaries", _RecommendationSummaries)

	PutRecommendationPreferencesRequest_resourceType = PutRecommendationPreferencesRequest.AddMember("resourceType", ResourceType)

	PutRecommendationPreferencesRequest_scope = PutRecommendationPreferencesRequest.AddMember("scope", Scope)

	PutRecommendationPreferencesRequest_enhancedInfrastructureMetrics = PutRecommendationPreferencesRequest.AddMember("enhancedInfrastructureMetrics", EnhancedInfrastructureMetrics)

	PutRecommendationPreferencesRequest_inferredWorkloadTypes = PutRecommendationPreferencesRequest.AddMember("inferredWorkloadTypes", InferredWorkloadTypesPreference)

	PutRecommendationPreferencesRequest_externalMetricsPreference = PutRecommendationPreferencesRequest.AddMember("externalMetricsPreference", ExternalMetricsPreference)

	PutRecommendationPreferencesRequest_lookBackPeriod = PutRecommendationPreferencesRequest.AddMember("lookBackPeriod", LookBackPeriodPreference)

	PutRecommendationPreferencesRequest_utilizationPreferences = PutRecommendationPreferencesRequest.AddMember("utilizationPreferences", _UtilizationPreferences)

	PutRecommendationPreferencesRequest_preferredResources = PutRecommendationPreferencesRequest.AddMember("preferredResources", _PreferredResources)

	PutRecommendationPreferencesRequest_savingsEstimationMode = PutRecommendationPreferencesRequest.AddMember("savingsEstimationMode", SavingsEstimationMode)

	UpdateEnrollmentStatusRequest_status = UpdateEnrollmentStatusRequest.AddMember("status", Status)

	UpdateEnrollmentStatusRequest_includeMemberAccounts = UpdateEnrollmentStatusRequest.AddMember("includeMemberAccounts", _IncludeMemberAccounts)

	UpdateEnrollmentStatusResponse_status = UpdateEnrollmentStatusResponse.AddMember("status", Status)

	UpdateEnrollmentStatusResponse_statusReason = UpdateEnrollmentStatusResponse.AddMember("statusReason", _StatusReason)

}
